@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAntiAliasBinaryImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-04-20 13:36:35 $
-  Version:   $Revision: 1.14 $
+  Date:      $Date: 2009-04-23 03:53:34 $
+  Version:   $Revision: 1.15 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -128,8 +128,8 @@ public:
   itkTypeMacro(AntiAliasBinaryImageFilter, SparseFieldLevelSetImageFilter);
 
   /** Get the upper and lower binary values in the input image. */
-  itkGetMacro(UpperBinaryValue, BinaryValueType);
-  itkGetMacro(LowerBinaryValue, BinaryValueType);
+  itkGetConstMacro(UpperBinaryValue, BinaryValueType);
+  itkGetConstMacro(LowerBinaryValue, BinaryValueType);
 
   /** Set/Get the maximum number of iterations allowed for the solver.  This
    *  prevents infinite loops if a solution "bounces". */
