@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBalloonForceFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-04-05 17:56:57 $
-  Version:   $Revision: 1.38 $
+  Date:      $Date: 2009-11-22 18:19:44 $
+  Version:   $Revision: 1.42 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -34,9 +34,9 @@ namespace itk
  * \brief
  *
  * BalloonForceFilter is used to apply balloon force and the potential
- * force onto the 2D deformable model. For 3D (multi-slices) segmentation
- * please use BalloonForce3DFilter
- * The balloon force is vertical to the surface of the model. The potential
+ * force onto the 2D surface model embedded in a 3D space.
+ *
+ * The balloon force is normal to the surface of the model. The potential
  * force is given out by the estimated boundary points. These two will meet
  * a balance at the boundary, thus the deformable model will fit to the
  * boundary.
@@ -77,6 +77,10 @@ public:
   InputPointsContainerPointer;
   typedef typename InputMeshType::PointsContainer::Iterator
   InputPointsContainerIterator;
+  typedef typename InputMeshType::PointsContainerConstPointer
+  InputPointsContainerConstPointer;
+  typedef typename InputMeshType::PointsContainer::ConstIterator
+  InputPointsContainerConstIterator;
   typedef typename InputMeshType::PointDataContainerPointer
   InputPointDataContainerPointer;
   typedef typename InputMeshType::PointDataContainer::Iterator
@@ -89,6 +93,15 @@ public:
   InputCellDataContainerPointer;
   typedef typename InputMeshType::CellDataContainer::Iterator
   InputCellDataContainerIterator;
+  typedef typename InputMeshType::CellsContainerConstPointer
+  InputCellsContainerConstPointer;
+  typedef typename InputMeshType::CellsContainer::ConstIterator
+  InputCellsContainerConstIterator;
+  typedef typename InputMeshType::CellDataContainerConstPointer
+  InputCellDataContainerConstPointer;
+  typedef typename InputMeshType::CellDataContainer::ConstIterator
+  InputCellDataContainerConstIterator;
+
   typedef typename OutputMeshType::PointsContainerPointer
   OutputPointsContainerPointer;
   typedef typename OutputMeshType::PointsContainer::Iterator
@@ -102,6 +115,7 @@ public:
   typedef CovariantVector<PixelType, 2>         GradientType;
   typedef Image<GradientType, 2>                GradientImageType;
   typedef typename InputMeshType::Pointer       InputMeshPointer;
+  typedef typename InputMeshType::ConstPointer  InputMeshConstPointer;
   typedef typename OutputMeshType::Pointer      OutputMeshPointer;
   typedef typename ImageType::Pointer           ImagePointer;
   typedef typename ImageType::IndexType         IndexType;
@@ -114,10 +128,10 @@ public:
   typedef Vector<int, 2>                        Int2Vector;
 
   /** Cell related types. */
-  typedef typename InputMeshType::CellType     CellType;
-  typedef typename InputMeshType::CellTraits   CellTraits;
-  typedef CellInterface<PixelType, CellTraits> CellInterface;
-  typedef TriangleCell< CellInterface >        TriCell;
+  typedef typename InputMeshType::CellType              CellType;
+  typedef typename InputMeshType::CellTraits            CellTraits;
+  typedef ::itk::CellInterface<PixelType, CellTraits>   CellInterface;
+  typedef ::itk::TriangleCell< CellInterface >          TriCell;
 
 
   /** Some functions. */
@@ -137,7 +151,7 @@ public:
 
   /** Set the output image. */
   itkSetMacro(ImageOutput, ImagePointer);
-  itkGetMacro(ImageOutput, ImagePointer);
+  itkGetConstMacro(ImageOutput, ImagePointer);
   itkSetMacro(Gradient, GradientImagePointer);
 
   /** Set/Get information for the algorithm. */
@@ -146,14 +160,14 @@ public:
   itkSetMacro(GradientBegin, int);
   itkSetMacro(Resolution, int);
   itkSetMacro(Center, IndexType);
-  itkGetMacro(Normals, InputMeshPointer);
+  itkGetConstMacro(Normals, InputMeshPointer);
   itkSetMacro(DistanceForGradient, float);
   itkSetMacro(DistanceToStop, float);
   itkSetMacro(Potential, ImagePointer);
-  itkGetMacro(Locations, InputMeshPointer);
-  itkGetMacro(Displacements, InputMeshPointer);
-  itkGetMacro(Derives, InputMeshPointer);
-  itkGetMacro(Forces, InputMeshPointer);
+  itkGetConstMacro(Locations, InputMeshPointer);
+  itkGetConstMacro(Displacements, InputMeshPointer);
+  itkGetConstMacro(Derives, InputMeshPointer);
+  itkGetConstMacro(Forces, InputMeshPointer);
 
 protected:
   BalloonForceFilter();
