@@ -3,30 +3,27 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBioCellBase.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-07-15 18:24:28 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2010-03-30 15:20:03 $
+  Version:   $Revision: 1.8 $
 
-  Copyright (c) 2002 Insight Consortium. All rights reserved.
+  Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-
-
 #include "itkBioCellBase.h"
 #include <new>
 
 #include "vnl/vnl_math.h"
 #include "vnl/vnl_sample.h"
+#include "itkMath.h"
 
 namespace itk {
 
 namespace bio {
-
-
   
 CellBase::ColorType    CellBase::DefaultColor;
 
@@ -62,8 +59,6 @@ CellBase::ColorType    CellBase::WellNourishedColor;
 CellBase::ColorType    CellBase::HopefullColor;
 CellBase::ColorType    CellBase::StarvingColor;
 
-
-
 /**
  *    Constructor Lonely Cell
  */ 
@@ -108,9 +103,6 @@ CellBase
 
 }
 
-
-
-
 /**
  *    Destructor   
  */ 
@@ -129,10 +121,6 @@ CellBase
     }
 }
 
-
-
-
-
 /**
  *    DNA Replication 
  */ 
@@ -144,9 +132,6 @@ CellBase
   m_GenomeCopy->Copy( *m_Genome );
 }
 
-
-
-
 /**
  *    Programmed Cell Death 
  *    This is the cellular equivalent of suicide.
@@ -167,8 +152,6 @@ CellBase
     }
 }
 
-
-
 /**
  *    Check point after division
  *    This check point will control
@@ -183,7 +166,6 @@ CellBase
   return true;
 }
 
-
 /**
  *    Check point before initiating DNA replication.
  *    This check point controls the entrance in the 
@@ -235,8 +217,6 @@ CellBase
           !tooEarlyToReplicate && goodCellMatrix);
 }
 
-
-
 /**
  *    Check point before dividing the cell in two daughter cells
  *    at this point DNA replication has already been performed
@@ -256,9 +236,6 @@ CellBase
   return DNAProofRead;
 }
 
-
-
-
 /**
  *    Check point before apoptosis
  *    This check point will control
@@ -283,10 +260,6 @@ CellBase
   return executeApoptosis;
 }
 
-
-
-
-
 /**
  *    Initialize common variables
  *    All this should go away once we setup Gene Networks for controlling the cell.
@@ -304,17 +277,14 @@ CellBase
  
   SetMaximumGenerationLimit( 40 ); // it should use Teleomeres for implementing this
 
-  WellNourishedColor.Set(    0.0, 0.0, 1.0 );
-  HopefullColor.Set(         0.0, 1.0, 0.0 );
-  StarvingColor.Set(         1.0, 0.0, 0.0 );
+  WellNourishedColor.Set(    0.0f, 0.0f, 1.0f );
+  HopefullColor.Set(         0.0f, 1.0f, 0.0f );
+  StarvingColor.Set(         1.0f, 0.0f, 0.0f );
 
   SetDefaultColor( HopefullColor );
 
 }
 
-
-
-
 /**
  *  Mark this cell for removal
  *  The cellular aggregate with remove
@@ -327,8 +297,6 @@ CellBase
   m_MarkedForRemoval = true;
 }
 
-
-
 /**
  *  Mark this cell for removal
  *  The cellular aggregate with remove
@@ -341,9 +309,6 @@ CellBase
   return m_MarkedForRemoval;
 }
 
-
-
-
 /**
  *   Cell Growth
  *   Growth is conditioned to the availability of 
@@ -374,8 +339,6 @@ CellBase
     }
 }
 
-
-
 /**
  *    Set Growth Latency Time
  */ 
@@ -386,9 +349,6 @@ CellBase
   CellBase::GrowthMaximumLatencyTime = latency;
 }
 
-
-
-
 /**
  *    Get Growth Latency Time
  */ 
@@ -399,10 +359,6 @@ CellBase
   return CellBase::GrowthMaximumLatencyTime;
 }
 
-
-
-
-
 /**
  *    Return the ID  of this cell
  */ 
@@ -413,8 +369,6 @@ CellBase
   return m_SelfIdentifier;
 }
 
-
-
 /**
  *    Return the ID  of the parent cell
  */ 
@@ -425,8 +379,6 @@ CellBase
   return m_ParentIdentifier;
 }
 
-
-
 /**
  *    Return the radius 
  */ 
@@ -437,7 +389,6 @@ CellBase
   return m_Radius;
 }
 
-
 /**
  *    Return the Color 
  */ 
@@ -448,8 +399,6 @@ CellBase
   return m_Color;
 }
 
-
-
 /**
  *    Set the value of the initial cell radius.
  */ 
@@ -460,8 +409,6 @@ CellBase
   DefaultRadius = value;
 }
 
-
-
 /**
  *    Set the value of the limiting cell radius
  *    this is a static value used for the whole
@@ -474,7 +421,6 @@ CellBase
   GrowthRadiusLimit = value;
 }
 
-
 /**
  *    Set the amount of Energy that is needed for Self-repair.
  *    Cells that go below this level will degrade and enter
@@ -487,7 +433,6 @@ CellBase
   EnergySelfRepairLevel = value;
 }
 
-
 /**
  *    Set the amount of Nutrients that are needed for Self-repair.
  *    Cells that go below this level will degrade and enter
@@ -500,7 +445,6 @@ CellBase
   NutrientSelfRepairLevel = value;
 }
 
-
 /**
  *    Set the value of the limit of cell generation.
  *    After this generation cells will stop dividing
@@ -515,8 +459,6 @@ CellBase
   MaximumGenerationLimit = generationLimit;
 }
 
-
-
 /**
  *    Get the value of the limiting cell radius
  *    this is a static value used for the whole
@@ -529,7 +471,6 @@ CellBase
   return GrowthRadiusLimit;
 }
 
-
 /**
  *    Set the value of the increment in cellular
  *    radius at each time step
@@ -543,9 +484,6 @@ CellBase
   GrowthRadiusIncrement = value;
 }
 
-
-
-
 /**
  *    Ingestion of nutrients
  */
@@ -556,8 +494,6 @@ CellBase
   m_NutrientsReserveLevel += DefaultNutrientsIntake;
 }
 
-
-
 /**
  *    Acquisition of energy
  */
@@ -568,8 +504,6 @@ CellBase
   m_EnergyReserveLevel += DefaultEnergyIntake;
 }
 
-
-
 /**
  *   Compute the Gene Network
  *   This method update the level of expression of 
@@ -633,7 +567,6 @@ CellBase
 
 }
 
-
 /**
  *   Secrete synthetized products resulting from 
  *   the gene network update
@@ -642,14 +575,13 @@ void
 CellBase
 ::SecreteProducts(void) 
 {
-  m_Color.SetRed(    m_Genome->GetExpressionLevel( RedGene   ) );
-  m_Color.SetGreen(  m_Genome->GetExpressionLevel( GreenGene ) );
-  m_Color.SetBlue(   m_Genome->GetExpressionLevel( BlueGene  ) );
+  typedef ColorType::ValueType ColorValueType;
+
+  m_Color.SetRed(   ColorValueType( m_Genome->GetExpressionLevel( RedGene   ) ) );
+  m_Color.SetGreen( ColorValueType( m_Genome->GetExpressionLevel( GreenGene ) ) );
+  m_Color.SetBlue(  ColorValueType( m_Genome->GetExpressionLevel( BlueGene  ) ) );
 }
 
-
-
-
 /**
  *    Set default Color
  */
@@ -660,8 +592,6 @@ CellBase
   DefaultColor = color;
 }
 
-
-
 /**
  *    Reset the counter 
  */
@@ -672,8 +602,6 @@ CellBase
   Counter = 0;
 }
 
- 
-
 /**
  *    Set Division Latency Time
  */ 
@@ -684,9 +612,6 @@ CellBase
   CellBase::DivisionMaximumLatencyTime = latency;
 }
 
-
-
-
 /**
  *    Get Division Latency Time
  */ 
@@ -697,8 +622,6 @@ CellBase
   return CellBase::DivisionMaximumLatencyTime;
 }
 
-
-
 /**
  *    Set ChemoAttractantLowThreshold
  */ 
@@ -709,8 +632,6 @@ CellBase
   CellBase::ChemoAttractantLowThreshold = lowvalue;
 }
 
-
-
 /**
  *    Set ChemoAttractantHighThreshold
  */ 
@@ -721,12 +642,6 @@ CellBase
   CellBase::ChemoAttractantHighThreshold = highvalue;
 }
 
-
-
-
-
 }  // end namespace bio
 
 }  // end namespace itk
-
-
