@@ -3,14 +3,14 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBioCellBase.h,v $
   Language:  C++
-  Date:      $Date: 2007-07-15 18:24:28 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-05-12 17:26:20 $
+  Version:   $Revision: 1.8 $
 
-  Copyright (c) 2002 Insight Consortium. All rights reserved.
+  Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
@@ -26,13 +26,11 @@ namespace itk {
 
 namespace bio {
 
-
-
 /** \class CellBase
  * \brief non-templated Base class from which the templated Cell classes will be derived.
  * Derived classes are instantiated for a specific space dimension.
  */
-class CellBase 
+class ITK_EXPORT CellBase 
 {
 public:
   typedef   itk::RGBPixel<float>                ColorType;
@@ -174,4 +172,3 @@ protected:
 
 
 #endif
-
