@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCannySegmentationLevelSetFunction.h,v $
   Language:  C++
-  Date:      $Date: 2004-06-17 20:51:52 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2008-10-23 16:15:22 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkCannySegmentationLevelSetFunction_h_
-#define __itkCannySegmentationLevelSetFunction_h_
+#ifndef __itkCannySegmentationLevelSetFunction_h
+#define __itkCannySegmentationLevelSetFunction_h
 
 #include "itkSegmentationLevelSetFunction.h"
 #include "itkCastImageFilter.h"
@@ -24,7 +24,7 @@
 
 namespace itk {
 
-/**
+/** \class CannySegmentationLevelSetFunction
  * \brief A refinement of the standard level-set function which computes a
  * speed term and advection term based on pseudo-Canny edges.  See
  * CannySegmentationLevelSetImageFilter for complete information.
@@ -35,11 +35,12 @@ class ITK_EXPORT CannySegmentationLevelSetFunction
 {
 public:
   /** Standard class typedefs. */
-  typedef CannySegmentationLevelSetFunction Self;
-  typedef SegmentationLevelSetFunction<TImageType, TFeatureImageType> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
-  typedef TFeatureImageType FeatureImageType;
+  typedef CannySegmentationLevelSetFunction  Self;
+  typedef SegmentationLevelSetFunction<TImageType, TFeatureImageType>
+                                             Superclass;
+  typedef SmartPointer<Self>                 Pointer;
+  typedef SmartPointer<const Self>           ConstPointer;
+  typedef TFeatureImageType                  FeatureImageType;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -48,11 +49,11 @@ public:
   itkTypeMacro( CannySegmentationLevelSetFunction, SegmentationLevelSetFunction );
 
   /** Extract some parameters from the superclass. */
-  typedef typename Superclass::ImageType ImageType;
-  typedef typename Superclass::ScalarValueType ScalarValueType;
-  typedef typename Superclass::VectorImageType VectorImageType;
+  typedef typename Superclass::ImageType         ImageType;
+  typedef typename Superclass::ScalarValueType   ScalarValueType;
+  typedef typename Superclass::VectorImageType   VectorImageType;
   typedef typename Superclass::FeatureScalarType FeatureScalarType;
-  typedef typename Superclass::RadiusType RadiusType;
+  typedef typename Superclass::RadiusType        RadiusType;
 
   /** Extract some parameters from the superclass. */
   itkStaticConstMacro(ImageDimension, unsigned int,
@@ -60,15 +61,15 @@ public:
 
   /** */
   void SetThreshold(ScalarValueType v)
-  { m_Threshold = v; }
+    { m_Threshold = v; }
   ScalarValueType GetThreshold() const
-  { return m_Threshold; }
+    { return m_Threshold; }
 
   /** */
   void SetVariance(double v)
-  { m_Variance = v; }
+    { m_Variance = v; }
   double GetVariance() const
-  { return m_Variance; }
+    { return m_Variance; }
 
   /** Compute the Speed Image. The Speed Image is the distance to the
       canny edges. */
@@ -79,30 +80,30 @@ public:
   virtual void CalculateAdvectionImage();
 
   /** Compute the distance image. This is the distance to the canny
-      edges. */
+   * edges. */
   virtual void CalculateDistanceImage();
 
   virtual void Initialize(const RadiusType &r)
-  {
+    {
     Superclass::Initialize(r);
     
     this->SetAdvectionWeight(-1.0 * NumericTraits<ScalarValueType>::One);
     this->SetPropagationWeight(-1.0 * NumericTraits<ScalarValueType>::One);
     this->SetCurvatureWeight(NumericTraits<ScalarValueType>::One);
-  }
+    }
 
   ImageType *GetCannyImage()
     { return m_Canny->GetOutput(); }
 
 protected:
   CannySegmentationLevelSetFunction()
-  {
+    {
     m_Variance = 0.0;
     m_Threshold = NumericTraits<ScalarValueType>::Zero;
     m_Caster = CastImageFilter<FeatureImageType,ImageType>::New();
     m_Canny = CannyEdgeDetectionImageFilter<ImageType,ImageType>::New();
     m_Distance = DanielssonDistanceMapImageFilter<ImageType,ImageType>::New();
-  }
+    }
   virtual ~CannySegmentationLevelSetFunction() {}
 
   CannySegmentationLevelSetFunction(const Self&); //purposely not implemented
@@ -110,9 +111,12 @@ protected:
 
 private:
   ScalarValueType m_Variance;
-  double m_Threshold;
+  double          m_Threshold;
+
   typename CannyEdgeDetectionImageFilter<ImageType,ImageType>::Pointer m_Canny;
+
   typename DanielssonDistanceMapImageFilter<ImageType,ImageType>::Pointer m_Distance;
+
   typename CastImageFilter<FeatureImageType, ImageType>::Pointer m_Caster;
 
   
