@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCurvesLevelSetImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2008-03-03 13:58:41 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2008-10-23 16:15:24 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkCurvesLevelSetImageFilter_h_
-#define __itkCurvesLevelSetImageFilter_h_
+#ifndef __itkCurvesLevelSetImageFilter_h
+#define __itkCurvesLevelSetImageFilter_h
 
 #include "itkSegmentationLevelSetImageFilter.h"
 #include "itkCurvesLevelSetFunction.h"
@@ -104,21 +104,21 @@ class ITK_EXPORT CurvesLevelSetImageFilter
 {
 public:
    /** Standard class typedefs */
-  typedef CurvesLevelSetImageFilter Self;
-  typedef  SegmentationLevelSetImageFilter<TInputImage, TFeatureImage, TOutputPixelType> Superclass;
-  typedef SmartPointer<Self>  Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef CurvesLevelSetImageFilter               Self;
+  typedef  SegmentationLevelSetImageFilter<
+    TInputImage, TFeatureImage, TOutputPixelType> Superclass;
+  typedef SmartPointer<Self>                      Pointer;
+  typedef SmartPointer<const Self>                ConstPointer;
 
   /** Inherited typedef from the superclass. */
-  typedef typename Superclass::ValueType ValueType;
-  typedef typename Superclass::OutputImageType OutputImageType;
-  typedef typename Superclass::FeatureImageType FeatureImageType;
+  typedef typename Superclass::ValueType          ValueType;
+  typedef typename Superclass::OutputImageType    OutputImageType;
+  typedef typename Superclass::FeatureImageType   FeatureImageType;
   
   /** Type of the segmentation function */
-  typedef CurvesLevelSetFunction<OutputImageType,
-                                                FeatureImageType> CurvesFunctionType;
-  typedef typename CurvesFunctionType::Pointer
-    CurvesFunctionPointer;
+  typedef CurvesLevelSetFunction<
+    OutputImageType, FeatureImageType>            CurvesFunctionType;
+  typedef typename CurvesFunctionType::Pointer    CurvesFunctionPointer;
   
   /** Run-time type information (and related methods). */
   itkTypeMacro(CurvesLevelSetImageFilter, SegmentationLevelSetImageFilter);
@@ -128,10 +128,12 @@ public:
      
   /** Set the value of sigma used to compute derivatives */
   void SetDerivativeSigma( float value )
-   { m_CurvesFunction->SetDerivativeSigma( value ); 
-     this->Modified(); }
+    {
+    m_CurvesFunction->SetDerivativeSigma( value ); 
+    this->Modified();
+    }
   float GetDerivativeSigma() const
-   { return m_CurvesFunction->GetDerivativeSigma(); }
+    { return m_CurvesFunction->GetDerivativeSigma(); }
     
 #ifdef ITK_USE_CONCEPT_CHECKING
   /** Begin concept checking */
@@ -158,8 +160,6 @@ private:
 
 } // end namespace itk
 
-
-
 #ifndef ITK_MANUAL_INSTANTIATION
 #include "itkCurvesLevelSetImageFilter.txx"
 #endif
