@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkDeformableSimplexMesh3DGradientConstraintForceFilter.h,v $
   Language:  C++
-  Date:      $Date: 2009-05-12 17:26:20 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-08-16 13:33:47 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -124,7 +124,8 @@ public:
   typedef Image<float, 3>                                 OriginalImageType;
   typedef typename OriginalImageType::IndexType           OriginalImageIndexType;
   typedef typename OriginalImageIndexType::IndexValueType ImageIndexValueType;
-  typedef typename OriginalImageType::Pointer             OriginalImagePointer;
+  typedef typename OriginalImageType::ConstPointer        OriginalImagePointer;
+
   /** control the range of search for Bresenham at normal line */
   itkSetMacro(Range, int);
   itkGetConstMacro(Range, int);
@@ -143,7 +144,7 @@ public:
   /**
    * Set Original image
    */ 
-  itkSetMacro(Image, OriginalImagePointer);
+  itkSetConstObjectMacro( Image, OriginalImageType );
 
 protected:
   DeformableSimplexMesh3DGradientConstraintForceFilter();
