@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFEMFiniteDifferenceFunctionLoad.h,v $
   Language:  C++
-  Date:      $Date: 2006-09-25 22:41:06 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-05-12 17:26:20 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef _itkFEMFiniteDifferenceFunctionLoad_h_
-#define _itkFEMFiniteDifferenceFunctionLoad_h_
+#ifndef __itkFEMFiniteDifferenceFunctionLoad_h
+#define __itkFEMFiniteDifferenceFunctionLoad_h
 
 #include "itkFEMLoadElementBase.h"
 
@@ -61,27 +61,27 @@ namespace fem
  * and more functionality will be available (such as scale selection).
  */ 
 template<class TMoving,class TFixed> 
-class FiniteDifferenceFunctionLoad : public LoadElement
+class ITK_EXPORT FiniteDifferenceFunctionLoad : public LoadElement
 {
-FEM_CLASS(FiniteDifferenceFunctionLoad,LoadElement)
+  FEM_CLASS(FiniteDifferenceFunctionLoad,LoadElement)
 public:
 
-// Necessary typedefs for dealing with images BEGIN
+  // Necessary typedefs for dealing with images BEGIN
   typedef typename LoadElement::Float Float;
 
-  typedef TMoving MovingImageType;
+  typedef TMoving                                 MovingImageType;
   typedef typename MovingImageType::ConstPointer  MovingConstPointer;
-  typedef MovingImageType*  MovingPointer;
-  typedef TFixed       FixedImageType;
-  typedef FixedImageType*  FixedPointer;
-  typedef typename FixedImageType::ConstPointer  FixedConstPointer;
+  typedef MovingImageType*                        MovingPointer;
+  typedef TFixed                                  FixedImageType;
+  typedef FixedImageType*                         FixedPointer;
+  typedef typename FixedImageType::ConstPointer   FixedConstPointer;
 
   /** Dimensionality of input and output data is assumed to be the same. */
   itkStaticConstMacro(ImageDimension, unsigned int,
                       MovingImageType::ImageDimension);
 
   typedef ImageRegionIteratorWithIndex<MovingImageType> MovingRegionIteratorType; 
-  typedef ImageRegionIteratorWithIndex<FixedImageType>    FixedRegionIteratorType; 
+  typedef ImageRegionIteratorWithIndex<FixedImageType>  FixedRegionIteratorType; 
   
 
   typedef NeighborhoodIterator<MovingImageType> 
@@ -103,13 +103,16 @@ public:
 // IMAGE DATA
   typedef   typename  MovingImageType::PixelType   MovingPixelType;
   typedef   typename  FixedImageType::PixelType    FixedPixelType;
-  typedef   Float PixelType;
-  typedef   Float ComputationType;
-  typedef   Image< PixelType, itkGetStaticConstMacro(ImageDimension) >            ImageType;
-  typedef   itk::Vector<float,itkGetStaticConstMacro(ImageDimension)>             VectorType;
-  typedef   vnl_vector<Float>             FEMVectorType;
-  typedef   Image< VectorType, itkGetStaticConstMacro(ImageDimension) >           DeformationFieldType;
-  typedef   typename DeformationFieldType::Pointer    DeformationFieldTypePointer;
+  typedef   Float                                  PixelType;
+  typedef   Float                                  ComputationType;
+  typedef   Image< PixelType, itkGetStaticConstMacro(ImageDimension) >
+                                                   ImageType;
+  typedef   itk::Vector<float,itkGetStaticConstMacro(ImageDimension)> 
+                                                   VectorType;
+  typedef   vnl_vector<Float>                      FEMVectorType;
+  typedef   Image< VectorType, itkGetStaticConstMacro(ImageDimension) >
+                                                   DeformationFieldType;
+  typedef   typename DeformationFieldType::Pointer DeformationFieldTypePointer;
 
 
   typedef NeighborhoodIterator<DeformationFieldType> 
@@ -119,8 +122,10 @@ public:
 
   /** PDEDeformableRegistrationFilterFunction type. */
   typedef PDEDeformableRegistrationFunction<FixedImageType,MovingImageType,
-    DeformationFieldType>  FiniteDifferenceFunctionType;
+    DeformationFieldType>                                FiniteDifferenceFunctionType;
   typedef typename FiniteDifferenceFunctionType::Pointer FiniteDifferenceFunctionTypePointer;
+
+
   typedef typename FiniteDifferenceFunctionType::TimeStepType TimeStepType;
  
   typedef MeanSquareRegistrationFunction<FixedImageType,MovingImageType,
@@ -141,87 +146,119 @@ public:
    * will be used by the filter to calculate updates at image pixels.
    * \returns A FiniteDifferenceObject pointer. */
   void SetDifferenceFunction( FiniteDifferenceFunctionTypePointer drfp)
-  { 
+    { 
     drfp->SetFixedImage(m_FixedImage);
     drfp->SetMovingImage(m_MovingImage);
     drfp->SetRadius(m_MetricRadius);
     drfp->SetDeformationField(m_DeformationField);
     drfp->InitializeIteration();
     this->m_DifferenceFunction=drfp; 
-  }
+    }
 
   void SetMetric( FiniteDifferenceFunctionTypePointer drfp )
-  {
+    {
     this->SetDifferenceFunction( static_cast<FiniteDifferenceFunctionType *>(
     drfp.GetPointer() ) );
 
     m_FixedSize=m_DeformationField->GetLargestPossibleRegion().GetSize();
-  }
-
-
+    }
 
  /** Define the reference (moving) image. */
   void SetMovingImage(MovingImageType* R)
-  { 
+    { 
     m_MovingImage = R; 
     m_MovingSize=m_MovingImage->GetLargestPossibleRegion().GetSize();
     if (this->m_DifferenceFunction) this->m_DifferenceFunction->SetMovingImage(m_MovingImage);
-//     this->InitializeIteration();   
-  };
+    };
 
 
   /** Define the target (fixed) image. */ 
   void SetFixedImage(FixedImageType* T)
-  { 
-     m_FixedImage=T; 
-     m_FixedSize=T->GetLargestPossibleRegion().GetSize();
-     if (this->m_DifferenceFunction) this->m_DifferenceFunction->SetFixedImage(m_MovingImage); 
-//     this->InitializeIteration();   
-  };
+    { 
+    m_FixedImage=T; 
+    m_FixedSize=T->GetLargestPossibleRegion().GetSize();
+    if (this->m_DifferenceFunction)
+      {
+      this->m_DifferenceFunction->SetFixedImage(m_MovingImage); 
+      }
+    }
 
+  MovingPointer GetMovingImage()
+    {
+    return m_MovingImage;
+    }
 
-  MovingPointer GetMovingImage() { return m_MovingImage; };
-  FixedPointer GetFixedImage() { return m_FixedImage; };
+  FixedPointer GetFixedImage()
+    {
+    return m_FixedImage;
+    }
 
   /** Define the metric region size. */ 
-  void SetMetricRadius(MovingRadiusType T) {m_MetricRadius  = T; };    
+  void SetMetricRadius(MovingRadiusType T)
+    {
+    m_MetricRadius  = T;
+    }
   /** Get the metric region size. */ 
-  MovingRadiusType GetMetricRadius() { return m_MetricRadius; };       
+  MovingRadiusType GetMetricRadius()
+    {
+    return m_MetricRadius;
+    }
   
   /** Set/Get methods for the number of integration points to use 
-    * in each 1-dimensional line integral when evaluating the load.
-    * This value is passed to the load implementation.
-    */
-  void SetNumberOfIntegrationPoints(unsigned int i){ m_NumberOfIntegrationPoints=i;}
-  unsigned int GetNumberOfIntegrationPoints(){ return m_NumberOfIntegrationPoints;}
+   * in each 1-dimensional line integral when evaluating the load.
+   * This value is passed to the load implementation.
+   */
+  void SetNumberOfIntegrationPoints(unsigned int i)
+    {
+    m_NumberOfIntegrationPoints=i;
+    }
+  unsigned int GetNumberOfIntegrationPoints()
+    {
+    return m_NumberOfIntegrationPoints;
+    }
 
   /** Set the direction of the gradient (uphill or downhill). 
     * E.g. the mean squares metric should be minimized while NCC and PR should be maximized.
     */ 
-  void SetSign(Float s) {m_Sign=s;}
+  void SetSign(Float s)
+    {
+    m_Sign=s;
+    }
   
   /** Set the sigma in a gaussian measure. */
-  void SetTemp(Float s) {m_Temp=s;}
+  void SetTemp(Float s)
+    {
+    m_Temp=s;
+    }
 
 
   /** Scaling of the similarity energy term */
-  void SetGamma(Float s) {m_Gamma=s;}
+  void SetGamma(Float s)
+    {
+    m_Gamma=s;
+    }
 
-  void SetSolution(Solution::ConstPointer ptr) {  m_Solution=ptr; }
-  Solution::ConstPointer GetSolution() {  return m_Solution; }
+  void SetSolution(Solution::ConstPointer ptr)
+    {
+    m_Solution=ptr;
+    }
+  Solution::ConstPointer GetSolution()
+    {
+    return m_Solution;
+    }
 
   // FIXME - WE ASSUME THE 2ND VECTOR (INDEX 1) HAS THE INFORMATION WE WANT
   Float GetSolution(unsigned int i,unsigned int which=0)
-  {  
+    {  
     return m_Solution->GetSolutionValue(i,which); 
-  }
+    }
 
   FiniteDifferenceFunctionLoad(); // cannot be private until we always use smart pointers
   Float EvaluateMetricGivenSolution ( Element::ArrayType* el, Float step=1.0);
  
-/**
- * Compute the image based load - implemented with ITK metric derivatives.
- */
+  /**
+   * Compute the image based load - implemented with ITK metric derivatives.
+   */
   VectorType Fe1(VectorType);
   FEMVectorType Fe(FEMVectorType,FEMVectorType);
  
@@ -266,14 +303,12 @@ private:
   typename DeformationFieldType::Pointer             m_DeformationField;
   /** Dummy static int that enables automatic registration
       with FEMObjectFactory. */
-  static const int DummyCLID;
+  static const int m_DummyCLID;
 
 };
 
-
-
-
-}} // end namespace fem/itk
+}
+} // end namespace fem/itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
 #include "itkFEMFiniteDifferenceFunctionLoad.txx"
