@@ -3,14 +3,14 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFFTWRealToComplexConjugateImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-08-29 21:30:32 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2010-02-26 05:28:24 $
+  Version:   $Revision: 1.12 $
 
-  Copyright (c) 2002 Insight Consortium. All rights reserved.
+  Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+     This software is distributed WITHOUT ANY WARRANTY; without even 
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
@@ -23,24 +23,24 @@
 
 namespace itk
 {
-/** /class FFTWRealToComplexConjugateImageFilter
- * /brief
+/** \class FFTWRealToComplexConjugateImageFilter
+ * \brief
  *
  * \ingroup
  */
 
-template <class TPixel, unsigned int Dimension = 3>
+template <class TPixel, unsigned int VDimension = 3>
 class ITK_EXPORT FFTWRealToComplexConjugateImageFilter :
-    public FFTRealToComplexConjugateImageFilter<TPixel,Dimension>
+    public FFTRealToComplexConjugateImageFilter<TPixel,VDimension>
 {
 public:
-  typedef FFTWRealToComplexConjugateImageFilter Self;
-  typedef FFTRealToComplexConjugateImageFilter<TPixel,Dimension> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> constPointer;
+  typedef FFTWRealToComplexConjugateImageFilter                   Self;
+  typedef FFTRealToComplexConjugateImageFilter<TPixel,VDimension> Superclass;
+  typedef SmartPointer<Self>                                      Pointer;
+  typedef SmartPointer<const Self>                                ConstPointer;
 
-  /** Standard class typedefs.*/
-  typedef typename Superclass::TInputImageType TInputImageType;
+  /** Standard class typedefs. */
+  typedef typename Superclass::TInputImageType  TInputImageType;
   typedef typename Superclass::TOutputImageType TOutputImageType;
 
   /**
@@ -68,26 +68,27 @@ protected:
                                             m_LastImageSize(0),
                                             m_InputBuffer(0),
                                             m_OutputBuffer(0)
-  {
-  }
+    {
+    }
   ~FFTWRealToComplexConjugateImageFilter()
-  {
+    {
     if(m_PlanComputed)
       {
       FFTWProxyType::DestroyPlan(this->m_Plan);
       delete [] this->m_InputBuffer;
       delete [] this->m_OutputBuffer;
       }
-  }
+    }
 
   virtual bool FullMatrix();
 private:
   FFTWRealToComplexConjugateImageFilter(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
-  bool m_PlanComputed;
+  bool                             m_PlanComputed;
   typename FFTWProxyType::PlanType m_Plan;
-  unsigned int m_LastImageSize;
-  TPixel *m_InputBuffer;
+  unsigned int                     m_LastImageSize;
+
+  TPixel *                             m_InputBuffer;
   typename FFTWProxyType::ComplexType *m_OutputBuffer;
 
 };
