@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkHistogramMatchingImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-07-31 23:09:16 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-05-02 05:43:54 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -63,10 +63,10 @@ class ITK_EXPORT HistogramMatchingImageFilter:
 {
 public:
   /** Standard class typedefs. */
-  typedef HistogramMatchingImageFilter         Self;
+  typedef HistogramMatchingImageFilter                  Self;
   typedef ImageToImageFilter<TInputImage,TOutputImage>  Superclass;
-  typedef SmartPointer<Self>  Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                            Pointer;
+  typedef SmartPointer<const Self>                      ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);  
@@ -84,25 +84,29 @@ public:
   typedef typename TOutputImage::RegionType OutputImageRegionType;
 
   /** Inherited typedefs. */
-  typedef typename Superclass::InputImageType InputImageType;
-  typedef typename Superclass::InputImagePointer InputImagePointer;
+  typedef typename Superclass::InputImageType         InputImageType;
+  typedef typename Superclass::InputImagePointer      InputImagePointer;
   typedef typename Superclass::InputImageConstPointer InputImageConstPointer;
-  typedef typename Superclass::OutputImageType OutputImageType;
-  typedef typename Superclass::OutputImagePointer OutputImagePointer;
+  typedef typename Superclass::OutputImageType        OutputImageType;
+  typedef typename Superclass::OutputImagePointer     OutputImagePointer;
   
   /** Pixel related typedefs. */
-  typedef typename InputImageType::PixelType InputPixelType;
+  typedef typename InputImageType::PixelType  InputPixelType;
   typedef typename OutputImageType::PixelType OutputPixelType;
 
   /** Histogram related typedefs. */
+#ifdef ITK_USE_REVIEW_STATISTICS
+  typedef Statistics::Histogram<THistogramMeasurement >   HistogramType;
+#else
   typedef Statistics::Histogram<THistogramMeasurement, 1> HistogramType;
-  typedef typename HistogramType::Pointer HistogramPointer;
+#endif
+  typedef typename HistogramType::Pointer                 HistogramPointer;
 
   /** Set/Get the source image. */
   void SetSourceImage( const InputImageType * source )
-  { this->SetInput( source ); }
+    { this->SetInput( source ); }
   const InputImageType * GetSourceImage(void)
-  { return this->GetInput(); }
+    { return this->GetInput(); }
 
   /** Set/Get the reference image. */
   void SetReferenceImage( const InputImageType * reference );
@@ -110,11 +114,11 @@ public:
 
   /** Set/Get the number of histogram levels used. */
   itkSetMacro( NumberOfHistogramLevels, unsigned long );
-  itkGetMacro( NumberOfHistogramLevels, unsigned long );
+  itkGetConstMacro( NumberOfHistogramLevels, unsigned long );
 
   /** Set/Get the number of match points used. */
   itkSetMacro( NumberOfMatchPoints, unsigned long );
-  itkGetMacro( NumberOfMatchPoints, unsigned long );
+  itkGetConstMacro( NumberOfMatchPoints, unsigned long );
 
   /** Set/Get the threshold at mean intensity flag.
    * If true, only source (reference) pixels which are greater
@@ -122,7 +126,7 @@ public:
    * the histogram matching. If false, all pixels are
    * used. */
   itkSetMacro( ThresholdAtMeanIntensity, bool );
-  itkGetMacro( ThresholdAtMeanIntensity, bool );
+  itkGetConstMacro( ThresholdAtMeanIntensity, bool );
   itkBooleanMacro( ThresholdAtMeanIntensity );
 
   /** This filter requires all of the input to be in the buffer. */
