@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageRegistrationMethod.h,v $
   Language:  C++
-  Date:      $Date: 2007-11-19 16:55:38 $
-  Version:   $Revision: 1.20 $
+  Date:      $Date: 2009-04-23 03:53:35 $
+  Version:   $Revision: 1.22 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -65,9 +65,9 @@ class ITK_EXPORT ImageRegistrationMethod : public ProcessObject
 public:
   /** Standard class typedefs. */
   typedef ImageRegistrationMethod  Self;
-  typedef ProcessObject  Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef ProcessObject            Superclass;
+  typedef SmartPointer<Self>       Pointer;
+  typedef SmartPointer<const Self> ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -95,9 +95,9 @@ public:
 
   /** Type for the output: Using Decorator pattern for enabling
    *  the Transform to be passed in the data pipeline */
-  typedef  DataObjectDecorator< TransformType >    TransformOutputType;
-  typedef typename TransformOutputType::Pointer    TransformOutputPointer;
-  typedef typename TransformOutputType::ConstPointer    TransformOutputConstPointer;
+  typedef  DataObjectDecorator< TransformType >      TransformOutputType;
+  typedef typename TransformOutputType::Pointer      TransformOutputPointer;
+  typedef typename TransformOutputType::ConstPointer TransformOutputConstPointer;
   
   /**  Type of the Interpolator. */
   typedef  typename MetricType::InterpolatorType   InterpolatorType;
@@ -173,7 +173,7 @@ public:
   itkGetConstReferenceMacro( FixedImageRegion, FixedImageRegionType );
   /** True if a region has been defined for the fixed image to which
    the ImageMetric will limit its computation */
-  itkGetMacro( FixedImageRegionDefined, bool );
+  itkGetConstMacro( FixedImageRegionDefined, bool );
   /** Turn on/off the use of a fixed image region to which
    the ImageMetric will limit its computation.
    \warning The region must have been previously defined using the
@@ -237,6 +237,3 @@ private:
 #endif
 
 #endif
-
-
-
