@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkKappaStatisticImageToImageMetric.h,v $
   Language:  C++
-  Date:      $Date: 2008-02-03 04:05:28 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-04-23 03:53:35 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -55,11 +55,10 @@ class ITK_EXPORT KappaStatisticImageToImageMetric :
 public:
 
   /** Standard class typedefs. */
-  typedef KappaStatisticImageToImageMetric    Self;
+  typedef KappaStatisticImageToImageMetric                Self;
   typedef ImageToImageMetric<TFixedImage, TMovingImage >  Superclass;
-
-  typedef SmartPointer<Self>         Pointer;
-  typedef SmartPointer<const Self>   ConstPointer;
+  typedef SmartPointer<Self>                              Pointer;
+  typedef SmartPointer<const Self>                        ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -108,7 +107,7 @@ public:
   /** This method allows the user to set the foreground value.  The default 
    *  value is 255. */
   itkSetMacro(ForegroundValue, RealType); 
-  itkGetMacro(ForegroundValue, RealType);
+  itkGetConstMacro(ForegroundValue, RealType);
 
 
   /** Set/Get whether this metric returns 2*|A&B|/(|A|+|B|) 
@@ -117,7 +116,7 @@ public:
    * metric values use ComplementOn().  */
   itkSetMacro(Complement, bool);
   itkBooleanMacro(Complement);
-  itkGetMacro(Complement, bool);
+  itkGetConstMacro(Complement, bool);
   
 
 protected:
@@ -142,6 +141,3 @@ private:
 #endif
 
 #endif
-
-
-
