@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkOtsuMultipleThresholdsCalculator.h,v $
   Language:  C++
-  Date:      $Date: 2005-11-25 15:50:35 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-05-12 17:26:21 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -37,49 +37,54 @@ namespace itk
  */
 
 template< class TInputHistogram >
-class OtsuMultipleThresholdsCalculator :
+class ITK_EXPORT OtsuMultipleThresholdsCalculator :
       public HistogramAlgorithmBase< TInputHistogram >
 {
 public:
   /**Standard class typedefs. */
-  typedef OtsuMultipleThresholdsCalculator Self;
+  typedef OtsuMultipleThresholdsCalculator        Self;
   typedef HistogramAlgorithmBase<TInputHistogram> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef SmartPointer<Self>                      Pointer;
+  typedef SmartPointer<const Self>                ConstPointer;
 
   typedef typename TInputHistogram::MeasurementType MeasurementType;
-  typedef typename TInputHistogram::FrequencyType FrequencyType;
+
+#ifdef ITK_USE_REVIEW_STATISTICS
+  typedef typename TInputHistogram::AbsoluteFrequencyType   FrequencyType;
+#else
+  typedef typename TInputHistogram::FrequencyType   FrequencyType;
+#endif
 
   typedef typename NumericTraits<MeasurementType>::RealType MeanType;
   typedef typename NumericTraits<MeasurementType>::RealType VarianceType;
 
-  typedef std::vector<MeanType> MeanVectorType;
+  typedef std::vector<MeanType>      MeanVectorType;
   typedef std::vector<FrequencyType> FrequencyVectorType;
 
   typedef typename TInputHistogram::InstanceIdentifier InstanceIdentifierType;
-  typedef std::vector<InstanceIdentifierType> InstanceIdentifierVectorType;
+  typedef std::vector<InstanceIdentifierType>          InstanceIdentifierVectorType;
 
   /**Standard Macros */
   itkTypeMacro(OtsuMultipleThresholdsCalculator, HistogramAlgorithmsBase);
-  itkNewMacro(Self) ;
-                                                                                                                                      
+  itkNewMacro(Self);
+
   /** Typedef for the thresholds output */
-  typedef std::vector<MeasurementType> OutputType ;
-                                                                                                                                      
+  typedef std::vector<MeasurementType> OutputType;
+
   /** Returns the thresholds vector */
-  const OutputType& GetOutput() ;
+  const OutputType& GetOutput();
 
   /** Set/Get the number of thresholds. */
   itkSetClampMacro(NumberOfThresholds, unsigned long, 1, NumericTraits<unsigned long>::max() );
-  itkGetMacro(NumberOfThresholds,unsigned long);
+  itkGetConstMacro(NumberOfThresholds,unsigned long);
                                              
 protected:
-  OtsuMultipleThresholdsCalculator() ;
+  OtsuMultipleThresholdsCalculator();
   virtual ~OtsuMultipleThresholdsCalculator() {}
   void PrintSelf(std::ostream& os, Indent indent) const;
                                                                                                                                       
   /** Calculates the thresholds and save them */
-  void GenerateData() ;
+  void GenerateData();
                          
   /** Increment the thresholds of one position */
   bool IncrementThresholds(InstanceIdentifierVectorType& thresholdIds, MeanType totalMean, MeanVectorType& classMean, FrequencyVectorType& classFrequency);
@@ -87,9 +92,9 @@ protected:
 private:
   /** Internal thresholds storage */
   unsigned long m_NumberOfThresholds;
-  OutputType m_Output ;
+  OutputType    m_Output;
 
-} ; // end of class
+}; // end of class
                                                                                                                                       
 } // end of namespace itk
 
