@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkScalarImageKmeansImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-04-05 13:59:37 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2010-01-31 19:29:05 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -25,11 +25,18 @@
 #include "itkKdTreeBasedKmeansEstimator.h"
 #include "itkWeightedCentroidKdTreeGenerator.h"
 
+#ifdef ITK_USE_REVIEW_STATISTICS
+#include "itkEuclideanDistanceMetric.h"
+#include "itkSampleClassifierFilter.h"
+#include "itkImageToListSampleAdaptor.h"
+#include "itkMinimumDecisionRule2.h"
+#else
 #include "itkMinimumDecisionRule.h"
 #include "itkEuclideanDistance.h"
 #include "itkSampleClassifier.h"
-
 #include "itkScalarImageToListAdaptor.h"
+#endif
+
 #include "itkImageRegion.h"
 #include "itkRegionOfInterestImageFilter.h"
 
@@ -58,10 +65,10 @@ namespace itk
  * 
  * \ingroup ClassificationFilters 
  */
-template <class TInputImage >
+template <class TInputImage,
+          class TOutputImage=Image<unsigned char, ::itk::GetImageDimension<TInputImage>::ImageDimension> >
 class ITK_EXPORT ScalarImageKmeansImageFilter :
-    public ImageToImageFilter< TInputImage, Image<unsigned char,
-             ::itk::GetImageDimension<TInputImage>::ImageDimension> >
+    public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
   /** Extract dimension from input and output image. */
@@ -69,15 +76,14 @@ public:
                       TInputImage::ImageDimension);
 
   /** Convenient typedefs for simplifying declarations. */
-  typedef TInputImage InputImageType;
-  typedef Image<unsigned char,
-             ::itk::GetImageDimension<TInputImage>::ImageDimension> OutputImageType;
+  typedef TInputImage  InputImageType;
+  typedef TOutputImage OutputImageType;
 
   /** Standard class typedefs. */
-  typedef ScalarImageKmeansImageFilter Self;
+  typedef ScalarImageKmeansImageFilter                         Self;
   typedef ImageToImageFilter< InputImageType, OutputImageType> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                                   Pointer;
+  typedef SmartPointer<const Self>                             ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -86,24 +92,53 @@ public:
   itkTypeMacro(ScalarImageKmeansImageFilter, ImageToImageFilter);
   
   /** Image typedef support. */
-  typedef typename InputImageType::PixelType InputPixelType;
+  typedef typename InputImageType::PixelType  InputPixelType;
   typedef typename OutputImageType::PixelType OutputPixelType;
 
   /** Type used for representing the Mean values */
   typedef typename NumericTraits< InputPixelType >::RealType RealPixelType;
   
   /** Create a List from the scalar image */
+#ifdef ITK_USE_REVIEW_STATISTICS
+  typedef itk::Statistics::ImageToListSampleAdaptor< InputImageType > AdaptorType;
+#else
   typedef itk::Statistics::ScalarImageToListAdaptor< 
                                    InputImageType > AdaptorType;
- 
+#endif  
+
   /** Define the Measurement vector type from the AdaptorType */
   typedef typename AdaptorType::MeasurementVectorType  MeasurementVectorType;
 
+#ifdef ITK_USE_REVIEW_STATISTICS
+  typedef itk::Statistics::DistanceToCentroidMembershipFunction< MeasurementVectorType > MembershipFunctionType;
+  typedef itk::Statistics::SampleClassifierFilter< AdaptorType > ClassifierType;
+  typedef itk::Statistics::MinimumDecisionRule2                  DecisionRuleType;
+#else
+  typedef itk::Statistics::EuclideanDistance< MeasurementVectorType > MembershipFunctionType;
+  typedef itk::Statistics::SampleClassifier< AdaptorType > ClassifierType;
+  typedef itk::MinimumDecisionRule                         DecisionRuleType;
+#endif
+
+#ifdef ITK_USE_REVIEW_STATISTICS
+  typedef typename ClassifierType::ClassLabelVectorType ClassLabelVectorType;
+#else
+  typedef std::vector< unsigned int > ClassLabelVectorType;
+#endif
+  
+#ifdef ITK_USE_REVIEW_STATISTICS
+  typedef typename ClassifierType::MembershipFunctionVectorType MembershipFunctionVectorType;
+  typedef typename MembershipFunctionType::CentroidType  MembershipFunctionOriginType;
+#else
+  typedef typename MembershipFunctionType::OriginType  MembershipFunctionOriginType;
+#endif
+  
+  typedef typename MembershipFunctionType::Pointer     MembershipFunctionPointer;
+  
   /** Create the K-d tree structure */
   typedef itk::Statistics::WeightedCentroidKdTreeGenerator< 
                                                       AdaptorType > 
-                                                              TreeGeneratorType;
-  typedef typename TreeGeneratorType::KdTreeType TreeType;
+                                                                TreeGeneratorType;
+  typedef typename TreeGeneratorType::KdTreeType                TreeType;
   typedef itk::Statistics::KdTreeBasedKmeansEstimator<TreeType> EstimatorType;
 
   typedef typename EstimatorType::ParametersType ParametersType;
@@ -150,9 +185,9 @@ protected:
 
   /** This method runs the statistical methods that identify the means of the
    * classes and the use the distances to those means in order to label the
-   * image pixels.   *
+   * image pixels.
    * \sa ImageToImageFilter::GenerateData() 
-   **/
+   */
   void GenerateData();
 
 private:
