@@ -3,8 +3,8 @@
 Program:   Insight Segmentation & Registration Toolkit
 Module:    $RCSfile: itkSimplexMeshVolumeCalculator.h,v $
 Language:  C++
-Date:      $Date: 2007-04-10 15:45:19 $
-Version:   $Revision: 1.4 $
+Date:      $Date: 2009-06-10 12:07:17 $
+Version:   $Revision: 1.6 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -123,6 +123,7 @@ public:
       PointIdIterator  it =  poly->PointIdsBegin();
       InputPointType center,p;
       center.Fill(0);
+      p.Fill(0.0);
 
       while ( it != poly->PointIdsEnd() )
         {
@@ -170,10 +171,10 @@ public:
   void Compute(void);
     
   /** Return the computed volume. */
-  itkGetMacro(Volume, double);
+  itkGetConstMacro(Volume, double);
 
   /** Return the computed area. */
-  itkGetMacro(Area, double);
+  itkGetConstMacro(Area, double);
 
 protected:
   SimplexMeshVolumeCalculator();
