@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkThresholdSegmentationLevelSetImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2004-06-01 18:33:45 $
-  Version:   $Revision: 1.19 $
+  Date:      $Date: 2009-01-27 19:30:16 $
+  Version:   $Revision: 1.20 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkThresholdSegmentationLevelSetImageFilter_h_
-#define __itkThresholdSegmentationLevelSetImageFilter_h_
+#ifndef __itkThresholdSegmentationLevelSetImageFilter_h
+#define __itkThresholdSegmentationLevelSetImageFilter_h
 
 #include "itkSegmentationLevelSetImageFilter.h"
 #include "itkThresholdSegmentationLevelSetFunction.h"
@@ -86,13 +86,14 @@ class ITK_EXPORT ThresholdSegmentationLevelSetImageFilter
 public:
   /** Standard class typedefs */
   typedef ThresholdSegmentationLevelSetImageFilter Self;
-  typedef  SegmentationLevelSetImageFilter<TInputImage, TFeatureImage, TOutputPixelType > Superclass;
-  typedef SmartPointer<Self>  Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef  SegmentationLevelSetImageFilter<TInputImage, TFeatureImage, TOutputPixelType >
+                                                   Superclass;
+  typedef SmartPointer<Self>                       Pointer;
+  typedef SmartPointer<const Self>                 ConstPointer;
 
   /** Inherited typedef from the superclass. */
-  typedef typename Superclass::ValueType ValueType;
-  typedef typename Superclass::OutputImageType OutputImageType;
+  typedef typename Superclass::ValueType        ValueType;
+  typedef typename Superclass::OutputImageType  OutputImageType;
   typedef typename Superclass::FeatureImageType FeatureImageType;
   
   /** Type of the segmentation function */
@@ -108,74 +109,74 @@ public:
   
   /** Get/Set the threshold values that will be used to calculate the speed function. */
   void SetUpperThreshold(ValueType v)
-  {
+    {
     this->m_ThresholdFunction->SetUpperThreshold(v);
     this->Modified();
-  }
+    }
   void SetLowerThreshold(ValueType v)
-  {
+    {
     this->m_ThresholdFunction->SetLowerThreshold(v);
     this->Modified();
-  }
+    }
   ValueType GetUpperThreshold() const
-  {
+    {
     return m_ThresholdFunction->GetUpperThreshold();
-  }
+    }
   ValueType GetLowerThreshold() const
-  {
+    {
     return m_ThresholdFunction->GetLowerThreshold();
-  }
+    }
 
   /** Set/Get the weight applied to the edge (Laplacian) attractor in the speed
    *  term function. Zero will turn this term off. */
   void SetEdgeWeight(ValueType v)
-  {
+    {
     this->m_ThresholdFunction->SetEdgeWeight(v);
     this->Modified();
-  }
-    ValueType GetEdgeWeight() const
-  {
+    }
+  ValueType GetEdgeWeight() const
+    {
     return m_ThresholdFunction->GetEdgeWeight();
-  }
+    }
 
   /** Anisotropic diffusion is applied to the FeatureImage before calculating
    * the Laplacian (edge) term. This method sets/gets the number of diffusion
    * iterations. */
   void SetSmoothingIterations(int v)
-  {
+    {
     this->m_ThresholdFunction->SetSmoothingIterations(v);
     this->Modified();
-  }
+    }
   int GetSmoothingIterations() const
-  {
+    {
     return m_ThresholdFunction->GetSmoothingIterations();
-  }
+    }
 
   /** Anisotropic diffusion is applied to the FeatureImage before calculating
    * the Laplacian (edge) term. This method sets/gets the diffusion time
    * step. */
   void SetSmoothingTimeStep(ValueType v)
-  {
+    {
     this->m_ThresholdFunction->SetSmoothingTimeStep(v);
     this->Modified();
-  }
+    }
   ValueType GetSmoothingTimeStep() const
-  {
+    {
     return m_ThresholdFunction->GetSmoothingTimeStep();
-  }
+    }
 
   /** Anisotropic diffusion is applied to the FeatureImage before calculatign
    * the Laplacian (edge) term. This method sets/gets the smoothing
    * conductance. */
   void SetSmoothingConductance(ValueType v)
-  {
+    {
     this->m_ThresholdFunction->SetSmoothingConductance(v);
     this->Modified();
-  }
-    ValueType GetSmoothingConductance() const
-  {
+    }
+  ValueType GetSmoothingConductance() const
+    {
     return m_ThresholdFunction->GetSmoothingConductance();
-  }
+    } 
   
 protected:
   ~ThresholdSegmentationLevelSetImageFilter() {}
@@ -191,8 +192,6 @@ private:
 
 } // end namespace itk
 
-
-
 #ifndef ITK_MANUAL_INSTANTIATION
 #include "itkThresholdSegmentationLevelSetImageFilter.txx"
 #endif
