@@ -3,14 +3,14 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVnlFFTComplexConjugateToRealImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-12-22 13:54:14 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-01-27 19:30:16 $
+  Version:   $Revision: 1.13 $
 
-  Copyright (c) 2002 Insight Consortium. All rights reserved.
+  Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
@@ -21,19 +21,23 @@
 namespace itk
 {
 
-template <class TPixel, unsigned int Dimension = 3>
+/** \class VnlFFTComplexConjugateToRealImageFilter
+ * 
+ * \brief TODO
+ */
+template <class TPixel, unsigned int VDimension = 3>
 class VnlFFTComplexConjugateToRealImageFilter :
-    public FFTComplexConjugateToRealImageFilter<TPixel,Dimension>
+    public FFTComplexConjugateToRealImageFilter<TPixel,VDimension>
 {
 public:
-  /** Standard class typedefs.*/ 
-  typedef Image< std::complex<TPixel>,Dimension> TInputImageType;
-  typedef Image<TPixel,Dimension> TOutputImageType;
+  /** Standard class typedefs. */ 
+  typedef Image< std::complex<TPixel>,VDimension> TInputImageType;
+  typedef Image<TPixel,VDimension>                TOutputImageType;
 
-  typedef VnlFFTComplexConjugateToRealImageFilter Self;
-  typedef FFTComplexConjugateToRealImageFilter<TPixel,Dimension> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> constPointer;
+  typedef VnlFFTComplexConjugateToRealImageFilter                 Self;
+  typedef FFTComplexConjugateToRealImageFilter<TPixel,VDimension> Superclass;
+  typedef SmartPointer<Self>                                      Pointer;
+  typedef SmartPointer<const Self>                                ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -43,7 +47,7 @@ public:
                FFTComplexConjugateToRealImageFilter);
 
   /** Image type typedef support. */
-  typedef TInputImageType ImageType;
+  typedef TInputImageType              ImageType;
   typedef typename ImageType::SizeType ImageSizeType;
 
   //
@@ -63,9 +67,10 @@ protected:
   virtual ~VnlFFTComplexConjugateToRealImageFilter(){ }
 
 private:
-  inline std::complex<TPixel> myConj(const std::complex<TPixel>& __z) {
+  inline std::complex<TPixel> myConj(const std::complex<TPixel>& __z)
+    {
     return std::complex<TPixel>(__z.real(), -__z.imag());
-  }
+    }
   VnlFFTComplexConjugateToRealImageFilter(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
 };
