@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVoronoiSegmentationImageFilterBase.h,v $
   Language:  C++
-  Date:      $Date: 2006-01-19 12:19:20 $
-  Version:   $Revision: 1.28 $
+  Date:      $Date: 2010-02-26 05:28:24 $
+  Version:   $Revision: 1.32 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef _itkVoronoiSegmentationImageFilterBase_h
-#define _itkVoronoiSegmentationImageFilterBase_h
+#ifndef __itkVoronoiSegmentationImageFilterBase_h
+#define __itkVoronoiSegmentationImageFilterBase_h
 
 #include "itkImageToImageFilter.h"
 #include "itkVoronoiDiagram2D.h"
@@ -26,7 +26,7 @@ namespace itk
 {
 
 /** \class VoronoiSegmentationImageFilterBase
- * /brief Base class for VoronoiSegmentationImageFilter
+ * \brief Base class for VoronoiSegmentationImageFilter
  * 
  * Voronoi SegmentationImageFilter is a class of segmenation algorithms that 
  * works on 2D image. 
@@ -61,10 +61,10 @@ class ITK_EXPORT VoronoiSegmentationImageFilterBase:
 {
 public:
   /** Standard class typedefs. */
-  typedef VoronoiSegmentationImageFilterBase       Self;
+  typedef VoronoiSegmentationImageFilterBase             Self;
   typedef ImageToImageFilter<TInputImage,TOutputImage>   Superclass;
-  typedef SmartPointer <Self>  Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer <Self>                            Pointer;
+  typedef SmartPointer<const Self>                       ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -77,81 +77,83 @@ public:
                       TInputImage::ImageDimension);
   
   /** Convenient typedefs. */
-  typedef TInputImage InputImageType;
-  typedef typename TInputImage::Pointer InputImagePointer;
+  typedef TInputImage                        InputImageType;
+  typedef typename TInputImage::Pointer      InputImagePointer;
   typedef typename TInputImage::ConstPointer InputImageConstPointer;
-  typedef TOutputImage OutputImageType;
-  typedef typename TInputImage::IndexType IndexType;
-  typedef typename TInputImage::SizeType SizeType;
-  typedef typename TInputImage::RegionType RegionType;
-  typedef typename TInputImage::PixelType PixelType;
-  typedef typename TOutputImage::PixelType OutputPixelType;
-  typedef VoronoiDiagram2D<double> VoronoiDiagram;
-  typedef VoronoiDiagram2DGenerator<double> VoronoiDiagramGenerator;
-  typedef typename VoronoiDiagram::PointType PointType;
-  typedef typename VoronoiDiagram::CellType CellType;
-  typedef typename VoronoiDiagram::CellAutoPointer CellAutoPointer;
-  typedef typename VoronoiDiagram::Pointer VoronoiPointer;
-  typedef typename CellType::PointIdIterator PointIdIterator;
-  typedef typename VoronoiDiagram::SeedsType SeedsType;
-  typedef typename VoronoiDiagram::SeedsIterator SeedsIterator;
-  typedef typename VoronoiDiagram::NeighborIdIterator NeighborIdIterator;
+  typedef typename TInputImage::IndexType    IndexType;
+  typedef typename TInputImage::SizeType     SizeType;
+  typedef typename TInputImage::RegionType   RegionType;
+  typedef typename TInputImage::PixelType    PixelType;
+
+  typedef TOutputImage                       OutputImageType;
+  typedef typename TOutputImage::PixelType   OutputPixelType;
+
+  typedef VoronoiDiagram2D<double>                     VoronoiDiagram;
+  typedef VoronoiDiagram2DGenerator<double>            VoronoiDiagramGenerator;
+  typedef typename VoronoiDiagram::PointType           PointType;
+  typedef typename VoronoiDiagram::CellType            CellType;
+  typedef typename VoronoiDiagram::CellAutoPointer     CellAutoPointer;
+  typedef typename VoronoiDiagram::Pointer             VoronoiPointer;
+  typedef typename CellType::PointIdIterator           PointIdIterator;
+  typedef typename VoronoiDiagram::SeedsType           SeedsType;
+  typedef typename VoronoiDiagram::SeedsIterator       SeedsIterator;
+  typedef typename VoronoiDiagram::NeighborIdIterator  NeighborIdIterator;
   typedef typename VoronoiDiagram::VoronoiEdgeIterator EdgeIterator;
-  typedef typename VoronoiDiagram::VoronoiEdge EdgeInfo;
-  typedef std::vector<PointType> PointTypeVector;
-  typedef std::deque<PointType> PointTypeDeque;
-  typedef TBinaryPriorImage     BinaryObjectImage;
-  typedef typename BinaryObjectImage::Pointer  BinaryObjectImagePointer;
-  typedef std::vector<IndexType> IndexList;
+  typedef typename VoronoiDiagram::VoronoiEdge         EdgeInfo;
+  typedef std::vector<PointType>                       PointTypeVector;
+  typedef std::deque<PointType>                        PointTypeDeque;
+  typedef TBinaryPriorImage                            BinaryObjectImage;
+  typedef typename BinaryObjectImage::Pointer          BinaryObjectImagePointer;
+  typedef std::vector<IndexType>                       IndexList;
 
   /** To output the drawing of Voronoi Diagram (VD) . */ 
-  typedef Image<unsigned char,2>  VDImage; 
+  typedef Image<unsigned char,2>     VDImage; 
   typedef typename VDImage::Pointer  VDImagePointer; 
     
   /** Set/Get the initial number of seeds for VD. */
   itkSetMacro(NumberOfSeeds, int);
-  itkGetMacro(NumberOfSeeds, int);
+  itkGetConstMacro(NumberOfSeeds, int);
 
   /** Set/Get the smallest region to be divided. */
   itkSetMacro(MinRegion, int);
-  itkGetMacro(MinRegion, int);
+  itkGetConstMacro(MinRegion, int);
 
   /** Set/Get the number of iterations to run (if set to 0: the classification
   * run process runs until no more cells can be divided). */
   itkSetMacro(Steps, int);
-  itkGetMacro(Steps, int);
+  itkGetConstMacro(Steps, int);
 
   /** Get the number of seeds before adding new ones. */
-  itkGetMacro(LastStepSeeds, int);
+  itkGetConstMacro(LastStepSeeds, int);
 
   /** Get the number of seeds to add. */
-  itkGetMacro(NumberOfSeedsToAdded, int); 
+  itkGetConstMacro(NumberOfSeedsToAdded, int); 
 
   /**  */
   itkSetMacro(UseBackgroundInAPrior, bool);
-  itkGetMacro(UseBackgroundInAPrior, bool);
+  itkGetConstMacro(UseBackgroundInAPrior, bool);
 
   /** Enable the generation of the output boundary. */
   itkSetMacro(OutputBoundary, bool);
-  itkGetMacro(OutputBoundary, bool);
+  itkGetConstMacro(OutputBoundary, bool);
 
   /** Output the segmentation on every iteration.  Useful for iteractive
       sessions. The setting of OutputBoundary determines the type of output. */
   itkSetMacro(InteractiveSegmentation, bool);
-  itkGetMacro(InteractiveSegmentation, bool);
+  itkGetConstMacro(InteractiveSegmentation, bool);
   itkBooleanMacro(InteractiveSegmentation);
   
   /** Set/Get the mean deviation. */
   itkSetMacro(MeanDeviation, double);
-  itkGetMacro(MeanDeviation, double);
+  itkGetConstMacro(MeanDeviation, double);
 
   /** Set/Get the region size. */
   itkSetMacro(Size,SizeType);
-  itkGetMacro(Size,SizeType);
+  itkGetConstMacro(Size,SizeType);
 
   /** Take a prior from other segmentation node. This should be a
    * binary object. */
-  virtual void TakeAPrior(const BinaryObjectImage*){};
+  virtual void TakeAPrior(const BinaryObjectImage*){}
   
   /** Perform the segmentation. */
   void RunSegment(void);
@@ -165,20 +167,32 @@ public:
 
   /** Return the Voroni Diagram structure. */
   VoronoiPointer GetVoronoiDiagram(void)
-  { return m_WorkingVD; }
+    { return m_WorkingVD; }
     
+#if !defined(CABLE_CONFIGURATION)  // generates invalid iterator instantiation with msvc
   /** Seeds positions are randomly set. 
    * If you need to set seeds position then use the SetSeeds method
    * after the InitializeSegment method .  */ 
   void SetSeeds(int num, SeedsIterator begin)
-  { 
+    { 
     m_NumberOfSeeds = num; 
     m_WorkingVD->SetSeeds(num,begin); 
-  }; 
+    } 
+#endif
+
+  /** Seeds positions are randomly set. 
+   * If you need to set seeds position then use the SetSeeds method
+   * after the InitializeSegment method .  */ 
+  void SetSeeds(SeedsType & seeds)
+    { 
+    m_NumberOfSeeds = seeds.size();
+    typename SeedsType::iterator it = seeds.begin();
+    m_WorkingVD->SetSeeds(m_NumberOfSeeds, it); 
+    } 
     
   /** Get the point specified by the ID given. */
   PointType GetSeed(int SeedID)
-  { return m_WorkingVD->GetSeed(SeedID); } 
+    { return m_WorkingVD->GetSeed(SeedID); } 
       
   /** Draw the Voronoi Diagram structure. */
   void DrawDiagram(VDImagePointer result,unsigned char incolor, 
@@ -202,20 +216,22 @@ protected:
   void GenerateData(void); //general pipeline function.
 
   SizeType m_Size;
-  int m_NumberOfSeeds;
-  int m_MinRegion;
-  int m_Steps;
-  int m_LastStepSeeds;
-  int m_NumberOfSeedsToAdded;
-  int m_NumberOfBoundary;
-  std::vector<int> m_NumberOfPixels;
+  int      m_NumberOfSeeds;
+  int      m_MinRegion;
+  int      m_Steps;
+  int      m_LastStepSeeds;
+  int      m_NumberOfSeedsToAdded;
+  int      m_NumberOfBoundary;
+
+  std::vector<int>           m_NumberOfPixels;
   std::vector<unsigned char> m_Label;
+
   double m_MeanDeviation;
-  bool m_UseBackgroundInAPrior;
-  bool m_OutputBoundary; //if =1 then output the boundaries, if = 0 then output the object.
-  bool m_InteractiveSegmentation;
+  bool   m_UseBackgroundInAPrior;
+  bool   m_OutputBoundary; //if =1 then output the boundaries, if = 0 then output the object.
+  bool   m_InteractiveSegmentation;
   
-  typename VoronoiDiagram::Pointer m_WorkingVD;
+  typename VoronoiDiagram::Pointer          m_WorkingVD;
   typename VoronoiDiagramGenerator::Pointer m_VDGenerator;
 
   std::vector<PointType> m_SeedsToAdded;
@@ -229,7 +245,8 @@ protected:
   
   // Compute the statistics of the pixels inside the cell.
   void GetPixelIndexFromPolygon(PointTypeDeque VertList, IndexList *PixelPool);
-  virtual bool TestHomogeneity(IndexList&){return 1;}
+  virtual bool TestHomogeneity(IndexList&)
+    {return 1;}
   
   void FillPolygon(PointTypeDeque vertlist, OutputPixelType color=1);
   
@@ -253,7 +270,3 @@ private:
 #endif
 
 #endif
-
-
-
-
