@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkWatershedImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-31 14:31:05 $
-  Version:   $Revision: 1.43 $
+  Date:      $Date: 2009-04-23 03:53:37 $
+  Version:   $Revision: 1.45 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -207,36 +207,36 @@ public:
     }
 
   virtual void SetInput( unsigned int i, const TInputImage * image)
-  {
+    {
     if (i != 0)
       { itkExceptionMacro(<< "Filter has only one input."); }
     else
       { this->SetInput(image); }
-  }
+    }
   /** Set/Get the input thresholding parameter.  Units are a percentage of
    * the maximum depth in the image. */
   void SetThreshold(double);
-  itkGetMacro(Threshold, double);
+  itkGetConstMacro(Threshold, double);
   
   /** Set/Get the flood level for generating the merge tree from the initial
    * segmentation   */
   void SetLevel(double);
-  itkGetMacro(Level, double);
+  itkGetConstMacro(Level, double);
 
   /** Get the basic segmentation from the Segmenter member filter. */
   typename watershed::Segmenter<InputImageType>::OutputImageType *
   GetBasicSegmentation()
-  {
+    {
     m_Segmenter->Update();
     return m_Segmenter->GetOutputImage();
-  }
+    }
 
   /** Get the segmentation tree from from the TreeGenerator member filter. */
   typename watershed::SegmentTreeGenerator<ScalarType>::SegmentTreeType *
   GetSegmentTree()
-  {
+    {
     return m_TreeGenerator->GetOutputSegmentTree();
-  }
+    }
    
   // Override since the filter produces all of its output
   void EnlargeOutputRequestedRegion(DataObject *data);
@@ -273,22 +273,25 @@ private:
 
   /** The percentage of the maximum saliency value among adjacencies in the
    *  segments of the initial segmentation to which ``flooding'' of the image
-   *  should occur.  A tree of segment merges is calculated up to this level*/
+   *  should occur.  A tree of segment merges is calculated up to this
+   *  level. */
   double m_Level;
 
   /** The component parts of the segmentation algorithm.  These objects
    * must save state between calls to GenerateData() so that the
    * computationally expensive execution of segment tree generation is
    * not unneccessarily repeated. */
-  typename watershed::Segmenter<InputImageType>::Pointer m_Segmenter;
+  typename watershed::Segmenter<InputImageType>::Pointer        m_Segmenter;
   typename watershed::SegmentTreeGenerator<ScalarType>::Pointer m_TreeGenerator;
-  typename watershed::Relabeler<ScalarType, itkGetStaticConstMacro(ImageDimension)>::Pointer m_Relabeler;
+  typename watershed::Relabeler<ScalarType, itkGetStaticConstMacro(ImageDimension)>::Pointer
+                                                                m_Relabeler;
 
   unsigned long m_ObserverTag;
 
   bool m_LevelChanged;
   bool m_ThresholdChanged;
   bool m_InputChanged;
+
   TimeStamp m_GenerateDataMTime;
 };
 
