@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAcosImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:39 $
-  Version:   $Revision: 1.23 $
+  Date:      $Date: 2009-04-01 14:36:05 $
+  Version:   $Revision: 1.25 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -52,17 +52,17 @@ public:
   Acos() {};
   ~Acos() {};
   bool operator!=( const Acos & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const Acos & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  inline TOutput operator()( const TInput & A )
-  {
+    }
+  inline TOutput operator()( const TInput & A ) const
+    {
     return static_cast<TOutput>( vcl_acos(static_cast<double>(A) ) );
-  }
+    }
 }; 
 }
 
@@ -80,7 +80,8 @@ public:
   typedef UnaryFunctorImageFilter<TInputImage,TOutputImage, 
                                   Functor::Acos< typename TInputImage::PixelType, 
                                                  typename TOutputImage::PixelType> >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
+
+  typedef SmartPointer<Self>        Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
 
   /** Method for creation through the object factory. */
