@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAndImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:39 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-04-01 14:36:08 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -52,17 +52,17 @@ public:
   AND() {};
   ~AND() {};
   bool operator!=( const AND & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const AND & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  inline TOutput operator()( const TInput1 & A, const TInput2 & B)
-  {
+    }
+  inline TOutput operator()( const TInput1 & A, const TInput2 & B) const
+    {
     return static_cast<TOutput>( A & B );
-  }
+    }
 }; 
 
 }
@@ -79,15 +79,14 @@ BinaryFunctorImageFilter<TInputImage1,TInputImage2,TOutputImage,
 {
 public:
   /** Standard class typedefs. */
-  typedef AndImageFilter  Self;
+  typedef AndImageFilter                Self;
   typedef BinaryFunctorImageFilter<TInputImage1,TInputImage2,TOutputImage, 
                                    Functor::AND< 
     typename TInputImage1::PixelType, 
     typename TInputImage2::PixelType,
-    typename TOutputImage::PixelType>   
-  >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+    typename TOutputImage::PixelType> > Superclass;
+  typedef SmartPointer<Self>            Pointer;
+  typedef SmartPointer<const Self>      ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
