@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAnisotropicDiffusionImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2005-10-29 23:04:52 $
-  Version:   $Revision: 1.41 $
+  Date:      $Date: 2009-04-25 12:27:04 $
+  Version:   $Revision: 1.43 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkAnisotropicDiffusionImageFilter_h_
-#define __itkAnisotropicDiffusionImageFilter_h_
+#ifndef __itkAnisotropicDiffusionImageFilter_h
+#define __itkAnisotropicDiffusionImageFilter_h
 
 #include "itkDenseFiniteDifferenceImageFilter.h"
 #include "itkAnisotropicDiffusionFunction.h"
@@ -76,9 +76,9 @@ public:
   /** Standard class typedefs. */
   typedef AnisotropicDiffusionImageFilter Self;
   typedef DenseFiniteDifferenceImageFilter<TInputImage, TOutputImage>
-  Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+                                          Superclass;
+  typedef SmartPointer<Self>              Pointer;
+  typedef SmartPointer<const Self>        ConstPointer;
 
   /** Run-time type information. */
   itkTypeMacro(AnisotropicDiffusionImageFilter,
@@ -95,27 +95,27 @@ public:
 
   /** The pixel type of the output image will be used in computations.
    * Inherited from the superclass. */
-  typedef typename Superclass::PixelType PixelType;
+  typedef typename Superclass::PixelType    PixelType;
   typedef typename Superclass::TimeStepType TimeStepType;
 
   /** Set/Get the time step for each iteration */
   itkSetMacro(TimeStep, TimeStepType);
-  itkGetMacro(TimeStep, TimeStepType);
+  itkGetConstMacro(TimeStep, TimeStepType);
 
   /** Set/Get the conductance parameter governing sensitivity of the
       conductance equation. */
   itkSetMacro(ConductanceParameter, double);
-  itkGetMacro(ConductanceParameter, double);
+  itkGetConstMacro(ConductanceParameter, double);
 
   /** Set/Get the interval at which a new scaling for the conductance term is
       calculated.  */
   itkSetMacro(ConductanceScalingUpdateInterval, unsigned int);
-  itkGetMacro(ConductanceScalingUpdateInterval, unsigned int);
+  itkGetConstMacro(ConductanceScalingUpdateInterval, unsigned int);
 
   /** The following parameters are not used at this time.  Setting them will
       have no effect on the output */
   itkSetMacro(ConductanceScalingParameter, double);
-  itkGetMacro(ConductanceScalingParameter, double);
+  itkGetConstMacro(ConductanceScalingParameter, double);
 
   /** Supplies a fixed value for the average gradient magnitude of the image to 
       the AnisotropicDiffusionFunction at each iteration.  The average gradient 
@@ -125,12 +125,12 @@ public:
       block artifacts by overriding the normal gradient magnitude calculation
       (i.e. all image chunks are scaled uniformly). */
   void SetFixedAverageGradientMagnitude(double a)
-  {
+    {
     m_FixedAverageGradientMagnitude= a;
     this->Modified();
     m_GradientMagnitudeIsFixed = true;
-  }
-  itkGetMacro(FixedAverageGradientMagnitude, double);
+    }
+  itkGetConstMacro(FixedAverageGradientMagnitude, double);
   
 protected:
   AnisotropicDiffusionImageFilter();
