@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAtanImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:39 $
-  Version:   $Revision: 1.21 $
+  Date:      $Date: 2009-04-01 14:36:09 $
+  Version:   $Revision: 1.23 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -52,17 +52,17 @@ public:
   Atan() {};
   ~Atan() {};
   bool operator!=( const Atan & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const Atan & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  inline TOutput operator()( const TInput & A )
-  {
+    }
+  inline TOutput operator()( const TInput & A ) const
+    {
     return static_cast<TOutput>( vcl_atan(static_cast<double>(A) ) );
-  }
+    }
 }; 
 
 }
@@ -76,13 +76,13 @@ UnaryFunctorImageFilter<TInputImage,TOutputImage,
 {
 public:
   /** Standard class typedefs. */
-  typedef AtanImageFilter  Self;
+  typedef AtanImageFilter           Self;
   typedef UnaryFunctorImageFilter<TInputImage,TOutputImage, 
                                   Functor::Atan< 
     typename TInputImage::PixelType, 
     typename TOutputImage::PixelType>   
-  >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
+  >                                 Superclass;
+  typedef SmartPointer<Self>        Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
 
   /** Method for creation through the object factory. */
