@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBinaryMagnitudeImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:40 $
-  Version:   $Revision: 1.14 $
+  Date:      $Date: 2009-04-01 14:36:09 $
+  Version:   $Revision: 1.16 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -54,20 +54,20 @@ public:
   Modulus2() {};
   ~Modulus2() {};
   bool operator!=( const Modulus2 & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const Modulus2 & other ) const
-  {
+    {
     return !(*this != other);
-  }
+    }
   inline TOutput operator()( const TInput1 & A, 
-                             const TInput2 & B)
-  {
+                             const TInput2 & B) const
+    {
     const double dA = static_cast<double>( A );
     const double dB = static_cast<double>( B );
     return static_cast<TOutput>( vcl_sqrt(dA*dA + dB*dB) );
-  }
+    }
 }; 
 }
 
@@ -84,13 +84,13 @@ public:
   /** Standard class typedefs. */
   typedef BinaryMagnitudeImageFilter  Self;
   typedef BinaryFunctorImageFilter<TInputImage1,TInputImage2,TOutputImage, 
-                                   Functor::Modulus2< 
+                                      Functor::Modulus2< 
     typename TInputImage1::PixelType, 
     typename TInputImage2::PixelType,
     typename TOutputImage::PixelType>   
-  >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  >                                   Superclass;
+  typedef SmartPointer<Self>          Pointer;
+  typedef SmartPointer<const Self>    ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
