@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkChangeInformationImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2005-04-18 18:14:58 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2009-04-25 12:27:17 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -50,10 +50,10 @@ class ITK_EXPORT ChangeInformationImageFilter:
 {
 public:
   /** Standard class typedefs. */
-  typedef ChangeInformationImageFilter         Self;
+  typedef ChangeInformationImageFilter                 Self;
   typedef ImageToImageFilter<TInputImage,TInputImage>  Superclass;
-  typedef SmartPointer<Self>  Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                           Pointer;
+  typedef SmartPointer<const Self>                     ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);  
@@ -70,12 +70,12 @@ public:
   typedef typename TInputImage::PixelType InputImagePixelType;
 
   /** Typedef to describe the output and input image index and size types. */
-  typedef typename TInputImage::IndexType OutputImageIndexType;
-  typedef typename TInputImage::IndexType InputImageIndexType;
-  typedef typename TInputImage::SizeType OutputImageSizeType;
-  typedef typename TInputImage::SizeType InputImageSizeType;
-  typedef typename TInputImage::OffsetType OutputImageOffsetType;
-  typedef typename TInputImage::OffsetType InputImageOffsetType;
+  typedef typename TInputImage::IndexType     OutputImageIndexType;
+  typedef typename TInputImage::IndexType     InputImageIndexType;
+  typedef typename TInputImage::SizeType      OutputImageSizeType;
+  typedef typename TInputImage::SizeType      InputImageSizeType;
+  typedef typename TInputImage::OffsetType    OutputImageOffsetType;
+  typedef typename TInputImage::OffsetType    InputImageOffsetType;
   typedef typename TInputImage::DirectionType OutputImageDirectionType;
   typedef typename TInputImage::DirectionType InputImageDirectionType;
 
@@ -84,8 +84,8 @@ public:
                       TInputImage::ImageDimension);
 
   /** Image spacing, origin and direction typedefs */
-  typedef typename TInputImage::SpacingType SpacingType;
-  typedef typename TInputImage::PointType   PointType;
+  typedef typename TInputImage::SpacingType   SpacingType;
+  typedef typename TInputImage::PointType     PointType;
   typedef typename TInputImage::DirectionType DirectionType;
 
   /** Run-time type information (and related methods). */
@@ -94,19 +94,19 @@ public:
   /** Copy the information from another Image.  By default,
    *  the information is copied from the input image. */
   void SetReferenceImage (TInputImage *image)
-  {
+    {
     if (image != m_ReferenceImage)
       {
       m_ReferenceImage = image;
       this->ProcessObject::SetNthInput(1, image);
       this->Modified();
       }
-  }
+    }
   itkGetObjectMacro(ReferenceImage, TInputImage);
 
   itkSetMacro(UseReferenceImage, bool);
   itkBooleanMacro(UseReferenceImage);
-  itkGetMacro(UseReferenceImage, bool);
+  itkGetConstMacro(UseReferenceImage, bool);
 
   /** Specify a new data spacing explicitly.  The default is to
    * use the spacing of the Input, or of the ReferenceImage
@@ -139,22 +139,22 @@ public:
 
   /** Change the origin, spacing and region of the output image. */
   void ChangeAll()
-  {
+    {
     this->ChangeSpacingOn();
     this->ChangeOriginOn();
     this->ChangeDirectionOn();
     this->ChangeRegionOn();
-  }
+    }
 
   /** Do not change the origin, spacing, direction or region of the
    * output image. */
   void ChangeNone()
-  {
+    {
     this->ChangeSpacingOff();
     this->ChangeOriginOff();
     this->ChangeDirectionOff();
     this->ChangeRegionOff();
-  }
+    }
 
   /** Change the Spacing of the output image. If false, the output
    *  image spacing will be set to the input image spacing. If true, the
@@ -164,7 +164,7 @@ public:
 
   itkSetMacro(ChangeSpacing, bool);
   itkBooleanMacro(ChangeSpacing);
-  itkGetMacro(ChangeSpacing, bool);
+  itkGetConstMacro(ChangeSpacing, bool);
 
   /** Change the Origin of the output image. If false, the output
    *  image origin will be set to the input image origin. If true, the
@@ -174,7 +174,7 @@ public:
 
   itkSetMacro(ChangeOrigin, bool);
   itkBooleanMacro(ChangeOrigin);
-  itkGetMacro(ChangeOrigin, bool);
+  itkGetConstMacro(ChangeOrigin, bool);
 
   /** Change the direction of the output image. If false, the output
    *  image direction will be set to the input image direction. If true, the
@@ -184,20 +184,20 @@ public:
 
   itkSetMacro(ChangeDirection, bool);
   itkBooleanMacro(ChangeDirection);
-  itkGetMacro(ChangeDirection, bool);
+  itkGetConstMacro(ChangeDirection, bool);
 
   /** Change the BufferedRegion of the output image. */
 
   itkSetMacro(ChangeRegion, bool);
   itkBooleanMacro(ChangeRegion);
-  itkGetMacro(ChangeRegion, bool);
+  itkGetConstMacro(ChangeRegion, bool);
 
   /** Set the Origin of the output so that image coordinate (0,0,0)
    * lies at the Center of the Image.  This will override 
    * SetOutputOrigin. */
   itkSetMacro(CenterImage, bool);
   itkBooleanMacro(CenterImage);
-  itkGetMacro(CenterImage, bool);
+  itkGetConstMacro(CenterImage, bool);
 
   /** Apply changes to the output image information. */
   virtual void GenerateOutputInformation();
@@ -226,11 +226,11 @@ private:
   bool m_ChangeRegion;
   bool m_UseReferenceImage;
   
-  SpacingType m_OutputSpacing;
-  PointType m_OutputOrigin;
+  SpacingType   m_OutputSpacing;
+  PointType     m_OutputOrigin;
   DirectionType m_OutputDirection;
 
-  long m_OutputOffset[ImageDimension];
+  long                  m_OutputOffset[ImageDimension];
   OutputImageOffsetType m_Shift;
 };
 
