@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkChangeLabelImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2008-02-13 20:52:34 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-03-30 11:32:14 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -90,11 +90,12 @@ public:
     m_ChangeMap.clear(); 
     }
 
-  inline TOutput operator()( const TInput & A )
+  inline TOutput operator()( const TInput & A ) const
     {
-    if ( m_ChangeMap.find(A) != m_ChangeMap.end() )
+    const typename ChangeMapType::const_iterator it = m_ChangeMap.find(A);
+    if ( it != m_ChangeMap.end() )
       {
-      return m_ChangeMap[A];
+      return it->second;
       }
     return A;
     }
