@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkContourMeanDistanceImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-27 17:01:04 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-04-25 12:27:20 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -58,7 +58,7 @@ namespace itk {
  * \ingroup MultiThreaded
  * 
  * \author Teo Popa, ISIS Center, Georgetown University
- *                   
+ *
  */
 template<class TInputImage1, class TInputImage2>
 class ITK_EXPORT ContourMeanDistanceImageFilter : 
@@ -66,10 +66,10 @@ class ITK_EXPORT ContourMeanDistanceImageFilter :
 {
 public:
   /** Standard Self typedef */
-  typedef ContourMeanDistanceImageFilter Self;
+  typedef ContourMeanDistanceImageFilter                 Self;
   typedef ImageToImageFilter<TInputImage1,TInputImage1>  Superclass;
-  typedef SmartPointer<Self>        Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                             Pointer;
+  typedef SmartPointer<const Self>                       ConstPointer;
   
   /** Method for creation through the object factory. */
   itkNewMacro(Self);  
@@ -78,16 +78,16 @@ public:
   itkTypeMacro(ContourMeanDistanceImageFilter, ImageToImageFilter);
   
   /** Image related typedefs. */
-  typedef TInputImage1 InputImage1Type;
-  typedef TInputImage2 InputImage2Type;
-  typedef typename TInputImage1::Pointer InputImage1Pointer;
-  typedef typename TInputImage2::Pointer InputImage2Pointer;
+  typedef TInputImage1                        InputImage1Type;
+  typedef TInputImage2                        InputImage2Type;
+  typedef typename TInputImage1::Pointer      InputImage1Pointer;
+  typedef typename TInputImage2::Pointer      InputImage2Pointer;
   typedef typename TInputImage1::ConstPointer InputImage1ConstPointer;
   typedef typename TInputImage2::ConstPointer InputImage2ConstPointer;
 
-  typedef typename TInputImage1::RegionType RegionType ;
-  typedef typename TInputImage1::SizeType SizeType ;
-  typedef typename TInputImage1::IndexType IndexType ;
+  typedef typename TInputImage1::RegionType RegionType;
+  typedef typename TInputImage1::SizeType   SizeType;
+  typedef typename TInputImage1::IndexType  IndexType;
 
   typedef typename TInputImage1::PixelType InputImage1PixelType;
   typedef typename TInputImage2::PixelType InputImage2PixelType;
@@ -101,20 +101,24 @@ public:
 
   /** Set the first input. */
   void SetInput1( const InputImage1Type * image )
-    { this->SetInput( image ); }
+    {
+    this->SetInput( image );
+    }
 
   /** Set the second input. */
   void SetInput2( const InputImage2Type * image );
 
   /** Get the first input. */
   const InputImage1Type * GetInput1(void)
-    { return this->GetInput(); }
+    {
+    return this->GetInput();\
+    }
   
   /** Get the second input. */
   const InputImage2Type * GetInput2(void);
   
   /** Return the computed Mean distance. */
-  itkGetMacro(MeanDistance,RealType);
+  itkGetConstMacro(MeanDistance,RealType);
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   /** Begin concept checking */
@@ -143,7 +147,7 @@ private:
 
   RealType                            m_MeanDistance;
 
-} ; // end of class
+}; // end of class
 
 } // end namespace itk
   
