@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCurvatureAnisotropicDiffusionImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-27 17:01:04 $
-  Version:   $Revision: 1.31 $
+  Date:      $Date: 2008-10-13 18:54:28 $
+  Version:   $Revision: 1.32 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkCurvatureAnisotropicDiffusionImageFilter_h_
-#define __itkCurvatureAnisotropicDiffusionImageFilter_h_
+#ifndef __itkCurvatureAnisotropicDiffusionImageFilter_h
+#define __itkCurvatureAnisotropicDiffusionImageFilter_h
 
 #include "itkAnisotropicDiffusionImageFilter.h"
 #include "itkCurvatureNDAnisotropicDiffusionFunction.h"
@@ -59,9 +59,9 @@ public:
   /** Standard class typedefs. */
   typedef CurvatureAnisotropicDiffusionImageFilter Self;
   typedef AnisotropicDiffusionImageFilter<TInputImage, TOutputImage>
-  Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+                                                   Superclass;
+  typedef SmartPointer<Self>                       Pointer;
+  typedef SmartPointer<const Self>                 ConstPointer;
 
   /** Standard method for creation through object factory. */
   itkNewMacro(Self);
@@ -86,21 +86,21 @@ public:
 
 protected:
   CurvatureAnisotropicDiffusionImageFilter()
-  {
+    {
     typename CurvatureNDAnisotropicDiffusionFunction<UpdateBufferType>::Pointer q
       = CurvatureNDAnisotropicDiffusionFunction<UpdateBufferType>::New();
     this->SetDifferenceFunction(q);
-  }
+    }
   ~CurvatureAnisotropicDiffusionImageFilter() {}
 
   virtual void InitializeIteration()
-  {
+    {
     Superclass::InitializeIteration();
     if (this->GetTimeStep() >  0.5 / vcl_pow(2.0, static_cast<double>(ImageDimension))  )
       {
       itkWarningMacro(<< "Anisotropic diffusion is using a time step which may introduce instability into the solution." );
       }
-  }
+    }
   
 private:
   CurvatureAnisotropicDiffusionImageFilter(const Self&); //purposely not implemented
