@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkDilateObjectMorphologyImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-27 17:01:06 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-04-28 14:36:18 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -68,15 +68,18 @@ public:
   typedef typename KernelType::ConstIterator KernelIteratorType;
 
   /** duplicates from base class to avoid compiler warnings */
-  typedef NeighborhoodIterator<TOutputImage> OutputNeighborhoodIteratorType ;
+  typedef NeighborhoodIterator<TOutputImage> OutputNeighborhoodIteratorType;
 
   typedef typename Superclass::DefaultBoundaryConditionType 
-                                             DefaultBoundaryConditionType ;
+                                             DefaultBoundaryConditionType;
+
+  /** Type of the pixels in the Kernel. */
+  typedef typename TKernel::PixelType            KernelPixelType;
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   /** Begin concept checking */
-  itkConceptMacro(KernelGreaterThanIntCheck,
-    (Concept::GreaterThanComparable<typename TKernel::PixelType, int>));
+  itkConceptMacro(KernelGreaterThanComparableCheck,
+    (Concept::GreaterThanComparable<KernelPixelType>));
   /** End concept checking */
 #endif
 
@@ -101,7 +104,7 @@ private:
   DefaultBoundaryConditionType m_DilateBoundaryCondition;
 
 
-} ; // end of class
+}; // end of class
 
 } // end namespace itk
   
@@ -110,5 +113,3 @@ private:
 #endif
 
 #endif
-
-
