@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkDirectedHausdorffDistanceImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-27 17:01:06 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2009-04-25 12:27:21 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -64,10 +64,10 @@ class ITK_EXPORT DirectedHausdorffDistanceImageFilter :
 {
 public:
   /** Standard Self typedef */
-  typedef DirectedHausdorffDistanceImageFilter Self;
+  typedef DirectedHausdorffDistanceImageFilter           Self;
   typedef ImageToImageFilter<TInputImage1,TInputImage1>  Superclass;
-  typedef SmartPointer<Self>        Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                             Pointer;
+  typedef SmartPointer<const Self>                       ConstPointer;
   
   /** Method for creation through the object factory. */
   itkNewMacro(Self);  
@@ -76,16 +76,16 @@ public:
   itkTypeMacro(DirectedHausdorffDistanceImageFilter, ImageToImageFilter);
   
   /** Image related typedefs. */
-  typedef TInputImage1 InputImage1Type;
-  typedef TInputImage2 InputImage2Type;
-  typedef typename TInputImage1::Pointer InputImage1Pointer;
-  typedef typename TInputImage2::Pointer InputImage2Pointer;
+  typedef TInputImage1                        InputImage1Type;
+  typedef TInputImage2                        InputImage2Type;
+  typedef typename TInputImage1::Pointer      InputImage1Pointer;
+  typedef typename TInputImage2::Pointer      InputImage2Pointer;
   typedef typename TInputImage1::ConstPointer InputImage1ConstPointer;
   typedef typename TInputImage2::ConstPointer InputImage2ConstPointer;
 
-  typedef typename TInputImage1::RegionType RegionType ;
-  typedef typename TInputImage1::SizeType SizeType ;
-  typedef typename TInputImage1::IndexType IndexType ;
+  typedef typename TInputImage1::RegionType RegionType;
+  typedef typename TInputImage1::SizeType   SizeType;
+  typedef typename TInputImage1::IndexType  IndexType;
 
   typedef typename TInputImage1::PixelType InputImage1PixelType;
   typedef typename TInputImage2::PixelType InputImage2PixelType;
@@ -99,20 +99,21 @@ public:
 
   /** Set the first input. */
   void SetInput1( const InputImage1Type * image )
-  { this->SetInput( image ); }
+    { this->SetInput( image ); }
 
   /** Set the second input. */
   void SetInput2( const InputImage2Type * image );
 
   /** Get the first input. */
   const InputImage1Type * GetInput1(void)
-  { return this->GetInput(); }
+    { return this->GetInput(); }
   
   /** Get the second input. */
   const InputImage2Type * GetInput2(void);
   
   /** Return the computed directed Hausdorff distance. */
-  itkGetMacro(DirectedHausdorffDistance,RealType);
+  itkGetConstMacro(DirectedHausdorffDistance,RealType);
+  itkGetConstMacro(AverageHausdorffDistance,RealType);
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   /** Begin concept checking */
@@ -126,8 +127,9 @@ protected:
   ~DirectedHausdorffDistanceImageFilter(){};
   void PrintSelf(std::ostream& os, Indent indent) const;
 
-  /** Pass the input through unmodified. Do this by Grafting in the AllocateOutputs method. */
-  void AllocateOutputs();      
+  /** Pass the input through unmodified. Do this by Grafting in the
+   * AllocateOutputs method. */
+  void AllocateOutputs();
 
   /** Initialize some accumulators before the threads run. */
   void BeforeThreadedGenerateData ();
@@ -138,7 +140,7 @@ protected:
   /** Multi-thread version GenerateData. */
   void  ThreadedGenerateData (const RegionType& 
                               outputRegionForThread,
-                              int threadId) ;
+                              int threadId);
 
   // Override since the filter needs all the data for the algorithm
   void GenerateInputRequestedRegion();
@@ -154,9 +156,12 @@ private:
   
   typename DistanceMapType::Pointer   m_DistanceMap;
   Array<RealType>                     m_MaxDistance;
+  Array<unsigned int>                 m_PixelCount;
+  Array<RealType>                     m_Sum;
   RealType                            m_DirectedHausdorffDistance;
+  RealType                            m_AverageHausdorffDistance;
 
-} ; // end of class
+}; // end of class
 
 } // end namespace itk
   
