@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGrayscaleGeodesicErodeImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-17 14:22:27 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-04-25 12:27:26 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -67,22 +67,22 @@ public:
   /** Standard class typedefs. */
   typedef GrayscaleGeodesicErodeImageFilter Self;
   typedef ImageToImageFilter<TInputImage, TOutputImage>
-  Superclass;
-  typedef SmartPointer<Self>        Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+                                            Superclass;
+  typedef SmartPointer<Self>                Pointer;
+  typedef SmartPointer<const Self>          ConstPointer;
 
   /** Some convenient typedefs. */
-  typedef TInputImage MarkerImageType;
-  typedef TInputImage MaskImageType;
-  typedef TOutputImage OutputImageType;
+  typedef TInputImage                              MarkerImageType;
   typedef typename MarkerImageType::Pointer        MarkerImagePointer;
   typedef typename MarkerImageType::ConstPointer   MarkerImageConstPointer;
   typedef typename MarkerImageType::RegionType     MarkerImageRegionType;
   typedef typename MarkerImageType::PixelType      MarkerImagePixelType;
+  typedef TInputImage                              MaskImageType;
   typedef typename MaskImageType::Pointer          MaskImagePointer;
   typedef typename MaskImageType::ConstPointer     MaskImageConstPointer;
   typedef typename MaskImageType::RegionType       MaskImageRegionType;
   typedef typename MaskImageType::PixelType        MaskImagePixelType;
+  typedef TOutputImage                             OutputImageType;
   typedef typename OutputImageType::Pointer        OutputImagePointer;
   typedef typename OutputImageType::ConstPointer   OutputImageConstPointer;
   typedef typename OutputImageType::RegionType     OutputImageRegionType;
@@ -119,12 +119,12 @@ public:
    * convergence. When run to convergence, this filter is equivalent
    * to "reconstruction by erosion". Default is off. */
   itkSetMacro(RunOneIteration, bool);
-  itkGetMacro(RunOneIteration, bool);
+  itkGetConstMacro(RunOneIteration, bool);
   itkBooleanMacro(RunOneIteration);
 
   /** Get the number of iterations used to produce the current
    * output. */
-  itkGetMacro(NumberOfIterationsUsed, unsigned long);
+  itkGetConstMacro(NumberOfIterationsUsed, unsigned long);
 
   /**
    * Set/Get whether the connected components are defined strictly by
@@ -180,17 +180,17 @@ protected:
    * called. */
   void ThreadedGenerateData (const OutputImageRegionType& 
                              outputRegionForThread,
-                             int threadId) ;
+                             int threadId);
 
 private:
   GrayscaleGeodesicErodeImageFilter(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
 
-  bool m_RunOneIteration;
+  bool          m_RunOneIteration;
   unsigned long m_NumberOfIterationsUsed;
-  bool m_FullyConnected;
+  bool          m_FullyConnected;
 
-} ; // end of class
+}; // end of class
 
 } // end namespace itk
   
@@ -199,5 +199,3 @@ private:
 #endif
 
 #endif
-
-
