@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkHConvexImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-10-16 14:22:34 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-04-25 12:27:26 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -45,19 +45,19 @@ class ITK_EXPORT HConvexImageFilter :
 {
 public:
   /** Standard class typedefs. */
-  typedef HConvexImageFilter Self;
+  typedef HConvexImageFilter        Self;
   typedef ImageToImageFilter<TInputImage, TOutputImage>
-  Superclass;
+                                    Superclass;
   typedef SmartPointer<Self>        Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
 
   /** Some convenient typedefs. */
-  typedef TInputImage InputImageType;
-  typedef TOutputImage OutputImageType;
+  typedef TInputImage                              InputImageType;
   typedef typename InputImageType::Pointer         InputImagePointer;
   typedef typename InputImageType::ConstPointer    InputImageConstPointer;
   typedef typename InputImageType::RegionType      InputImageRegionType;
   typedef typename InputImageType::PixelType       InputImagePixelType;
+  typedef TOutputImage                             OutputImageType;
   typedef typename OutputImageType::Pointer        OutputImagePointer;
   typedef typename OutputImageType::ConstPointer   OutputImageConstPointer;
   typedef typename OutputImageType::RegionType     OutputImageRegionType;
@@ -81,7 +81,7 @@ public:
    * processing. Local maxima below this value are replaced with an
    * estimate of the local background. */
   itkSetMacro(Height, InputImagePixelType);
-  itkGetMacro(Height, InputImagePixelType);
+  itkGetConstMacro(Height, InputImagePixelType);
   
   /** \deprecated
    * Get the number of iterations used to produce the current
@@ -122,7 +122,7 @@ protected:
   /** HConvexImageFilter needs the entire input be
    * available. Thus, it needs to provide an implementation of
    * GenerateInputRequestedRegion(). */
-  void GenerateInputRequestedRegion() ;
+  void GenerateInputRequestedRegion();
 
   /** HConvexImageFilter will produce the entire output. */
   void EnlargeOutputRequestedRegion(DataObject *itkNotUsed(output));
@@ -137,9 +137,9 @@ private:
   void operator=(const Self&); //purposely not implemented
 
   InputImagePixelType m_Height;
-  unsigned long m_NumberOfIterationsUsed;
+  unsigned long       m_NumberOfIterationsUsed;
   bool                m_FullyConnected;
-} ; // end of class
+}; // end of class
 
 } // end namespace itk
   
@@ -148,5 +148,3 @@ private:
 #endif
 
 #endif
-
-
