@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkHausdorffDistanceImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-28 19:59:05 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2009-04-25 12:27:26 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -62,10 +62,10 @@ class ITK_EXPORT HausdorffDistanceImageFilter :
 {
 public:
   /** Standard Self typedef */
-  typedef HausdorffDistanceImageFilter Self;
+  typedef HausdorffDistanceImageFilter                   Self;
   typedef ImageToImageFilter<TInputImage1,TInputImage1>  Superclass;
-  typedef SmartPointer<Self>        Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                             Pointer;
+  typedef SmartPointer<const Self>                       ConstPointer;
   
   /** Method for creation through the object factory. */
   itkNewMacro(Self);  
@@ -74,16 +74,16 @@ public:
   itkTypeMacro(HausdorffDistanceImageFilter, ImageToImageFilter);
   
   /** Image related typedefs. */
-  typedef TInputImage1 InputImage1Type;
-  typedef TInputImage2 InputImage2Type;
-  typedef typename TInputImage1::Pointer InputImage1Pointer;
-  typedef typename TInputImage2::Pointer InputImage2Pointer;
+  typedef TInputImage1                        InputImage1Type;
+  typedef TInputImage2                        InputImage2Type;
+  typedef typename TInputImage1::Pointer      InputImage1Pointer;
+  typedef typename TInputImage2::Pointer      InputImage2Pointer;
   typedef typename TInputImage1::ConstPointer InputImage1ConstPointer;
   typedef typename TInputImage2::ConstPointer InputImage2ConstPointer;
 
-  typedef typename TInputImage1::RegionType RegionType ;
-  typedef typename TInputImage1::SizeType SizeType ;
-  typedef typename TInputImage1::IndexType IndexType ;
+  typedef typename TInputImage1::RegionType RegionType;
+  typedef typename TInputImage1::SizeType   SizeType;
+  typedef typename TInputImage1::IndexType  IndexType;
 
   typedef typename TInputImage1::PixelType InputImage1PixelType;
   typedef typename TInputImage2::PixelType InputImage2PixelType;
@@ -97,20 +97,21 @@ public:
 
   /** Set the first input. */
   void SetInput1( const InputImage1Type * image )
-  { this->SetInput( image ); }
+    { this->SetInput( image ); }
 
   /** Set the second input. */
   void SetInput2( const InputImage2Type * image );
 
   /** Get the first input. */
   const InputImage1Type * GetInput1(void)
-  { return this->GetInput(); }
+    { return this->GetInput(); }
   
   /** Get the second input. */
   const InputImage2Type * GetInput2(void);
   
   /** Return the computed Hausdorff distance. */
-  itkGetMacro(HausdorffDistance,RealType);
+  itkGetConstMacro(HausdorffDistance,RealType);
+  itkGetConstMacro(AverageHausdorffDistance,RealType);
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   /** Begin concept checking */
@@ -138,8 +139,9 @@ private:
   void operator=(const Self&); //purposely not implemented
 
   RealType                            m_HausdorffDistance;
+  RealType                            m_AverageHausdorffDistance;
 
-} ; // end of class
+}; // end of class
 
 } // end namespace itk
   
