@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkHoughTransform2DLinesImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-29 14:53:39 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2010-02-03 18:53:41 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -67,12 +67,12 @@ public:
   typedef HoughTransform2DLinesImageFilter Self;
 
   /** Input Image typedef */
-  typedef Image<TInputPixelType,2> InputImageType;
-  typedef typename InputImageType::Pointer InputImagePointer;
+  typedef Image<TInputPixelType,2>              InputImageType;
+  typedef typename InputImageType::Pointer      InputImagePointer;
   typedef typename InputImageType::ConstPointer InputImageConstPointer;
   
   /** Output Image typedef */
-  typedef Image<TOutputPixelType,2> OutputImageType;
+  typedef Image<TOutputPixelType,2>         OutputImageType;
   typedef typename OutputImageType::Pointer OutputImagePointer;
 
   /** Smart pointer typedef support. */
@@ -111,7 +111,7 @@ public:
   itkSetMacro(Threshold,float);
 
   /** Get the threshold value */
-  itkGetMacro(Threshold,float);
+  itkGetConstMacro(Threshold,float);
 
   /** Set the resolution angle:
       The hough space descibes (in the angle direction) [-PI,PI[
@@ -119,7 +119,7 @@ public:
   itkSetMacro(AngleResolution,float);
 
   /** Get the resolution angle */
-  itkGetMacro(AngleResolution,float);
+  itkGetConstMacro(AngleResolution,float);
 
   /** Simplify the accumulator */
   void Simplify(void);
@@ -132,16 +132,16 @@ public:
 
   /** Set/Get the number of lines to extract */
   itkSetMacro(NumberOfLines,unsigned int);
-  itkGetMacro(NumberOfLines,unsigned int);
+  itkGetConstMacro(NumberOfLines,unsigned int);
 
   /** Set/Get the radius of the disc to remove from the accumulator
    *  for each line found */
   itkSetMacro(DiscRadius,float);
-  itkGetMacro(DiscRadius,float);
+  itkGetConstMacro(DiscRadius,float);
 
   /** Set the variance of the gaussian bluring for the accumulator */
   itkSetMacro(Variance,float);
-  itkGetMacro(Variance,float);
+  itkGetConstMacro(Variance,float);
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   /** Begin concept checking */
@@ -159,9 +159,6 @@ protected:
   HoughTransform2DLinesImageFilter();
   virtual ~HoughTransform2DLinesImageFilter() {};
 
-  HoughTransform2DLinesImageFilter(const Self&) {}
-  void operator=(const Self&) {}
-
   void PrintSelf(std::ostream& os, Indent indent) const;
 
   /** HoughTransform2DLinesImageFilter needs the entire input. Therefore
@@ -182,15 +179,18 @@ protected:
   
 private:
 
-  float m_AngleResolution;
-  float m_Threshold;
+  HoughTransform2DLinesImageFilter(const Self&);
+  void operator=(const Self&);
+
+  float              m_AngleResolution;
+  float              m_Threshold;
   OutputImagePointer m_SimplifyAccumulator;
-  LinesListType m_LinesList;
-  unsigned int  m_NumberOfLines;
-  float         m_DiscRadius;
-  float         m_Variance;
-  unsigned long m_OldModifiedTime;
-  unsigned long m_OldNumberOfLines;
+  LinesListType      m_LinesList;
+  unsigned int       m_NumberOfLines;
+  float              m_DiscRadius;
+  float              m_Variance;
+  unsigned long      m_OldModifiedTime;
+  unsigned long      m_OldNumberOfLines;
 };
 
 } // end namespace itk
