@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkInterpolateImagePointsFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-29 14:53:40 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-04-25 12:27:27 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -76,10 +76,10 @@ class ITK_EXPORT InterpolateImagePointsFilter :
 {
 public:
   /** Standard class typedefs. */
-  typedef InterpolateImagePointsFilter       Self;
+  typedef InterpolateImagePointsFilter                  Self;
   typedef ImageToImageFilter<TInputImage, TOutputImage> Superclass;
-  typedef SmartPointer<Self>                 Pointer;
-  typedef SmartPointer<const Self>           ConstPointer;
+  typedef SmartPointer<Self>                            Pointer;
+  typedef SmartPointer<const Self>                      ConstPointer;
 
   /** Run-time type information (and related methods). */
   itkTypeMacro(InterpolateImagePointsFilter, ImageToImageFilter);
@@ -92,23 +92,21 @@ public:
   itkStaticConstMacro(ImageDimension, unsigned int, TInputImage::ImageDimension );
 
   /** Typedefs from the Superclass */
-  typedef typename Superclass::InputImageType InputImageType;
-  typedef typename Superclass::OutputImageType OutputImageType;
+  typedef typename Superclass::InputImageType    InputImageType;
+  typedef typename Superclass::OutputImageType   OutputImageType;
   typedef typename Superclass::InputImagePointer InputImagePointer;
 
   /** Typedefs to describe and access output image. */
-  typedef typename TOutputImage::Pointer OutputImagePointer;
-  typedef ImageRegionIterator<InputImageType> OutputImageIterator;
-  typedef typename OutputImageType::RegionType             OutputImageRegionType;
+  typedef typename TOutputImage::Pointer       OutputImagePointer;
+  typedef ImageRegionIterator<InputImageType>  OutputImageIterator;
+  typedef typename OutputImageType::RegionType OutputImageRegionType;
 
   /** Image pixel value typedef. */
   typedef typename TOutputImage::PixelType   PixelType;
 
-
-
   /** Typedefs to describe and access Interpolator */
-  typedef typename InterpolatorType::Pointer InterpolatorPointer;
-  typedef typename InterpolatorType::ContinuousIndexType    ContinuousIndexType;
+  typedef typename InterpolatorType::Pointer              InterpolatorPointer;
+  typedef typename InterpolatorType::ContinuousIndexType  ContinuousIndexType;
 
   /** Typedefs to describe and access coordinate images */
   typedef Image< TCoordType, itkGetStaticConstMacro(ImageDimension) > CoordImageType;
@@ -130,11 +128,11 @@ public:
   itkSetMacro(DefaultPixelValue,PixelType);
 
   /** Get the pixel value when a transformed pixel is outside of the image */
-  itkGetMacro(DefaultPixelValue,PixelType);
+  itkGetConstMacro(DefaultPixelValue,PixelType);
 
   /** Returns a pointer to the  interpolator. */
   InterpolatorPointer GetInterpolator()
-  {  return m_Interpolator;  }
+    { return m_Interpolator; }
    
   /** Overloaded to ensure that output is sized the same as the coordinate inputs
     * and not the size of the input image. */
@@ -153,7 +151,6 @@ public:
 protected:
   /** Main function for calculating interpolated values at each coordinate 
     * set.  Access is through the update() call. */
-//  void EvaluateAtContinuousIndex( OutputImagePointer );
 
   /** TODO:  This needs to be modified for a threaded implementation.
     */
@@ -168,9 +165,9 @@ protected:
 private:
 
   /** Typedefs to describe and access coordinate images */
-  typedef typename CoordImageType::Pointer CoordImageTypePointer;
-  typedef ImageRegionConstIterator<CoordImageType>   CoordImageIterator;
-  typedef typename CoordImageType::RegionType              CoordImageRegionType;
+  typedef typename CoordImageType::Pointer         CoordImageTypePointer;
+  typedef ImageRegionConstIterator<CoordImageType> CoordImageIterator;
+  typedef typename CoordImageType::RegionType      CoordImageRegionType;
 
   InterpolateImagePointsFilter( const Self& ); //purposely not implemented
   void operator=( const Self& ); //purposely not implemented
