@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkInverseDeformationFieldImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-29 14:53:40 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-04-25 12:27:27 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -66,15 +66,16 @@ class ITK_EXPORT InverseDeformationFieldImageFilter:
 {
 public:
   /** Standard class typedefs. */
-  typedef InverseDeformationFieldImageFilter         Self;
+  typedef InverseDeformationFieldImageFilter            Self;
   typedef ImageToImageFilter<TInputImage,TOutputImage>  Superclass;
-  typedef SmartPointer<Self>        Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
-  typedef TInputImage InputImageType;
-  typedef TOutputImage OutputImageType;
+  typedef SmartPointer<Self>                            Pointer;
+  typedef SmartPointer<const Self>                      ConstPointer;
+
+  typedef TInputImage                           InputImageType;
   typedef typename InputImageType::Pointer      InputImagePointer;
   typedef typename InputImageType::ConstPointer InputImageConstPointer;
   typedef typename InputImageType::RegionType   InputImageRegionType;
+  typedef TOutputImage                          OutputImageType;
   typedef typename OutputImageType::Pointer     OutputImagePointer;
 
   /** Method for creation through the object factory. */
@@ -91,8 +92,9 @@ public:
    *
    * \todo Check that input and output images have the same number of 
      * dimensions; this is required for consistency.  */
-  typedef KernelTransform<double, itkGetStaticConstMacro(ImageDimension)> KernelTransformType;
-  typedef typename KernelTransformType::Pointer KernelTransformPointerType;
+  typedef KernelTransform<
+    double, itkGetStaticConstMacro(ImageDimension)> KernelTransformType;
+  typedef typename KernelTransformType::Pointer     KernelTransformPointerType;
 
   /** Image size typedef. */
   typedef typename OutputImageType::SizeType SizeType;
@@ -145,7 +147,7 @@ public:
    * precise computation of the inverse field at the price of large memory
    * consumption and long computational time. */
   itkSetMacro( SubsamplingFactor, unsigned int );
-  itkGetMacro( SubsamplingFactor, unsigned int );
+  itkGetConstMacro( SubsamplingFactor, unsigned int );
 
   /** InverseDeformationFieldImageFilter produces an image which is a different size
    * than its input.  As such, it needs to provide an implementation
