@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLogImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:40 $
-  Version:   $Revision: 1.21 $
+  Date:      $Date: 2009-04-01 14:36:27 $
+  Version:   $Revision: 1.24 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -37,17 +37,17 @@ public:
   Log() {}
   ~Log() {}
   bool operator!=( const Log & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const Log & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  inline TOutput operator()( const TInput & A )
-  {
-    return (TOutput)vcl_log((double)A);
-  }
+    }
+  inline TOutput operator()( const TInput & A ) const
+    {
+    return static_cast<TOutput>( vcl_log( static_cast<double>( A ) ) );
+    }
 }; 
 }
 template <class TInputImage, class TOutputImage>
@@ -59,12 +59,13 @@ UnaryFunctorImageFilter<TInputImage,TOutputImage,
 {
 public:
   /** Standard class typedefs. */
-  typedef LogImageFilter  Self;
-  typedef UnaryFunctorImageFilter<TInputImage,TOutputImage, 
-                                  Function::Log< typename TInputImage::PixelType, 
-                                                 typename TOutputImage::PixelType> > Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef LogImageFilter                               Self;
+  typedef UnaryFunctorImageFilter<
+    TInputImage,TOutputImage, 
+    Function::Log< typename TInputImage::PixelType, 
+                   typename TOutputImage::PixelType> > Superclass;
+  typedef SmartPointer<Self>                           Pointer;
+  typedef SmartPointer<const Self>                     ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
