@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMinimumMaximumImageCalculator.h,v $
   Language:  C++
-  Date:      $Date: 2005-01-21 20:20:27 $
-  Version:   $Revision: 1.15 $
+  Date:      $Date: 2009-04-25 12:27:32 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -23,22 +23,23 @@
 namespace itk
 {
 
-/** This calculator computes the minimum and the maximum intensity values of
+/** \class MinimumMaximumImageCalculator
+ * This calculator computes the minimum and the maximum intensity values of
  * an image.  It is templated over input image type.  If only Maximum or
  * Minimum value is needed, just call ComputeMaximum() (ComputeMinimum())
  * otherwise Compute() will compute both.
  *
  * \ingroup Operators
  */
-template <class TInputImage>            
+template <class TInputImage>
 class ITK_EXPORT MinimumMaximumImageCalculator : public Object 
 {
 public:
   /** Standard class typedefs. */
   typedef MinimumMaximumImageCalculator Self;
-  typedef Object  Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef Object                        Superclass;
+  typedef SmartPointer<Self>            Pointer;
+  typedef SmartPointer<const Self>      ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -77,10 +78,10 @@ public:
   void Compute(void);
 
   /** Return the minimum intensity value. */
-  itkGetMacro(Minimum,PixelType);
+  itkGetConstMacro(Minimum,PixelType);
   
   /** Return the maximum intensity value. */
-  itkGetMacro(Maximum,PixelType);
+  itkGetConstMacro(Maximum,PixelType);
 
   /** Return the index of the minimum intensity value. */
   itkGetConstReferenceMacro(IndexOfMinimum,IndexType);
