@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMultiplyImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:41 $
-  Version:   $Revision: 1.25 $
+  Date:      $Date: 2009-04-01 14:36:31 $
+  Version:   $Revision: 1.27 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -40,15 +40,15 @@ public:
   Mult() {}
   ~Mult() {}
   bool operator!=( const Mult & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const Mult & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  inline TOutput operator()( const TInput1 & A, const TInput2 & B)
-  { return (TOutput)(A * B); }
+    }
+  inline TOutput operator()( const TInput1 & A, const TInput2 & B) const
+    { return (TOutput)(A * B); }
 }; 
 }
 
@@ -63,14 +63,14 @@ BinaryFunctorImageFilter<TInputImage1,TInputImage2,TOutputImage,
 {
 public:
   /** Standard class typedefs. */
-  typedef MultiplyImageFilter  Self;
+  typedef MultiplyImageFilter       Self;
   typedef BinaryFunctorImageFilter<TInputImage1,TInputImage2,TOutputImage, 
                                    Function::Mult< 
     typename TInputImage1::PixelType, 
     typename TInputImage2::PixelType,
     typename TOutputImage::PixelType>   
-  > Superclass;
-  typedef SmartPointer<Self>   Pointer;
+  >                                 Superclass;
+  typedef SmartPointer<Self>        Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
 
   /** Method for creation through the object factory. */
