@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNeighborhoodConnectedImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-10-05 10:31:58 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-04-25 12:27:41 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -20,7 +20,7 @@
 #include "itkImage.h"
 #include "itkImageToImageFilter.h"
 
-namespace itk{
+namespace itk {
 
 /** \class NeighborhoodConnectedImageFilter
  * \brief Label pixels that are connected to a seed and lie within a neighborhood
@@ -37,10 +37,10 @@ class ITK_EXPORT NeighborhoodConnectedImageFilter:
 {
 public:
   /** Standard class typedefs. */
-  typedef NeighborhoodConnectedImageFilter Self;
+  typedef NeighborhoodConnectedImageFilter             Self;
   typedef ImageToImageFilter<TInputImage,TOutputImage> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef SmartPointer<Self>                           Pointer;
+  typedef SmartPointer<const Self>                     ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -49,53 +49,43 @@ public:
   itkTypeMacro(NeighborhoodConnectedImageFilter,
                ImageToImageFilter);
 
-  typedef TInputImage InputImageType;
-  typedef typename InputImageType::Pointer InputImagePointer;
+  typedef TInputImage                         InputImageType;
+  typedef typename InputImageType::Pointer    InputImagePointer;
   typedef typename InputImageType::RegionType InputImageRegionType; 
-  typedef typename InputImageType::PixelType InputImagePixelType; 
-  typedef typename InputImageType::IndexType IndexType;
-  typedef typename InputImageType::SizeType InputImageSizeType;
+  typedef typename InputImageType::PixelType  InputImagePixelType; 
+  typedef typename InputImageType::IndexType  IndexType;
+  typedef typename InputImageType::SizeType   InputImageSizeType;
   
-  typedef TOutputImage OutputImageType;
-  typedef typename OutputImageType::Pointer OutputImagePointer;
+  typedef TOutputImage                         OutputImageType;
+  typedef typename OutputImageType::Pointer    OutputImagePointer;
   typedef typename OutputImageType::RegionType OutputImageRegionType; 
-  typedef typename OutputImageType::PixelType OutputImagePixelType; 
+  typedef typename OutputImageType::PixelType  OutputImagePixelType; 
   
   void PrintSelf ( std::ostream& os, Indent indent ) const;
 
   /** Clear the seeds */
-  void ClearSeeds()
-  {
-    m_Seeds.clear();
-    this->Modified();
-  }
+  void ClearSeeds();
+
   /** Set seed point. */
-  void SetSeed(const IndexType & seed)
-  {
-    this->ClearSeeds();
-    this->AddSeed ( seed );
-  }
+  void SetSeed(const IndexType & seed);
+
   /** Add a seed point */
-  void AddSeed ( const IndexType & seed )
-  {
-    m_Seeds.push_back ( seed );
-    this->Modified();
-  };
+  void AddSeed ( const IndexType & seed );
 
   /** Set/Get the lower threshold. The default is 0. */
   itkSetMacro(Lower, InputImagePixelType);
-  itkGetMacro(Lower, InputImagePixelType);
+  itkGetConstMacro(Lower, InputImagePixelType);
 
   /** Set/Get the upper threshold. The default is the largest possible
    *  value for the InputPixelType. */
   itkSetMacro(Upper, InputImagePixelType);
-  itkGetMacro(Upper, InputImagePixelType);
+  itkGetConstMacro(Upper, InputImagePixelType);
   
   /** Set/Get value to replace thresholded pixels. Pixels that lie *
    *  within Lower and Upper (inclusive) will be replaced with this
    *  value. The default is 1. */
   itkSetMacro(ReplaceValue, OutputImagePixelType);
-  itkGetMacro(ReplaceValue, OutputImagePixelType);
+  itkGetConstMacro(ReplaceValue, OutputImagePixelType);
 
   /** Set the radius of the neighborhood used for a mask. */
   itkSetMacro(Radius, InputImageSizeType);
@@ -128,10 +118,10 @@ protected:
   NeighborhoodConnectedImageFilter();
   ~NeighborhoodConnectedImageFilter(){};
   std::vector<IndexType> m_Seeds;
-  InputImagePixelType m_Lower;
-  InputImagePixelType m_Upper;
-  OutputImagePixelType m_ReplaceValue;
-  InputImageSizeType m_Radius;
+  InputImagePixelType    m_Lower;
+  InputImagePixelType    m_Upper;
+  OutputImagePixelType   m_ReplaceValue;
+  InputImageSizeType     m_Radius;
 
   
   // Override since the filter needs all the data for the algorithm
