@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNormalizedCorrelationImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-08-24 12:45:32 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2008-10-16 19:33:45 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -46,10 +46,11 @@ class ITK_EXPORT NormalizedCorrelationImageFilter :
 {
 public:
   /** Standard "Self" & Superclass typedef. */
-  typedef NormalizedCorrelationImageFilter Self;
-  typedef NeighborhoodOperatorImageFilter< TInputImage, TOutputImage, TOperatorValueType > Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef NormalizedCorrelationImageFilter          Self;
+  typedef NeighborhoodOperatorImageFilter<
+    TInputImage, TOutputImage, TOperatorValueType > Superclass;
+  typedef SmartPointer<Self>                        Pointer;
+  typedef SmartPointer<const Self>                  ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -76,19 +77,18 @@ public:
                       TMaskImage::ImageDimension);
   
   /** Image typedef support. */
-  typedef TInputImage  InputImageType;
-  typedef TMaskImage   MaskImageType;
-  typedef TOutputImage OutputImageType;
+  typedef TInputImage                      InputImageType;
+  typedef TMaskImage                       MaskImageType;
+  typedef TOutputImage                     OutputImageType;
   typedef typename InputImageType::Pointer InputImagePointer;
-  typedef typename MaskImageType::Pointer MaskImagePointer;
+  typedef typename MaskImageType::Pointer  MaskImagePointer;
   
   /** Typedef for generic boundary condition pointer. */
-  typedef ImageBoundaryCondition<OutputImageType> *
-  ImageBoundaryConditionPointerType;
+  typedef ImageBoundaryCondition<OutputImageType> *ImageBoundaryConditionPointerType;
 
   /** Superclass typedefs. */
   typedef typename Superclass::OutputImageRegionType OutputImageRegionType;
-  typedef typename Superclass::OperatorValueType         OperatorValueType;
+  typedef typename Superclass::OperatorValueType     OperatorValueType;
 
   /** Neighborhood types */
   typedef typename Superclass::OutputNeighborhoodType OutputNeighborhoodType;
@@ -107,9 +107,9 @@ public:
    * correlation. The elements of the template must be set prior to
    * calling SetTemplate(). */
   void SetTemplate(const OutputNeighborhoodType &t)
-  {
+    {
     this->SetOperator(t);
-  }
+    }
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   /** Begin concept checking */
@@ -164,4 +164,3 @@ private:
 #endif
 
 #endif
-
