@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkObjectMorphologyImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-29 14:43:58 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2009-04-25 12:27:45 $
+  Version:   $Revision: 1.10 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -75,21 +75,22 @@ class ITK_EXPORT ObjectMorphologyImageFilter :
 {
 public:
   /** Standard Self typedef */
-  typedef ObjectMorphologyImageFilter Self;
+  typedef ObjectMorphologyImageFilter                   Self;
   typedef ImageToImageFilter<TInputImage,TOutputImage>  Superclass;
-  typedef SmartPointer<Self>        Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                            Pointer;
+  typedef SmartPointer<const Self>                      ConstPointer;
   
   /** Runtime information support. */
   itkTypeMacro(ObjectMorphologyImageFilter, ImageToImageFilter);
   
   /** Image related typedefs. */
-  typedef TInputImage InputImageType;
-  typedef TOutputImage OutputImageType;
-  typedef typename TInputImage::RegionType RegionType ;
-  typedef typename TInputImage::SizeType SizeType ;
-  typedef typename TInputImage::IndexType IndexType ;
-  typedef typename TInputImage::PixelType PixelType ;
+  typedef TInputImage                      InputImageType;
+  typedef TOutputImage                     OutputImageType;
+  typedef typename TInputImage::RegionType RegionType;
+  typedef typename TInputImage::SizeType   SizeType;
+  typedef typename TInputImage::IndexType  IndexType;
+  typedef typename TInputImage::PixelType  PixelType;
+
   typedef typename Superclass::OutputImageRegionType OutputImageRegionType;
 
   typedef ImageBoundaryCondition<InputImageType> * 
@@ -109,19 +110,18 @@ public:
 
   /** Neighborhood iterator type. */
   typedef ConstNeighborhoodIterator<TInputImage> 
-  InputNeighborhoodIteratorType ;
-
+                                 InputNeighborhoodIteratorType;
   typedef NeighborhoodIterator<TOutputImage> 
-  OutputNeighborhoodIteratorType ;
+                                 OutputNeighborhoodIteratorType;
 
   /** Kernel typedef. */
   typedef TKernel KernelType;
   
   /** Kernel (structuring element) iterator. */
-  typedef typename KernelType::ConstIterator KernelIteratorType ;
+  typedef typename KernelType::ConstIterator KernelIteratorType;
   
   /** n-dimensional Kernel radius. */
-  typedef typename KernelType::SizeType RadiusType ;
+  typedef typename KernelType::SizeType RadiusType;
 
   /** Set kernel (structuring element). */
   itkSetMacro(Kernel, KernelType);
@@ -130,7 +130,7 @@ public:
   itkGetConstReferenceMacro(Kernel, KernelType);
 
   /** Get the pixel value being used to identify the object of interest */
-  itkGetMacro(ObjectValue, PixelType);
+  itkGetConstMacro(ObjectValue, PixelType);
 
   /** Set the pixel value being used to identify the object of interest */
   itkSetMacro(ObjectValue, PixelType);
@@ -140,7 +140,7 @@ public:
    * requested region is expanded by the radius of the structuring element.
    * If the request extends past the LargestPossibleRegion for the input,
    * the request is cropped by the LargestPossibleRegion. */
-  void GenerateInputRequestedRegion() ;
+  void GenerateInputRequestedRegion();
 
   /** Allows a user to override the internal boundary condition. Care should be
    * be taken to ensure that the overriding boundary condition is a persistent
@@ -156,7 +156,7 @@ public:
     { m_BoundaryCondition = &m_DefaultBoundaryCondition; }
   
   /** Get the current boundary condition. */
-  itkGetMacro(BoundaryCondition, ImageBoundaryConditionPointerType);
+  itkGetConstMacro(BoundaryCondition, ImageBoundaryConditionPointerType);
 
   /** Enable/disable the use of boundary condition.  Defaults to false.
    * if false, a neighborhood operator extends outside an image, it does
@@ -168,7 +168,7 @@ public:
    * if false, a neighborhood operator extends outside an image, it does
    * not consider that outside extent when determining if a pixel is on
    * an object's boundary. */
-  itkGetMacro(UseBoundaryCondition, bool);
+  itkGetConstMacro(UseBoundaryCondition, bool);
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   /** Begin concept checking */
@@ -198,7 +198,7 @@ protected:
   /** Multi-thread version GenerateData. */
   void  ThreadedGenerateData (const OutputImageRegionType& 
                               outputRegionForThread,
-                              int threadId) ;
+                              int threadId);
 
   /** Evaluate image neighborhood with kernel to find the new value 
    * for the center pixel value. */
@@ -221,7 +221,7 @@ protected:
   bool m_UseBoundaryCondition;
 
   /** kernel or structuring element to use. */
-  KernelType m_Kernel ;
+  KernelType m_Kernel;
 
   /** Pixel value that indicates the object be operated upon */
   PixelType m_ObjectValue;
@@ -234,7 +234,7 @@ private:
 
   
 
-} ; // end of class
+}; // end of class
 
 } // end namespace itk
   
