@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPadImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2005-04-27 12:54:57 $
-  Version:   $Revision: 1.13 $
+  Date:      $Date: 2009-07-12 10:52:52 $
+  Version:   $Revision: 1.16 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -18,6 +18,7 @@
 #define __itkPadImageFilter_h
 
 #include "itkImageToImageFilter.h"
+#include "itkSize.h"
 
 namespace itk
 {
@@ -43,27 +44,28 @@ class ITK_EXPORT PadImageFilter:
 {
 public:
   /** Standard class typedefs. */
-  typedef PadImageFilter         Self;
+  typedef PadImageFilter                                Self;
   typedef ImageToImageFilter<TInputImage,TOutputImage>  Superclass;
-  typedef SmartPointer<Self>  Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                            Pointer;
+  typedef SmartPointer<const Self>                      ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);  
 
   /** Typedef to describe the output and input image region types. */
   typedef typename TOutputImage::RegionType OutputImageRegionType;
-  typedef typename TInputImage::RegionType InputImageRegionType;
+  typedef typename TInputImage::RegionType  InputImageRegionType;
 
   /** Typedef to describe the type of pixel. */
   typedef typename TOutputImage::PixelType OutputImagePixelType;
-  typedef typename TInputImage::PixelType InputImagePixelType;
+  typedef typename TInputImage::PixelType  InputImagePixelType;
 
   /** Typedef to describe the output and input image index and size types. */
-  typedef typename TOutputImage::IndexType OutputImageIndexType;
-  typedef typename TInputImage::IndexType InputImageIndexType;
-  typedef typename TOutputImage::SizeType OutputImageSizeType;
-  typedef typename TInputImage::SizeType InputImageSizeType;
+  typedef typename TOutputImage::IndexType      OutputImageIndexType;
+  typedef typename TInputImage::IndexType       InputImageIndexType;
+  typedef typename TOutputImage::SizeType       OutputImageSizeType;
+  typedef typename TInputImage::SizeType        InputImageSizeType;
+  typedef typename TInputImage::SizeValueType   SizeValueType;
 
   /** Run-time type information (and related methods). */
   itkTypeMacro(PadImageFilter, ImageToImageFilter);
@@ -74,11 +76,28 @@ public:
 
   /** Set/Get the output image padding.  Default is no padding 
    *  (same as input). */
-  itkSetVectorMacro(PadLowerBound, const unsigned long, ImageDimension);
-  itkSetVectorMacro(PadUpperBound, const unsigned long, ImageDimension);
-  itkGetVectorMacro(PadLowerBound, const unsigned long, ImageDimension);
-  itkGetVectorMacro(PadUpperBound, const unsigned long, ImageDimension);
+  itkSetVectorMacro(PadLowerBound, const SizeValueType, ImageDimension);
+  itkSetVectorMacro(PadUpperBound, const SizeValueType, ImageDimension);
+  itkGetVectorMacro(PadLowerBound, const SizeValueType, ImageDimension);
+  itkGetVectorMacro(PadUpperBound, const SizeValueType, ImageDimension);
                  
+  
+  void SetPadLowerBound(const InputImageSizeType & bound)
+    {
+    this->SetPadLowerBound( bound.m_Size );
+    }
+    
+  void SetPadUpperBound(const InputImageSizeType & bound)
+    {
+    this->SetPadUpperBound( bound.m_Size );
+    }
+    
+  void SetPadBound(const InputImageSizeType & bound)
+    {
+    this->SetPadLowerBound( bound );
+    this->SetPadUpperBound( bound );
+    }
+
   /** PadImageFilter produces an image which is a different resolution
    * than its input image.  As such, PadImageFilter needs to
    * provide an implementation for GenerateOutputInformation() in order
@@ -103,8 +122,8 @@ private:
   PadImageFilter(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
 
-  unsigned long m_PadLowerBound[ImageDimension];
-  unsigned long m_PadUpperBound[ImageDimension];
+  SizeValueType    m_PadLowerBound[ImageDimension];
+  SizeValueType    m_PadUpperBound[ImageDimension];
 };
 
   
