@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRescaleIntensityImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:41 $
-  Version:   $Revision: 1.15 $
+  Date:      $Date: 2010-01-25 23:37:03 $
+  Version:   $Revision: 1.18 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -32,19 +32,19 @@ class IntensityLinearTransform
 public:
   typedef typename NumericTraits< TInput >::RealType RealType;
   IntensityLinearTransform()
-  {
+    {
     m_Factor = 1.0;
     m_Offset = 0.0;
     m_Minimum = NumericTraits<TOutput>::NonpositiveMin();
     m_Maximum = NumericTraits<TOutput>::max();
-  }
+    }
   ~IntensityLinearTransform() {}
   void SetFactor( RealType a ) { m_Factor = a; }
   void SetOffset( RealType b ) { m_Offset = b; }
   void SetMinimum( TOutput min ) { m_Minimum = min; }
   void SetMaximum( TOutput max ) { m_Maximum = max; }
   bool operator!=( const IntensityLinearTransform & other ) const
-  {
+    {
     if( m_Factor != other.m_Factor ||
         m_Offset != other.m_Offset ||
         m_Maximum != other.m_Maximum    ||
@@ -53,19 +53,19 @@ public:
       return true;
       }
     return false;
-   }
+    }
   bool operator==( const IntensityLinearTransform & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  inline TOutput operator()( const TInput & x )
-  {
+    }
+  inline TOutput operator()( const TInput & x ) const
+    {
     RealType value  = static_cast<RealType>(x) * m_Factor + m_Offset;
     TOutput  result = static_cast<TOutput>( value );
     result = ( result > m_Maximum ) ? m_Maximum : result;
     result = ( result < m_Minimum ) ? m_Minimum : result;
     return result;
-  }
+    }
 private:
   RealType m_Factor;
   RealType m_Offset;
@@ -85,6 +85,14 @@ private:
  * is defined by the user in terms of the minimum and maximum values that 
  * the output image should have.
  * 
+ * The following equation gives the mapping of the intensity values
+ *
+ * \par
+ * \f[ 
+ *  \[ outputPixel = ( inputPixel - inputMin) \times 
+ *  \frac{(outputMax - outputMin )}{(inputMax - inputMin)} + outputMin \]
+ * \f]
+ *
  * All computations are performed in the precison of the input pixel's 
  * RealType. Before assigning the computed value to the output pixel. 
  *
@@ -93,7 +101,7 @@ private:
  * supposed to set those values in this filter. If you need a filter where you
  * can set the minimum and maximum values of the input, please use the
  * IntensityWindowingImageFilter. If you want a filter that can use a
- * user-defined linear transformation for the intensity, then please use teh
+ * user-defined linear transformation for the intensity, then please use the
  * ShiftScaleImageFilter.
  *
  * \sa IntensityWindowingImageFilter
@@ -111,16 +119,17 @@ UnaryFunctorImageFilter<TInputImage,TOutputImage,
 {
 public:
   /** Standard class typedefs. */
-  typedef RescaleIntensityImageFilter  Self;
-  typedef UnaryFunctorImageFilter<TInputImage,TOutputImage, 
-                                  Functor::IntensityLinearTransform< 
-    typename TInputImage::PixelType, 
-    typename TOutputImage::PixelType> >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef RescaleIntensityImageFilter      Self;
+  typedef UnaryFunctorImageFilter<
+    TInputImage,TOutputImage, 
+    Functor::IntensityLinearTransform< 
+      typename TInputImage::PixelType, 
+      typename TOutputImage::PixelType> >  Superclass;
+  typedef SmartPointer<Self>               Pointer;
+  typedef SmartPointer<const Self>         ConstPointer;
 
-  typedef typename TOutputImage::PixelType OutputPixelType;
-  typedef typename TInputImage::PixelType  InputPixelType;
+  typedef typename TOutputImage::PixelType                 OutputPixelType;
+  typedef typename TInputImage::PixelType                  InputPixelType;
   typedef typename NumericTraits<InputPixelType>::RealType RealType;
 
   /** Method for creation through the object factory. */
