@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSimpleContourExtractorImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-30 15:36:25 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2008-10-17 20:49:56 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -17,6 +17,16 @@
 #ifndef __itkSimpleContourExtractorImageFilter_h
 #define __itkSimpleContourExtractorImageFilter_h
 
+
+// First make sure that the configuration is available.
+// This line can be removed once the optimized versions
+// gets integrated into the main directories.
+#include "itkConfigure.h"
+
+#ifdef ITK_USE_CONSOLIDATED_MORPHOLOGY
+#include "itkOptSimpleContourExtractorImageFilter.h"
+#else
+
 #include "itkImageToImageFilter.h"
 #include "itkImage.h"
 #include "itkNumericTraits.h"
@@ -55,14 +65,14 @@ public:
     TOutputImage::ImageDimension);
   
   /** Convenient typedefs for simplifying declarations. */
-  typedef TInputImage InputImageType;
+  typedef TInputImage  InputImageType;
   typedef TOutputImage OutputImageType;
   
   /** Standard class typedefs. */
-  typedef SimpleContourExtractorImageFilter Self;
+  typedef SimpleContourExtractorImageFilter                    Self;
   typedef ImageToImageFilter< InputImageType, OutputImageType> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                                   Pointer;
+  typedef SmartPointer<const Self>                             ConstPointer;
   
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -71,11 +81,11 @@ public:
   itkTypeMacro(SimpleContourExtractorImageFilter, ImageToImageFilter);
   
   /** Image typedef support. */
-  typedef typename InputImageType::PixelType InputPixelType;
-  typedef typename OutputImageType::PixelType OutputPixelType;
+  typedef typename InputImageType::PixelType               InputPixelType;
+  typedef typename OutputImageType::PixelType              OutputPixelType;
   typedef typename NumericTraits<InputPixelType>::RealType InputRealType;
   
-  typedef typename InputImageType::RegionType InputImageRegionType;
+  typedef typename InputImageType::RegionType  InputImageRegionType;
   typedef typename OutputImageType::RegionType OutputImageRegionType;
   
   typedef typename InputImageType::SizeType InputSizeType;
@@ -121,12 +131,12 @@ public:
   itkGetConstReferenceMacro(OutputBackgroundValue, OutputPixelType);
   
   /** SimpleContourExtractorImageFilter needs a larger input requested
-  * region than the output requested region.  As such,
-  * SimpleContourExtractorImageFilter needs to provide an
-  * implementation for GenerateInputRequestedRegion() in order to
-  * inform the pipeline execution model. 
-  *
-  * \sa ImageToImageFilter::GenerateInputRequestedRegion() */
+   * region than the output requested region.  As such,
+   * SimpleContourExtractorImageFilter needs to provide an
+   * implementation for GenerateInputRequestedRegion() in order to
+   * inform the pipeline execution model. 
+   *
+   * \sa ImageToImageFilter::GenerateInputRequestedRegion() */
   virtual void GenerateInputRequestedRegion() throw(InvalidRequestedRegionError);
 
 #ifdef ITK_USE_CONCEPT_CHECKING
@@ -161,9 +171,9 @@ private:
   SimpleContourExtractorImageFilter(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
   
-  InputSizeType m_Radius;
-  InputPixelType m_InputForegroundValue;
-  InputPixelType m_InputBackgroundValue;
+  InputSizeType   m_Radius;
+  InputPixelType  m_InputForegroundValue;
+  InputPixelType  m_InputBackgroundValue;
   OutputPixelType m_OutputForegroundValue;
   OutputPixelType m_OutputBackgroundValue;
 };
@@ -175,3 +185,5 @@ private:
 #endif
 
 #endif
+
+#endif
