@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTanImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:41 $
-  Version:   $Revision: 1.21 $
+  Date:      $Date: 2009-04-01 14:36:36 $
+  Version:   $Revision: 1.23 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -37,15 +37,15 @@ public:
   Tan() {}
   ~Tan() {}
   bool operator!=( const Tan & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const Tan & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  inline TOutput operator()( const TInput & A )
-  { return (TOutput)vcl_tan((double)A); }
+    }
+  inline TOutput operator()( const TInput & A ) const
+    { return (TOutput)vcl_tan((double)A); }
 }; 
 }
 template <class TInputImage, class TOutputImage>
@@ -57,12 +57,13 @@ UnaryFunctorImageFilter<TInputImage,TOutputImage,
 {
 public:
   /** Standard class typedefs. */
-  typedef TanImageFilter  Self;
-  typedef UnaryFunctorImageFilter<TInputImage,TOutputImage, 
-                                  Function::Tan< typename TInputImage::PixelType, 
-                                                 typename TOutputImage::PixelType> >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef TanImageFilter                                Self;
+  typedef UnaryFunctorImageFilter<
+    TInputImage,TOutputImage, 
+    Function::Tan< typename TInputImage::PixelType, 
+                   typename TOutputImage::PixelType> >  Superclass;
+  typedef SmartPointer<Self>                            Pointer;
+  typedef SmartPointer<const Self>                      ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
