@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTensorFractionalAnisotropyImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-10-27 19:51:42 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-04-01 14:36:36 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -34,14 +34,14 @@ public:
   TensorFractionalAnisotropyFunction() {}
   ~TensorFractionalAnisotropyFunction() {}
   bool operator!=( const TensorFractionalAnisotropyFunction & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const TensorFractionalAnisotropyFunction & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  inline RealValueType operator()( const TInput & x )
+    }
+  inline RealValueType operator()( const TInput & x ) const
     {
     return x.GetFractionalAnisotropy();
     }
@@ -74,12 +74,12 @@ UnaryFunctorImageFilter<TInputImage,TOutputImage,
 public:
   /** Standard class typedefs. */
   typedef TensorFractionalAnisotropyImageFilter  Self;
-  typedef UnaryFunctorImageFilter<TInputImage,TOutputImage, 
-                                  Functor::TensorFractionalAnisotropyFunction< 
-                                    typename TInputImage::PixelType> >  Superclass;
-
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef UnaryFunctorImageFilter<
+    TInputImage,TOutputImage, 
+    Functor::TensorFractionalAnisotropyFunction< 
+      typename TInputImage::PixelType> >         Superclass;
+  typedef SmartPointer<Self>                     Pointer;
+  typedef SmartPointer<const Self>               ConstPointer;
 
   typedef typename Superclass::OutputImageType    OutputImageType;
   typedef typename TOutputImage::PixelType        OutputPixelType;
