@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVectorCastImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:41 $
-  Version:   $Revision: 1.14 $
+  Date:      $Date: 2008-10-17 16:30:53 $
+  Version:   $Revision: 1.16 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -18,6 +18,7 @@
 #define __itkVectorCastImageFilter_h
 
 #include "itkUnaryFunctorImageFilter.h"
+#include "itkNumericTraitsFixedArrayPixel.h"
 
 namespace itk
 {
@@ -46,22 +47,24 @@ public:
   VectorCast() {}
   ~VectorCast() {}
   bool operator!=( const VectorCast & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const VectorCast & other ) const
-  {
+    {
     return !(*this != other);
-  }
+    }
   inline TOutput operator()( const TInput & A ) const
-  {
+    {
     typedef typename TOutput::ValueType OutputValueType;
 
     TOutput value;
     for( unsigned int k = 0; k < TOutput::Dimension; k++ )
-      { value[k] = static_cast<OutputValueType>( A[k] ); }
+      {
+      value[k] = static_cast<OutputValueType>( A[k] );
+      }
     return value;
-  }
+    }
 }; 
 }
 
@@ -74,12 +77,13 @@ UnaryFunctorImageFilter<TInputImage,TOutputImage,
 {
 public:
   /** Standard class typedefs. */
-  typedef VectorCastImageFilter  Self;
-  typedef UnaryFunctorImageFilter<TInputImage,TOutputImage, 
-                                  Functor::VectorCast< typename TInputImage::PixelType, 
-                                                       typename TOutputImage::PixelType> >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef VectorCastImageFilter                               Self;
+  typedef UnaryFunctorImageFilter<
+    TInputImage,TOutputImage, 
+    Functor::VectorCast< typename TInputImage::PixelType, 
+                         typename TOutputImage::PixelType> >  Superclass;
+  typedef SmartPointer<Self>                                  Pointer;
+  typedef SmartPointer<const Self>                            ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
