@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVectorConfidenceConnectedImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-04-03 15:07:52 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-04-25 12:28:11 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,10 +21,10 @@
 #include "itkImageToImageFilter.h"
 #include "itkMahalanobisDistanceThresholdImageFunction.h"
 
-namespace itk{
+namespace itk {
 
-/** /class VectorConfidenceConnectedImageFilter
- * /brief Segment pixels with similar statistics using connectivity
+/** \class VectorConfidenceConnectedImageFilter
+ * \brief Segment pixels with similar statistics using connectivity
  *
  * This filter extracts a connected set of pixels whose pixel
  * intensities are consistent with the pixel statistics of a seed
@@ -60,10 +60,10 @@ class ITK_EXPORT VectorConfidenceConnectedImageFilter:
 {
 public:
   /** Standard class typedefs. */
-  typedef VectorConfidenceConnectedImageFilter Self;
+  typedef VectorConfidenceConnectedImageFilter         Self;
   typedef ImageToImageFilter<TInputImage,TOutputImage> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef SmartPointer<Self>                           Pointer;
+  typedef SmartPointer<const Self>                     ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -72,14 +72,14 @@ public:
   itkTypeMacro(VectorConfidenceConnectedImageFilter,
                ImageToImageFilter);
 
-  typedef TInputImage InputImageType;
+  typedef TInputImage                           InputImageType;
   typedef typename InputImageType::Pointer      InputImagePointer;
   typedef typename InputImageType::RegionType   InputImageRegionType; 
   typedef typename InputImageType::PixelType    InputImagePixelType; 
   typedef typename InputImageType::IndexType    IndexType;
   typedef typename InputImageType::SizeType     SizeType;
   
-  typedef TOutputImage OutputImageType;
+  typedef TOutputImage                          OutputImageType;
   typedef typename OutputImageType::Pointer     OutputImagePointer;
   typedef typename OutputImageType::RegionType  OutputImageRegionType; 
   typedef typename OutputImageType::PixelType   OutputImagePixelType; 
@@ -100,31 +100,30 @@ public:
 
   /** Set seed point. This method is deprecated, please use AddSeed() */
   void SetSeed(const IndexType & seed)
-  {
+    {
     m_Seeds.clear();
     this->AddSeed( seed );
-  };
-
+    }
 
   /** Add seed point. */
   void AddSeed(const IndexType & seed)
-  {
+    {
     m_Seeds.push_back( seed );
     this->Modified();
-  };
+    }
 
   /** Set/Get the multiplier to define the confidence interval.  Multiplier
    * can be anything greater than zero. A typical value is 2.5 */
   itkSetMacro(Multiplier, double);
-  itkGetMacro(Multiplier, double);
+  itkGetConstMacro(Multiplier, double);
 
   /** Set/Get the number of iterations */
   itkSetMacro(NumberOfIterations, unsigned int);
-  itkGetMacro(NumberOfIterations, unsigned int);
+  itkGetConstMacro(NumberOfIterations, unsigned int);
 
   /** Set/Get value to replace thresholded pixels */
   itkSetMacro(ReplaceValue, OutputImagePixelType);
-  itkGetMacro(ReplaceValue, OutputImagePixelType);
+  itkGetConstMacro(ReplaceValue, OutputImagePixelType);
 
   /** Get/Set the radius of the neighborhood over which the
       statistics are evaluated */
