@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVectorConnectedComponentImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-09-26 12:05:05 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2010-03-02 03:40:37 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,7 +26,10 @@
 
 namespace itk
 {
-  
+
+namespace Functor 
+{  
+
 /** \class SimilarVectorsFunctor
  *
  *  \brief A connected components filter that labels the
@@ -35,43 +38,49 @@ namespace itk
  *         threshold.  Vectors that are 180 degrees out of phase
  *         are similar.  Assumes that vectors are normalized.
  */
-
-namespace Functor {  
   
 template<class TInput>
 class SimilarVectorsFunctor
 {
 public:
   SimilarVectorsFunctor()
-    {threshold = itk::NumericTraits<ITK_TYPENAME TInput::ValueType>::Zero;};
+    {m_Threshold = itk::NumericTraits<ITK_TYPENAME TInput::ValueType>::Zero;}
 
   ~SimilarVectorsFunctor() {};
 
   void SetDistanceThreshold(const typename TInput::ValueType &thresh)
-    {threshold = thresh;};
-  typename TInput::ValueType GetDistanceThreshold() {return (threshold);};
+    {m_Threshold = thresh;}
+  typename TInput::ValueType GetDistanceThreshold() {return (m_Threshold);}
   
   bool operator!=( const SimilarVectorsFunctor & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const SimilarVectorsFunctor & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  bool operator()(const TInput &a, const TInput &b)
+    }
+  bool operator()(const TInput &a, const TInput &b) const
     {
     typename TInput::ValueType dotProduct = vnl_math_abs(a * b);
-    return (1.0 - dotProduct <= threshold);
-    };
+    return (1.0 - dotProduct <= m_Threshold);
+    }
 
 protected:
-  typename TInput::ValueType threshold;
+  typename TInput::ValueType m_Threshold;
                             
 };
 
 } // end namespace Functor 
 
+/** \class VectorConnectedComponentImageFilter
+ *
+ *  \brief A connected components filter that labels the
+ *         objects in a vector image.  Two vectors are pointing
+ *         similar directions if one minus their dot product is less than a
+ *         threshold.  Vectors that are 180 degrees out of phase
+ *         are similar.  Assumes that vectors are normalized.
+ */
 template <class TInputImage, class TOutputImage, class TMaskImage=TInputImage>
 class ITK_EXPORT VectorConnectedComponentImageFilter :
     public ConnectedComponentFunctorImageFilter<TInputImage,TOutputImage,
@@ -83,9 +92,9 @@ public:
   typedef VectorConnectedComponentImageFilter Self;
   typedef ConnectedComponentFunctorImageFilter<TInputImage,TOutputImage, 
              Functor::SimilarVectorsFunctor<typename TInputImage::ValueType>,
-             TMaskImage> Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+             TMaskImage>                      Superclass;
+  typedef SmartPointer<Self>                  Pointer;
+  typedef SmartPointer<const Self>            ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
