@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVectorRescaleIntensityImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2008-01-28 17:24:05 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-04-01 14:36:37 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -36,19 +36,19 @@ public:
   void SetFactor( RealType a ) { m_Factor = a; }
   itkStaticConstMacro(VectorDimension,unsigned int,TInput::Dimension);
   bool operator!=( const VectorMagnitudeLinearTransform & other ) const
-  {
+    {
     if( m_Factor != other.m_Factor )
       {
       return true;
       }
     return false;
-   }
+    }
   bool operator==( const VectorMagnitudeLinearTransform & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  inline TOutput operator()( const TInput & x )
-  {
+    }
+  inline TOutput operator()( const TInput & x ) const
+    {
     TOutput  result;
     for(unsigned int i=0; i<VectorDimension; i++)
       {
@@ -56,7 +56,7 @@ public:
       result[i]= static_cast< typename TOutput::ValueType >( scaledComponent );
       }
     return result;
-  }
+    }
 private:
   RealType m_Factor;
 }; 
@@ -92,12 +92,13 @@ UnaryFunctorImageFilter<TInputImage,TOutputImage,
 public:
   /** Standard class typedefs. */
   typedef VectorRescaleIntensityImageFilter  Self;
-  typedef UnaryFunctorImageFilter<TInputImage,TOutputImage, 
-                                  Functor::VectorMagnitudeLinearTransform< 
-    typename TInputImage::PixelType, 
-    typename TOutputImage::PixelType> >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef UnaryFunctorImageFilter<
+    TInputImage,TOutputImage, 
+    Functor::VectorMagnitudeLinearTransform< 
+      typename TInputImage::PixelType, 
+      typename TOutputImage::PixelType> >    Superclass;
+  typedef SmartPointer<Self>                 Pointer;
+  typedef SmartPointer<const Self>           ConstPointer;
 
   typedef typename TOutputImage::PixelType                  OutputPixelType;
   typedef typename TInputImage::PixelType                   InputPixelType;
