@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVotingBinaryHoleFillingImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-23 15:24:22 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2010-04-01 20:51:27 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -47,14 +47,14 @@ public:
                       TOutputImage::ImageDimension);
 
   /** Convenient typedefs for simplifying declarations. */
-  typedef TInputImage InputImageType;
+  typedef TInputImage  InputImageType;
   typedef TOutputImage OutputImageType;
 
   /** Standard class typedefs. */
-  typedef VotingBinaryHoleFillingImageFilter Self;
+  typedef VotingBinaryHoleFillingImageFilter                        Self;
   typedef VotingBinaryImageFilter< InputImageType, OutputImageType> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                                        Pointer;
+  typedef SmartPointer<const Self>                                  ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -63,13 +63,14 @@ public:
   itkTypeMacro(VotingBinaryHoleFillingImageFilter, VotingBinaryImageFilter);
   
   /** Image typedef support. */
-  typedef typename InputImageType::PixelType InputPixelType;
+  typedef typename InputImageType::PixelType  InputPixelType;
   typedef typename OutputImageType::PixelType OutputPixelType;
 
-  typedef typename InputImageType::RegionType InputImageRegionType;
+  typedef typename InputImageType::RegionType  InputImageRegionType;
   typedef typename OutputImageType::RegionType OutputImageRegionType;
 
-  typedef typename InputImageType::SizeType InputSizeType;
+  typedef typename InputImageType::SizeType       InputSizeType;
+  typedef typename InputImageType::SizeValueType  SizeValueType;
 
 
   /** Majority threshold. It is the number of pixels over 50% that will decide
@@ -83,7 +84,7 @@ public:
 
 
   /** Returns the number of pixels that changed when the filter was executed. */
-  itkGetConstReferenceMacro( NumberOfPixelsChanged, unsigned int );
+  itkGetConstReferenceMacro( NumberOfPixelsChanged, SizeValueType );
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   /** Begin concept checking */
@@ -102,10 +103,10 @@ protected:
    /** Make protected the methods SetBirthThreshold() and
     * SetSurvivalThreshold() so users of this filter do not have access to
     * them. */
-  void SetBirthThreshold( const InputPixelType value ) 
-            { this->Superclass::SetBirthThreshold( value );  }
-  void SetSurvivalThreshold( const InputPixelType value ) 
-            { this->Superclass::SetSurvivalThreshold( value );  }
+  void SetBirthThreshold( const unsigned int value ) 
+    { this->Superclass::SetBirthThreshold( value );  }
+  void SetSurvivalThreshold( const unsigned int value ) 
+    { this->Superclass::SetSurvivalThreshold( value );  }
 
 
   /** VotingBinaryHoleFillingImageFilter can be implemented as a multithreaded filter.
@@ -130,12 +131,12 @@ private:
   VotingBinaryHoleFillingImageFilter(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
 
-  unsigned int m_MajorityThreshold;
+  unsigned int            m_MajorityThreshold;
 
-  unsigned int m_NumberOfPixelsChanged;
+  SizeValueType           m_NumberOfPixelsChanged;
 
   // Auxiliary array for multi-threading
-  Array<unsigned int>     m_Count;
+  Array<SizeValueType>    m_Count;
 };
   
 } // end namespace itk
