@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVotingBinaryImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-04-04 13:13:51 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2008-10-17 20:50:03 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -45,14 +45,14 @@ public:
                       TOutputImage::ImageDimension);
 
   /** Convenient typedefs for simplifying declarations. */
-  typedef TInputImage InputImageType;
+  typedef TInputImage  InputImageType;
   typedef TOutputImage OutputImageType;
 
   /** Standard class typedefs. */
-  typedef VotingBinaryImageFilter Self;
+  typedef VotingBinaryImageFilter                              Self;
   typedef ImageToImageFilter< InputImageType, OutputImageType> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                                   Pointer;
+  typedef SmartPointer<const Self>                             ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -61,10 +61,10 @@ public:
   itkTypeMacro(VotingBinaryImageFilter, ImageToImageFilter);
   
   /** Image typedef support. */
-  typedef typename InputImageType::PixelType InputPixelType;
+  typedef typename InputImageType::PixelType  InputPixelType;
   typedef typename OutputImageType::PixelType OutputPixelType;
 
-  typedef typename InputImageType::RegionType InputImageRegionType;
+  typedef typename InputImageType::RegionType  InputImageRegionType;
   typedef typename OutputImageType::RegionType OutputImageRegionType;
 
   typedef typename InputImageType::SizeType InputSizeType;
@@ -87,13 +87,13 @@ public:
  
   /** Birth threshold. Pixels that are OFF will turn ON when the number of
    * neighbors ON is larger than the value defined in this threshold. */
-  itkGetConstReferenceMacro(BirthThreshold, InputPixelType);
-  itkSetMacro(BirthThreshold, InputPixelType);
+  itkGetConstReferenceMacro(BirthThreshold, unsigned int);
+  itkSetMacro(BirthThreshold, unsigned int);
 
   /** Survival threshold. Pixels that are ON will turn OFF when the number of
    * neighbors ON is smaller than the value defined in this survival threshold. */
-  itkGetConstReferenceMacro(SurvivalThreshold, InputPixelType);
-  itkSetMacro(SurvivalThreshold, InputPixelType);
+  itkGetConstReferenceMacro(SurvivalThreshold, unsigned int);
+  itkSetMacro(SurvivalThreshold, unsigned int);
 
   /** VotingBinaryImageFilter needs a larger input requested region than
    * the output requested region.  As such, VotingBinaryImageFilter needs
@@ -145,8 +145,8 @@ private:
   InputPixelType     m_ForegroundValue;
   InputPixelType     m_BackgroundValue;
 
-  InputPixelType     m_BirthThreshold;
-  InputPixelType     m_SurvivalThreshold;
+  unsigned int       m_BirthThreshold;
+  unsigned int       m_SurvivalThreshold;
 };
   
 } // end namespace itk
