@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCellInterface.h,v $
   Language:  C++
-  Date:      $Date: 2007-04-06 12:50:58 $
-  Version:   $Revision: 1.66 $
+  Date:      $Date: 2009-08-08 20:13:35 $
+  Version:   $Revision: 1.72 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -51,12 +51,7 @@ virtual void Accept(unsigned long cellid, typename CellInterface<PixelType,\
   typedef AutoPointer<const Self>   ConstSelfAutoPointer;  \
   typedef AutoPointer<Self>         SelfAutoPointer;   \
   typedef Self *                    RawPointer;        \
-  typedef const Self *              ConstRawPointer;   \
-  SelfAutoPointer   New(void) {                        \
-                SelfAutoPointer ptr( new celltype );   \
-                ptr.TakeOwnership();                   \
-                return ptr;                            \
-                }                                      \
+  typedef const Self *              ConstRawPointer
 
 
 // Define a macro for the common typedefs required by the 
@@ -82,6 +77,7 @@ virtual void Accept(unsigned long cellid, typename CellInterface<PixelType,\
   typedef typename Superclass::CellFeatureIdentifier   CellFeatureIdentifier; \
   typedef typename Superclass::CellFeatureIdentifier   CellFeatureCount; \
   typedef typename Superclass::PointType               PointType; \
+  typedef typename Superclass::VectorType              VectorType; \
   typedef typename Superclass::PointsContainer         PointsContainer; \
   typedef typename Superclass::UsingCellsContainer     UsingCellsContainer; \
   typedef typename Superclass::CellGeometry            CellGeometry;  \
@@ -135,6 +131,9 @@ public:
   typedef typename CellTraits::PointType               PointType;
   typedef typename CellTraits::PointsContainer         PointsContainer;
   typedef typename CellTraits::UsingCellsContainer     UsingCellsContainer;
+
+  ///NOTE: it should normally be defined in the traits
+  typedef typename PointType::VectorType               VectorType;
     
   /** Save the dimension from the template parameters. */
   itkStaticConstMacro(PointDimension, unsigned int,CellTraits::PointDimension);
@@ -162,7 +161,7 @@ public:
   typedef Array<CoordRepType>                 ParametricCoordArrayType;
   typedef Array<InterpolationWeightType>      ShapeFunctionsArrayType;
 
-  static int GetNextUserCellId(); // never return > MAX_INTERFACE
+//  static int GetNextUserCellId(); // never return > MAX_INTERFACE
 
   /** \class MultiVisitor 
    * \brief A visitor that can visit different cell types in a mesh.
@@ -412,6 +411,7 @@ public:
    */
   virtual unsigned int GetNumberOfUsingCells(void);
 
+#if !defined(CABLE_CONFIGURATION)
   /**
    * Get a begin iterator for the UsingCellsContainer.
    */
@@ -421,7 +421,8 @@ public:
    * Get an end iterator for the UsingCellsContainer.
    */
   virtual UsingCellsContainerIterator UsingCellsEnd(void);
-    
+#endif
+
   /** Standard part of every itk Object. */
   itkTypeMacro(CellInterface, LightObject);
 
@@ -489,8 +490,10 @@ public:
 
 } // end namespace itk
 
-#ifndef ITK_MANUAL_INSTANTIATION
+#if !defined(CABLE_CONFIGURATION)
+# ifndef ITK_MANUAL_INSTANTIATION
 #include "itkCellInterface.txx"
 #endif
+#endif
 
 #endif
