@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkDifferenceImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-02-08 18:55:54 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-04-25 12:24:03 $
+  Version:   $Revision: 1.15 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -41,25 +41,25 @@ class ITK_EXPORT DifferenceImageFilter :
 {
 public:
   /** Standard class typedefs. */
-  typedef DifferenceImageFilter  Self;
-  typedef ImageToImageFilter<TInputImage,TOutputImage>  Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef DifferenceImageFilter                           Self;
+  typedef ImageToImageFilter<TInputImage,TOutputImage>    Superclass;
+  typedef SmartPointer<Self>                              Pointer;
+  typedef SmartPointer<const Self>                        ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
-  
+
   /** Run-time type information (and related methods). */
   itkTypeMacro(DifferenceImageFilter, ImageToImageFilter);
-  
+
   /** Some convenient typedefs. */
-  typedef TInputImage InputImageType;
-  typedef TOutputImage OutputImageType;
-  typedef typename OutputImageType::PixelType OutputPixelType;
-  typedef typename OutputImageType::RegionType OutputImageRegionType;
-  typedef typename NumericTraits<OutputPixelType>::RealType RealType;
-  typedef typename NumericTraits<RealType>::AccumulateType AccumulateType;  
-  
+  typedef TInputImage                                         InputImageType;
+  typedef TOutputImage                                        OutputImageType;
+  typedef typename OutputImageType::PixelType                 OutputPixelType;
+  typedef typename OutputImageType::RegionType                OutputImageRegionType;
+  typedef typename NumericTraits<OutputPixelType>::RealType   RealType;
+  typedef typename NumericTraits<RealType>::AccumulateType    AccumulateType;
+ 
   /** Set the valid image input.  This will be input 0.  */
   virtual void SetValidInput(const InputImageType* validImage);
   
@@ -69,17 +69,23 @@ public:
   /** Set/Get the maximum distance away to look for a matching pixel.
       Default is 0. */
   itkSetMacro(ToleranceRadius, int);
-  itkGetMacro(ToleranceRadius, int);
+  itkGetConstMacro(ToleranceRadius, int);
   
   /** Set/Get the minimum threshold for pixels to be different.
       Default is 0. */
   itkSetMacro(DifferenceThreshold, OutputPixelType);
-  itkGetMacro(DifferenceThreshold, OutputPixelType);
+  itkGetConstMacro(DifferenceThreshold, OutputPixelType);
+  
+  /** Set/Get ignore boundary pixels.  Useful when resampling may have
+   *    introduced difference pixel values along the image edge 
+   *    Default = false */
+  itkSetMacro(IgnoreBoundaryPixels, bool);
+  itkGetConstMacro(IgnoreBoundaryPixels, bool);
   
   /** Get parameters of the difference image after execution.  */
-  itkGetMacro(MeanDifference, RealType);
-  itkGetMacro(TotalDifference, AccumulateType);
-  itkGetMacro(NumberOfPixelsWithDifferences, unsigned long);
+  itkGetConstMacro(MeanDifference, RealType);
+  itkGetConstMacro(TotalDifference, AccumulateType);
+  itkGetConstMacro(NumberOfPixelsWithDifferences, unsigned long);
   
 protected:
   DifferenceImageFilter();
@@ -100,22 +106,24 @@ protected:
    *     ImageToImageFilter::GenerateData()  */
   void ThreadedGenerateData(const OutputImageRegionType& threadRegion,
                             int threadId);
-  
+
   void BeforeThreadedGenerateData();
   void AfterThreadedGenerateData();
-  
-  OutputPixelType m_DifferenceThreshold;
-  RealType m_MeanDifference;
-  AccumulateType m_TotalDifference;
-  unsigned long  m_NumberOfPixelsWithDifferences;
-  int m_ToleranceRadius;
-  
-  Array<AccumulateType> m_ThreadDifferenceSum;
-  Array<unsigned long>  m_ThreadNumberOfPixels;
-  
+ 
+  OutputPixelType          m_DifferenceThreshold;
+  RealType                 m_MeanDifference;
+  AccumulateType           m_TotalDifference;
+  unsigned long            m_NumberOfPixelsWithDifferences;
+  int                      m_ToleranceRadius;
+
+  Array<AccumulateType>    m_ThreadDifferenceSum;
+  Array<unsigned long>     m_ThreadNumberOfPixels;
+
 private:
   DifferenceImageFilter(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
+
+  bool m_IgnoreBoundaryPixels;
 };
 
 } // end namespace itk
