@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkElasticBodyReciprocalSplineKernelTransform.h,v $
   Language:  C++
-  Date:      $Date: 2007-12-20 17:10:46 $
-  Version:   $Revision: 1.13 $
+  Date:      $Date: 2009-04-25 12:24:05 $
+  Version:   $Revision: 1.15 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -73,15 +73,15 @@ public:
   itkSetMacro( Alpha, TScalarType );
   
   /** Get alpha */
-  itkGetMacro( Alpha, TScalarType );
+  itkGetConstMacro( Alpha, TScalarType );
   
   /** These (rather redundant) typedefs are needed because on SGI, typedefs
    * are not inherited */
-  typedef typename Superclass::InputPointType  InputPointType;
-  typedef typename Superclass::OutputPointType  OutputPointType;
-  typedef typename Superclass::InputVectorType InputVectorType;
-  typedef typename Superclass::OutputVectorType OutputVectorType;
-  typedef typename Superclass::InputCovariantVectorType InputCovariantVectorType;
+  typedef typename Superclass::InputPointType            InputPointType;
+  typedef typename Superclass::OutputPointType           OutputPointType;
+  typedef typename Superclass::InputVectorType           InputVectorType;
+  typedef typename Superclass::OutputVectorType          OutputVectorType;
+  typedef typename Superclass::InputCovariantVectorType  InputCovariantVectorType;
   typedef typename Superclass::OutputCovariantVectorType OutputCovariantVectorType;
     
 
@@ -113,7 +113,7 @@ protected:
   /** alpha, Poisson's ratio */
   TScalarType m_Alpha;
 
-  private:
+private:
   ElasticBodyReciprocalSplineKernelTransform(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
 
