@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGaussianSpatialFunction.h,v $
   Language:  C++
-  Date:      $Date: 2007-02-13 15:52:57 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2009-04-25 12:24:09 $
+  Version:   $Revision: 1.10 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -45,10 +45,10 @@ class ITK_EXPORT GaussianSpatialFunction
 {
 public:
   /** Standard class typedefs. */
-  typedef GaussianSpatialFunction Self;
-  typedef SpatialFunction<TOutput, VImageDimension, TInput> Superclass;
-  typedef SmartPointer<Self>  Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef GaussianSpatialFunction                                 Self;
+  typedef SpatialFunction<TOutput, VImageDimension, TInput>       Superclass;
+  typedef SmartPointer<Self>                                      Pointer;
+  typedef SmartPointer<const Self>                                ConstPointer;
   
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -70,13 +70,13 @@ public:
 
   /** Gets and sets for gaussian parameters */
   itkSetMacro(Scale, double);
-  itkGetMacro(Scale, double);
+  itkGetConstMacro(Scale, double);
   itkSetMacro(Normalized, bool);
-  itkGetMacro(Normalized, bool);
+  itkGetConstMacro(Normalized, bool);
   itkSetMacro(Sigma, ArrayType);
-  itkGetMacro(Sigma, ArrayType);
+  itkGetConstMacro(Sigma, ArrayType);
   itkSetMacro(Mean, ArrayType);
-  itkGetMacro(Mean, ArrayType);
+  itkGetConstMacro(Mean, ArrayType);
 
 protected:
   GaussianSpatialFunction();
