@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkHexahedronCellTopology.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:29:09 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2008-10-17 01:21:45 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,19 +26,22 @@ namespace itk
  */
 const int
 HexahedronCellTopology
-::m_Edges[12][2] = { {0,1}, {1,2}, {3,2}, {0,3}, 
-                     {4,5}, {5,6}, {7,6}, {4,7},
-                     {0,4}, {1,5}, {3,7}, {2,6} };
+::m_Edges[12][2] = 
+{ {0,1}, {1,2}, {3,2}, {0,3}, 
+  {4,5}, {5,6}, {7,6}, {4,7},
+  {0,4}, {1,5}, {3,7}, {2,6}
+};
 
 /**
  * The hexahedron's topology data: Faces.
  */
 const int
 HexahedronCellTopology
-::m_Faces[6][4] = { {0,4,7,3}, {1,2,6,5},
-                    {0,1,5,4}, {3,7,6,2},
-                    {0,3,2,1}, {4,5,6,7} };
-
+::m_Faces[6][4] = 
+{ {0,4,7,3}, {1,2,6,5},
+  {0,1,5,4}, {3,7,6,2},
+  {0,3,2,1}, {4,5,6,7} 
+};
 
 
 HexahedronCellTopology
@@ -53,4 +56,3 @@ HexahedronCellTopology
 
 
 } // end namespace itk
-
