@@ -3,14 +3,14 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageConstIterator.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-30 20:56:08 $
-  Version:   $Revision: 1.22 $
+  Date:      $Date: 2009-05-11 21:48:29 $
+  Version:   $Revision: 1.27 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
@@ -21,13 +21,14 @@
 #include "itkIndex.h"
 #include "itkSize.h"
 #include "itkOffset.h"
+#include "itkNumericTraits.h"
 
 namespace itk
 {
 
 /** \class ImageConstIterator
  * \brief A multi-dimensional image iterator templated over image type.
- * 
+ *
  * ImageConstIterator is a templated class to represent a multi-dimensional
  * iterator. ImageConstIterator is templated over the type of
  * the image to be iterated over.
@@ -36,7 +37,7 @@ namespace itk
  * the basic construction and comparison operations.  However, it does not
  * provide mechanisms for moving the iterator.  A subclass of ImageConstIterator
  * must be used to move the iterator.
- * 
+ *
  * ImageConstIterator is a multi-dimensional iterator, requiring more information
  * be specified before the iterator can be used than conventional iterators.
  * Whereas the std::vector::iterator from the STL only needs to be passed
@@ -60,25 +61,25 @@ namespace itk
  *
  * \sa ImageConstIterator \sa ConditionalConstIterator
  * \sa ConstNeighborhoodIterator \sa ConstShapedNeighborhoodIterator
- * \sa ConstSliceIterator  \sa CorrespondenceDataStructureIterator 
- * \sa FloodFilledFunctionConditionalConstIterator 
- * \sa FloodFilledImageFunctionConditionalConstIterator 
- * \sa FloodFilledImageFunctionConditionalIterator 
- * \sa FloodFilledSpatialFunctionConditionalConstIterator 
- * \sa FloodFilledSpatialFunctionConditionalIterator 
- * \sa ImageConstIterator \sa ImageConstIteratorWithIndex 
+ * \sa ConstSliceIterator  \sa CorrespondenceDataStructureIterator
+ * \sa FloodFilledFunctionConditionalConstIterator
+ * \sa FloodFilledImageFunctionConditionalConstIterator
+ * \sa FloodFilledImageFunctionConditionalIterator
+ * \sa FloodFilledSpatialFunctionConditionalConstIterator
+ * \sa FloodFilledSpatialFunctionConditionalIterator
+ * \sa ImageConstIterator \sa ImageConstIteratorWithIndex
  * \sa ImageIterator \sa ImageIteratorWithIndex
- * \sa ImageLinearConstIteratorWithIndex  \sa ImageLinearIteratorWithIndex 
- * \sa ImageRandomConstIteratorWithIndex  \sa ImageRandomIteratorWithIndex 
- * \sa ImageRegionConstIterator \sa ImageRegionConstIteratorWithIndex 
- * \sa ImageRegionExclusionConstIteratorWithIndex 
- * \sa ImageRegionExclusionIteratorWithIndex 
- * \sa ImageRegionIterator  \sa ImageRegionIteratorWithIndex 
- * \sa ImageRegionReverseConstIterator  \sa ImageRegionReverseIterator 
- * \sa ImageReverseConstIterator  \sa ImageReverseIterator 
- * \sa ImageSliceConstIteratorWithIndex  \sa ImageSliceIteratorWithIndex 
- * \sa NeighborhoodIterator \sa PathConstIterator  \sa PathIterator 
- * \sa ShapedNeighborhoodIterator  \sa SliceIterator 
+ * \sa ImageLinearConstIteratorWithIndex  \sa ImageLinearIteratorWithIndex
+ * \sa ImageRandomConstIteratorWithIndex  \sa ImageRandomIteratorWithIndex
+ * \sa ImageRegionConstIterator \sa ImageRegionConstIteratorWithIndex
+ * \sa ImageRegionExclusionConstIteratorWithIndex
+ * \sa ImageRegionExclusionIteratorWithIndex
+ * \sa ImageRegionIterator  \sa ImageRegionIteratorWithIndex
+ * \sa ImageRegionReverseConstIterator  \sa ImageRegionReverseIterator
+ * \sa ImageReverseConstIterator  \sa ImageReverseIterator
+ * \sa ImageSliceConstIteratorWithIndex  \sa ImageSliceIteratorWithIndex
+ * \sa NeighborhoodIterator \sa PathConstIterator  \sa PathIterator
+ * \sa ShapedNeighborhoodIterator  \sa SliceIterator
  */
 template<typename TImage>
 class ITK_EXPORT ImageConstIterator
@@ -86,8 +87,8 @@ class ITK_EXPORT ImageConstIterator
 public:
   /** Standard class typedefs. */
   typedef ImageConstIterator Self;
-  
-  /** Dimension of the image the iterator walks.  This constant is needed so 
+
+  /** Dimension of the image the iterator walks.  This constant is needed so
    * functions that are templated over image iterator type (as opposed to
    * being templated over pixel type and dimension) can have compile time
    * access to the dimension of the image that the iterator walks. */
@@ -95,29 +96,29 @@ public:
                       TImage::ImageDimension);
 
   /** Index typedef support. */
-  typedef typename TImage::IndexType  IndexType;
-  typedef typename TImage::IndexValueType  IndexValueType;
-  
+  typedef typename TImage::IndexType          IndexType;
+  typedef typename TImage::IndexValueType     IndexValueType;
+
   /** Size typedef support. */
-  typedef typename TImage::SizeType    SizeType;
-  typedef typename TImage::SizeValueType  SizeValueType;
-    
+  typedef typename TImage::SizeType           SizeType;
+  typedef typename TImage::SizeValueType      SizeValueType;
+
   /** Offset typedef support. */
-  typedef typename TImage::OffsetType    OffsetType;
-  typedef typename TImage::OffsetValueType  OffsetValueType;
-    
+  typedef typename TImage::OffsetType         OffsetType;
+  typedef typename TImage::OffsetValueType    OffsetValueType;
+
   /** Region typedef support. */
-  typedef typename TImage::RegionType   RegionType;
+  typedef typename TImage::RegionType         RegionType;
 
   /** Image typedef support. */
-  typedef TImage   ImageType;
+  typedef TImage                              ImageType;
 
   /** PixelContainer typedef support. Used to refer to the container for
    * the pixel data. While this was already typdef'ed in the superclass
    * it needs to be redone here for this subclass to compile properly with gcc. */
-  typedef typename TImage::PixelContainer PixelContainer;
-  typedef typename PixelContainer::Pointer PixelContainerPointer;
-  
+  typedef typename TImage::PixelContainer     PixelContainer;
+  typedef typename PixelContainer::Pointer    PixelContainerPointer;
+
   /** Internal Pixel Type */
   typedef typename TImage::InternalPixelType   InternalPixelType;
 
@@ -135,14 +136,14 @@ public:
     : m_Region(),
       m_PixelAccessor(),
       m_PixelAccessorFunctor()
-  {
+    {
     m_Image = 0;
     m_Buffer = 0;
     m_Offset = 0;
     m_BeginOffset = 0;
     m_EndOffset = 0;
     m_PixelAccessorFunctor.SetBegin( m_Buffer );
-  }
+    }
 
   /** Default Destructor. */
   virtual ~ImageConstIterator() {};
@@ -150,11 +151,11 @@ public:
   /** Copy Constructor. The copy constructor is provided to make sure the
    * handle to the image is properly reference counted. */
   ImageConstIterator(const Self& it)
-  {
+    {
     m_Image = it.m_Image;     // copy the smart pointer
 
     m_Region = it.m_Region;
-    
+
     m_Buffer = it.m_Buffer;
     m_Offset = it.m_Offset;
     m_BeginOffset = it.m_BeginOffset;
@@ -162,21 +163,30 @@ public:
     m_PixelAccessor = it.m_PixelAccessor;
     m_PixelAccessorFunctor = it.m_PixelAccessorFunctor;
     m_PixelAccessorFunctor.SetBegin( m_Buffer );
-  }
+    }
 
   /** Constructor establishes an iterator to walk a particular image and a
    * particular region of that image. */
   ImageConstIterator( const ImageType *ptr,
                       const RegionType &region )
-  {
+    {
     m_Image = ptr;
     m_Buffer = m_Image->GetBufferPointer();
     m_Region = region;
 
+#ifdef ITK_USE_REGION_VALIDATION_IN_ITERATORS
+    if( region.GetNumberOfPixels() > 0 ) // If region is non-empty
+      {
+      const RegionType & bufferedRegion = m_Image->GetBufferedRegion();
+      itkAssertOrThrowMacro( (bufferedRegion.IsInside( m_Region )),
+        "Region " << m_Region << " is outside of buffered region " << bufferedRegion );
+      }
+#endif
+
     // Compute the start offset
     m_Offset = m_Image->ComputeOffset( m_Region.GetIndex() );
     m_BeginOffset = m_Offset;
-    
+
     // Compute the end offset. If any component of m_Region.GetSize()
     // is zero, the region is not valid and we set the EndOffset
     // to be same as BeginOffset so that iterator end condition is met
@@ -201,15 +211,15 @@ public:
     m_PixelAccessor = ptr->GetPixelAccessor();
     m_PixelAccessorFunctor.SetPixelAccessor( m_PixelAccessor );
     m_PixelAccessorFunctor.SetBegin( m_Buffer );
-  }
-  
+    }
+
   /** operator= is provided to make sure the handle to the image is properly
    * reference counted. */
   Self &operator=(const Self& it)
-  {
+    {
     m_Image = it.m_Image;     // copy the smart pointer
     m_Region = it.m_Region;
-    
+
     m_Buffer = it.m_Buffer;
     m_Offset = it.m_Offset;
     m_BeginOffset = it.m_BeginOffset;
@@ -219,10 +229,10 @@ public:
     m_PixelAccessorFunctor.SetBegin( m_Buffer );
 
     return *this;
-  }
-  
+    }
+
   /** Get the dimension (size) of the index. */
-  static unsigned int GetImageIteratorDimension() 
+  static unsigned int GetImageIteratorDimension()
     {return ImageIteratorDimension;}
 
   /** Comparison operator. Two iterators are the same if they "point to" the
@@ -242,7 +252,7 @@ public:
     // two iterators are the same if they "point to" the same memory location
     return (m_Buffer + m_Offset) == (it.m_Buffer + it.m_Offset);
     };
-  
+
   /** Comparison operator. An iterator is "less than" another if it "points to"
    * a lower memory location. */
   bool
@@ -298,34 +308,34 @@ public:
   /** Get the region that this iterator walks. ImageConstIterators know the
    * beginning and the end of the region of the image to iterate over. */
   const RegionType& GetRegion() const
-    { return m_Region; };
+    { return m_Region; }
 
   /** Get the image that this iterator walks. */
   const ImageType * GetImage() const
-    { return m_Image.GetPointer(); };
+    { return m_Image.GetPointer(); }
 
   /** Get the pixel value */
-  PixelType Get(void) const  
+  PixelType Get(void) const
     { return m_PixelAccessorFunctor.Get(*(m_Buffer+m_Offset)); }
-  
-  /** Return a const reference to the pixel 
+
+  /** Return a const reference to the pixel
    * This method will provide the fastest access to pixel
    * data, but it will NOT support ImageAdaptors. */
-  const PixelType & Value(void) const  
+  const PixelType & Value(void) const
     { return *(m_Buffer + m_Offset); }
- 
+
   /** Return an iterator for the beginning of the region. "Begin"
    * is defined as the first pixel in the region.
    * \deprecated Use GoToBegin() instead.
    */
   Self Begin(void) const;
 
- /** Move an iterator to the beginning of the region. "Begin" is
-  * defined as the first pixel in the region. */
+  /** Move an iterator to the beginning of the region. "Begin" is
+   * defined as the first pixel in the region. */
   void GoToBegin()
     {
     m_Offset = m_BeginOffset;
-    };
+    }
 
   /** Return an iterator for the end of the region. "End" is defined
    * as one pixel past the last pixel of the region.
@@ -333,12 +343,12 @@ public:
    */
   Self End(void) const;
 
- /** Move an iterator to the end of the region. "End" is defined as
-  * one pixel past the last pixel of the region. */
+  /** Move an iterator to the end of the region. "End" is defined as
+   * one pixel past the last pixel of the region. */
   void GoToEnd()
     {
     m_Offset = m_EndOffset;
-    };
+    }
 
   /** Is the iterator at the beginning of the region? "Begin" is defined
    * as the first pixel in the region. */
@@ -353,12 +363,12 @@ public:
     {
     return (m_Offset == m_EndOffset);
     }
-  
 
-protected: //made protected so other iterators can access 
-  typename TImage::ConstWeakPointer  m_Image;
-  RegionType                     m_Region;      // region to iterate over
-  
+
+protected: //made protected so other iterators can access
+  typename TImage::ConstWeakPointer     m_Image;
+  RegionType                            m_Region;  // region to iterate over
+
   unsigned long  m_Offset;
   unsigned long  m_BeginOffset; // offset to first pixel in region
   unsigned long  m_EndOffset;  // offset to one pixel past last pixel in region
@@ -386,4 +396,4 @@ protected: //made protected so other iterators can access
 # include "itkImageConstIterator.txx"
 #endif
 
-#endif 
+#endif
