@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageIterator.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-30 23:39:53 $
-  Version:   $Revision: 1.51 $
+  Date:      $Date: 2008-10-18 20:31:36 $
+  Version:   $Revision: 1.54 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -113,17 +113,23 @@ public:
   Self &operator=(const Self& it);
   
   /** Set the pixel value */
-  void Set( const PixelType & value) const  
+  void Set( const PixelType & value ) const  
     { 
-    this->m_PixelAccessorFunctor.Set(*(const_cast<InternalPixelType *>
-          (this->m_Buffer)+this->m_Offset), value); 
+    // const_cast is needed here because m_Buffer is declared as a const
+    // pointer in the superclass which is the ConstIterator.
+    this->m_PixelAccessorFunctor.Set(
+      *(const_cast<InternalPixelType *>(this->m_Buffer)+this->m_Offset), value); 
     }
 
   /** Return a reference to the pixel 
    * This method will provide the fastest access to pixel
    * data, but it will NOT support ImageAdaptors. */
   PixelType & Value(void) 
-    { return *(const_cast<InternalPixelType *>(this->m_Buffer)+this->m_Offset); }
+    { 
+    // const_cast is needed here because m_Buffer is declared as a const
+    // pointer in the superclass which is the ConstIterator.
+    return *(const_cast<InternalPixelType *>(this->m_Buffer)+this->m_Offset);
+    }
 
   /** Return an iterator for the beginning of the region. "Begin"
    * is defined as the first pixel in the region.
@@ -137,7 +143,11 @@ public:
 
   /** Get the image that this iterator walks. */
   ImageType * GetImage() const
-    { return const_cast<ImageType *>( this->m_Image.GetPointer() ); };
+    {
+    // const_cast is needed here because m_Image is declared as a const pointer
+    // in the base class which is the ConstIterator.
+    return const_cast<ImageType *>( this->m_Image.GetPointer() );
+    }
 
 
 protected:
