@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageRandomConstIteratorWithIndex.h,v $
   Language:  C++
-  Date:      $Date: 2005-10-03 15:18:45 $
-  Version:   $Revision: 1.13 $
+  Date:      $Date: 2008-10-18 21:13:25 $
+  Version:   $Revision: 1.14 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -114,8 +114,8 @@ class ITK_EXPORT ImageRandomConstIteratorWithIndex : public ImageConstIteratorWi
 {
 public:
   /** Standard class typedefs. */
-  typedef ImageRandomConstIteratorWithIndex Self;
-  typedef ImageConstIteratorWithIndex<TImage>  Superclass;
+  typedef ImageRandomConstIteratorWithIndex       Self;
+  typedef ImageConstIteratorWithIndex<TImage>     Superclass;
   
   /** Index typedef support. While this was already typdef'ed in the superclass
    * it needs to be redone here for this subclass to compile properly with gcc.
@@ -138,8 +138,8 @@ public:
   /** PixelContainer typedef support. Used to refer to the container for
    * the pixel data. While this was already typdef'ed in the superclass
    * it needs to be redone here for this subclass to compile properly with gcc. */
-  typedef typename TImage::PixelContainer PixelContainer;
-  typedef typename PixelContainer::Pointer PixelContainerPointer;
+  typedef typename TImage::PixelContainer       PixelContainer;
+  typedef typename PixelContainer::Pointer      PixelContainerPointer;
   
   /** Default constructor. Needed since we provide a cast constructor. */
   ImageRandomConstIteratorWithIndex();
@@ -160,21 +160,21 @@ public:
 
   /** Move an iterator to the beginning of the region. */
   void GoToBegin(void)
-  {
+    {
     this->RandomJump();
     m_NumberOfSamplesDone = 0L;
-  }
+    }
 
   /** Move an iterator to one position past the End of the region. */
   void GoToEnd(void)
-  {
+    {
     this->RandomJump();
     m_NumberOfSamplesDone = m_NumberOfSamplesRequested;
-  }
+    }
 
   /** Is the iterator at the beginning of the region? */
   bool IsAtBegin(void) const
-    { return (m_NumberOfSamplesDone == 0L) ; }
+    { return (m_NumberOfSamplesDone == 0L); }
 
   /** Is the iterator at the end of the region? */
   bool IsAtEnd(void) const
@@ -183,20 +183,20 @@ public:
   /** Increment (prefix) the selected dimension.
    * No bounds checking is performed. \sa GetIndex \sa operator-- */
   Self & operator++()
-  {
+    {
     this->RandomJump();
     m_NumberOfSamplesDone++;
     return *this;
-  }
+    }
 
   /** Decrement (prefix) the selected dimension.
    * No bounds checking is performed. \sa GetIndex \sa operator++ */
   Self & operator--()
-  {
+    {
     this->RandomJump();
     m_NumberOfSamplesDone--;
     return *this;
-  }
+    }
   
   /** Set/Get number of random samples to get from the image region */
   void SetNumberOfSamples( unsigned long number );
@@ -208,10 +208,11 @@ public:
 
 private:
   void RandomJump();
-  Statistics::MersenneTwisterRandomVariateGenerator::Pointer m_Generator;
-  unsigned long  m_NumberOfSamplesRequested;
-  unsigned long  m_NumberOfSamplesDone;
-  unsigned long  m_NumberOfPixelsInRegion;
+  typedef Statistics::MersenneTwisterRandomVariateGenerator::Pointer  GeneratorPointer;
+  GeneratorPointer  m_Generator;
+  unsigned long     m_NumberOfSamplesRequested;
+  unsigned long     m_NumberOfSamplesDone;
+  unsigned long     m_NumberOfPixelsInRegion;
 };
 
 } // end namespace itk
@@ -221,6 +222,3 @@ private:
 #endif
 
 #endif 
-
-
-
