@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkInterpolateImageFunction.h,v $
   Language:  C++
-  Date:      $Date: 2006-02-06 22:01:56 $
-  Version:   $Revision: 1.19 $
+  Date:      $Date: 2009-10-29 11:18:40 $
+  Version:   $Revision: 1.22 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -38,17 +38,19 @@ namespace itk
  * \ingroup ImageFunctions ImageInterpolators
  * 
  * */
-template <class TInputImage, class TCoordRep = float>
-class ITK_EXPORT InterpolateImageFunction : 
-  public ImageFunction< TInputImage, 
-    ITK_TYPENAME NumericTraits<typename TInputImage::PixelType>::RealType, TCoordRep > 
+template <class TInputImage, class TCoordRep = double>
+class ITK_EXPORT InterpolateImageFunction :
+  public ImageFunction< TInputImage,
+    ITK_TYPENAME NumericTraits<typename TInputImage::PixelType>::RealType, TCoordRep >
 {
 public:
   /** Standard class typedefs. */
-  typedef InterpolateImageFunction Self;
-  typedef ImageFunction<TInputImage,typename NumericTraits<typename TInputImage::PixelType>::RealType,TCoordRep> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef InterpolateImageFunction     Self;
+  typedef ImageFunction<TInputImage,
+    typename NumericTraits<typename TInputImage::PixelType>::RealType,
+    TCoordRep>                         Superclass;
+  typedef SmartPointer<Self>           Pointer;
+  typedef SmartPointer<const Self>     ConstPointer;
   
   /** Run-time type information (and related methods). */
   itkTypeMacro(InterpolateImageFunction, ImageFunction);
@@ -67,7 +69,8 @@ public:
   typedef typename Superclass::PointType PointType;
 
   /** Index typedef support. */
-  typedef typename Superclass::IndexType IndexType;
+  typedef typename Superclass::IndexType      IndexType;
+  typedef typename Superclass::IndexValueType IndexValueType;
 
   /** ContinuousIndex typedef support. */
   typedef typename Superclass::ContinuousIndexType ContinuousIndexType;
