@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLightProcessObject.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:29:14 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-11-24 02:27:27 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -22,30 +22,30 @@ namespace itk
 {
 
 /**
-   * Instantiate object with no start, end, or progress methods.
-   */
+ * Instantiate object with no start, end, or progress methods.
+ */
 LightProcessObject
 ::LightProcessObject()
 {
   m_AbortGenerateData = false;
-  m_Progress = 0.0;
+  m_Progress = 0.0f;
 }
 
 
 /**
-   * Destructor for the LightProcessObject class. We've got to
-   * UnRegister() the use of any input classes.
-   */
+ * Destructor for the LightProcessObject class. We've got to
+ * UnRegister() the use of any input classes.
+ */
 LightProcessObject
 ::~LightProcessObject()
 {}
 
 
 /**
-   * Update the progress of the process object. If a ProgressMethod exists, 
-   * executes it. Then set the Progress ivar to amount. The parameter amount 
-   * should range between (0,1).
-   */
+ * Update the progress of the process object. If a ProgressMethod exists, 
+ * executes it. Then set the Progress ivar to amount. The parameter amount 
+ * should range between (0,1).
+ */
 void 
 LightProcessObject
 ::UpdateProgress(float amount)
@@ -56,8 +56,8 @@ LightProcessObject
 
 
 /**
-   *
-   */
+ *
+ */
 void 
 LightProcessObject
 ::PrintSelf(std::ostream& os, Indent indent) const
@@ -80,21 +80,21 @@ LightProcessObject
   this->InvokeEvent( StartEvent() );
 
   /**
-     * GenerateData this object - we have not aborted yet, and our progress
-     * before we start to execute is 0.0.
-     */
+   * GenerateData this object - we have not aborted yet, and our progress
+   * before we start to execute is 0.0.
+   */
   m_AbortGenerateData = 0;
-  m_Progress = 0.0;
+  m_Progress = 0.0f;
 
   this->GenerateData();
 
   /**
-     * If we ended due to aborting, push the progress up to 1.0 (since
-     * it probably didn't end there)
-     */
+   * If we ended due to aborting, push the progress up to 1.0 (since
+   * it probably didn't end there)
+   */
   if ( !m_AbortGenerateData )
     {
-    this->UpdateProgress(1.0);
+    this->UpdateProgress(1.0f);
     }
 
   // Notify end event observers
