@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNumericTraitsVariableLengthVectorPixel.h,v $
   Language:  C++
-  Date:      $Date: 2007-12-10 14:03:14 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-12-01 16:53:10 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkNumericTraitsVariableLengthVector_h
-#define __itkNumericTraitsVariableLengthVector_h
+#ifndef __itkNumericTraitsVariableLengthVectorPixel_h
+#define __itkNumericTraitsVariableLengthVectorPixel_h
 
 #include "itkNumericTraits.h"
 #include "itkVariableLengthVector.h"
@@ -64,15 +64,15 @@ public: \
  \
   typedef ElementRealType ScalarRealType; \
  \
-  static const RealType max( const Self & a ) \
+  static const Self max( const Self & a ) \
     {  \
-      RealType b(a.Size());  \
+      Self b(a.Size());  \
       b.Fill( NumericTraits< T >::max() ); \
       return b; \
     } \
-  static const RealType min( const Self & a ) \
+  static const Self min( const Self & a ) \
     {  \
-      RealType b(a.Size());  \
+      Self b(a.Size());  \
       b.Fill( NumericTraits< T >::min() ); \
       return b; \
     } \
@@ -91,13 +91,7 @@ public: \
 };
 
 
-//
-// Visual Studio 6.0 is not capable of managing the template implementation
-// defined at the end of this file. Therefore we provide an alternative
-// primitive implementation based on macros that define explicit
-// instantiations.
-//
-#if defined( _MSC_VER ) && ( _MSC_VER < 1310 )
+#ifndef ITK_USE_NUMERIC_TRAITS_PARTIAL_SPECIALIZATION
 
 // These two symbols below are defined empty on purpose
 #define _TYPENAME_
@@ -140,9 +134,7 @@ itkNumericTraitsVariableLengthVectorPixelMacro( double );
 //
 itkNumericTraitsVariableLengthVectorPixelMacro( T );
 
-#endif
-
-
+#endif // ITK_USE_NUMERIC_TRAITS_PARTIAL_SPECIALIZATION
 
 //
 // Finally, to avoid contamination of other files with the symbols defined
@@ -155,4 +147,3 @@ itkNumericTraitsVariableLengthVectorPixelMacro( T );
 } // end namespace itk
 
 #endif // __itkNumericTraitsVariableLengthVector_h
-
