@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkObjectStore.h,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:29:19 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-04-25 12:24:12 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -61,9 +61,9 @@ class ITK_EXPORT ObjectStore : public Object
 {
 public:
    /** Standard typedefs. */
-  typedef ObjectStore Self;
-  typedef Object  Superclass;
-  typedef SmartPointer<Self>  Pointer;
+  typedef ObjectStore               Self;
+  typedef Object                    Superclass;
+  typedef SmartPointer<Self>        Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
 
   /** Method for creation through the object factory. */
@@ -75,7 +75,7 @@ public:
   /** Type of the objects in storage. */
   typedef TObjectType ObjectType;
 
-  /** Type of list for storing pointers to free memory.*/
+  /** Type of list for storing pointers to free memory. */
   typedef std::vector<ObjectType *> FreeListType;
 
   /** Type of memory allocation strategy */
@@ -91,7 +91,7 @@ public:
 
   /** Returns the size of the container.  This is not the number of objects
    *  available, but the total number of objects allocated. */
-  itkGetMacro(Size, ::size_t);
+  itkGetConstMacro(Size, ::size_t);
 
   /** Ensures that there are at least n elements allocated in the storage
    *  container.  Will not shrink the container, but may enlarge the
@@ -107,19 +107,19 @@ public:
 
   /** Set/Get the linear growth size */
   itkSetMacro(LinearGrowthSize, ::size_t);
-  itkGetMacro(LinearGrowthSize, ::size_t);
+  itkGetConstMacro(LinearGrowthSize, ::size_t);
 
   /** Set/Get the growth strategy. */
   itkSetMacro(GrowthStrategy, GrowthStrategyType);
-  itkGetMacro(GrowthStrategy, GrowthStrategyType);
+  itkGetConstMacro(GrowthStrategy, GrowthStrategyType);
 
   /** Set growth strategy to exponential */
   void SetGrowthStrategyToExponential()
-  { this->SetGrowthStrategy(EXPONENTIAL_GROWTH); }
+    { this->SetGrowthStrategy(EXPONENTIAL_GROWTH); }
 
   /** Set growth strategy to linear */
   void SetGrowthStrategyToLinear()
-  { this->SetGrowthStrategy(LINEAR_GROWTH); }
+    { this->SetGrowthStrategy(LINEAR_GROWTH); }
   
 protected:
   ObjectStore();
@@ -130,20 +130,20 @@ protected:
   ::size_t GetGrowthSize();
   
   struct MemoryBlock
-  {
+    {
     MemoryBlock(): Size(0), Begin(0) {}
 
     MemoryBlock(::size_t n) : Size(n)
-    { Begin = new ObjectType[n];  }
+      { Begin = new ObjectType[n];  }
 
     ~MemoryBlock()  {  } // Purposely does *not* free memory
 
     void Delete()
-    { if (Begin !=0) delete[] Begin; }
+      { if (Begin !=0) delete[] Begin; }
     
     ObjectType *Begin;
     ::size_t Size;
-  };
+    };
   
 private:
   ObjectStore(const Self&);    //purposely not implemented
