@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPathFunctions.h,v $
   Language:  C++
-  Date:      $Date: 2006-11-09 14:23:30 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-04-06 00:08:10 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,9 +26,6 @@
 
 namespace itk
 {
-
-
-
 /** Make a chain code trace another path of same dimensionality.
  * If restrictMovement is true, then individual steps are allowed to move
  * through only one dimension at a time; for 2D paths this results in an
@@ -75,8 +72,6 @@ void MakeChainCodeTracePath( TChainCodePath & chainPath,
     }
 }
 
-
-
 /** Make a Fourier series path trace a chain code path of same dimensionality.
  * numHarmonics is the number of harmonics (frequency coefficients, which
  * include the "DC" term) to compute.  If chainPath has too few steps to
@@ -105,7 +100,7 @@ void MakeFourierSeriesPathTraceChainCode( TFourierSeriesPath & FSPath,
   int         dimension =     OffsetType::GetOffsetDimension();
   unsigned    numSteps  =     chainPath.NumberOfSteps();
   
-  const double PI = 4.0 * atan( 1.0 );
+  const double PI = 4.0 * vcl_atan( 1.0 );
 
   FSPath.Clear();
   
@@ -128,18 +123,17 @@ void MakeFourierSeriesPathTraceChainCode( TFourierSeriesPath & FSPath,
       
       // turn the current index into a vector
       for( int d=0; d<dimension; d++ )
+        {
         indexVector[d] = index[d];
-      
-      cosCoefficient += indexVector * (cos(theta)/numSteps);
-      sinCoefficient += indexVector * (sin(theta)/numSteps);
+        }
+      cosCoefficient += indexVector * (vcl_cos(theta)/numSteps);
+      sinCoefficient += indexVector * (vcl_sin(theta)/numSteps);
       }
     
     FSPath.AddHarmonic( cosCoefficient, sinCoefficient );
     }
 }
 
-
-
 } // end namespace itk
 
 #endif
