@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPixelTraits.h,v $
   Language:  C++
-  Date:      $Date: 2007-10-10 11:57:19 $
-  Version:   $Revision: 1.28 $
+  Date:      $Date: 2009-03-03 15:07:54 $
+  Version:   $Revision: 1.30 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -44,97 +44,86 @@ public:
   typedef typename TPixelType::ValueType ValueType;
 };
 
-/** Specialization of PixelTraitss for scalar images. */
-template <>
-class PixelTraits<bool>
+/** \class PixelTraits<bool>
+ * Specialization of PixelTraits for scalar images. */
+template <> class PixelTraits<bool>
 {
 public:
   itkStaticConstMacro(Dimension, unsigned int, 1);
   typedef bool ValueType;
 };
 
-template <>
-class PixelTraits<char>
+template <> class PixelTraits<char>
 {
 public:
   itkStaticConstMacro(Dimension, unsigned int, 1);
   typedef char ValueType;
 };
 
-template <>
-class PixelTraits<signed char>
+template <> class PixelTraits<signed char>
 {
 public:
   itkStaticConstMacro(Dimension, unsigned int, 1);
   typedef char ValueType;
 };
 
-template <>
-class PixelTraits<unsigned char>
+template <> class PixelTraits<unsigned char>
 {
 public:
   itkStaticConstMacro(Dimension, unsigned int, 1);
   typedef unsigned char ValueType;
 };
 
-template <>
-class PixelTraits<short>
+template <> class PixelTraits<short>
 {
 public:
   itkStaticConstMacro(Dimension, unsigned int, 1);
   typedef short ValueType;
 };
 
-template <>
-class PixelTraits<unsigned short>
+template <> class PixelTraits<unsigned short>
 {
 public:
   itkStaticConstMacro(Dimension, unsigned int, 1);
   typedef unsigned short ValueType;
 };
 
-template <>
-class PixelTraits<int>
+template <> class PixelTraits<int>
 {
 public:
   itkStaticConstMacro(Dimension, unsigned int, 1);
   typedef int ValueType;
 };
 
-template <>
-class PixelTraits<unsigned int>
+template <> class PixelTraits<unsigned int>
 {
 public:
   itkStaticConstMacro(Dimension, unsigned int, 1);
   typedef unsigned int ValueType;
 };
 
-template <>
-class PixelTraits<long>
+template <> class PixelTraits<long>
 {
 public:
   itkStaticConstMacro(Dimension, unsigned int, 1);
   typedef long ValueType;
 };
 
-template <>
-class PixelTraits<unsigned long>
+template <> class PixelTraits<unsigned long>
 {
 public:
   itkStaticConstMacro(Dimension, unsigned int, 1);
   typedef unsigned long ValueType;
 };
 
-template <>
-class PixelTraits<float>
+template <> class PixelTraits<float>
 {
 public:
   itkStaticConstMacro(Dimension, unsigned int, 1);
   typedef float ValueType;
 };
 
-template <>
-class PixelTraits<double>
+template <> class PixelTraits<double>
 {
 public:
   itkStaticConstMacro(Dimension, unsigned int, 1);
@@ -165,7 +154,8 @@ public:
   typedef TValueType1 ValueType;
 };
 
-/** Specializations for bool. */
+/** \class JoinTraits
+ * Specializations for bool. */
 template<>
 class JoinTraits<bool, bool>
 {
@@ -243,7 +233,8 @@ public:
   typedef double ValueType;
 };
 
-/** Specializations for char. */
+/**  \class PixelTraits<char>
+ * Specializations for char. */
 template<>
 class JoinTraits<char, bool>
 {
@@ -322,7 +313,8 @@ public:
   typedef double ValueType;
 };
 
-/** Specializations for unsigned char. */
+/**  \class PixelTraits<unsigned char>
+ * Specializations for unsigned char. */
 template<>
 class JoinTraits<unsigned char, bool>
 {
@@ -400,7 +392,8 @@ public:
   typedef double ValueType;
 };
   
-/** Specializations for short. */
+/**  \class PixelTraits<short>
+ * Specializations for short. */
 template<>
 class JoinTraits<short, bool>
 {
@@ -479,7 +472,8 @@ public:
   typedef double ValueType;
 };
   
-/** Specializations for unsigned short. */
+/**  \class PixelTraits<unsigned short>
+ * Specializations for unsigned short. */
 template<>
 class JoinTraits<unsigned short, bool>
 {
@@ -557,7 +551,8 @@ public:
   typedef double ValueType;
 };
   
-/** Specializations for int. */
+/**  \class PixelTraits<int>
+ * Specializations for int. */
 template<>
 class JoinTraits<int, bool>
 {
@@ -636,7 +631,8 @@ public:
   typedef double ValueType;
 };
   
-/** Specializations for unsigned int. */
+/**  \class PixelTraits<unsigned int>
+ * Specializations for unsigned int. */
 template<>
 class JoinTraits<unsigned int, bool>
 {
@@ -717,7 +713,8 @@ public:
   typedef double ValueType;
 };
   
-/** Specializations for long. */
+/** \class PixelTraits<long>
+ * Specializations for long. */
 template<>
 class JoinTraits<long, bool>
 {
@@ -795,7 +792,8 @@ public:
   typedef double ValueType;
 };
   
-/** Specializations for unsigned long. */
+/** \class PixelTraits<unsigned long>
+ * Specializations for unsigned long. */
 template<>
 class JoinTraits<unsigned long, bool>
 {
@@ -873,7 +871,8 @@ public:
   typedef double ValueType;
 };
   
-/** Specializations for float. */
+/**  \class PixelTraits<float>
+ * Specializations for float. */
 template<>
 class JoinTraits<float, bool>
 {
@@ -951,7 +950,8 @@ public:
   typedef double ValueType;
 };
   
-/** Specializations for double. */
+/** \class PixelTraits<double>
+ * Specializations for double. */
 template<>
 class JoinTraits<double, bool>
 {
