@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPoint.h,v $
   Language:  C++
-  Date:      $Date: 2006-04-20 14:54:10 $
-  Version:   $Revision: 1.65 $
+  Date:      $Date: 2010-03-24 21:51:55 $
+  Version:   $Revision: 1.70 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -46,7 +46,7 @@ class Point : public FixedArray< TCoordRep, NPointDimension >
 {
 public:
   /** Standard class typedefs. */
-  typedef Point  Self;
+  typedef Point                                  Self;
   typedef FixedArray<TCoordRep,NPointDimension>  Superclass;
   
   /** ValueType can be used to declare a variable that is the same type
@@ -60,7 +60,7 @@ public:
   itkStaticConstMacro(PointDimension, unsigned int, NPointDimension);
 
   /** The Array type from which this Vector is derived. */
-  typedef FixedArray<TCoordRep, NPointDimension>         BaseArray;
+  typedef FixedArray<TCoordRep, NPointDimension>    BaseArray;
   typedef typename BaseArray::Iterator              Iterator;
   typedef typename BaseArray::ConstIterator         ConstIterator;
     
@@ -74,8 +74,9 @@ public:
   /** Default constructor has nothing to do. */
   Point() {}
 
-  /** Pass-through constructor for the Array base class. */
-  Point(const Self& r): BaseArray(r) {}
+  /** Pass-through constructors for the Array base class. */
+  template< class TPointValueType >
+  Point(const Point< TPointValueType, NPointDimension>& r): BaseArray(r) {}
   Point(const ValueType r[PointDimension]): BaseArray(r) {}  
     
   /** Pass-through assignment operator for the Array base class. */
@@ -150,7 +151,9 @@ public:
   /** Set the current point to a barycentric combination of the two points
    * given as arguments.
    *
-   * \param  \f$ \alpha \f$ = weight for the first point
+   * \param A First point
+   * \param B Second point
+   * \param alpha Weight for the first point
    * 
    * The first point is multiplied by \f$ \alpha \f$, the second is multiplied 
    * by * \f$ (1-\alpha) \f$, and the sum is stored in the Point on which the
@@ -210,42 +213,40 @@ public:
    *  Casting is done with C-Like rules  */
   template < typename TCoordRepB >
   void CastFrom( const Point<TCoordRepB,NPointDimension> & pa )
-  {
+    {
     for(unsigned int i=0; i<NPointDimension; i++ )
       {
       (*this)[i] = static_cast<TCoordRep>( pa[i] );
       }
-  }
-
+    }
 
   /** Compute the Squared Euclidean Distance from this point to another point
-    * with a different representation type.  Casting is done with C-Like rules  */
+    * with a different representation type.  Casting is done with
+    * C-Like rules */
 
   template < typename TCoordRepB >
   RealType SquaredEuclideanDistanceTo( const Point<TCoordRepB,NPointDimension> & pa ) const
-  {
+    {
     RealType sum = NumericTraits< RealType >::Zero;
     for(unsigned int i=0; i<NPointDimension; i++ )
       {
       const RealType component =  static_cast< RealType >( pa[i] );
-      const ValueType difference = (*this)[i] - component;
+      const RealType difference = static_cast< RealType >( (*this)[i] ) - component;
       sum += difference * difference;
       }
-  return sum;
-  }
-
-
+    return sum;
+    }
 
   /** Compute the Euclidean Distance from this point to another point
-    * with a different representation type.  Casting is done with C-Like rules  */
+    * with a different representation type.  Casting is done with
+    * C-Like rules */
   template < typename TCoordRepB >
   RealType EuclideanDistanceTo( const Point<TCoordRepB,NPointDimension> & pa ) const
-  {
-  const double distance = vcl_sqrt(
-    static_cast<double>( this->SquaredEuclideanDistanceTo( pa ) ) ) ;
-  return static_cast<RealType>( distance );
-  }
-
+    {
+    const double distance = vcl_sqrt(
+      static_cast<double>( this->SquaredEuclideanDistanceTo( pa ) ) );
+    return static_cast<RealType>( distance );
+    }
 
 };
 
@@ -257,7 +258,8 @@ template< class T, unsigned int NPointDimension >
 ITK_EXPORT std::istream& operator>>(std::istream& is, 
                                     Point<T,NPointDimension> & v); 
 
-/** Class that computes the barycentric combination of an array of N points
+/** \class BarycentricCombination  
+ * Class that computes the barycentric combination of an array of N points
  *
  * An array of (N-1) values is expected to weight the contribution of the 
  * first (N-1) points, the weight of the Nth point is computed to ensure that 
@@ -283,10 +285,10 @@ ITK_EXPORT class BarycentricCombination
 {
 public:
   /** Convenient typedefs. */
-  typedef TPointContainer PointContainerType;
+  typedef TPointContainer                      PointContainerType;
   typedef typename PointContainerType::Pointer PointContainerPointer;
   typedef typename PointContainerType::Element PointType;
-  typedef TWeightContainer WeightContainerType;
+  typedef TWeightContainer                     WeightContainerType;
   
   BarycentricCombination() {}; 
   ~BarycentricCombination() {};
