@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSTLConstContainerAdaptor.h,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:29:24 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-03-03 15:09:06 $
+  Version:   $Revision: 1.4 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -58,22 +58,17 @@ private:
   
 public:
 
-  STLConstContainerAdaptor(AdapteeType & adaptee)
-    : m_AdapteeRef(adaptee)
-  {}
+  STLConstContainerAdaptor(AdapteeType & adaptee) : m_AdapteeRef(adaptee) {}
   
-  STLConstContainerAdaptor(AdapteeType * adaptee)
-    : m_AdapteeRef(*adaptee)
-  {}
+  STLConstContainerAdaptor(AdapteeType * adaptee) : m_AdapteeRef(*adaptee) {}
   
   TargetType & GetSTLConstContainerRef()
-  {
+    {
     return m_AdapteeRef.CastToSTLConstContainer(); 
-  }
+    }
   
 };
 
-
 }   // end namespace itk
 
 #endif
