@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTimeProbe.h,v $
   Language:  C++
-  Date:      $Date: 2008-04-03 16:21:58 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2008-10-26 15:20:21 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -18,28 +18,26 @@
 #define __itkTimeProbe_h
 
 #include "itkConfigure.h"
-
-#ifdef ITK_USE_REVIEW
-#include "../Review/itkTimeProbe.h"
-#else
+#include "itkResourceProbe.h"
 #include "itkRealTimeClock.h"
 
-
 namespace itk 
 {
  
-  /** \class TimeProbe 
-   * 
-   *  \brief Class for computing the time passed between two points in the code.
-   *   
-   *   This class allows the user to trace the time passed between the execution of two pieces of code.
-   *   It can be started and stopped in order to evaluate the execution over multiple passes.
-   *   The values of time are taken from the RealTimeClock.
-   *
-   *   \sa RealTimeClock
-   *
-   */
-class ITKCommon_EXPORT TimeProbe
+/** \class TimeProbe 
+ * 
+ *  \brief Class for computing the time passed between two points in the code.
+ *   
+ *   This class allows the user to trace the time passed between the execution
+ *   of two pieces of code.  It can be started and stopped in order to evaluate
+ *   the execution over multiple passes.  The values of time are taken from the
+ *   RealTimeClock.
+ *
+ *   \sa RealTimeClock
+ *
+ */
+class ITKCommon_EXPORT TimeProbe: public 
+  ResourceProbe<RealTimeClock::TimeStampType,RealTimeClock::TimeStampType>
 {
 
 public:
@@ -57,39 +55,26 @@ public:
   TimeProbe();
 
   /** Destructor */
-  ~TimeProbe();
+  virtual ~TimeProbe();
 
-  /** Start counting the time */
-  void Start(void);
-
-  /** Stop counting the time */
-  void Stop(void);
-
-  /** Returns the number of times that the probe has been started. */
-  CountType     GetNumberOfStarts(void) const;
-
-  /** Returns the number of times that the probe has been stopped. */
-  CountType     GetNumberOfStops(void) const;
+  /** Get the current time.
+   *  Warning: the returned value is not the elapsed time since the last Start() call. 
+   */ 
+  virtual RealTimeClock::TimeStampType GetInstantValue(void)const;
 
   /** Returns the average times passed between the starts and stops of the
-   * probe. See the RealTimeClock for details on the precision and units of
-   * this time value. */
+   *  probe. See the RealTimeClock for details on the precision and units of
+   *  this time value. Obsolete method kept for backward compatibility, 
+   *  use Probe::GetMean() instead.
+   *  \deprecated
+   */
   TimeStampType GetMeanTime(void) const;
 
 private:
-
-    TimeStampType   m_Start;
-    TimeStampType   m_TotalTime;
-    
-    CountType       m_NumberOfStarts;
-    CountType       m_NumberOfStops;
-
-    RealTimeClock::Pointer   m_RealTimeClock;
+  RealTimeClock::Pointer   m_RealTimeClock;
 };
 
 
-}
+} // end namespace itk
 
-#endif // ITK_USE_REVIEW
-
-#endif
+#endif //__itkTimeProbe_h
