@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTreeContainerBase.h,v $
   Language:  C++
-  Date:      $Date: 2004-11-01 16:31:24 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-03-03 15:10:35 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -20,7 +20,6 @@
 #include "itkMacro.h"
 #include <itkObject.h>
 #include <iostream>
-#include <itkObjectFactory.h>
 #include <itkTreeNode.h>
 
 namespace itk
@@ -33,9 +32,9 @@ class TreeContainerBase : public Object
  
 public:
 
-  typedef Object Superclass;
-  typedef TreeContainerBase Self;
-  typedef SmartPointer<Self>  Pointer;
+  typedef Object                    Superclass;
+  typedef TreeContainerBase         Self;
+  typedef SmartPointer<Self>        Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
 
   typedef TValueType ValueType;
@@ -45,7 +44,7 @@ public:
 
   /** Set the root element. 
    * A new node is created and the element is added to the node */
-  virtual bool SetRoot( TValueType element ) = 0;
+  virtual bool SetRoot( const TValueType element ) = 0;
 
   /** Set the root has a node */
   virtual bool SetRoot( TreeNode<TValueType>* node) = 0;
@@ -79,9 +78,6 @@ protected:
 
 };
 
-
-
 } // namespace itk
 
 #endif
-
