@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVersorRigid3DTransform.h,v $
   Language:  C++
-  Date:      $Date: 2006-08-09 04:35:32 $
-  Version:   $Revision: 1.27 $
+  Date:      $Date: 2009-11-24 15:25:15 $
+  Version:   $Revision: 1.30 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -91,6 +91,10 @@ public:
   typedef typename Superclass::AxisType               AxisType;
   typedef typename Superclass::AngleType              AngleType;
   
+  typedef typename Superclass::AxisValueType          AxisValueType;
+  typedef typename Superclass::TranslationValueType   TranslationValueType;
+  typedef typename Superclass::ParameterValueType     ParameterValueType;
+
   /** Set the transformation from a container of parameters
    * This is typically used by optimizers.
    * There are 6 parameters. The first three represent the
@@ -114,10 +118,6 @@ protected:
 
   void PrintSelf(std::ostream &os, Indent indent) const;
 
-  /** This method must be made protected here because it is not a safe way of
-   * initializing the Versor */
-  virtual void SetRotationMatrix(const MatrixType & matrix)
-    { this->Superclass::SetRotationMatrix( matrix ); }
  
 private:
   VersorRigid3DTransform(const Self&); //purposely not implemented
