@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVersorTransform.h,v $
   Language:  C++
-  Date:      $Date: 2006-08-09 04:35:32 $
-  Version:   $Revision: 1.17 $
+  Date:      $Date: 2009-11-24 02:27:28 $
+  Version:   $Revision: 1.20 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,7 +26,7 @@
 namespace itk
 {
 
-/**
+/** \class VersorTransform
  *
  * VersorTransform of a vector space (e.g. space coordinates)
  *
@@ -39,12 +39,12 @@ namespace itk
  * The serialization of the fixed parameters is an array of 3 elements defining
  * the center of rotation.
  *
- * \TODO Need to make sure that the translation parameters in the baseclass
+ * TODO: Need to make sure that the translation parameters in the baseclass
  * cannot be set to non-zero values.
  *
  * \ingroup Transforms
  *
- **/
+ */
 template < class TScalarType=double >//Data type for scalars (float or double)
 class ITK_EXPORT VersorTransform : public Rigid3DTransform< TScalarType > 
 {
@@ -94,6 +94,8 @@ public:
   typedef Versor<TScalarType>                   VersorType;
   typedef typename VersorType::VectorType       AxisType;
   typedef typename VersorType::ValueType        AngleType;
+  typedef typename AxisType::ValueType          AxisValueType;
+  typedef typename ParametersType::ValueType    ParameterValueType;
 
   /**
    * Set the transformation from a container of parameters
