@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkXMLFileOutputWindow.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:29:30 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2009-03-03 15:11:51 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,12 +14,13 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifdef _WIN32
+#ifdef _MSC_VER
 #pragma warning ( disable : 4786 )
 #endif
 
 #include "itkXMLFileOutputWindow.h"
 #include <fstream>
+#include <string.h>
 
 namespace itk
 {
@@ -79,7 +80,7 @@ XMLFileOutputWindow
 ::DisplayXML(const char* tag, const char* text)
 {
   char *xmlText;
-
+  
   if(!text)
     {
     return;
@@ -98,27 +99,39 @@ XMLFileOutputWindow
     switch (*s)
       {
       case '&':
+        {
         strcat(x, "&amp;"); x += 5;
         break;
+        }
       case '"':
+        { 
         strcat(x, "&quot;"); x += 6;
         break;
+        }
       case '\'':
+        {
         strcat(x, "&apos;"); x += 6;
         break;
+        }
       case '<':
+        {
         strcat(x, "&lt;"); x += 4;
         break;
+        }
       case '>':
+        {
         strcat(x, "&gt;"); x += 4;
         break;
+        }
       default:
+        {
         *x = *s; x++;
         *x = '\0'; // explicitly terminate the new string
+        }
       }
     s++;
     }
-
+  
   if (!m_Stream)
     {
     this->Initialize();
