@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGDCMImageIO.h,v $
   Language:  C++
-  Date:      $Date: 2009-04-25 12:25:42 $
-  Version:   $Revision: 1.39 $
+  Date:      $Date: 2010-03-12 18:47:12 $
+  Version:   $Revision: 1.41 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -91,6 +91,11 @@ public:
   /** Reads the data from disk into the memory buffer provided. */
   virtual void Read(void* buffer);
 
+  /** Get the original component type of the image. This differs from
+   * ComponentType which may change as a function of rescale slope and
+   * intercept. */
+  itkGetEnumMacro(InternalComponentType,IOComponentType);
+
   /*-------- This part of the interfaces deals with writing data. ----- */
 
   /** Determine the file type. Returns true if this ImageIO can write the
@@ -173,12 +178,14 @@ public:
    * this binary structure in memory since it can consume lot of memory. Therefore
    * any field that is bigger than the default value 0xfff is discarded and just seek'd 
    * This method allow advanced user to force the reading of such field
+   * \warning this is a GDCM 1.x only option, no effect on GDCM 2.x
    */
   itkSetMacro(MaxSizeLoadEntry, long);
 
   /** Parse any sequences in the DICOM file. Defaults to the value of
    *  LoadSequencesDefault. Loading DICOM files is faster when
    *  sequences are not needed.
+   * \warning this is a GDCM 1.x only option, no effect on GDCM 2.x
    */
   itkSetMacro(LoadSequences, bool);
   itkGetConstMacro(LoadSequences, bool);
@@ -187,6 +194,7 @@ public:
   /** Parse any private tags in the DICOM file. Defaults to the value
    * of LoadPrivateTagsDefault. Loading DICOM files is faster when
    * private tags are not needed.
+   * \warning this is a GDCM 1.x only option, no effect on GDCM 2.x
    */
   itkSetMacro(LoadPrivateTags, bool);
   itkGetConstMacro(LoadPrivateTags, bool);
@@ -197,7 +205,9 @@ public:
    * ivar LoadSequences is initialized to the value of
    * LoadSequencesDefault.  This method is useful when relying on the
    * IO factory mechanism to load images rather than specifying a
-   * particular ImageIO object on the readers. Default is false. */
+   * particular ImageIO object on the readers. Default is false.
+   * \warning this is a GDCM 1.x only option, no effect on GDCM 2.x
+   */
   static void SetLoadSequencesDefault(bool b)
     { m_LoadSequencesDefault = b; }
   static void LoadSequencesDefaultOn()
@@ -212,7 +222,9 @@ public:
    * ivar LoadPrivateTags is initialized to the value of
    * LoadPrivateTagsDefault.  This method is useful when relying on the
    * IO factory mechanism to load images rather than specifying a
-   * particular ImageIO object on the readers. Default is false. */
+   * particular ImageIO object on the readers. Default is false.
+   * \warning this is a GDCM 1.x only option, no effect on GDCM 2.x
+   */
   static void SetLoadPrivateTagsDefault(bool b)
     { m_LoadPrivateTagsDefault = b; }
   static void LoadPrivateTagsDefaultOn()
