@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageIOBase.h,v $
   Language:  C++
-  Date:      $Date: 2009-05-19 19:26:25 $
-  Version:   $Revision: 1.53 $
+  Date:      $Date: 2009-11-29 15:51:11 $
+  Version:   $Revision: 1.56 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -70,6 +70,10 @@ public:
   itkSetStringMacro(FileName);
   itkGetStringMacro(FileName);
 
+  /** Types for managing image size and image index components. */
+  typedef   long              IndexValueType;
+  typedef   unsigned long     SizeValueType;
+
   /**
    * \class UnknownType
    * Used to return information when types are unknown.
@@ -248,8 +252,15 @@ public:
   /** Type for representing size of bytes, and or positions along a file */
   typedef std::streamoff SizeType;
 
+  /** Type for representing size of bytes, and or positions along a memory buffer */
+  typedef size_t    BufferSizeType;
+
   /** Convenient method for accessing the number of bytes to get to
-   * the next pixel. Returns m_Strides[1]; */
+   * the next pixel. Returns m_Strides[1]; 
+   * 
+   * Please note that this methods depends the private methods
+   * ComputeStrides being called, otherwise this is the incorrect value.
+   */
   virtual SizeType GetPixelStride () const;
 
   /** Return the number of pixels in the image. */
@@ -262,6 +273,14 @@ public:
    * of components in the image. */
   SizeType GetImageSizeInComponents() const;
 
+
+  /** Compute the size (in bytes) of the components of a pixel. For
+   * example, and RGB pixel of unsigned char would have a 
+   * component size of 1 byte. This method can be invoked only after
+   * the component type is set. */
+  virtual unsigned int GetComponentSize() const;
+
+
   /*-------- This part of the interfaces deals with reading data ----- */
 
   /** Determine the file type. Returns true if this ImageIO can read the
@@ -424,7 +443,7 @@ protected:
   ImageIORegion m_IORegion;
 
   /** The array which stores the number of pixels in the x, y, z directions. */
-  std::vector<unsigned int> m_Dimensions;
+  std::vector< SizeValueType > m_Dimensions;
 
   /** The array which stores the spacing of pixels in the 
    * x, y, z directions. */
@@ -447,6 +466,10 @@ protected:
   void Resize(const unsigned int numDimensions, 
               const unsigned int* dimensions);
 
+  /** Compute the size (in bytes) of the pixel. For
+   * example, and RGB pixel of unsigned char would have size 3 bytes. */
+  virtual unsigned int GetPixelSize() const;
+
   /** Calculates the different strides (distance from one thing to the next).
    * Upon return,
    * strides[0] = bytes to get to the next component of a pixel,
@@ -455,16 +478,6 @@ protected:
    * strides[3] = bytes to get to the next slice in z direction, etc. */
   void ComputeStrides();
 
-  /** Compute the size (in bytes) of the pixel. For
-   * example, and RGB pixel of unsigned char would have size 3 bytes. */
-  virtual unsigned int GetPixelSize() const;
-
-  /** Compute the size (in bytes) of the components of a pixel. For
-   * example, and RGB pixel of unsigned char would have a 
-   * component size of 1 byte. This method can be invoked only after
-   * the component type is set. */
-  virtual unsigned int GetComponentSize() const;
-
   /** Convenient method for accessing number of bytes to get to the next pixel 
    * component. Returns m_Strides[0]. */
   SizeType GetComponentStride() const;
