@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkJPEGImageIO.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-07-28 12:35:25 $
-  Version:   $Revision: 1.22 $
+  Date:      $Date: 2009-12-15 20:01:01 $
+  Version:   $Revision: 1.28 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -24,6 +24,7 @@
 #include "itkRGBPixel.h"
 #include "itkRGBAPixel.h"
 #include <stdio.h>
+#include <itksys/SystemTools.hxx>
 
 extern "C"
 {
@@ -32,6 +33,10 @@ extern "C"
   #include <setjmp.h>
 }
 
+#ifndef itk_secret_symbol_mangled_jpeg8
+#error Sorry something went wrong with your configuration, you are using a system jpeglib.h instead of the special mangled one
+#endif
+
 
 // create an error handler for jpeg that
 // can longjmp out of the jpeg library 
@@ -212,7 +217,10 @@ void JPEGImageIO::Read(void* buffer)
   if(!fp)
     {
     itkExceptionMacro("Error JPEGImageIO could not open file: " 
-                      << this->GetFileName());
+                      << this->GetFileName()
+                      << std::endl
+                      << "Reason: "
+                      << itksys::SystemTools::GetLastSystemError());
     return;
     }
  
@@ -294,6 +302,16 @@ JPEGImageIO::JPEGImageIO()
   
   m_Origin[0] = 0.0;
   m_Origin[1] = 0.0;
+
+  this->AddSupportedWriteExtension(".jpg");
+  this->AddSupportedWriteExtension(".JPG");
+  this->AddSupportedWriteExtension(".jpeg");
+  this->AddSupportedWriteExtension(".JPEG");
+
+  this->AddSupportedReadExtension(".jpg");
+  this->AddSupportedReadExtension(".JPG");
+  this->AddSupportedReadExtension(".jpeg");
+  this->AddSupportedReadExtension(".JPEG");
 }
 
 JPEGImageIO::~JPEGImageIO()
@@ -323,7 +341,10 @@ void JPEGImageIO::ReadImageInformation()
   if(!fp)
     {
     itkExceptionMacro("Error JPEGImageIO could not open file: " 
-                      << this->GetFileName());
+                      << this->GetFileName()
+                      << std::endl
+                      << "Reason: "
+                      << itksys::SystemTools::GetLastSystemError());
     return;
     }
 
@@ -430,10 +451,8 @@ void JPEGImageIO::WriteImageInformation(void)
 
 void JPEGImageIO::Write(const void* buffer)
 {
-  ImageIORegion ioRegion = this->GetIORegion();
-
-  // Make sure the region to be written is 2D
-  if ( ioRegion.GetRegionDimension() != 2 )
+  // the IORegion is not requred to be set so we must use GetNumberOfDimensions
+  if ( this->GetNumberOfDimensions() != 2 )
     {
     itkExceptionMacro(<<"JPEG Writer can only write 2-dimensional images");
     }
@@ -449,14 +468,19 @@ void JPEGImageIO::Write(const void* buffer)
 
 void JPEGImageIO::WriteSlice(std::string& fileName, const void* buffer)
 {
-  const JSAMPLE *outPtr = ( (const JSAMPLE*) buffer);
+  volatile const JSAMPLE *outPtr = ( (const JSAMPLE*) buffer);
 
   // use this class so return will call close
   JPEGFileWrapper JPEGfp(fileName.c_str(),"wb");
   FILE* fp = JPEGfp.m_FilePointer;
   if(!fp)
     {
-    itkExceptionMacro("Unable to open file " << fileName);
+    itkExceptionMacro("Unable to open file "
+                      << fileName
+                      <<" for writing."
+                      << std::endl
+                      << "Reason: "
+                      << itksys::SystemTools::GetLastSystemError());
     }
 
   // Call the correct templated function for the output
