@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMetaImageIO.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-07-07 22:03:39 $
-  Version:   $Revision: 1.102 $
+  Date:      $Date: 2009-12-15 14:28:19 $
+  Version:   $Revision: 1.104 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -894,17 +894,26 @@ void MetaImageIO::Read(void* buffer)
     
     delete [] indexMin;
     delete [] indexMax;
+
+    
+    m_MetaImage.ElementByteOrderFix( m_IORegion.GetNumberOfPixels() );
+    
     }
-  else if(!m_MetaImage.Read(m_FileName.c_str(), true, buffer))
+  else 
     {
-    itkExceptionMacro("File cannot be read: "
-                      << this->GetFileName() << " for reading."
-                      << std::endl
-                      << "Reason: "
-                      << itksys::SystemTools::GetLastSystemError());
+    if(!m_MetaImage.Read(m_FileName.c_str(), true, buffer))
+      {
+      itkExceptionMacro("File cannot be read: "
+                        << this->GetFileName() << " for reading."
+                        << std::endl
+                        << "Reason: "
+                        << itksys::SystemTools::GetLastSystemError());
+      }
+
+    // since we are not streaming m_IORegion may not be set, so 
+    m_MetaImage.ElementByteOrderFix( this->GetImageSizeInPixels() );
     }
 
-  m_MetaImage.ElementByteOrderFix( m_IORegion.GetNumberOfPixels() );
 } 
 
 MetaImage * MetaImageIO::GetMetaImagePointer(void)
@@ -1450,7 +1459,7 @@ MetaImageIO::GetActualNumberOfSplitsForWriting(unsigned int numberOfRequestedSpl
       itkDebugMacro("Requested streaming and compression");
       itkDebugMacro("Meta IO is not streaming now!");
       }
-     return 1;
+    return 1;
     }
 
   if (!itksys::SystemTools::FileExists( m_FileName.c_str() )) 
@@ -1547,7 +1556,7 @@ MetaImageIO::GetActualNumberOfSplitsForWriting(unsigned int numberOfRequestedSpl
     {
     // we are going be streaming
     
-    // need to remove the file incase the file doesn't match out
+    // need to remove the file incase the file doesn't match our
     // current header/meta data information
     if (!itksys::SystemTools::RemoveFile(m_FileName.c_str()))
       itkExceptionMacro("Unable to remove file for streaming: " << m_FileName);
