@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPNGImageIO.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-13 21:38:38 $
-  Version:   $Revision: 1.64 $
+  Date:      $Date: 2008-09-30 22:01:48 $
+  Version:   $Revision: 1.70 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -25,6 +25,7 @@ namespace itk
 
 extern "C"
 {
+  #include <setjmp.h>
   /* The PNG library does not expect the error function to return.
      Therefore we must use this ugly longjmp call.  */
   void itkPNGWriteErrorFunction(png_structp png_ptr,
@@ -73,6 +74,12 @@ bool PNGImageIO::CanReadFile(const char* file)
     return false;
     }
 
+  this->AddSupportedWriteExtension(".png");
+  this->AddSupportedWriteExtension(".PNG");
+
+  this->AddSupportedReadExtension(".png");
+  this->AddSupportedReadExtension(".PNG");
+
   // Now check the file header
   PNGFileWrapper pngfp(file,"rb");
   if(pngfp.m_FilePointer==NULL)
@@ -172,12 +179,15 @@ void PNGImageIO::Read(void* buffer)
     return;
     }
   
+  //  VS 7.1 has problems with setjmp/longjmp in C++ code
+#if !defined(MSC_VER) || _MSC_VER != 1310
   if( setjmp( png_jmpbuf( png_ptr ) ) )
     {
     png_destroy_read_struct( &png_ptr, &info_ptr, &end_info );
     itkExceptionMacro("File is not png type " << this->GetFileName());
     return;
     }
+#endif
 
   png_init_io(png_ptr, fp);
   png_set_sig_bytes(png_ptr, 8);
@@ -427,7 +437,7 @@ void PNGImageIO::Write(const void* buffer)
 
 void PNGImageIO::WriteSlice(const std::string& fileName, const void* buffer)
 {
-  const unsigned char *outPtr = ( (const unsigned char *) buffer);
+  volatile const unsigned char *outPtr = ( (const unsigned char *) buffer);
 
   // use this class so return will call close
   PNGFileWrapper pngfp(fileName.c_str(),"wb");
@@ -443,7 +453,7 @@ void PNGImageIO::WriteSlice(const std::string& fileName, const void* buffer)
     throw excp; 
     }
 
-  int bitDepth;
+  volatile int bitDepth;
   switch (this->GetComponentType())
     {
     case UCHAR:
@@ -481,6 +491,9 @@ void PNGImageIO::WriteSlice(const std::string& fileName, const void* buffer)
     }
 
   png_init_io(png_ptr, fp);
+
+//  VS 7.1 has problems with setjmp/longjmp in C++ code
+#if !defined(_MSC_VER) || _MSC_VER != 1310
   png_set_error_fn(png_ptr, png_ptr,
                    itkPNGWriteErrorFunction, itkPNGWriteWarningFunction);
   if (setjmp(png_ptr->jmpbuf))
@@ -493,6 +506,7 @@ void PNGImageIO::WriteSlice(const std::string& fileName, const void* buffer)
                       << itksys::SystemTools::GetLastSystemError());
     return;
     } 
+#endif
 
   int colorType;
   unsigned int numComp = this->GetNumberOfComponents();
