@@ -3,7 +3,7 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPolygonGroupSpatialObjectXMLFile.h,v $
   Language:  C++
-  Date:      $Date: 2007-03-22 14:28:52 $
+  Date:      $Date: 2008-05-13 18:48:32 $
   Version:   $1.0$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
@@ -57,10 +57,16 @@ public:
   /** Determine if a file can be read */
   virtual int CanReadFile(const char* name);
 protected:
+  PolygonGroupSpatialObjectXMLFileReader() {};
+  virtual ~PolygonGroupSpatialObjectXMLFileReader() {};
+
   virtual void StartElement(const char * name,const char **atts);
   virtual void EndElement(const char *name);
   virtual void CharacterDataHandler(const char *inData, int inLength);
 private:
+  PolygonGroupSpatialObjectXMLFileReader(const Self&); //purposely not implemented
+  void operator=(const Self&); //purposely not implemented
+
   PGroupSpatialObjectType::Pointer  m_PGroup;
   PolygonSpatialObjectType::Pointer m_CurPoly;
   PointListType                     m_CurPointList;
@@ -93,6 +99,13 @@ public:
   virtual int CanWriteFile(const char* name);
   /** Actually write out the file in question */
   virtual int WriteFile();
+protected:
+  PolygonGroupSpatialObjectXMLFileWriter() {};
+  virtual ~PolygonGroupSpatialObjectXMLFileWriter() {};
+private:
+  PolygonGroupSpatialObjectXMLFileWriter(const Self&); //purposely not implemented
+  void operator=(const Self&); //purposely not implemented
+
 };
 
 }
