@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkStimulateImageIO.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-27 13:46:29 $
-  Version:   $Revision: 1.20 $
+  Date:      $Date: 2009-05-27 17:48:12 $
+  Version:   $Revision: 1.27 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,6 +21,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <itksys/SystemTools.hxx>
+#include <itksys/RegularExpression.hxx>
 #include "itkByteSwapper.h"
 
 namespace itk
@@ -199,6 +200,11 @@ void StimulateImageIO::Read(void* buffer)
 
   if( !OpenStimulateFileForReading( file_data, m_DataFileName.c_str()) )
     {
+    itkExceptionMacro("StimulateImageIO could not open file: "
+                      << m_DataFileName << " for reading."
+                      << std::endl
+                      << "Reason: "
+                      << itksys::SystemTools::GetLastSystemError());
     return;
     }
 
@@ -207,26 +213,27 @@ void StimulateImageIO::Read(void* buffer)
     itkExceptionMacro(<<"Read failed: Wanted " 
                       << this->GetImageSizeInBytes()
                       << " bytes, but read " 
-                      << file_data.gcount() << " bytes.");
+                      << file_data.gcount() << " bytes."
+                      << " from file " << m_DataFileName );
     }
 
   //byte swapping depending on pixel type:
   switch (this->GetComponentType())
     {
     case CHAR:
-      ByteSwapper<char>::SwapRangeFromSystemToBigEndian((char *)buffer, this->GetImageSizeInComponents() );
+      ByteSwapper<char>::SwapRangeFromSystemToBigEndian((char *)buffer, static_cast<unsigned long>(this->GetImageSizeInComponents()) );
       break;
     case SHORT:
-      ByteSwapper<short>::SwapRangeFromSystemToBigEndian((short *)buffer, this->GetImageSizeInComponents() );
+      ByteSwapper<short>::SwapRangeFromSystemToBigEndian((short *)buffer, static_cast<unsigned long>(this->GetImageSizeInComponents()) );
       break;
     case INT:
-      ByteSwapper<int>::SwapRangeFromSystemToBigEndian((int *)buffer, this->GetImageSizeInComponents() );
+      ByteSwapper<int>::SwapRangeFromSystemToBigEndian((int *)buffer, static_cast<unsigned long>(this->GetImageSizeInComponents()) );
       break;
     case FLOAT:
-      ByteSwapper<float>::SwapRangeFromSystemToBigEndian((float *)buffer, this->GetImageSizeInComponents() );
+      ByteSwapper<float>::SwapRangeFromSystemToBigEndian((float *)buffer, static_cast<unsigned long>(this->GetImageSizeInComponents()) );
       break;
     case DOUBLE:
-      ByteSwapper<double>::SwapRangeFromSystemToBigEndian((double *)buffer, this->GetImageSizeInComponents() );
+      ByteSwapper<double>::SwapRangeFromSystemToBigEndian((double *)buffer, static_cast<unsigned long>(this->GetImageSizeInComponents()) );
       break;
     default:
       break;
@@ -243,11 +250,20 @@ void StimulateImageIO::InternalReadImageInformation(std::ifstream& file)
   std::string text;
 
   //read .sdt file (header)
+
   if ( ! this->OpenStimulateFileForReading(file, m_FileName.c_str()) )
     {
-    itkExceptionMacro(<< "Cannot read requested file");
+    itkExceptionMacro("StimulateImageIO could not open sdt file: "
+                      << m_FileName << " for reading."
+                      << std::endl
+                      << "Reason: "
+                      << itksys::SystemTools::GetLastSystemError());
     }
 
+  // re open in ascii mode
+  file.close();
+  file.open( m_FileName.c_str(), std::ios::in );
+
   //extract dimensions, spacing, origin
   unsigned int dim;
   unsigned int dims[4];
@@ -272,7 +288,6 @@ void StimulateImageIO::InternalReadImageInformation(std::ifstream& file)
   
   //char fidName[256] = "";   
   //char orient[256] = "";
-  char datafilename[256] = "";
 
   bool fov_specified = false;
   bool origin_specified = false;
@@ -280,6 +295,15 @@ void StimulateImageIO::InternalReadImageInformation(std::ifstream& file)
   while((file.getline(line, 255), file.gcount() > 0))
     {
     text = line;
+#ifdef __CYGWIN__
+    // If terminated with \r\n, getline only removes \n. Explictly
+    // strip \r.
+    if (text.size() > 0 
+        && (text[text.size() - 1] == '\r'))
+      {
+      text.resize(text.size() - 1);
+      }
+#endif
     
     if ( text.find("numDim") < text.length())
       {
@@ -433,10 +457,15 @@ void StimulateImageIO::InternalReadImageInformation(std::ifstream& file)
       //not documented
       itkDebugMacro(<<"mapTypeName was specified");
       }
-    else if ( text.find("stimFileName") < text.length())
+    else if ( text.find("stimFileName:") < text.length())
       {
       //file data name is explicitely specified
-      sscanf(line, "%*s %s", datafilename);
+      std::string datafilename;
+      // Remove leading and trailing blanks
+      itksys::RegularExpression regexp("stimFileName:[ ]*(.*)[ ]*$");
+      regexp.find(text);
+      datafilename = regexp.match(1);
+
       //if the data filename has a directory specified, use it as is,
       //otherwise prepend the path of the .spr file.
       std::string datafilenamePath =
@@ -562,8 +591,8 @@ void StimulateImageIO::Write(const void* buffer)
     }
 
   //preparation for writing buffer:
-  const unsigned long numberOfBytes      = this->GetImageSizeInBytes();
-  const unsigned long numberOfComponents = this->GetImageSizeInComponents();
+  const unsigned long numberOfBytes      = static_cast<unsigned long>(this->GetImageSizeInBytes());
+  const unsigned long numberOfComponents = static_cast<unsigned long>(this->GetImageSizeInComponents());
 
   file << "\ndataType: ";
   {
