@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTestDriver.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-03-22 14:28:53 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-07-28 18:30:04 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -187,6 +187,11 @@ int RegressionTestImage (const char *testImageFilename, const char *baselineImag
       rescale->SetInput(diff->GetOutput());
       rescale->Update();
       }
+    catch(const std::exception& e)
+      {
+      std::cerr << "Error during rescale of " << diffName.str() << std::endl;
+      std::cerr << e.what() << "\n";
+      }
     catch (...)
       {
       std::cerr << "Error during rescale of " << diffName.str() << std::endl;
@@ -196,6 +201,11 @@ int RegressionTestImage (const char *testImageFilename, const char *baselineImag
       {
       writer->Update();
       }
+    catch(const std::exception& e)
+      {
+      std::cerr << "Error during write of " << diffName.str() << std::endl;
+      std::cerr << e.what() << "\n";
+      }
     catch (...)
       {
       std::cerr << "Error during write of " << diffName.str() << std::endl;
@@ -212,6 +222,11 @@ int RegressionTestImage (const char *testImageFilename, const char *baselineImag
       rescale->SetInput(baselineReader->GetOutput());
       rescale->Update();
       }
+    catch(const std::exception& e)
+      {
+      std::cerr << "Error during rescale of " << baseName.str() << std::endl;
+      std::cerr << e.what() << "\n";
+      }
     catch (...)
       {
       std::cerr << "Error during rescale of " << baseName.str() << std::endl;
@@ -221,6 +236,11 @@ int RegressionTestImage (const char *testImageFilename, const char *baselineImag
       writer->SetFileName(baseName.str().c_str());
       writer->Update();
       }
+    catch(const std::exception& e)
+      {
+      std::cerr << "Error during write of " << baseName.str() << std::endl;
+      std::cerr << e.what() << "\n";
+      }
     catch (...)
       {
       std::cerr << "Error during write of " << baseName.str() << std::endl;
@@ -237,16 +257,25 @@ int RegressionTestImage (const char *testImageFilename, const char *baselineImag
       rescale->SetInput(testReader->GetOutput());
       rescale->Update();
       }
+    catch(const std::exception& e)
+      {
+      std::cerr << "Error during rescale of " << testName.str() << std::endl;
+      std::cerr << e.what() << "\n";
+      }
     catch (...)
       {
-      std::cerr << "Error during rescale of " << testName.str()
-                << std::endl;
+      std::cerr << "Error during rescale of " << testName.str() << std::endl;
       }
     try
       {
       writer->SetFileName(testName.str().c_str());
       writer->Update();
       }
+    catch(const std::exception& e)
+      {
+      std::cerr << "Error during write of " << testName.str() << std::endl;
+      std::cerr << e.what() << "\n";
+      }
     catch (...)
       {
       std::cerr << "Error during write of " << testName.str() << std::endl;
@@ -304,8 +333,6 @@ int main(int ac, char* av[] )
   std::vector< char* > args;
   typedef std::pair< char *, char *> ComparePairType;
   std::vector< ComparePairType > compareList;
-  // with putenv(), we must keep the string allocated
-  std::vector< std::string > envList;
   
   // parse the command line
   int i = 1;
@@ -328,8 +355,24 @@ int main(int ac, char* av[] )
         libpath += KWSYS_SHARED_FORWARD_PATH_SEP;
         libpath += oldenv;
         }
-      envList.push_back( libpath );
-      putenv( const_cast<char *>( envList.back().c_str() ) );
+      itksys::SystemTools::PutEnv( libpath.c_str() );
+      // on some 64 bit systems, LD_LIBRARY_PATH_64 is used before
+      // LD_LIBRARY_PATH if it is set. It can lead the test to load
+      // the system library instead of the expected one, so this
+      // var must also be set
+      if( std::string(KWSYS_SHARED_FORWARD_LDPATH) == "LD_LIBRARY_PATH" )
+        {
+        std::string libpath = "LD_LIBRARY_PATH_64";
+        libpath += "=";
+        libpath += av[i+1];
+        char * oldenv = getenv("LD_LIBRARY_PATH_64");
+        if( oldenv )
+          {
+          libpath += KWSYS_SHARED_FORWARD_PATH_SEP;
+          libpath += oldenv;
+          }
+        itksys::SystemTools::PutEnv( libpath.c_str() );
+        }
       i += 2;
       }
     else if( !skip && strcmp(av[i], "--add-before-env") == 0 )
@@ -348,8 +391,7 @@ int main(int ac, char* av[] )
         env += KWSYS_SHARED_FORWARD_PATH_SEP;
         env += oldenv;
         }
-      envList.push_back( env );
-      putenv( const_cast<char *>( envList.back().c_str() ) );
+      itksys::SystemTools::PutEnv( env.c_str() );
       i += 3;
       }
     else if( !skip && strcmp(av[i], "--compare") == 0 )
