@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTransformFileReader.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-09 15:15:39 $
-  Version:   $Revision: 1.24 $
+  Date:      $Date: 2010-02-08 20:23:21 $
+  Version:   $Revision: 1.26 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -81,7 +81,7 @@ void TransformFileReader
   pbuf=in.rdbuf();
 
   // get file size using buffer's members
-  int size=pbuf->pubseekoff (0,std::ios::end,std::ios::in);
+  int size=static_cast<int>(pbuf->pubseekoff (0,std::ios::end,std::ios::in));
   pbuf->pubseekpos (0,std::ios::in);
 
   // allocate memory to contain file data
@@ -108,10 +108,21 @@ void TransformFileReader
   bool haveFixedParameters = false;
   bool haveParameters = false;
  
+  //
+  // check for line end convention
+  std::string line_end("\n");
+  if(data.find('\n') == std::string::npos)
+    {
+    if(data.find('\r') == std::string::npos)
+      {
+      itkExceptionMacro ( "No line ending character found, not a valid ITK Transform TXT file" );
+      }
+    line_end = "\r";
+    }
   while ( position < data.size() )
     {
     // Find the next string
-    std::string::size_type end = data.find ( "\n", position );
+    std::string::size_type end = data.find ( line_end, position );
     std::string line = trim ( data.substr ( position, end - position ) );
     position = end+1;
     itkDebugMacro ("Found line: \"" << line << "\"" );
