@@ -3,7 +3,7 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkXMLFile.cxx,v $
   Language:  C++
-  Date:      $Date: 2004-01-08 00:39:08 $
+  Date:      $Date: 2008-09-30 22:07:08 $
   Version:   $1.0$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
@@ -26,31 +26,38 @@ namespace itk
 {
 
 //----------------------------------------------------------------------------
-static void itkXMLParserStartElement(void* parser, const char *name,
-                              const char **atts)
+extern "C"
 {
-  // Begin element handler that is registered with the XML_Parser.
-  // This just casts the user data to a itkXMLParser and calls
-  // StartElement.
-  static_cast<XMLReaderBase*>(parser)->StartElement(name, atts);
+  static void itkXMLParserStartElement(void* parser, const char *name,
+                                       const char **atts)
+    {
+    // Begin element handler that is registered with the XML_Parser.
+    // This just casts the user data to a itkXMLParser and calls
+    // StartElement.
+    static_cast<XMLReaderBase*>(parser)->StartElement(name, atts);
+    }
 }
 
 //----------------------------------------------------------------------------
-static void itkXMLParserEndElement(void* parser, const char *name)
-{
-  // End element handler that is registered with the XML_Parser.  This
-  // just casts the user data to a itkXMLParser and calls EndElement.
-  static_cast<XMLReaderBase*>(parser)->EndElement(name);
+extern "C" {
+  static void itkXMLParserEndElement(void* parser, const char *name)
+    {
+    // End element handler that is registered with the XML_Parser.  This
+    // just casts the user data to a itkXMLParser and calls EndElement.
+    static_cast<XMLReaderBase*>(parser)->EndElement(name);
+    }
 }
 
 //----------------------------------------------------------------------------
-static void itkXMLParserCharacterDataHandler(void* parser, const char* data,
-                                      int length)
-{
-  // Character data handler that is registered with the XML_Parser.
-  // This just casts the user data to a itkXMLParser and calls
-  // CharacterDataHandler.
-  static_cast<XMLReaderBase*>(parser)->CharacterDataHandler(data, length);
+extern "C" {
+  static void itkXMLParserCharacterDataHandler(void* parser, const char* data,
+                                               int length)
+    {
+    // Character data handler that is registered with the XML_Parser.
+    // This just casts the user data to a itkXMLParser and calls
+    // CharacterDataHandler.
+    static_cast<XMLReaderBase*>(parser)->CharacterDataHandler(data, length);
+    }
 }
 
 void
