@@ -3,7 +3,7 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkXMLFile.h,v $
   Language:  C++
-  Date:      $Date: 2007-03-17 21:02:11 $
+  Date:      $Date: 2008-05-13 18:48:32 $
   Version:   $1.0$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
@@ -34,6 +34,8 @@ class
 XMLReaderBase : public LightProcessObject
 {
 public:
+  typedef XMLReaderBase Self;
+
   /** Set the filename to write */
   itkSetStringMacro(Filename);
 
@@ -57,12 +59,20 @@ public:
    */
   virtual void CharacterDataHandler(const char *inData, int inLength) = 0;
 protected:
+  XMLReaderBase() {};
+  virtual ~XMLReaderBase() {};
+
   /** Instantiates and invokes the XML parser for the file named by
    * m_Filename.  The parser will throw an exception in the case of XML
    * syntax errors, missing filenames, unreadable input file, etc.
    */
   void parse(void);
   std::string m_Filename;
+
+private:
+  XMLReaderBase(const Self&); //purposely not implemented
+  void operator=(const Self&); //purposely not implemented
+
 };
 
 /** \class XMLReader -- template base class for an XMLReader
@@ -75,6 +85,8 @@ template <class T> class
 XMLReader : public XMLReaderBase
 {
 public:
+  typedef XMLReader Self;
+
   /** Set the output object.  Doesn't make sense for a client of the XMLReader,
    * but could be used in derived class to assign pointer to result object.
    */
@@ -83,7 +95,14 @@ public:
    */
   T *GetOutputObject(void) { return m_OutputObject; }
 protected:
+  XMLReader() {};
+  virtual ~XMLReader() {};
+
   T *m_OutputObject;
+
+private:
+  XMLReader(const Self&); //purposely not implemented
+  void operator=(const Self&); //purposely not implemented
 };
 
 /** \class XMLWriterBase
@@ -98,6 +117,8 @@ template <class T>
 class XMLWriterBase : public LightProcessObject
 {
 public:
+  typedef XMLWriterBase Self;
+
   /** Constructor
    * Sets object pointer to zero.
    */
@@ -148,6 +169,10 @@ public:
 protected:
   T          *m_InputObject;    // object to write out to an XML file
   std::string m_Filename;       // name of file to write.
+
+private:
+  XMLWriterBase(const Self&); //purposely not implemented
+  void operator=(const Self&); //purposely not implemented
 };
 
 }
