@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFEMElement3DC0LinearTetrahedronStrain.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:29:41 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-01-29 20:09:12 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -38,9 +38,10 @@ Element3DC0LinearTetrahedronStrain
       Material::ConstPointer m_) : Superclass()
 {
   // Set the geometrical points
-  for (int k=0; k<4; k++) { 
+  for (int k=0; k<4; k++)
+    { 
     this->SetNode( k, ns_[k] ); 
-  }
+    }
 
   /*
    * Initialize the pointer to material object and check that
@@ -48,17 +49,11 @@ Element3DC0LinearTetrahedronStrain
    * If the material class was incorrect an exception is thrown.
    */
   if( (m_mat=dynamic_cast<const MaterialLinearElasticity*>(&*m_)) == 0 )
-  {
+    {
     throw FEMExceptionWrongClass(__FILE__,__LINE__,"Element3DC0LinearTetrahedronStrain::Element3DC0LinearTetrahedronStrain()");
-  }
+    }
 }
 
-
-
-
 FEM_CLASS_REGISTER(Element3DC0LinearTetrahedronStrain)
 
-
-
-
 }} // end namespace itk::fem
