@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFEMLinearSystemWrapperDenseVNL.h,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:29:42 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2010-01-31 19:28:28 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,7 +21,6 @@
 #include "vnl/vnl_matrix.h"
 #include "vnl/vnl_vector.h"
 #include "vnl/algo/vnl_svd.h"
-#include <vnl/algo/vnl_lsqr.h>
 #include <vector>
 
 
@@ -108,6 +107,4 @@ private:
 
 }} // end namespace itk::fem
 
-#endif // #ifndef __itkFEMLinearSystemWrapperDenseVNL_h
-
-
+#endif
