@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFEMLoadImplementationTest.h,v $
   Language:  C++
-  Date:      $Date: 2004-12-19 16:47:22 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-01-30 21:10:18 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -24,9 +24,6 @@
 namespace itk {
 namespace fem {
 
-
-
-
 /**
  * \class LoadImplementationTest
  * \brief Example implementation of templated LoadTest class.
@@ -62,7 +59,7 @@ public:
     std::cout<<"Load object's data:"<<l0->data<<"\n";
   }
 private:
-  static const bool registered;
+  static const bool m_Registered;
 };
 
 // When the templated load implementation function is instantiated,
@@ -71,13 +68,10 @@ private:
 // Instantiating the implementation function will also instantiate the
 // corresponding Load class.
 template<class TLoadClass>
-const bool LoadImplementationTest<TLoadClass>::registered=
+const bool LoadImplementationTest<TLoadClass>::m_Registered=
   VisitorDispatcher<Element2DC0LinearLineStress,Element::LoadType,Element2DC0LinearLineStress::LoadImplementationFunctionPointer>
   ::RegisterVisitor((TLoadClass*)0, &LoadImplementationTest<TLoadClass>::impl);
 
-
-
-
 }} // end namespace itk::fem
 
 #endif // #ifndef __itkFEMLoadImplementationTest_h
