@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFEMSolverCrankNicolson.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-19 04:37:20 $
-  Version:   $Revision: 1.18 $
+  Date:      $Date: 2010-02-26 05:28:25 $
+  Version:   $Revision: 1.21 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -30,7 +30,6 @@
 #include "vnl/algo/vnl_svd.h"
 #include "vnl/algo/vnl_cholesky.h"
 #include <vnl/vnl_sparse_matrix_linear_system.h>
-#include <vnl/algo/vnl_lsqr.h>
 #include <math.h>
 
 
@@ -45,34 +44,36 @@ namespace fem {
  * This is the main class used for solving FEM time-dependent problems. 
  * It solves the following problem:
  *
- *      ( M + alpha*dt* K )*U_t=(M - (1.- alpha)*dt* K)* U_{t-1} + dt*(alpha*f_{n+1} + (1-alpha)*f_n) 
+ * \f[
+ *      ( M + \alpha*dt* K )*U_t=(M - (1.- \alpha)*dt* K)* U_{t-1} + dt*(\alpha*f_{n+1} + (1-\alpha)*f_n) 
+ * \f]
  *
- * which is the Crank-Nicolson formulation of the static problem if alpha=0.5.  
+ * which is the Crank-Nicolson formulation of the static problem if \f$\alpha=0.5\f$.  
  * The static solution is gained if :
- *      rho = 0.0;   alpha = 1.0;  dt = 1.0;  
+ *      \f$\rho = 0.0\f$;   \f$\alpha = 1.0\f$;  \f$dt = 1.0\f$;  
  * Practically, it is good to set rho to something small (for the itpack solver).
- * The advantage of choosing alpha=0.5 is that the solution is then stable for any
+ * The advantage of choosing \f$\alpha=0.5\f$ is that the solution is then stable for any
  * choice of time step, dt.  This class inherits and uses most of the Solver class
  * functionality.  One must call AssembleKandM instead of AssembleK and 
  * AssembleFforTimeStep instead of AssembleF.  
  * FIXMEs:  1) Members should be privatized, etc.
  * 2) We should also account for the contribution to the force from essential BCs.
- * Basically there are terms involving   M * (\dot g_b)  and   K * g_b  
- * where g_b is the essential BC vector.
+ * Basically there are terms involving  \f$ M * (\dot g_b) \f$  and  \f$ K * g_b \f$ 
+ * where\f$ g_b\f$ is the essential BC vector.
  */
 class SolverCrankNicolson : public Solver
 {
 public:
 
-/*
- * helper initialization function before assembly but after generate GFN.
- */
+  /**
+   * helper initialization function before assembly but after generate GFN.
+   */
   void InitializeForSolution(); 
   /**
    * Assemble the master stiffness and mass matrix.  We actually assemble
    * the right hand side and left hand side of the implicit scheme equation.
    */  
-  void AssembleKandM();            
+  void AssembleKandM();
 
   /**
    * Assemble the master force vector at a given time.
@@ -114,9 +115,10 @@ public:
 
   /* Finds a triplet that brackets the energy minimum.  From Numerical Recipes.*/
   void FindBracketingTriplet(Float* a,Float* b,Float* c);
+
   /** Finds the optimum value between the last two solutions 
-    * and sets the current solution to that value.  Uses Evaluate Residual;
-    */
+   * and sets the current solution to that value.  Uses Evaluate Residual;
+   */
   Float GoldenSection(Float tol=0.01,unsigned int MaxIters=25);
   /* Brents method from Numerical Recipes. */
   Float BrentsMethod(Float tol=0.01,unsigned int MaxIters=25);
@@ -130,14 +132,15 @@ public:
 
   Float GetCurrentMaxSolution() { return m_CurrentMaxSolution; }
 
-  /** Compute and print the minimum and maximum of the total solution and the last solution.*/
+  /** Compute and print the minimum and maximum of the total solution
+   * and the last solution. */
   void PrintMinMaxOfSolution();
    /**
    * Default constructor which sets the indices for the matrix and vector storage.
    * Time step and other parameters are also initialized.
    */
   SolverCrankNicolson() 
-  { 
+    { 
     m_deltaT=0.5; 
     m_rho=1.; 
     m_alpha=0.5;
@@ -153,7 +156,7 @@ public:
     SumMatrixIndex=0;                   // matrix
     DifferenceMatrixIndex=1;            // matrix
     m_CurrentMaxSolution=1.0;
-  }
+    }
 
  
   ~SolverCrankNicolson() { }
@@ -176,9 +179,6 @@ public:
   
 };
 
-
-
-
 }} // end namespace itk::fem
 
 #endif // #ifndef __itkFEMSolverCrankNicolson_h
