@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkErrorBackPropagationLearningWithMomentum.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-03 21:17:59 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-01-24 21:33:49 $
+  Version:   $Revision: 1.4 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -41,9 +41,10 @@ class ErrorBackPropagationLearningWithMomentum : public LearningFunctionBase<typ
 public:
 
   typedef ErrorBackPropagationLearningWithMomentum Self;
-  typedef LearningFunctionBase<typename LayerType::LayerInterfaceType, TTargetVector> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef LearningFunctionBase<typename LayerType::LayerInterfaceType, TTargetVector>
+                                                   Superclass;
+  typedef SmartPointer<Self>                       Pointer;
+  typedef SmartPointer<const Self>                 ConstPointer;
 
   /** Method for creation through the object factory. */
   itkTypeMacro(ErrorBackPropagationLearningWithMomentum, LearningFunctionBase);
