@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNNetDistanceMetricBase.h,v $
   Language:  C++
-  Date:      $Date: 2007-08-17 13:10:57 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2009-01-28 21:04:59 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -15,8 +15,8 @@
 
 =========================================================================*/
 
-#ifndef _itkNNetDistanceMetricBase_h
-#define _itkNNetDistanceMetricBase_h
+#ifndef __itkNNetDistanceMetricBase_h
+#define __itkNNetDistanceMetricBase_h
 
 #include "itkFunctionBase.h"
 
@@ -31,10 +31,10 @@ class NNetDistanceMetricBase : public FunctionBase<TMeasurementVector, double>
 public:
 
   /** Standard class typedefs. */
-  typedef NNetDistanceMetricBase Self;
+  typedef NNetDistanceMetricBase                  Self;
   typedef FunctionBase<TMeasurementVector,double> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef SmartPointer<Self>                      Pointer;
+  typedef SmartPointer<const Self>                ConstPointer;
 
   /** Run-time type information (and related methods). */
   itkTypeMacro(NNetDistanceMetricBase, FunctionBase);
