@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCovarianceCalculator.h,v $
   Language:  C++
-  Date:      $Date: 2005-07-26 15:54:54 $
-  Version:   $Revision: 1.13 $
+  Date:      $Date: 2009-03-04 15:23:43 $
+  Version:   $Revision: 1.16 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -23,8 +23,8 @@
 #include "itkArray.h"
 #include "itkVariableSizeMatrix.h"
 
-namespace itk{ 
-namespace Statistics{
+namespace itk { 
+namespace Statistics {
   
 /** \class CovarianceCalculator
  * \brief Calculates the covariance matrix of the target sample data.
@@ -55,14 +55,14 @@ class CovarianceCalculator :
 {
 public:
   /** Standard class typedefs. */
-  typedef CovarianceCalculator Self;
-  typedef SampleAlgorithmBase< TSample > Superclass ;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef CovarianceCalculator           Self;
+  typedef SampleAlgorithmBase< TSample > Superclass;
+  typedef SmartPointer<Self>             Pointer;
+  typedef SmartPointer<const Self>       ConstPointer;
 
   /** Standard Macros */
   itkTypeMacro(CovarianceCalculator, SampleAlgorithmBase);
-  itkNewMacro(Self) ;
+  itkNewMacro(Self);
   
   /** Length of a measurement vector */
   typedef typename Superclass::MeasurementVectorSizeType MeasurementVectorSizeType;
@@ -77,36 +77,36 @@ public:
   typedef VariableSizeMatrix< double >               OutputType;
 
   /** Stores the sample pointer */
-  void SetMean(MeanType* mean) ;
+  void SetMean( MeanType* mean );
 
   /** Returns the sample pointer */
-  MeanType* GetMean() ;
+  MeanType* GetMean( void );
 
   /** Returns the covariance matrix of the target sample data */ 
-  const OutputType * GetOutput() const;
+  const OutputType * GetOutput( void ) const;
 
 protected:
-  CovarianceCalculator() ;
-  virtual ~CovarianceCalculator() ;
+  CovarianceCalculator();
+  virtual ~CovarianceCalculator();
   void PrintSelf(std::ostream& os, Indent indent) const;
 
   /** Calculates the covariance and save it. This method calls 
    * ComputeCovarianceWithGivenMean, if the user provides mean vector
    * using SetMean method. Otherwise, it calls
    * ComputeCovarianceWithoutGivenMethod depending on */
-  void GenerateData() ;
+  void GenerateData( void );
 
   /** Calculates the covariance matrix using the given mean */ 
-  void ComputeCovarianceWithGivenMean() ;
+  void ComputeCovarianceWithGivenMean( void );
 
   /** Calculates the covariance matrix and the mean in a single pass */ 
-  void ComputeCovarianceWithoutGivenMean() ;
+  void ComputeCovarianceWithoutGivenMean( void );
 
 private:
-  MeanType* m_Mean ;
-  MeanType* m_InternalMean ;
-  OutputType m_Output ;
-} ; // end of class
+  MeanType*  m_Mean;
+  MeanType*  m_InternalMean;
+  OutputType m_Output;
+}; // end of class
     
 } // end of namespace Statistics 
 } // end of namespace itk 
@@ -116,4 +116,3 @@ private:
 #endif
 
 #endif
-
