@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGaussianDistribution.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-02-24 13:47:32 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2009-08-07 15:27:37 $
+  Version:   $Revision: 1.4 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -42,14 +42,14 @@ GaussianDistribution
     }
   else
     {
-    InvalidArgumentError exp(__FILE__, __LINE__);
+    InvalidArgumentError excep(__FILE__, __LINE__);
     ::itk::OStringStream message;
     message << "itk::ERROR: " << this->GetNameOfClass() 
             << "(" << this << "): "
             << "Invalid number of parameters to describe distribution.";
-    exp.SetDescription(message.str());
-    exp.SetLocation(ITK_LOCATION);
-    throw exp;
+    excep.SetDescription(message.str());
+    excep.SetLocation(ITK_LOCATION);
+    throw excep;
     return 0.0;
     }
 }
@@ -114,14 +114,14 @@ GaussianDistribution
     }
   else
     {
-    InvalidArgumentError exp(__FILE__, __LINE__);
+    InvalidArgumentError excep(__FILE__, __LINE__);
     ::itk::OStringStream message;
     message << "itk::ERROR: " << this->GetNameOfClass() 
             << "(" << this << "): "
             << "Invalid number of parameters to describe distribution.";
-    exp.SetDescription(message.str());
-    exp.SetLocation(ITK_LOCATION);
-    throw exp;
+    excep.SetDescription(message.str());
+    excep.SetLocation(ITK_LOCATION);
+    throw excep;
     return 0.0;
     }
 }
@@ -181,21 +181,17 @@ double
 GaussianDistribution
 ::PDF(double x)
 {
-  static const double oneonsqrttwopi = 1.0 / sqrt( 2.0 * vnl_math::pi );
-
-  return oneonsqrttwopi * exp(-0.5*x*x);
+  return vnl_math::one_over_sqrt2pi * vcl_exp(-0.5*x*x);
 }
 
 double
 GaussianDistribution
 ::PDF(double x, double mean, double variance)
 {
-  static const double oneonsqrttwopi = 1.0 / sqrt( 2.0 * vnl_math::pi );
-
   double xminusmean = x - mean;
   
-  return (oneonsqrttwopi / sqrt(variance))
-    * exp(-0.5*xminusmean*xminusmean / variance);
+  return (vnl_math::one_over_sqrt2pi / vcl_sqrt(variance))
+    * vcl_exp(-0.5*xminusmean*xminusmean / variance);
 }
 
 double
@@ -209,14 +205,14 @@ GaussianDistribution
     }
   else
     {
-    InvalidArgumentError exp(__FILE__, __LINE__);
+    InvalidArgumentError excep(__FILE__, __LINE__);
     ::itk::OStringStream message;
     message << "itk::ERROR: " 
             << "GaussianDistribution: "
             << "Invalid number of parameters to describe distribution.";
-    exp.SetDescription(message.str());
-    exp.SetLocation(ITK_LOCATION);
-    throw exp;
+    excep.SetDescription(message.str());
+    excep.SetLocation(ITK_LOCATION);
+    throw excep;
     return 0.0;
     }
 }
@@ -234,7 +230,7 @@ GaussianDistribution
 ::CDF(double x, double mean, double variance)
 {
   // convert to zero mean unit variance
-  double u = (x - mean) / sqrt(variance);
+  double u = (x - mean) / vcl_sqrt(variance);
   
   return 0.5 * (vnl_erf(vnl_math::sqrt1_2 * u) + 1.0);
 }
@@ -251,14 +247,14 @@ GaussianDistribution
     }
   else
     {
-    InvalidArgumentError exp(__FILE__, __LINE__);
+    InvalidArgumentError excep(__FILE__, __LINE__);
     ::itk::OStringStream message;
     message << "itk::ERROR: " 
             << "GaussianDistribution: "
             << "Invalid number of parameters to describe distribution.";
-    exp.SetDescription(message.str());
-    exp.SetLocation(ITK_LOCATION);
-    throw exp;
+    excep.SetDescription(message.str());
+    excep.SetLocation(ITK_LOCATION);
+    throw excep;
     return 0.0;
     }
 }
@@ -290,19 +286,19 @@ GaussianDistribution
     }
   
   
-  /**  Step 1:  use 26.2.23 from Abramowitz and Stegun **/
+  /**  Step 1:  use 26.2.23 from Abramowitz and Stegun */
   
-  dt = sqrt( -2.0 * log(dp) );
+  dt = vcl_sqrt( -2.0 * vcl_log(dp) );
   dx = dt
     - ((.010328e+0*dt + .802853e+0)*dt + 2.515517e+0)
     /(((.001308e+0*dt + .189269e+0)*dt + 1.432788e+0)*dt + 1.e+0);
   
-  /**  Step 2:  do 3 Newton steps to improve this **/
+  /**  Step 2:  do 3 Newton steps to improve this */
   
   for( newt=0; newt < 3; newt++ )
     {
-    dq  = 0.5e+0 * vnl_erfc( dx / 1.414213562373095e+0 ) - dp;
-    ddq = exp( -0.5e+0 * dx * dx ) / 2.506628274631000e+0;
+    dq  = 0.5e+0 * vnl_erfc( dx * vnl_math::sqrt1_2 ) - dp;
+    ddq = vcl_exp( -0.5e+0 * dx * dx ) / 2.506628274631000e+0;
     dx  = dx + dq / ddq;
     }
 
@@ -326,7 +322,7 @@ GaussianDistribution
 
   // apply the mean and variance to provide the value for the
   // prescribed Gaussian
-  x = x*sqrt(variance) + mean;
+  x = x*vcl_sqrt(variance) + mean;
   
   return x;
 }
@@ -342,14 +338,14 @@ GaussianDistribution
     }
   else
     {
-    InvalidArgumentError exp(__FILE__, __LINE__);
+    InvalidArgumentError excep(__FILE__, __LINE__);
     ::itk::OStringStream message;
     message << "itk::ERROR: " 
             << "GaussianDistribution: "
             << "Invalid number of parameters to describe distribution.";
-    exp.SetDescription(message.str());
-    exp.SetLocation(ITK_LOCATION);
-    throw exp;
+    excep.SetDescription(message.str());
+    excep.SetLocation(ITK_LOCATION);
+    throw excep;
     return 0.0;
     }
 }
@@ -369,14 +365,14 @@ GaussianDistribution
     }
   else
     {
-    InvalidArgumentError exp(__FILE__, __LINE__);
+    InvalidArgumentError excep(__FILE__, __LINE__);
     ::itk::OStringStream message;
     message << "itk::ERROR: " << this->GetNameOfClass() 
             << "(" << this << "): "
             << "Invalid number of parameters to describe distribution.";
-    exp.SetDescription(message.str());
-    exp.SetLocation(ITK_LOCATION);
-    throw exp;
+    excep.SetDescription(message.str());
+    excep.SetLocation(ITK_LOCATION);
+    throw excep;
     return 0.0;
     }
 }
@@ -396,14 +392,14 @@ GaussianDistribution
     }
   else
     {
-    InvalidArgumentError exp(__FILE__, __LINE__);
+    InvalidArgumentError excep(__FILE__, __LINE__);
     ::itk::OStringStream message;
     message << "itk::ERROR: " << this->GetNameOfClass() 
             << "(" << this << "): "
             << "Invalid number of parameters to describe distribution.";
-    exp.SetDescription(message.str());
-    exp.SetLocation(ITK_LOCATION);
-    throw exp;
+    excep.SetDescription(message.str());
+    excep.SetLocation(ITK_LOCATION);
+    throw excep;
     return 0.0;
     }
 }
@@ -436,14 +432,14 @@ GaussianDistribution
     }
   else
     {
-    InvalidArgumentError exp(__FILE__, __LINE__);
+    InvalidArgumentError excep(__FILE__, __LINE__);
     ::itk::OStringStream message;
     message << "itk::ERROR: " << this->GetNameOfClass() 
             << "(" << this << "): "
             << "Invalid number of parameters to describe distribution.";
-    exp.SetDescription(message.str());
-    exp.SetLocation(ITK_LOCATION);
-    throw exp;
+    excep.SetDescription(message.str());
+    excep.SetLocation(ITK_LOCATION);
+    throw excep;
     return 0.0;
     }
 }
@@ -463,14 +459,14 @@ GaussianDistribution
     }
   else
     {
-    InvalidArgumentError exp(__FILE__, __LINE__);
+    InvalidArgumentError excep(__FILE__, __LINE__);
     ::itk::OStringStream message;
     message << "itk::ERROR: " << this->GetNameOfClass() 
             << "(" << this << "): "
             << "Invalid number of parameters to describe distribution.";
-    exp.SetDescription(message.str());
-    exp.SetLocation(ITK_LOCATION);
-    throw exp;
+    excep.SetDescription(message.str());
+    excep.SetLocation(ITK_LOCATION);
+    throw excep;
     return 0.0;
     }
 }
@@ -503,14 +499,14 @@ GaussianDistribution
     }
   else
     {
-    InvalidArgumentError exp(__FILE__, __LINE__);
+    InvalidArgumentError excep(__FILE__, __LINE__);
     ::itk::OStringStream message;
     message << "itk::ERROR: " << this->GetNameOfClass() 
             << "(" << this << "): "
             << "Invalid number of parameters to describe distribution.";
-    exp.SetDescription(message.str());
-    exp.SetLocation(ITK_LOCATION);
-    throw exp;
+    excep.SetDescription(message.str());
+    excep.SetLocation(ITK_LOCATION);
+    throw excep;
     return 0.0;
     }
 }
@@ -530,14 +526,14 @@ GaussianDistribution
     }
   else
     {
-    InvalidArgumentError exp(__FILE__, __LINE__);
+    InvalidArgumentError excep(__FILE__, __LINE__);
     ::itk::OStringStream message;
     message << "itk::ERROR: " << this->GetNameOfClass() 
             << "(" << this << "): "
             << "Invalid number of parameters to describe distribution.";
-    exp.SetDescription(message.str());
-    exp.SetLocation(ITK_LOCATION);
-    throw exp;
+    excep.SetDescription(message.str());
+    excep.SetLocation(ITK_LOCATION);
+    throw excep;
     return 0.0;
     }
 }
