@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkHistogramToIntensityImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-10-27 19:51:47 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-04-01 14:36:37 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkHistogramIntensityFunction_h
-#define __itkHistogramIntensityFunction_h
+#ifndef __itkHistogramToIntensityImageFilter_h
+#define __itkHistogramToIntensityImageFilter_h
 
 #include "itkHistogramToImageFilter.h"
 
@@ -36,24 +36,23 @@ namespace itk
  */
 
 namespace Function {  
-template< class TInput>
+template< class TInput, class TOutput=unsigned long >
 class HistogramIntensityFunction
 {
 public:
   
   //Intensity function returns pixels of unsigned long.. 
-  typedef unsigned long  OutputPixelType   ;
-  
+  typedef TOutput  OutputPixelType;
   
   HistogramIntensityFunction(): 
       m_TotalFrequency(1) {}
 
   ~HistogramIntensityFunction() {};
  
-  inline OutputPixelType operator()( const TInput & A )
-  {
+  inline OutputPixelType operator()( const TInput & A ) const
+    {
     return static_cast<OutputPixelType>( A );
-  }
+    }
 
   void SetTotalFrequency( unsigned long n ) 
     {
@@ -70,15 +69,21 @@ private:
 }; 
 }
 
-template <class THistogram >
+template <class THistogram, class TOutputPixel=unsigned long >
 class ITK_EXPORT HistogramToIntensityImageFilter :
   public HistogramToImageFilter< THistogram, 
-  Function::HistogramIntensityFunction< unsigned long> > 
+  Function::HistogramIntensityFunction< unsigned long, TOutputPixel > > 
 {
 public:
   
   /** Standard class typedefs. */
   typedef HistogramToIntensityImageFilter                  Self;
+
+  /** Standard "Superclass" typedef. */
+  typedef HistogramToImageFilter< THistogram, 
+    Function::HistogramIntensityFunction< unsigned long, TOutputPixel > >
+                                                           Superclass;
+
   //typedef typename Function::HistogramIntensityFunction  FunctorType;
   typedef SmartPointer<Self>                               Pointer;
   typedef SmartPointer<const Self>                         ConstPointer;
@@ -102,6 +107,3 @@ private:
 } // end namespace itk
 
 #endif
-
-
-
