@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkHistogramToProbabilityImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-10-27 19:51:47 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-04-01 14:36:37 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkHistogramProbabilityFunction_h
-#define __itkHistogramProbabilityFunction_h
+#ifndef __itkHistogramToProbabilityImageFilter_h
+#define __itkHistogramToProbabilityImageFilter_h
 
 #include "itkHistogramToImageFilter.h"
 
@@ -44,7 +44,7 @@ namespace itk
  */
 
 namespace Function {  
-template< class TInput>
+template< class TInput, class TOutput=float >
 class HistogramProbabilityFunction
 {
 public:
@@ -53,7 +53,7 @@ public:
   //   Total Number of occurances. 
   //
   // Returns pixels of float.. 
-  typedef  float  OutputPixelType;
+  typedef  TOutput  OutputPixelType;
   
   
   HistogramProbabilityFunction(): 
@@ -61,11 +61,11 @@ public:
 
   ~HistogramProbabilityFunction() {};
 
-  inline OutputPixelType operator()( const TInput & A )
-  {
+  inline OutputPixelType operator()( const TInput & A ) const
+    {
     return static_cast<OutputPixelType>( static_cast<OutputPixelType>(A) / 
         static_cast<OutputPixelType>(m_TotalFrequency) );
-  }
+    }
 
   void SetTotalFrequency( unsigned long n ) 
     {
@@ -82,15 +82,21 @@ private:
 }; 
 }
 
-template <class THistogram >
+template <class THistogram, class TOutputPixel=float >
 class ITK_EXPORT HistogramToProbabilityImageFilter :
   public HistogramToImageFilter< THistogram, 
-  Function::HistogramProbabilityFunction< unsigned long> > 
+  Function::HistogramProbabilityFunction< unsigned long, TOutputPixel > > 
 {
 public:
   
   /** Standard class typedefs. */
   typedef HistogramToProbabilityImageFilter Self;
+  
+  /** Standard "Superclass" typedef. */
+  typedef HistogramToImageFilter< THistogram, 
+    Function::HistogramProbabilityFunction< unsigned long, TOutputPixel> >
+                                            Superclass;
+
   typedef SmartPointer<Self>                Pointer;
   typedef SmartPointer<const Self>          ConstPointer;
   
@@ -113,6 +119,3 @@ private:
 } // end namespace itk
 
 #endif
-
-
-
