@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFRPROptimizer.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-02-04 22:58:54 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-04-05 10:56:49 $
+  Version:   $Revision: 1.15 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -39,7 +39,7 @@ FRPROptimizer
 
 void
 FRPROptimizer
-::GetValueAndDerivative(ParametersType p, double * val,
+::GetValueAndDerivative(ParametersType & p, double * val,
                         ParametersType * xi)
 {
   this->m_CostFunction->GetValueAndDerivative(p, *val, *xi);
@@ -58,7 +58,7 @@ FRPROptimizer
       {
       len += (*xi)[i]*(*xi)[i];
       }
-    len = sqrt(len);
+    len = vcl_sqrt(len/this->GetSpaceDimension());
     for(unsigned int i=0; i<this->GetSpaceDimension(); i++)
       {
       (*xi)[i] /= len;
@@ -68,7 +68,16 @@ FRPROptimizer
 
 void
 FRPROptimizer
-::LineOptimize(ParametersType * p, ParametersType xi, double * val)
+::LineOptimize(ParametersType * p, ParametersType & xi, double * val)
+{
+  ParametersType tempCoord( this->GetSpaceDimension() );
+  this->LineOptimize( p, xi, val, tempCoord );
+}
+
+void
+FRPROptimizer
+::LineOptimize(ParametersType * p, ParametersType & xi, double * val, 
+               ParametersType & tempCoord )
 {
   this->SetLine(*p, xi);
 
@@ -79,15 +88,14 @@ FRPROptimizer
   double bx;
   double fb;
 
-  ParametersType pp = (*p);
-
-  this->LineBracket(&ax, &xx, &bx, &fa, &fx, &fb);
+  this->LineBracket(&ax, &xx, &bx, &fa, &fx, &fb, tempCoord);
   this->SetCurrentLinePoint(xx, fx);
 
   double extX = 0;
   double extVal = 0;
 
-  this->BracketedLineOptimize(ax, xx, bx, fa, fx, fb, &extX, &extVal);
+  this->BracketedLineOptimize(ax, xx, bx, fa, fx, fb, &extX, &extVal,
+                              tempCoord);
   this->SetCurrentLinePoint(extX, extVal);
 
   (*p) = this->GetCurrentPosition();
@@ -110,21 +118,21 @@ FRPROptimizer
 
   this->SetSpaceDimension(m_CostFunction->GetNumberOfParameters());
 
-  const unsigned int SpaceDimension = this->GetSpaceDimension();
+  FRPROptimizer::ParametersType tempCoord( this->GetSpaceDimension() );
 
   double gg, gam, dgg;
-  FRPROptimizer::ParametersType g( SpaceDimension );
-  FRPROptimizer::ParametersType h( SpaceDimension );
-  FRPROptimizer::ParametersType xi( SpaceDimension );
+  FRPROptimizer::ParametersType g( this->GetSpaceDimension() );
+  FRPROptimizer::ParametersType h( this->GetSpaceDimension() );
+  FRPROptimizer::ParametersType xi( this->GetSpaceDimension() );
 
-  FRPROptimizer::ParametersType p( SpaceDimension );
+  FRPROptimizer::ParametersType p( this->GetSpaceDimension() );
   p = this->GetInitialPosition();
   this->SetCurrentPosition(p);
 
   double fp;
   this->GetValueAndDerivative(p, &fp, &xi);
 
-  for( i = 0; i < SpaceDimension; i++ )
+  for( i = 0; i < this->GetSpaceDimension(); i++ )
     {
     g[i] = -xi[i];
     xi[i] = g[i];
@@ -141,12 +149,12 @@ FRPROptimizer
 
     double fret;
     fret = fp;
-    this->LineOptimize(&p, xi, &fret);
+    this->LineOptimize(&p, xi, &fret, tempCoord);
 
     if ( 2.0 * vcl_abs(fret - fp) <= 
       this->GetValueTolerance() * (vcl_abs(fret)+ vcl_abs(fp) + FRPR_TINY) )
       {
-      if( limitCount <  SpaceDimension )
+      if( limitCount <  this->GetSpaceDimension() )
         {
         this->GetValueAndDerivative(p, &fp, &xi);
         xi[limitCount] = 1;
@@ -170,7 +178,7 @@ FRPROptimizer
     
     if( m_OptimizationType == PolakRibiere )
       {
-      for( i=0; i< SpaceDimension; i++ )
+      for( i=0; i< this->GetSpaceDimension(); i++ )
         {
         gg += g[i] * g[i];
         dgg += (xi[i] + g[i]) * xi[i];
@@ -178,7 +186,7 @@ FRPROptimizer
       } 
     if( m_OptimizationType == FletchReeves )
       {
-      for( i=0; i< SpaceDimension; i++ )
+      for( i=0; i< this->GetSpaceDimension(); i++ )
         {
         gg += g[i] * g[i];
         dgg += xi[i] * xi[i];  
@@ -193,7 +201,7 @@ FRPROptimizer
       }
 
     gam = dgg/gg;
-    for( i = 0; i < SpaceDimension; i++)
+    for( i = 0; i < this->GetSpaceDimension(); i++)
       {
       g[i] = -xi[i];
       xi[i] = g[i] + gam * h[i];
@@ -204,7 +212,6 @@ FRPROptimizer
     this->InvokeEvent( IterationEvent() );
     }
 
-  this->SetCurrentPosition(p);
   this->InvokeEvent( EndEvent() );
 }
 
