@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFRPROptimizer.h,v $
   Language:  C++
-  Date:      $Date: 2008-02-04 22:58:54 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2008-04-23 12:49:10 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -91,11 +91,14 @@ protected:
   /** Get the value of the n-dimensional cost function at this scalar step
    * distance along the current line direction from the current line origin.
    * Line origin and distances are set via SetLine */
-  virtual void GetValueAndDerivative(ParametersType p, double * val,
+  virtual void GetValueAndDerivative(ParametersType & p, double * val,
                                      ParametersType * xi);
 
-  virtual void   LineOptimize(ParametersType * p, ParametersType xi,
+  virtual void   LineOptimize(ParametersType * p, ParametersType & xi,
                               double * val );
+  virtual void   LineOptimize(ParametersType * p, ParametersType & xi,
+                              double * val,
+                              ParametersType & tempCoord );
 
 
 private:
