@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLevenbergMarquardtOptimizer.h,v $
   Language:  C++
-  Date:      $Date: 2007-04-16 10:50:37 $
-  Version:   $Revision: 1.23 $
+  Date:      $Date: 2009-06-24 12:02:52 $
+  Version:   $Revision: 1.24 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -51,7 +51,7 @@ public:
   typedef   vnl_levenberg_marquardt   InternalOptimizerType;
 
   /** Method for getting access to the internal optimizer. */
-  vnl_levenberg_marquardt * GetOptimizer(void);
+  vnl_levenberg_marquardt * GetOptimizer(void) const;
 
   /** Start optimization with an initial value. */
   void StartOptimization( void );
@@ -67,6 +67,8 @@ public:
   /** Get the current value */
   MeasureType GetValue() const;
 
+  const std::string GetStopConditionDescription() const;
+
 protected:
   LevenbergMarquardtOptimizer();
   virtual ~LevenbergMarquardtOptimizer();
