@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkOptimizer.h,v $
   Language:  C++
-  Date:      $Date: 2007-03-22 14:29:14 $
-  Version:   $Revision: 1.37 $
+  Date:      $Date: 2009-06-24 12:02:54 $
+  Version:   $Revision: 1.39 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -79,6 +79,9 @@ public:
   /** Start optimization. */
   virtual void StartOptimization() {};
 
+  /** Get the reason for termination */
+  virtual const std::string GetStopConditionDescription() const;
+
 protected:
   Optimizer();
   virtual ~Optimizer() {};
@@ -89,14 +92,17 @@ protected:
 
   bool                    m_ScalesInitialized;
 
+  // Keep m_CurrentPosition as a protected var so that subclasses can
+  // have fast access.  This is important when optimizing high-dimensional
+  // spaces, e.g. bspline transforms.
+  ParametersType          m_CurrentPosition;
+
 private:
   Optimizer(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
   
   ParametersType          m_InitialPosition;
-  ParametersType          m_CurrentPosition;
   ScalesType              m_Scales;
-
 };
 
 } // end namespace itk
