@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAffineGeometryFrame.h,v $
   Language:  C++
-  Date:      $Date: 2007-07-16 23:09:53 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-04-07 14:33:52 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -25,15 +25,15 @@
 namespace itk 
 {
 
- /** \class AffineGeometryFrame
-  * \brief Describes the geometry of a data object  
-  */
+/** \class AffineGeometryFrame
+ * \brief Describes the geometry of a data object  
+ */
 template <class TScalarType = double, unsigned int NDimensions = 3>
-class AffineGeometryFrame : public itk::Object
+class ITK_EXPORT AffineGeometryFrame : public Object
 {
 public:
   typedef AffineGeometryFrame       Self;
-  typedef itk::Object               Superclass;
+  typedef Object                    Superclass;
   typedef SmartPointer<Self>        Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
 
@@ -59,7 +59,7 @@ public:
 
   /** Set the bounding box Only possible via the BoundsArray 
    * to make clear that a copy of the bounding-box is stored, 
-   * not a reference to it.*/
+   * not a reference to it. */
   virtual void SetBounds(const BoundsArrayType& bounds);
 
   /** Get the extent of the bounding box */
@@ -101,6 +101,7 @@ protected:
 
   AffineGeometryFrame();
   virtual ~AffineGeometryFrame();
+  void PrintSelf( std::ostream & os, Indent indent) const;
 
   /** used in clone to initialize the newly created geometry */
   virtual void InitializeGeometry(Self * newGeometry) const;
