@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCylinderSpatialObject.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-28 19:24:21 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-04-07 14:33:56 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -29,7 +29,7 @@ namespace itk
  * 
  * \brief This class describe a cylinder in 3D only.
  */
-class CylinderSpatialObject 
+class ITK_EXPORT CylinderSpatialObject 
   : public SpatialObject< 3 >
 {
 
@@ -69,7 +69,7 @@ public:
                         char * name=NULL) const;
      
   /** Return true if the object provides a method to evaluate the value 
-   * at the specified point, false otherwise.*/
+   * at the specified point, false otherwise. */
   virtual bool IsEvaluableAt( const PointType & point, 
                               unsigned int depth=0,
                               char * name=NULL) const;
