@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMetaEvent.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-28 19:24:56 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-04-07 14:34:04 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -22,7 +22,10 @@
 namespace itk 
 {
 
-class MetaEvent : public ::MetaEvent
+/** \class MetaEvent
+ * \brief Event abstract class
+ */
+class ITK_EXPORT MetaEvent : public ::MetaEvent
 {
 
 public:
