@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMetaSceneConverter.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-28 19:24:56 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2009-04-07 14:34:10 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -31,7 +31,7 @@ template <unsigned int NDimensions,
           typename TMeshTraits = 
             DefaultStaticMeshTraits< PixelType , NDimensions, NDimensions >
          >
-class MetaSceneConverter
+class ITK_EXPORT MetaSceneConverter
 {
 
 public:
