@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPlaneSpatialObject.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-28 19:24:56 $
-  Version:   $Revision: 1.16 $
+  Date:      $Date: 2009-04-07 14:34:12 $
+  Version:   $Revision: 1.18 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -31,7 +31,7 @@ namespace itk
  */
 
 template < unsigned int TDimension = 3  >
-class PlaneSpatialObject 
+class ITK_EXPORT PlaneSpatialObject 
   : public SpatialObject< TDimension >
 {
 
@@ -63,7 +63,7 @@ public:
                         unsigned int depth=0, char * name=NULL) const;
      
   /** return ture if the object provides a method to evaluate the value 
-   * at the specified point, else otherwise.*/
+   * at the specified point, else otherwise. */
   virtual bool IsEvaluableAt( const PointType & point,
                               unsigned int depth=0, char * name=NULL) const;
 
