@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSpatialObjectTreeNode.h,v $
   Language:  C++
-  Date:      $Date: 2007-07-16 23:15:51 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date: 2009-04-07 14:34:17 $
+  Version:   $Revision: 1.15 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,8 +26,11 @@ namespace itk
 
 template <unsigned int TDimension> class SpatialObject;
 
+/** \class SpatialObjectTreeNode
+ * \brief TODO
+ */
 template <unsigned int TDimension>
-class SpatialObjectTreeNode : public TreeNode< SpatialObject<TDimension> * >
+class ITK_EXPORT SpatialObjectTreeNode : public TreeNode< SpatialObject<TDimension> * >
 {
 
 public:
@@ -61,7 +64,7 @@ public:
   itkSetObjectMacro(NodeToWorldTransform,TransformType);
   itkGetConstReferenceObjectMacro(NodeToWorldTransform,TransformType);
 
-  /** Compute the NodeToWorld transform based on the parent*/
+  /** Compute the NodeToWorld transform based on the parent */
   void ComputeNodeToWorldTransform();
 
   /** Return a list of children (the list should be deleted by the user */
@@ -75,6 +78,14 @@ protected:
   /** Constructor */
   SpatialObjectTreeNode();
   virtual ~SpatialObjectTreeNode(){};
+  void PrintSelf(std::ostream &os, Indent indent) const
+    {
+    this->Superclass::PrintSelf(os, indent);
+    os << indent << "NodeToParentNodeTransform: "
+       << m_NodeToParentNodeTransform << std::endl;
+    os << indent << "NodeToWorldTransform: "
+       << m_NodeToWorldTransform << std::endl;
+    }
 
   TransformPointer m_NodeToParentNodeTransform;
   TransformPointer m_NodeToWorldTransform;
