@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:  $RCSfile: itkSurfaceSpatialObject.h,v $
   Language:  C++
-  Date:    $Date: 2007-01-28 19:24:57 $
-  Version:   $Revision: 1.25 $
+  Date:    $Date: 2009-04-07 14:34:17 $
+  Version:   $Revision: 1.27 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -27,16 +27,16 @@ namespace itk
 {
 
 /** 
-* \class SurfaceSpatialObject
-* \brief Representation of a Surface based on the spatial object classes.
-*
-* The Surface is basically defined by a set of points. 
-*
-* \sa SurfaceSpatialObjectPoint
-*/
+ * \class SurfaceSpatialObject
+ * \brief Representation of a Surface based on the spatial object classes.
+ *
+ * The Surface is basically defined by a set of points. 
+ *
+ * \sa SurfaceSpatialObjectPoint
+ */
 
 template < unsigned int TDimension = 3 >
-class SurfaceSpatialObject 
+class ITK_EXPORT SurfaceSpatialObject 
   :public PointBasedSpatialObject<  TDimension >
 {
 
@@ -57,7 +57,7 @@ public:
   typedef typename Superclass::BoundingBoxType          BoundingBoxType;
   typedef typename Superclass::CovariantVectorType      CovariantVectorType;
 
-  /** Method for creation through the object factory.*/
+  /** Method for creation through the object factory. */
   itkNewMacro( Self );
 
   /** Method for creation through the object factory. */
