@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSurfaceSpatialObjectPoint.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-28 19:24:57 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2009-04-07 14:34:17 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -25,16 +25,17 @@ namespace itk
 {
 
 /** \class SurfaceSpatialObjectPoint
-* \brief Point used for a Surface definition
-*
-* This class contains all the functions necessary to define a point
-* that can be used to build surfaces.
-* A surface point has a position and only one normal
-*
-* \sa SpatialObjectPoint 
-*/ 
+ * \brief Point used for a Surface definition
+ *
+ * This class contains all the functions necessary to define a point
+ * that can be used to build surfaces.
+ * A surface point has a position and only one normal
+ *
+ * \sa SpatialObjectPoint 
+ */ 
+
 template < unsigned int TPointDimension = 3 >
-class SurfaceSpatialObjectPoint 
+class ITK_EXPORT SurfaceSpatialObjectPoint 
   : public SpatialObjectPoint<TPointDimension>
 {
 
