@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTubeSpatialObject.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-28 19:24:57 $
-  Version:   $Revision: 1.45 $
+  Date:      $Date: 2010-01-21 22:33:38 $
+  Version:   $Revision: 1.48 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -27,20 +27,20 @@ namespace itk
 {
 
 /** 
-* \class TubeSpatialObject
-* \brief Representation of a tube based on the spatial object classes.
-*
-* The tube is basically defined by a set of points. Each tube can
-* be connected to a tube network, by using the AddSpatialObject() methods
-* of a TubeSpatialObject Object.
-* A tube is also identified by an id number when connected to a network.
-*
-* \sa TubeSpatialObjectPoint 
-*/
+ * \class TubeSpatialObject
+ * \brief Representation of a tube based on the spatial object classes.
+ *
+ * The tube is basically defined by a set of points. Each tube can
+ * be connected to a tube network, by using the AddSpatialObject() methods
+ * of a TubeSpatialObject Object.
+ * A tube is also identified by an id number when connected to a network.
+ *
+ * \sa TubeSpatialObjectPoint 
+ */
 
 template < unsigned int TDimension = 3, 
            typename TTubePointType = TubeSpatialObjectPoint<TDimension> >
-class TubeSpatialObject 
+class ITK_EXPORT TubeSpatialObject 
   :public PointBasedSpatialObject< TDimension >
 {
 
@@ -69,16 +69,16 @@ public:
   /** Method for creation through the object factory. */
   itkTypeMacro( TubeSpatialObject, PointBasedSpatialObject );
     
-  /** Returns a reference to the list of the tube points.*/
+  /** Returns a reference to the list of the tube points. */
   virtual PointListType & GetPoints( void );
 
-  /** Returns a reference to the list of the tube points.*/
+  /** Returns a reference to the list of the tube points. */
   virtual const PointListType & GetPoints( void ) const;
 
-  /** Set the list of tube points.*/
+  /** Set the list of tube points. */
   virtual void SetPoints( PointListType & newPoints );
 
-  /** Return a point in the list given the index */
+  /** Return a point in the list given the index. */
   virtual const SpatialObjectPointType* GetPoint(unsigned long ind) const 
     {return &(m_Points[ind]);}
   
@@ -154,7 +154,6 @@ public:
 
 
 protected:
-
   PointListType     m_Points;
   int               m_ParentPoint;
   unsigned int      m_EndType;
@@ -165,13 +164,17 @@ protected:
   TubeSpatialObject();
   virtual ~TubeSpatialObject();
 
-  /** Method to print the object.*/
+  /** Method to print the object. */
   virtual void PrintSelf( std::ostream& os, Indent indent ) const;
   
   /** TimeStamps */
   mutable unsigned long m_OldMTime;
   mutable unsigned long m_IndexToWorldTransformMTime;
-  
+
+private:
+  TubeSpatialObject(const Self&); //purposely not implemented
+  void operator=(const Self&); //purposely not implemented
+
 };
 
 } // end namespace itk
