@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: PointSetWithVectors.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-11-19 16:31:49 $
-  Version:   $Revision: 1.17 $
+  Date:      $Date: 2009-04-06 00:05:54 $
+  Version:   $Revision: 1.20 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -100,12 +100,12 @@ int main(int, char *[])
 
   for(unsigned int i=0; i<360; i++)
     {
-    const double angle = i * atan(1.0) / 45.0;
-    point[0] = radius * sin( angle );
-    point[1] = radius * cos( angle );
+    const double angle = i * vnl_math::pi / 180.0;
+    point[0] = radius * vcl_sin( angle );
+    point[1] = radius * vcl_cos( angle );
     point[2] = 1.0;   // flat on the Z plane
-    tangent[0] =  cos(angle);
-    tangent[1] = -sin(angle);
+    tangent[0] =  vcl_cos(angle);
+    tangent[1] = -vcl_sin(angle);
     tangent[2] = 0.0;  // flat on the Z plane
     pointSet->SetPoint( pointId, point );   
     pointSet->SetPointData( pointId, tangent );   
@@ -194,6 +194,3 @@ int main(int, char *[])
 
   return 0;
 }
-
-
-
