@@ -3,14 +3,14 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: DigitallyReconstructedRadiograph1.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-01-20 19:33:34 $
-  Version:   $Revision: 1.16 $
+  Date:      $Date: 2009-04-05 23:52:49 $
+  Version:   $Revision: 1.18 $
 
-  Copyright (c) 2002 Insight Consortium. All rights reserved.
+  Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
@@ -53,8 +53,6 @@
 #include "itkRayCastInterpolateImageFunction.h"
 // Software Guide : EndCodeSnippet
 
-
-
 //#define WRITE_CUBE_IMAGE_TO_FILE
 
 
@@ -83,8 +81,6 @@ void usage()
   exit(1);
 }
 
-
-
 int main( int argc, char *argv[] )
 {
   char *input_name = NULL;
@@ -129,7 +125,7 @@ int main( int argc, char *argv[] )
       {
       argc--; argv++;
       ok = true;
-      usage();      
+      usage();
       }
 
     if ((ok == false) && (strcmp(argv[1], "-v") == 0))
@@ -274,7 +270,7 @@ int main( int argc, char *argv[] )
 
 // Software Guide : BeginCodeSnippet
   const     unsigned int   Dimension = 3;
-  typedef   short  InputPixelType;
+  typedef   short         InputPixelType;
   typedef   unsigned char OutputPixelType;
   
   typedef itk::Image< InputPixelType,  Dimension >   InputImageType;
@@ -319,13 +315,13 @@ int main( int argc, char *argv[] )
 
     InputImageType::SpacingType spacing;
     spacing[0] = 3.; 
-    spacing[1] = 3.;    
+    spacing[1] = 3.;
     spacing[2] = 3.;
     image->SetSpacing( spacing );
 
     InputImageType::PointType origin;
     origin[0] = 0.; 
-    origin[1] = 0.;    
+    origin[1] = 0.;
     origin[2] = 0.;
     image->SetOrigin( origin );
 
@@ -496,7 +492,7 @@ int main( int argc, char *argv[] )
   translation[2] = tz;
 
   // constant for converting degrees into radians
-  const double dtr = ( atan(1.0) * 4.0 ) / 180.0;
+  const double dtr = ( vcl_atan(1.0) * 4.0 ) / 180.0;
 
   transform->SetTranslation( translation );
   transform->SetRotation( dtr*rx, dtr*ry, dtr*rz );
@@ -725,4 +721,3 @@ int main( int argc, char *argv[] )
 
   return EXIT_SUCCESS;
 }
-
