@@ -3,14 +3,14 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: FFTDirectInverse.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-05-14 12:12:51 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-03-16 21:52:48 $
+  Version:   $Revision: 1.5 $
 
-  Copyright (c) 2002 Insight Consortium. All rights reserved.
+  Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
@@ -22,17 +22,14 @@
 #define ITK_LEAN_AND_MEAN
 #endif
 
-
 //
-// This example was contributed by Stephan in the users list
+// This example was originally contributed by Stephan in the users list
 //
 //     http://public.kitware.com/pipermail/insight-users/2005-June/013482.html
 //
 //
 
 
-
-
 // Software Guide : BeginLatex
 //
 // This example illustrates how to compute the direct Fourier transform
@@ -41,17 +38,12 @@
 //
 // Software Guide : EndLatex 
 
-
 #include "itkImage.h"
 #include "itkImageFileReader.h"
 #include "itkImageFileWriter.h"
 #include "itkResampleImageFilter.h"
-#include "itkRescaleIntensityImageFilter.h"
 #include "itkVnlFFTRealToComplexConjugateImageFilter.h"
 #include "itkVnlFFTComplexConjugateToRealImageFilter.h"
-#include "itkFlipImageFilter.h"
-
-
 
 int main( int argc, char * argv[] )
 {
@@ -60,7 +52,7 @@ int main( int argc, char * argv[] )
     std::cerr << "Usage: " << argv[0] << " input output" << std::endl;
     return EXIT_FAILURE;
     }
-
+  
 // Software Guide : BeginLatex
 //
 // First we set up the types of the input and output images.
@@ -68,16 +60,16 @@ int main( int argc, char * argv[] )
 // Software Guide : EndLatex 
 
 // Software Guide : BeginCodeSnippet
-  const unsigned int      Dimension = 2;
-  typedef unsigned char   IOPixelType;
-  typedef float           WorkPixelType; 
+  const   unsigned int      Dimension = 2;
+  typedef unsigned short    IOPixelType;
+  typedef float             WorkPixelType; 
   
-  typedef itk::Image< IOPixelType,  Dimension > IOImageType;
+  typedef itk::Image< IOPixelType,  Dimension >  IOImageType;
   typedef itk::Image< WorkPixelType, Dimension > WorkImageType;
-// Software Guide : EndCodeSnippet
+  // Software Guide : EndCodeSnippet
 
   
-// File handling
+  // File handling
   typedef itk::ImageFileReader< IOImageType > ReaderType;
   typedef itk::ImageFileWriter< IOImageType > WriterType;
   
@@ -88,20 +80,15 @@ int main( int argc, char * argv[] )
   inputreader->SetFileName( argv[1] );
   writer->SetFileName( argv[2] );
 
-
-
-// Handle padding of the image with resampling
+  // Handle padding of the image with resampling
   typedef itk::ResampleImageFilter< 
                               IOImageType, 
                               WorkImageType >  ResamplerType;
 
   ResamplerType::Pointer inputresampler = ResamplerType::New();
-
   inputresampler->SetDefaultPixelValue(0);
 
-
-
-// Read the image and get its size
+  // Read the image and get its size
   inputreader->Update();
 
   IOImageType::SizeType     inputsize;
@@ -109,8 +96,8 @@ int main( int argc, char * argv[] )
 
   inputsize = inputreader->GetOutput()->GetLargestPossibleRegion().GetSize();
 
-// worksize is the nearest multiple of 2 larger than the input 
-  for( unsigned int i=0; i < 2 ; i++ ) 
+  // worksize is the nearest multiple of 2 larger than the input 
+  for( unsigned int i=0; i < 2; i++ ) 
     {
     int n=0;
     worksize[i] = inputsize[i];
@@ -120,70 +107,40 @@ int main( int argc, char * argv[] )
       }
     worksize[i] = 1 << (n+1);
 
+    std::cout << "inputsize[" << i << "]=" << inputsize[i] << std::endl;
     std::cout << "worksize[" << i << "]=" << worksize[i] << std::endl;
     }
 
   inputresampler->SetSize( worksize );
   inputresampler->SetInput( inputreader->GetOutput() );
 
-
-// Forward FFT filter
+  // Forward FFT filter
   typedef itk::VnlFFTRealToComplexConjugateImageFilter < 
                                               WorkPixelType, 
-                                              Dimension 
-                                                      > FFTFilterType;
-
+                                              Dimension > FFTFilterType;
   FFTFilterType::Pointer fftinput = FFTFilterType::New();
-
   fftinput->SetInput( inputresampler->GetOutput() );
 
-// This is the output type from the FFT filters
+  // This is the output type from the FFT filters
   typedef FFTFilterType::OutputImageType ComplexImageType;
 
-
-
-// Do the inverse transform = forward transform + flip all axes
+  // Do the inverse transform = forward transform / num voxels
   typedef itk::VnlFFTComplexConjugateToRealImageFilter < 
                                               WorkPixelType, 
                                               Dimension > invFFTFilterType;
-
   invFFTFilterType::Pointer fftoutput = invFFTFilterType::New();
-
   fftoutput->SetInput(fftinput->GetOutput()); // try to recover the input image
 
-// Flip all axes to complete the inverse transform
-  typedef itk::FlipImageFilter< WorkImageType > FlipperType;
+  // undo the padding
+  typedef itk::ResampleImageFilter<WorkImageType, IOImageType> ResampleOutType;
+  ResampleOutType::Pointer outputResampler = ResampleOutType::New();
+  outputResampler->SetDefaultPixelValue( 0 );
+  outputResampler->SetSize( inputsize );
+  outputResampler->SetInput( fftoutput->GetOutput() );
 
-  FlipperType::Pointer flipper = FlipperType::New();
-
-
-
-  bool fliparray[Dimension] = {true,true};
-
-  FlipperType::FlipAxesArrayType flipAxes( fliparray );
-
-  flipper->SetFlipAxes(flipAxes);
-
-  flipper->SetInput(fftoutput->GetOutput());
-
-// Rescale the output to suit the output image type
-  typedef itk::RescaleIntensityImageFilter< 
-                                      WorkImageType, 
-                                      IOImageType > RescaleFilterType;
-
-  RescaleFilterType::Pointer intensityrescaler = RescaleFilterType::New();
-
-  intensityrescaler->SetInput( flipper->GetOutput() );
-
-  intensityrescaler->SetOutputMinimum(  0  );
-  intensityrescaler->SetOutputMaximum( 255 );
-
-// Write the output
-  writer->SetInput(intensityrescaler->GetOutput());
+  // Write the output
+  writer->SetInput(outputResampler->GetOutput());
   writer->Update();
 
   return EXIT_SUCCESS;
-
-
 }
-
