@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: GaussianBlurImageFunction.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-08-27 01:45:54 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-05-13 14:14:28 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -36,7 +36,7 @@ int main( int argc, char * argv[] )
     return EXIT_FAILURE;
   }
 
-  typedef itk::Image< float, 2 >   ImageType;
+  typedef itk::Image< float, 2 >             ImageType;
   typedef itk::ImageFileReader< ImageType >  ReaderType;
   typedef itk::ImageRegionIterator< ImageType > IteratorType;
   typedef itk::ImageRegionConstIterator< ImageType > ConstIteratorType;
@@ -72,11 +72,13 @@ int main( int argc, char * argv[] )
 
   it.GoToBegin();
   out.GoToBegin();
-  while (!it.IsAtEnd()) {
-      out.Set( gaussianFunction->EvaluateAtIndex(it.GetIndex() ) );
-      ++it;
-      ++out;
-  }
+
+  while( !it.IsAtEnd() )
+    {
+    out.Set( gaussianFunction->EvaluateAtIndex(it.GetIndex() ) );
+    ++it;
+    ++out;
+    }
 
   typedef itk::ImageFileWriter < ImageType > WriterType;
   WriterType::Pointer writer = WriterType::New();
