@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ResampleImageFilter.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-05-14 12:12:52 $
-  Version:   $Revision: 1.32 $
+  Date:      $Date: 2009-02-20 19:23:32 $
+  Version:   $Revision: 1.33 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -263,6 +263,13 @@ int main( int argc, char * argv[] )
   // Software Guide : EndCodeSnippet
 
 
+  // Software Guide : BeginCodeSnippet
+  InputImageType::DirectionType direction;
+  direction.SetIdentity();
+  filter->SetOutputDirection( direction );
+  // Software Guide : EndCodeSnippet
+
+
   //  Software Guide : BeginLatex
   //
   //  The extent of the sampling grid on the output image is defined by a
