@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ResampleImageFilter2.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-05-14 12:12:52 $
-  Version:   $Revision: 1.32 $
+  Date:      $Date: 2009-02-20 19:23:32 $
+  Version:   $Revision: 1.33 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -142,6 +142,19 @@ int main( int argc, char * argv[] )
   // Software Guide : EndCodeSnippet
 
 
+  //  Software Guide : BeginLatex
+  //
+  //  We will preserve the orientation of the input image by using the following call.
+  //
+  //  \index{itk::ResampleImageFilter!SetOutputOrigin()}
+  //
+  //  Software Guide : EndLatex 
+
+  // Software Guide : BeginCodeSnippet
+  filter->SetOutputDirection( reader->GetOutput()->GetDirection() );
+  // Software Guide : EndCodeSnippet
+
+
   //  Software Guide : BeginLatex
   //
   //  Additionally, we will specify a non-zero origin. Note that the values
