@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ResampleImageFilter6.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-08-27 01:46:01 $
-  Version:   $Revision: 1.13 $
+  Date:      $Date: 2009-02-20 19:23:32 $
+  Version:   $Revision: 1.14 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -106,6 +106,14 @@ int main( int argc, char * argv[] )
   filter->SetOutputOrigin( origin );
   // Software Guide : EndCodeSnippet
 
+  
+  // Software Guide : BeginCodeSnippet
+  ImageType::DirectionType direction;
+  direction.SetIdentity();
+  filter->SetOutputDirection( direction );
+  // Software Guide : EndCodeSnippet
+
+
 
   ImageType::SizeType   size;
 
