@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ResampleImageFilter7.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-05-14 12:12:52 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-04-05 23:52:49 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -130,10 +130,13 @@ int main( int argc, char * argv[] )
     spacing = reader->GetOutput()->GetSpacing();
   const InputImageType::PointType&
     origin  = reader->GetOutput()->GetOrigin();
+  const InputImageType::DirectionType&
+    direction  = reader->GetOutput()->GetDirection();
   InputImageType::SizeType size = 
       reader->GetOutput()->GetLargestPossibleRegion().GetSize();
   filter->SetOutputOrigin( origin );
   filter->SetOutputSpacing( spacing );
+  filter->SetOutputDirection( direction );
   filter->SetSize( size );
   // Software Guide : EndCodeSnippet
 
@@ -157,7 +160,7 @@ int main( int argc, char * argv[] )
   std::cout << "imageCenterY = " << imageCenterY << std::endl;
 
 
-  const double degreesToRadians = atan(1.0) / 45.0;
+  const double degreesToRadians = vcl_atan(1.0) / 45.0;
   const double angle = angleInDegrees * degreesToRadians;
   transform->Rotate2D( -angle, false );
 
