@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ResampleVolumesToBeIsotropic.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-11-20 13:27:52 $
-  Version:   $Revision: 1.21 $
+  Date:      $Date: 2009-04-06 00:19:18 $
+  Version:   $Revision: 1.23 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -305,7 +305,7 @@ int main( int argc, char * argv[] )
 // Software Guide : EndLatex 
 
 // Software Guide : BeginCodeSnippet
-  const double isoSpacing = sqrt( inputSpacing[2] * inputSpacing[0] );
+  const double isoSpacing = vcl_sqrt( inputSpacing[2] * inputSpacing[0] );
   
   smootherX->SetSigma( isoSpacing );
   smootherY->SetSigma( isoSpacing );
@@ -422,13 +422,15 @@ int main( int argc, char * argv[] )
 
 // Software Guide : BeginLatex
 //
-// The origin of the output image is maintained, since we decided to resample
-// the image in the same physical extent of the input anisotropic image.
+// The origin and orientation of the output image is maintained, since we
+// decided to resample the image in the same physical extent of the input
+// anisotropic image.
 //
 // Software Guide : EndLatex 
 
 // Software Guide : BeginCodeSnippet
   resampler->SetOutputOrigin( inputImage->GetOrigin() );
+  resampler->SetOutputDirection( inputImage->GetDirection() );
 // Software Guide : EndCodeSnippet
 
 
