@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: SubsampleVolume.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-11-19 16:31:50 $
-  Version:   $Revision: 1.13 $
+  Date:      $Date: 2009-02-20 19:23:32 $
+  Version:   $Revision: 1.14 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -312,12 +312,14 @@ int main( int argc, char * argv[] )
 
 // Software Guide : BeginLatex
 //
-// The origin of the input image is preserved and passed to the output image.
+// The origin and direction of the input image is preserved and passed to the
+// output image.
 //
 // Software Guide : EndLatex 
 
 // Software Guide : BeginCodeSnippet
   resampler->SetOutputOrigin( inputImage->GetOrigin() );
+  resampler->SetOutputDirection( inputImage->GetDirection() );
 // Software Guide : EndCodeSnippet
 
 
