@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: FourierDescriptors1.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-24 17:07:09 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-04-06 20:32:34 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -178,8 +178,9 @@ int main(int argc, char * argv[] )
   //  Software Guide : EndLatex 
 
   // Software Guide : BeginCodeSnippet
-  const unsigned int powerOfTwo   = (unsigned int)ceil( log( (double)(numberOfPoints)) /
-                                          log( (double)(2.0)));
+  const unsigned int powerOfTwo   = 
+    (unsigned int)vcl_ceil( vcl_log( (double)(numberOfPoints)) /
+                            vcl_log( (double)(2.0)) );
 
   const unsigned int spectrumSize = 1 << powerOfTwo;
 
@@ -276,7 +277,7 @@ int main(int argc, char * argv[] )
     {
     const double real = signal[k].real();
     const double imag = signal[k].imag();
-    const double magnitude = sqrt( real * real + imag * imag );
+    const double magnitude = vcl_sqrt( real * real + imag * imag );
     std::cout << k << "  " << magnitude << std::endl;
     }
   // Software Guide : EndCodeSnippet
