@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: DeformableRegistration12.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-11 16:01:02 $
-  Version:   $Revision: 1.15 $
+  Date:      $Date: 2009-06-24 12:08:58 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -18,9 +18,6 @@
 #pragma warning ( disable : 4786 )
 #endif
 
-
-
-
 // Software Guide : BeginLatex
 //
 // This example illustrates the use of the
@@ -103,30 +100,30 @@ class CommandIterationUpdate : public itk::Command
 public:
   typedef  CommandIterationUpdate   Self;
   typedef  itk::Command             Superclass;
-  typedef itk::SmartPointer<Self>  Pointer;
+  typedef itk::SmartPointer<Self>   Pointer;
   itkNewMacro( Self );
 protected:
   CommandIterationUpdate() {};
 public:
-  typedef itk::LBFGSBOptimizer     OptimizerType;
-  typedef   const OptimizerType   *    OptimizerPointer;
+  typedef itk::LBFGSBOptimizer         OptimizerType;
+  typedef   const OptimizerType *      OptimizerPointer;
 
   void Execute(itk::Object *caller, const itk::EventObject & event)
     {
-      Execute( (const itk::Object *)caller, event);
+    Execute( (const itk::Object *)caller, event);
     }
 
   void Execute(const itk::Object * object, const itk::EventObject & event)
     {
-      OptimizerPointer optimizer = 
-        dynamic_cast< OptimizerPointer >( object );
-      if( !(itk::IterationEvent().CheckEvent( &event )) )
-        {
-        return;
-        }
-      std::cout << optimizer->GetCurrentIteration() << "   ";
-      std::cout << optimizer->GetCachedValue() << "   ";
-      std::cout << optimizer->GetInfinityNormOfProjectedGradient() << std::endl;
+    OptimizerPointer optimizer = 
+      dynamic_cast< OptimizerPointer >( object );
+    if( !(itk::IterationEvent().CheckEvent( &event )) )
+      {
+      return;
+      }
+    std::cout << optimizer->GetCurrentIteration() << "   ";
+    std::cout << optimizer->GetCachedValue() << "   ";
+    std::cout << optimizer->GetInfinityNormOfProjectedGradient() << std::endl;
     }
 };
 
@@ -269,7 +266,7 @@ int main( int argc, char *argv[] )
   SpacingType spacing = fixedImage->GetSpacing();
 
   typedef TransformType::OriginType OriginType;
-  OriginType origin = fixedImage->GetOrigin();;
+  OriginType origin = fixedImage->GetOrigin();
 
   FixedImageType::SizeType fixedImageSize = fixedRegion.GetSize();
 
@@ -277,13 +274,17 @@ int main( int argc, char *argv[] )
     {
     spacing[r] *= static_cast<double>(fixedImageSize[r] - 1)  / 
                   static_cast<double>(gridSizeOnImage[r] - 1);
-    origin[r]  -=  spacing[r]; 
     }
 
+  FixedImageType::DirectionType gridDirection = fixedImage->GetDirection();
+  SpacingType gridOriginOffset = gridDirection * spacing;
+
+  OriginType gridOrigin = origin - gridOriginOffset; 
+
   transform->SetGridSpacing( spacing );
-  transform->SetGridOrigin( origin );
+  transform->SetGridOrigin( gridOrigin );
   transform->SetGridRegion( bsplineRegion );
-  transform->SetGridDirection( fixedImage->GetDirection() );
+  transform->SetGridDirection( gridDirection );
   
 
   typedef TransformType::ParametersType     ParametersType;
@@ -298,8 +299,6 @@ int main( int argc, char *argv[] )
   transform->SetParameters( parameters );
   //  Software Guide : EndCodeSnippet
 
-
-
   //  Software Guide : BeginLatex
   //  
   //  We now pass the parameters of the current transform as the initial
@@ -381,6 +380,9 @@ int main( int argc, char *argv[] )
     itkProbesStart( "Registration" );
     registration->StartRegistration(); 
     itkProbesStop( "Registration" );
+    std::cout << "Optimizer stop condition = "
+              << registration->GetOptimizer()->GetStopConditionDescription()
+              << std::endl;
     } 
   catch( itk::ExceptionObject & err ) 
     { 
@@ -506,20 +508,19 @@ int main( int argc, char *argv[] )
       } 
     }
 
-
-
   // Generate the explicit deformation field resulting from 
   // the registration.
   if( argc > 6 )
     {
 
-    typedef itk::Vector< float, ImageDimension >  VectorType;
+    typedef itk::Vector< float, ImageDimension >      VectorType;
     typedef itk::Image< VectorType, ImageDimension >  DeformationFieldType;
 
     DeformationFieldType::Pointer field = DeformationFieldType::New();
     field->SetRegions( fixedRegion );
     field->SetOrigin( fixedImage->GetOrigin() );
     field->SetSpacing( fixedImage->GetSpacing() );
+    field->SetDirection( fixedImage->GetDirection() );
     field->Allocate();
 
     typedef itk::ImageRegionIterator< DeformationFieldType > FieldIterator;
@@ -577,4 +578,3 @@ int main( int argc, char *argv[] )
 #undef itkProbesStart
 #undef itkProbesStop
 #undef itkProbesReport
-
