@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: DeformableRegistration4.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-11 16:01:02 $
-  Version:   $Revision: 1.23 $
+  Date:      $Date: 2009-06-24 12:08:59 $
+  Version:   $Revision: 1.25 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -18,8 +18,6 @@
 #pragma warning ( disable : 4786 )
 #endif
 
-
-
 // Software Guide : BeginLatex
 //
 // This example illustrates the use of the \doxygen{BSplineDeformableTransform}
@@ -233,7 +231,7 @@ int main( int argc, char *argv[] )
   SpacingType spacing = fixedImage->GetSpacing();
 
   typedef TransformType::OriginType OriginType;
-  OriginType origin = fixedImage->GetOrigin();;
+  OriginType origin = fixedImage->GetOrigin();
 
   FixedImageType::SizeType fixedImageSize = fixedRegion.GetSize();
 
@@ -241,13 +239,17 @@ int main( int argc, char *argv[] )
     {
     spacing[r] *= static_cast<double>(fixedImageSize[r] - 1)  / 
                   static_cast<double>(gridSizeOnImage[r] - 1);
-    origin[r]  -=  spacing[r]; 
     }
 
+  FixedImageType::DirectionType gridDirection = fixedImage->GetDirection();
+  SpacingType gridOriginOffset = gridDirection * spacing;
+
+  OriginType gridOrigin = origin - gridOriginOffset; 
+
   transform->SetGridSpacing( spacing );
-  transform->SetGridOrigin( origin );
+  transform->SetGridOrigin( gridOrigin );
   transform->SetGridRegion( bsplineRegion );
-  transform->SetGridDirection( fixedImage->GetDirection() );
+  transform->SetGridDirection( gridDirection );
   
 
   typedef TransformType::ParametersType     ParametersType;
@@ -262,8 +264,6 @@ int main( int argc, char *argv[] )
   transform->SetParameters( parameters );
   //  Software Guide : EndCodeSnippet
 
-
-
   //  Software Guide : BeginLatex
   //  
   //  We now pass the parameters of the current transform as the initial
@@ -292,8 +292,6 @@ int main( int argc, char *argv[] )
   optimizer->SetMaximumNumberOfFunctionEvaluations( 1000 );
   // Software Guide : EndCodeSnippet
 
-
-
   // Add time and memory probes
   itkProbesCreate();
 
@@ -304,6 +302,9 @@ int main( int argc, char *argv[] )
     itkProbesStart( "Registration" );
     registration->StartRegistration(); 
     itkProbesStop( "Registration" );
+    std::cout << "Optimizer stop condition = "
+              << registration->GetOptimizer()->GetStopConditionDescription()
+              << std::endl;
     } 
   catch( itk::ExceptionObject & err ) 
     { 
@@ -439,18 +440,17 @@ int main( int argc, char *argv[] )
       } 
     }
 
-
-
   // Generate the explicit deformation field resulting from 
   // the registration.
 
-  typedef itk::Vector< float, ImageDimension >  VectorType;
+  typedef itk::Vector< float, ImageDimension >      VectorType;
   typedef itk::Image< VectorType, ImageDimension >  DeformationFieldType;
 
   DeformationFieldType::Pointer field = DeformationFieldType::New();
   field->SetRegions( fixedRegion );
   field->SetOrigin( fixedImage->GetOrigin() );
   field->SetSpacing( fixedImage->GetSpacing() );
+  field->SetDirection( fixedImage->GetDirection() );
   field->Allocate();
 
   typedef itk::ImageRegionIterator< DeformationFieldType > FieldIterator;
@@ -469,14 +469,11 @@ int main( int argc, char *argv[] )
     index = fi.GetIndex();
     field->TransformIndexToPhysicalPoint( index, fixedPoint );
     movingPoint = transform->TransformPoint( fixedPoint );
-    displacement[0] = movingPoint[0] - fixedPoint[0];
-    displacement[1] = movingPoint[1] - fixedPoint[1];
+    displacement = movingPoint - fixedPoint;
     fi.Set( displacement );
     ++fi;
     }
 
-
-
   typedef itk::ImageFileWriter< DeformationFieldType >  FieldWriterType;
   FieldWriterType::Pointer fieldWriter = FieldWriterType::New();
 
@@ -504,4 +501,3 @@ int main( int argc, char *argv[] )
 #undef itkProbesStart
 #undef itkProbesStop
 #undef itkProbesReport
-
