@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: DeformableRegistration6.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-11 16:01:02 $
-  Version:   $Revision: 1.16 $
+  Date:      $Date: 2009-06-24 12:09:00 $
+  Version:   $Revision: 1.18 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -18,8 +18,6 @@
 #pragma warning ( disable : 4786 )
 #endif
 
-
-
 // Software Guide : BeginLatex
 //
 // This example illustrates the use of the \doxygen{BSplineDeformableTransform}
@@ -219,7 +217,7 @@ int main( int argc, char *argv[] )
   SpacingType spacingLow = fixedImage->GetSpacing();
 
   typedef TransformType::OriginType OriginType;
-  OriginType originLow = fixedImage->GetOrigin();;
+  OriginType originLow = fixedImage->GetOrigin();
 
   FixedImageType::SizeType fixedImageSize = fixedRegion.GetSize();
 
@@ -227,13 +225,17 @@ int main( int argc, char *argv[] )
     {
     spacingLow[r] *= static_cast<double>(fixedImageSize[r] - 1)  / 
                      static_cast<double>(gridLowSizeOnImage[r] - 1);
-    originLow[r]  -=  spacingLow[r]; 
     }
 
+  FixedImageType::DirectionType gridDirection = fixedImage->GetDirection();
+  SpacingType gridOriginOffsetLow = gridDirection * spacingLow;
+
+  OriginType gridOriginLow = originLow - gridOriginOffsetLow; 
+
   transformLow->SetGridSpacing( spacingLow );
-  transformLow->SetGridOrigin( originLow );
+  transformLow->SetGridOrigin( gridOriginLow );
   transformLow->SetGridRegion( bsplineRegion );
-  transformLow->SetGridDirection( fixedImage->GetDirection() );
+  transformLow->SetGridDirection( gridDirection );
 
   typedef TransformType::ParametersType     ParametersType;
 
@@ -247,8 +249,6 @@ int main( int argc, char *argv[] )
   transformLow->SetParameters( parametersLow );
   //  Software Guide : EndCodeSnippet
 
-
-
   //  Software Guide : BeginLatex
   //  
   //  We now pass the parameters of the current transform as the initial
@@ -272,6 +272,9 @@ int main( int argc, char *argv[] )
   try 
     { 
     registration->StartRegistration(); 
+    std::cout << "Optimizer stop condition = "
+              << registration->GetOptimizer()->GetStopConditionDescription()
+              << std::endl;
     } 
   catch( itk::ExceptionObject & err ) 
     { 
@@ -299,19 +302,23 @@ int main( int argc, char *argv[] )
   bsplineRegion.SetSize( totalGridSize );
 
   SpacingType spacingHigh = fixedImage->GetSpacing();
-  OriginType  originHigh  = fixedImage->GetOrigin();;
+  OriginType  originHigh  = fixedImage->GetOrigin();
 
   for(unsigned int rh=0; rh<ImageDimension; rh++)
     {
     spacingHigh[rh] *= static_cast<double>(fixedImageSize[rh] - 1)  / 
                        static_cast<double>(gridHighSizeOnImage[rh] - 1);
-    originHigh[rh]  -=  spacingHigh[rh]; 
     }
 
+  SpacingType gridOriginOffsetHigh = gridDirection * spacingHigh;
+
+  OriginType gridOriginHigh = originHigh - gridOriginOffsetHigh; 
+
+
   transformHigh->SetGridSpacing( spacingHigh );
-  transformHigh->SetGridOrigin( originHigh );
+  transformHigh->SetGridOrigin( gridOriginHigh );
   transformHigh->SetGridRegion( bsplineRegion );
-  transformHigh->SetGridDirection( fixedImage->GetDirection() );
+  transformHigh->SetGridDirection( gridDirection );
 
   ParametersType parametersHigh( transformHigh->GetNumberOfParameters() );
   parametersHigh.Fill( 0.0 );
@@ -346,6 +353,7 @@ int main( int argc, char *argv[] )
     upsampler->SetSize( transformHigh->GetGridRegion().GetSize() );
     upsampler->SetOutputSpacing( transformHigh->GetGridSpacing() );
     upsampler->SetOutputOrigin( transformHigh->GetGridOrigin() );
+    upsampler->SetOutputDirection( fixedImage->GetDirection() );
 
     typedef itk::BSplineDecompositionImageFilter<ParametersImageType,ParametersImageType>
       DecompositionType;
@@ -405,8 +413,6 @@ int main( int argc, char *argv[] )
     } 
   // Software Guide : EndCodeSnippet
 
-
-
   // Finally we use the last transform parameters in order to resample the image.
   //
   transformHigh->SetParameters( registration->GetLastTransformParameters() );
@@ -511,18 +517,17 @@ int main( int argc, char *argv[] )
       } 
     }
 
-
-
   // Generate the explicit deformation field resulting from 
   // the registration.
 
-  typedef itk::Vector< float, ImageDimension >  VectorType;
+  typedef itk::Vector< float, ImageDimension >      VectorType;
   typedef itk::Image< VectorType, ImageDimension >  DeformationFieldType;
 
   DeformationFieldType::Pointer field = DeformationFieldType::New();
   field->SetRegions( fixedRegion );
   field->SetOrigin( fixedImage->GetOrigin() );
   field->SetSpacing( fixedImage->GetSpacing() );
+  field->SetDirection( fixedImage->GetDirection() );
   field->Allocate();
 
   typedef itk::ImageRegionIterator< DeformationFieldType > FieldIterator;
@@ -541,14 +546,11 @@ int main( int argc, char *argv[] )
     index = fi.GetIndex();
     field->TransformIndexToPhysicalPoint( index, fixedPoint );
     movingPoint = transformHigh->TransformPoint( fixedPoint );
-    displacement[0] = movingPoint[0] - fixedPoint[0];
-    displacement[1] = movingPoint[1] - fixedPoint[1];
+    displacement = movingPoint - fixedPoint;
     fi.Set( displacement );
     ++fi;
     }
 
-
-
   typedef itk::ImageFileWriter< DeformationFieldType >  FieldWriterType;
   FieldWriterType::Pointer fieldWriter = FieldWriterType::New();
 
@@ -571,4 +573,3 @@ int main( int argc, char *argv[] )
 
   return EXIT_SUCCESS;
 }
-
