@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ImageRegistration15.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-05-06 14:37:48 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-06-24 12:09:07 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -18,10 +18,6 @@
 #pragma warning ( disable : 4786 )
 #endif
 
-
-
-
-
 // Software Guide : BeginLatex
 //
 //  This example illustrates how to do registration with a 2D Translation Transform,
@@ -56,17 +52,17 @@ class CommandIterationUpdate : public itk::Command
 public:
   typedef  CommandIterationUpdate   Self;
   typedef  itk::Command             Superclass;
-  typedef itk::SmartPointer<Self>  Pointer;
+  typedef itk::SmartPointer<Self>   Pointer;
   itkNewMacro( Self );
 protected:
   CommandIterationUpdate() {m_LastMetricValue = 0;}
 public:
-  typedef itk::OnePlusOneEvolutionaryOptimizer     OptimizerType;
-  typedef   const OptimizerType   *    OptimizerPointer;
+  typedef itk::OnePlusOneEvolutionaryOptimizer OptimizerType;
+  typedef   const OptimizerType *              OptimizerPointer;
 
   void Execute(itk::Object *caller, const itk::EventObject & event)
     {
-      Execute( (const itk::Object *)caller, event);
+    Execute( (const itk::Object *)caller, event);
     }
 
   void Execute(const itk::Object * object, const itk::EventObject & event)
@@ -126,8 +122,6 @@ int main( int argc, char *argv[] )
                                           FixedImageType, 
                                           MovingImageType >    MetricType;
 
-
-
   TransformType::Pointer      transform     = TransformType::New();
   OptimizerType::Pointer      optimizer     = OptimizerType::New();
   InterpolatorType::Pointer   interpolator  = InterpolatorType::New();
@@ -167,8 +161,6 @@ int main( int argc, char *argv[] )
     
   metric->SetDerivativeStepLengthScales(scales);
 
-
-
   typedef itk::ImageFileReader< FixedImageType  > FixedImageReaderType;
   typedef itk::ImageFileReader< MovingImageType > MovingImageReaderType;
 
@@ -262,6 +254,9 @@ int main( int argc, char *argv[] )
   try 
     { 
     registration->StartRegistration(); 
+    std::cout << "Optimizer stop condition: "
+              << registration->GetOptimizer()->GetStopConditionDescription()
+              << std::endl;
     } 
   catch( itk::ExceptionObject & err ) 
     { 
@@ -323,10 +318,7 @@ int main( int argc, char *argv[] )
   writer->SetInput( resample->GetOutput() );
   writer->Update();
 
-// Software Guide : EndCodeSnippet
-
-
+  // Software Guide : EndCodeSnippet
 
   return EXIT_SUCCESS;
 }
-
