@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ImageRegistration7o.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-11-22 00:30:16 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-06-24 12:09:23 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -19,9 +19,6 @@
 #endif
 
 
-
-
-
 // Software Guide : BeginLatex
 //
 // This example illustrates the use of the \doxygen{CenteredSimilarity2DTransform}
@@ -90,30 +87,30 @@ class CommandIterationUpdate : public itk::Command
 public:
   typedef  CommandIterationUpdate   Self;
   typedef  itk::Command             Superclass;
-  typedef itk::SmartPointer<Self>  Pointer;
+  typedef itk::SmartPointer<Self>   Pointer;
   itkNewMacro( Self );
 protected:
   CommandIterationUpdate() {};
 public:
-  typedef itk::RegularStepGradientDescentOptimizer     OptimizerType;
-  typedef   const OptimizerType   *    OptimizerPointer;
+  typedef itk::RegularStepGradientDescentOptimizer  OptimizerType;
+  typedef   const OptimizerType *                   OptimizerPointer;
 
   void Execute(itk::Object *caller, const itk::EventObject & event)
     {
-      Execute( (const itk::Object *)caller, event);
+    Execute( (const itk::Object *)caller, event);
     }
 
   void Execute(const itk::Object * object, const itk::EventObject & event)
     {
-      OptimizerPointer optimizer = 
-        dynamic_cast< OptimizerPointer >( object );
-      if( ! itk::IterationEvent().CheckEvent( &event ) )
-        {
-        return;
-        }
-      std::cout << optimizer->GetCurrentIteration() << "   ";
-      std::cout << optimizer->GetValue() << "   ";
-      std::cout << optimizer->GetCurrentPosition() << std::endl;
+    OptimizerPointer optimizer = 
+      dynamic_cast< OptimizerPointer >( object );
+    if( ! itk::IterationEvent().CheckEvent( &event ) )
+      {
+      return;
+      }
+    std::cout << optimizer->GetCurrentIteration() << "   ";
+    std::cout << optimizer->GetValue() << "   ";
+    std::cout << optimizer->GetCurrentPosition() << std::endl;
     }
 };
 
@@ -317,6 +314,9 @@ int main( int argc, char *argv[] )
   try 
     { 
     registration->StartRegistration(); 
+    std::cout << "Optimizer stop condition: "
+              << registration->GetOptimizer()->GetStopConditionDescription()
+              << std::endl;
     } 
   catch( itk::ExceptionObject & err ) 
     { 
@@ -343,7 +343,7 @@ int main( int argc, char *argv[] )
 
   // Print out results
   //
-  const double finalAngleInDegrees = finalAngle * 45.0 / atan(1.0);
+  const double finalAngleInDegrees = finalAngle * 180.0 / vnl_math::pi;
 
   std::cout << "Result = " << std::endl;
   std::cout << " Scale         = " << finalScale  << std::endl;
@@ -442,7 +442,10 @@ int main( int argc, char *argv[] )
   typedef itk::ResampleImageFilter< MovingImageType, FixedImageType >
     ResampleFilterType;
   TransformType::Pointer finalTransform = TransformType::New();
+
   finalTransform->SetParameters( finalParameters );
+  finalTransform->SetFixedParameters( transform->GetFixedParameters() );
+
   ResampleFilterType::Pointer resample = ResampleFilterType::New();
 
   resample->SetTransform( finalTransform );
@@ -510,7 +513,5 @@ int main( int argc, char *argv[] )
     writer2->Update();
     }
 
-
   return EXIT_SUCCESS;
 }
-
