@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ImageRegistration9.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-11-22 00:30:16 $
-  Version:   $Revision: 1.34 $
+  Date:      $Date: 2009-06-24 12:09:28 $
+  Version:   $Revision: 1.38 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -18,10 +18,6 @@
 #pragma warning ( disable : 4786 )
 #endif
 
-
-
-
-
 //  Software Guide : BeginCommandLineArgs
 //    INPUTS: {BrainProtonDensitySliceBorder20.png}
 //    INPUTS: {BrainProtonDensitySliceR10X13Y17.png}
@@ -54,8 +50,6 @@
 
 #include "itkCenteredTransformInitializer.h"
 
-
-
 //  Software Guide : BeginLatex
 //  
 //  Let's start by including the header file of the AffineTransform.
@@ -88,21 +82,21 @@ class CommandIterationUpdate : public itk::Command
 public:
   typedef  CommandIterationUpdate   Self;
   typedef  itk::Command             Superclass;
-  typedef itk::SmartPointer<Self>  Pointer;
+  typedef itk::SmartPointer<Self>   Pointer;
   itkNewMacro( Self );
 protected:
   CommandIterationUpdate() {};
 public:
-  typedef itk::RegularStepGradientDescentOptimizer     OptimizerType;
-  typedef   const OptimizerType   *    OptimizerPointer;
+  typedef itk::RegularStepGradientDescentOptimizer OptimizerType;
+  typedef   const OptimizerType *                  OptimizerPointer;
 
   void Execute(itk::Object *caller, const itk::EventObject & event)
-  {
+    {
     Execute( (const itk::Object *)caller, event);
-  }
+    }
 
   void Execute(const itk::Object * object, const itk::EventObject & event)
-  {
+    {
     OptimizerPointer optimizer = 
                       dynamic_cast< OptimizerPointer >( object );
     if( ! itk::IterationEvent().CheckEvent( &event ) )
@@ -122,8 +116,8 @@ public:
       vnl_svd<double> svd(p);
       vnl_matrix<double> r(2, 2);
       r = svd.U() * vnl_transpose(svd.V());
-      double angle = asin(r[1][0]);
-      std::cout << " AffineAngle: " << angle * 45.0 / atan(1.0) << std::endl;
+      double angle = vcl_asin(r[1][0]);
+      std::cout << " AffineAngle: " << angle * 180.0 / vnl_math::pi << std::endl;
     }
 };
 
@@ -365,6 +359,9 @@ int main( int argc, char *argv[] )
   try 
     { 
     registration->StartRegistration(); 
+    std::cout << "Optimizer stop condition: "
+              << registration->GetOptimizer()->GetStopConditionDescription()
+              << std::endl;
     } 
   catch( itk::ExceptionObject & err ) 
     { 
@@ -426,11 +423,13 @@ int main( int argc, char *argv[] )
   vnl_svd<double> svd(p);
   vnl_matrix<double> r(2, 2);
   r = svd.U() * vnl_transpose(svd.V());
-  double angle = asin(r[1][0]);
+  double angle = vcl_asin(r[1][0]);
   
-  std::cout << " Scale 1         = " << svd.W(0)                 << std::endl;
-  std::cout << " Scale 2         = " << svd.W(1)                 << std::endl;
-  std::cout << " Angle (degrees) = " << angle * 45.0 / atan(1.0) << std::endl;
+  const double angleInDegrees = angle * 180.0 / vnl_math::pi;
+
+  std::cout << " Scale 1         = " << svd.W(0)        << std::endl;
+  std::cout << " Scale 2         = " << svd.W(1)        << std::endl;
+  std::cout << " Angle (degrees) = " << angleInDegrees  << std::endl;
   
 
   //  Software Guide : BeginLatex
@@ -532,8 +531,8 @@ int main( int argc, char *argv[] )
 
   TransformType::Pointer finalTransform = TransformType::New();
 
-  finalTransform->SetCenter( transform->GetCenter() );
   finalTransform->SetParameters( finalParameters );
+  finalTransform->SetFixedParameters( transform->GetFixedParameters() );
 
   ResampleFilterType::Pointer resampler = ResampleFilterType::New();
 
@@ -617,7 +616,5 @@ int main( int argc, char *argv[] )
     writer2->Update();
     }
 
-
   return EXIT_SUCCESS;
 }
-
