@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: RegistrationExamples14.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-07 00:05:37 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2009-12-04 03:25:22 $
+  Version:   $Revision: 1.2 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -33,6 +33,9 @@
 void RegisterTests()
 {
   REGISTER_TEST(DeformableRegistration15Test);
+  REGISTER_TEST(IterativeClosestPoint1Test);
+  REGISTER_TEST(IterativeClosestPoint2Test);
+  REGISTER_TEST(IterativeClosestPoint3Test);
 }
 
 #undef main
@@ -41,3 +44,21 @@ void RegisterTests()
 #define CommandIterationUpdate CommandIterationUpdate15
 #include "DeformableRegistration15.cxx"
 
+#undef main
+#define main  IterativeClosestPoint1Test
+#undef CommandIterationUpdate
+#define CommandIterationUpdate CommandIterationUpdateICP1
+#include "IterativeClosestPoint1.cxx"
+
+#undef main
+#define main  IterativeClosestPoint2Test
+#undef CommandIterationUpdate
+#define CommandIterationUpdate CommandIterationUpdateICP2
+#include "IterativeClosestPoint2.cxx"
+
+#undef main
+#define main  IterativeClosestPoint3Test
+#undef CommandIterationUpdate
+#define CommandIterationUpdate CommandIterationUpdateICP3
+#include "IterativeClosestPoint3.cxx"
+
