@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: SpatialObjectToImageStatisticsCalculator.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-12-10 17:10:51 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-07-12 10:52:54 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -45,7 +45,7 @@ int main(int, char * [] )
   typedef itk::Image<unsigned char,2> ImageType;
   typedef itk::RandomImageSource<ImageType> RandomImageSourceType;
   RandomImageSourceType::Pointer randomImageSource = RandomImageSourceType::New();
-  unsigned long size[2];
+  ImageType::SizeValueType size[2];
   size[0] = 10;
   size[1] = 10;
   randomImageSource->SetSize(size);
