@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ImageToListAdaptor.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-08 03:56:48 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-07-12 10:52:54 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -82,13 +82,17 @@ int main()
   random->SetMin(    0.0 );
   random->SetMax( 1000.0 );
   
-  unsigned long size[2] = {20, 20};
+  typedef FloatImage2DType::SpacingValueType  SpacingValueType;
+  typedef FloatImage2DType::SizeValueType     SizeValueType;
+  typedef FloatImage2DType::PointValueType    PointValueType;
+
+  SizeValueType size[2] = {20, 20};
   random->SetSize( size );
 
-  float spacing[2] = {0.7, 2.1};
+  SpacingValueType spacing[2] = {0.7, 2.1};
   random->SetSpacing( spacing );
 
-  float origin[2] = {15, 400};
+  PointValueType origin[2] = {15, 400};
   random->SetOrigin( origin );
   // Software Guide : EndCodeSnippet
 
