@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCurvatureRegistrationFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-08-30 13:39:59 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-07-12 10:52:55 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -116,7 +116,7 @@ int itkCurvatureRegistrationFilterTest(int, char* [] )
   std::cout << "Generate input images and initial deformation field";
   std::cout << std::endl;
 
-  unsigned long sizeArray[ImageDimension] = { 128, 128 };
+  ImageType::SizeValueType sizeArray[ImageDimension] = { 128, 128 };
   SizeType size;
   size.SetSize( sizeArray );
 
