@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkDemonsRegistrationFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-04-25 15:23:59 $
-  Version:   $Revision: 1.25 $
+  Date:      $Date: 2009-07-12 10:52:55 $
+  Version:   $Revision: 1.27 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -118,7 +118,7 @@ int itkDemonsRegistrationFilterTest(int, char* [] )
   std::cout << "Generate input images and initial deformation field";
   std::cout << std::endl;
 
-  unsigned long sizeArray[ImageDimension] = { 128, 128 };
+  ImageType::SizeValueType sizeArray[ImageDimension] = { 128, 128 };
   SizeType size;
   size.SetSize( sizeArray );
 
@@ -231,6 +231,8 @@ int itkDemonsRegistrationFilterTest(int, char* [] )
   warper->SetInterpolator( interpolator );
   warper->SetOutputSpacing( fixed->GetSpacing() );
   warper->SetOutputOrigin( fixed->GetOrigin() );
+  warper->SetOutputDirection( fixed->GetDirection() );
+  warper->SetEdgePaddingValue( bgnd );
 
   warper->Print( std::cout );
 
