@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkExtensionVelocitiesImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-04-07 12:32:59 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2009-04-06 16:04:06 $
+  Version:   $Revision: 1.10 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -109,7 +109,7 @@ SimpleVelocity( const TPoint & p )
       }
     }
 
-  return ( 10 * sin( value ) );
+  return ( 10 * vcl_sin( value ) );
 
 }
 
