@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFEMRegistrationFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-11-30 19:08:30 $
-  Version:   $Revision: 1.13 $
+  Date:      $Date: 2009-07-12 10:52:55 $
+  Version:   $Revision: 1.14 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -131,7 +131,8 @@ int itkFEMRegistrationFilterTest(int, char* [] )
   std::cout << "Generate input images and initial deformation field";
   std::cout << std::endl;
 
-  unsigned long sizeArray[ImageDimension] = { 32, 32, 32 };
+  FloatImageType::SizeValueType sizeArray[ImageDimension] = { 32, 32, 32 };
+
   SizeType size;
   size.SetSize( sizeArray );
 
