@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGeodesicActiveContourShapePriorLevelSetImageFilterTest_2.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-10-07 16:43:01 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2008-10-20 03:20:05 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -18,6 +18,7 @@
 #pragma warning ( disable : 4786 )
 #endif
 
+#include "itkImage.h"
 #include "itkGeodesicActiveContourShapePriorLevelSetImageFilter.h"
 #include "itkPCAShapeSignedDistanceFunction.h"
 #include "itkShapePriorMAPCostFunction.h"
@@ -362,7 +363,8 @@ int itkGeodesicActiveContourShapePriorLevelSetImageFilterTest_2( int, char *[])
   thresholder->SetUpperThreshold( 0.0 );
   thresholder->SetOutsideValue( 0 );
   thresholder->SetInsideValue( 255 );
-
+  thresholder->Update();
+#ifndef __BORLANDC__
   /**
    * Compute overlap between the true shape and the segmented shape
    */
@@ -448,7 +450,7 @@ int itkGeodesicActiveContourShapePriorLevelSetImageFilterTest_2( int, char *[])
     return EXIT_FAILURE;
     }
 
-
+#endif
   std::cout << "Test passed." << std::endl;
   return EXIT_SUCCESS;
 
