@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMatchCardinalityImageToImageMetricTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2004-10-11 11:24:40 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2009-04-06 11:27:08 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -71,10 +71,10 @@ int itkMatchCardinalityImageToImageMetricTest(int argc, char* argv[] )
         {
         std::cout << "Offset: " << offset << " = " << metric->GetValue(offset) << std::endl;
         }
-      catch( itk::ExceptionObject & exp )
+      catch( itk::ExceptionObject & excp )
         {
         std::cerr << "Exception thrown while computing metric " << std::endl;
-        std::cerr << exp << std::endl;
+        std::cerr << excp << std::endl;
         return EXIT_FAILURE;
         }
       }
@@ -93,10 +93,10 @@ int itkMatchCardinalityImageToImageMetricTest(int argc, char* argv[] )
         {
         std::cout << "Offset: " << offset << " = " << metric->GetValue(offset) << std::endl;
         }
-      catch( itk::ExceptionObject & exp )
+      catch( itk::ExceptionObject & excp )
         {
         std::cerr << "Exception thrown while computing metric " << std::endl;
-        std::cerr << exp << std::endl;
+        std::cerr << excp << std::endl;
         return EXIT_FAILURE;
         }
       }
