@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMultiResolutionImageRegistrationMethodTest_1.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-03-27 20:12:33 $
-  Version:   $Revision: 1.13 $
+  Date:      $Date: 2009-04-06 11:27:10 $
+  Version:   $Revision: 1.14 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -598,7 +598,7 @@ double F( itk::Vector<double,3> & v )
   double y = v[1]; 
   double z = v[2];
   const double s = 50;
-  double value = 200.0 * exp( - ( x*x + y*y + z*z )/(s*s) );
+  double value = 200.0 * vcl_exp( - ( x*x + y*y + z*z )/(s*s) );
   x -= 8; y += 3; z += 0;
   double r = vcl_sqrt( x*x + y*y + z*z );
   if( r > 35 )
