@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMultiResolutionPyramidImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-02-03 04:05:34 $
-  Version:   $Revision: 1.22 $
+  Date:      $Date: 2009-04-10 19:18:15 $
+  Version:   $Revision: 1.26 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -18,6 +18,7 @@
 #pragma warning ( disable : 4786 )
 #endif
 #include "itkMultiResolutionPyramidImageFilter.h"
+#include "itkRecursiveMultiResolutionPyramidImageFilter.h"
 #include "itkImage.h"
 #include "itkVector.h"
 #include "itkImageRegionIterator.h"
@@ -37,7 +38,7 @@ namespace
 double F( double x, double y, double z )
 {
   const double s = 50;
-  double value = 200.0 * exp( - ( x*x + y*y + z*z )/(s*s) );
+  double value = 200.0 * vcl_exp( - ( x*x + y*y + z*z )/(s*s) );
   x -= 8; y += 3; z += 0;
   double r = vcl_sqrt( x*x + y*y + z*z );
   if( r > 35 )
@@ -69,7 +70,26 @@ public:
 };
 }
 
-int itkMultiResolutionPyramidImageFilterTest(int, char* [] )
+#include "itkImageMomentsCalculator.h"
+template <class ImageType>
+typename ImageType::PointType GetCenterOfMass(const ImageType * volume)
+{
+  typename ImageType::PointType CenterOfMass;
+    {
+    typedef itk::ImageMomentsCalculator<ImageType> momentsCalculatorType;
+    typename momentsCalculatorType::Pointer moments=momentsCalculatorType::New();
+    moments->SetImage(volume);
+    moments->Compute();
+    typename ImageType::PointType::VectorType tempCenterOfMass=moments->GetCenterOfGravity();
+    for( unsigned int q=0;q<ImageType::ImageDimension;q++ )
+      {
+      CenterOfMass[q]=tempCenterOfMass[q];
+      }
+    }
+  return  CenterOfMass;
+}
+
+int itkMultiResolutionPyramidImageFilterTest(int argc, char* argv[] )
 {
 
 //------------------------------------------------------------
@@ -77,21 +97,65 @@ int itkMultiResolutionPyramidImageFilterTest(int, char* [] )
 //------------------------------------------------------------
 
   // Allocate Images
-  typedef signed short PixelType;
+  //typedef signed short PixelType;
+  typedef float PixelType;
   typedef itk::Image<PixelType,3>           InputImageType;
   typedef itk::Image<float,3>               OutputImageType;
   enum { ImageDimension = InputImageType::ImageDimension };
-
-  InputImageType::SizeType size = {{101,101,41}};
+  bool useShrinkFilter(false);
+  if(argc > 1)
+    {
+    std::string s(argv[1]);
+    std::cout << "useShrinkFilter ";
+    if(s == "Shrink")
+      {
+      useShrinkFilter = true;
+      std::cout << "true";
+      }
+    else
+      {
+      std::cout << "false";
+      }
+    std::cout << std::endl;
+    }
+  bool TestRecursive(false);
+  if(argc > 2)
+    {
+    std::string s(argv[2]);
+    if(s == "TestRecursive")
+      {
+      TestRecursive = true;
+      }
+    }
+  //At best center of mass can be preserved very closely only when
+  //shrink factors divisible into the original image size
+  //are used, so only test that option.
+  //When shrink factors are not divisible, this still does
+  //a best does the best possible job.
+  //InputImageType::SizeType size = {{101,101,41}};
+  InputImageType::SizeType size = {{128,132,48}};
   InputImageType::IndexType index = {{0,0,0}};
   InputImageType::RegionType region;
   region.SetSize( size );
   region.SetIndex( index );
 
+  InputImageType::SpacingType spacing;
+  spacing[0]=0.5;
+  spacing[1]=2.7;
+  spacing[2]=7.5;
+
+  InputImageType::DirectionType direction;
+  direction.Fill(0.0);
+  direction[0][1]=-1;
+  direction[1][2]=1;
+  direction[2][0]=1;
+
   InputImageType::Pointer imgTarget = InputImageType::New();
   imgTarget->SetLargestPossibleRegion( region );
   imgTarget->SetBufferedRegion( region );
   imgTarget->SetRequestedRegion( region );
+  imgTarget->SetSpacing( spacing );
+  imgTarget->SetDirection( direction );
   imgTarget->Allocate();
 
   // Fill images with a 3D gaussian with some directional pattern
@@ -127,9 +191,8 @@ int itkMultiResolutionPyramidImageFilterTest(int, char* [] )
   unsigned int j, k;
   for( j = 0; j < 3; j++ )
     {
-    transCenter[j] = -0.5 * double(size[j]);
+    transCenter[j] = -0.5 * double(size[j])*spacing[j];
     }
-
   imgTarget->SetOrigin( transCenter );
 
 
@@ -139,8 +202,22 @@ int itkMultiResolutionPyramidImageFilterTest(int, char* [] )
   typedef itk::MultiResolutionPyramidImageFilter<InputImageType,OutputImageType>
     PyramidType;
   typedef PyramidType::ScheduleType ScheduleType;
-  PyramidType::Pointer pyramid = PyramidType::New();
-
+  /**
+   * This is kind of cheating but it exploits the fact that Recursive... is derived
+   * from Multi... so it just swaps classes based on a command line flag. hey presto!
+   * new test!
+   */
+  PyramidType::Pointer pyramid;
+  if(!TestRecursive)
+    {
+    pyramid = PyramidType::New();
+    }
+  else
+    {
+    pyramid = 
+      itk::RecursiveMultiResolutionPyramidImageFilter<InputImageType,OutputImageType>::New();
+    }
+  pyramid->SetUseShrinkImageFilter(useShrinkFilter);
   pyramid->SetInput( imgTarget );
 
   unsigned int numLevels;
@@ -240,52 +317,86 @@ int itkMultiResolutionPyramidImageFilterTest(int, char* [] )
   pyramid->Print( std::cout );
 
 //  update pyramid at a particular level
-  unsigned int testLevel = 2;
-  pyramid->GetOutput( testLevel )->Update();
-
-// test output at another level
-  testLevel = 1;
-
-  // check the output image information
-  InputImageType::SizeType inputSize =
-    pyramid->GetInput()->GetLargestPossibleRegion().GetSize();
-  const InputImageType::PointType& inputOrigin =
-    pyramid->GetInput()->GetOrigin();
-  const InputImageType::SpacingType& inputSpacing =
-    pyramid->GetInput()->GetSpacing();
-
-  OutputImageType::SizeType outputSize =
-    pyramid->GetOutput( testLevel )->GetLargestPossibleRegion().GetSize();
-  const OutputImageType::PointType& outputOrigin =
-    pyramid->GetOutput( testLevel )->GetOrigin();
-  const OutputImageType::SpacingType& outputSpacing =
-    pyramid->GetOutput( testLevel )->GetSpacing();
-
-  for( j = 0; j < ImageDimension; j++ )
+  for (unsigned int testLevel=0; testLevel< numLevels; testLevel++)
     {
-    if( outputOrigin[j] != inputOrigin[j] )
-      {
-      break;
-      }
-    if( outputSpacing[j] !=
-      inputSpacing[j] * (double) schedule[testLevel][j] )
-      {
-      break;
-      }
-    unsigned int sz = inputSize[j] / schedule[testLevel][j];
-    if( sz == 0 ) sz = 1;
-    if( outputSize[j] != sz )
-      {
-      break;
-      }
-    }
+    pyramid->GetOutput( testLevel )->Update();
+    // check the output image information
+    InputImageType::SizeType inputSize =
+      pyramid->GetInput()->GetLargestPossibleRegion().GetSize();
+    //const InputImageType::PointType& inputOrigin =
+    //  pyramid->GetInput()->GetOrigin();
+    OutputImageType::PointType InputCenterOfMass=GetCenterOfMass<OutputImageType>( pyramid->GetInput() );
+    const InputImageType::SpacingType& inputSpacing =
+      pyramid->GetInput()->GetSpacing();
 
-  if( j != ImageDimension )
-    {
-    std::cout << "Output meta information incorrect." << std::endl;
-    pyramid->GetInput()->Print(std::cout);
-    pyramid->GetOutput( testLevel )->Print(std::cout);
-    return EXIT_FAILURE;
+    OutputImageType::SizeType outputSize =
+      pyramid->GetOutput( testLevel )->GetLargestPossibleRegion().GetSize();
+    //const OutputImageType::PointType& outputOrigin =
+    //  pyramid->GetOutput( testLevel )->GetOrigin();
+    const OutputImageType::SpacingType& outputSpacing =
+      pyramid->GetOutput( testLevel )->GetSpacing();
+
+
+      OutputImageType::PointType OutputCenterOfMass=GetCenterOfMass<OutputImageType>( pyramid->GetOutput( testLevel ) );
+      //NOTE:  Origins can not be preserved if the objects physical spaces are to be preserved!
+      //       The image center of physical space is what really needs to be preserved across
+      //       the different scales.
+      //if( outputOrigin[j] != inputOrigin[j] )
+      //  {
+      //  break;
+      //  }
+      //std::cout << "TEST:  "<< j<< " " << OutputCenterOfMass << " != " << InputCenterOfMass << std::endl;
+      //if( OutputCenterOfMass != InputCenterOfMass )
+        {
+        OutputImageType::PointType::VectorType ErrorCenterOfMass=OutputCenterOfMass-InputCenterOfMass;
+        const double CenterOfMassEpsilonAllowed=0.001;
+        const double ErrorPercentage=(ErrorCenterOfMass.GetNorm() / pyramid->GetOutput( testLevel )->GetSpacing().GetNorm() );
+        if( ErrorPercentage > CenterOfMassEpsilonAllowed)
+          {
+          std::cout << "ERROR:  " << testLevel << " " << OutputCenterOfMass
+            << " != " << InputCenterOfMass <<  " at pixel spacing level " <<
+            pyramid->GetOutput( testLevel )->GetDirection()*pyramid->GetOutput( testLevel )->GetSpacing()
+            << std::endl;
+          std::cout << "ERROR PERCENT:  " << ErrorCenterOfMass.GetNorm()
+           << "/" << pyramid->GetOutput( testLevel )->GetSpacing().GetNorm()
+           << " = " << ErrorPercentage
+           << std::endl;
+          }
+        else
+          {
+          std::cout << "WITHIN TOLERANCE PASSED:  " << testLevel << " " << OutputCenterOfMass << " != "
+            << InputCenterOfMass <<  " at pixel spacing level " <<
+            pyramid->GetOutput( testLevel )->GetDirection()*pyramid->GetOutput( testLevel )->GetSpacing()
+            << std::endl;
+          std::cout << "OFFSET DIFF PERCENT:  " << ErrorCenterOfMass.GetNorm()
+            << "/" << pyramid->GetOutput( testLevel )->GetSpacing().GetNorm()
+            << " = " << ErrorPercentage
+            << std::endl;
+          }
+        //break;
+        }
+    for( j = 0; j < ImageDimension; j++ )
+      {
+      if( outputSpacing[j] !=
+        inputSpacing[j] * (double) schedule[testLevel][j] )
+        {
+        break;
+        }
+      unsigned int sz = inputSize[j] / schedule[testLevel][j];
+      if( sz == 0 ) sz = 1;
+      if( outputSize[j] != sz )
+        {
+        break;
+        }
+      }
+
+    if( j != ImageDimension )
+      {
+      std::cout << "Output meta information incorrect." << std::endl;
+      pyramid->GetInput()->Print(std::cout);
+      pyramid->GetOutput( testLevel )->Print(std::cout);
+      return EXIT_FAILURE;
+      }
     }
 
   // check that the buffered region is equivalent the largestpossible
@@ -309,7 +420,7 @@ int itkMultiResolutionPyramidImageFilterTest(int, char* [] )
   ScheduleType temp2( pyramid->GetNumberOfLevels() - 1, ImageDimension );
   temp2.Fill( 1 );
   pyramid->SetSchedule( temp2 );
-  
+
   std::cout << "Test passed." << std::endl;
   return EXIT_SUCCESS;
 
