@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMutualInformationHistogramImageToImageMetricTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-12-10 23:17:16 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-07-12 10:52:57 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -45,14 +45,14 @@ int itkMutualInformationHistogramImageToImageMetricTest(int , char* [])
     typedef FixedImageSourceType::Pointer FixedImageSourcePointer;
     
     // Note: the following declarations are classical arrays
-    unsigned long fixedImageSize[] = {100,  100};
-    unsigned long movingImageSize[] = {100,  100}; 
+    FixedImageType::SizeValueType fixedImageSize[] = {100,  100};
+    MovingImageType::SizeValueType movingImageSize[] = {100,  100}; 
     
-    float fixedImageSpacing[]  = {1.0f, 1.0f}; 
-    float movingImageSpacing[] = {1.0f, 1.0f}; 
+    FixedImageType::SpacingValueType fixedImageSpacing[]  = {1.0f, 1.0f}; 
+    MovingImageType::SpacingValueType movingImageSpacing[] = {1.0f, 1.0f}; 
     
-    float fixedImageOrigin[] = {0.0f, 0.0f}; 
-    float movingImageOrigin[] = {0.0f, 0.0f}; 
+    FixedImageType::PointValueType fixedImageOrigin[] = {0.0f, 0.0f}; 
+    MovingImageType::PointValueType movingImageOrigin[] = {0.0f, 0.0f}; 
     
     MovingImageSourceType::Pointer movingImageSource =
       MovingImageSourceType::New();
@@ -88,6 +88,9 @@ int itkMutualInformationHistogramImageToImageMetricTest(int , char* [])
     
     unsigned int nBins = 256;
     MetricType::HistogramType::SizeType histSize;
+#ifdef ITK_USE_REVIEW_STATISTICS
+    histSize.SetSize(2);
+#endif
     histSize[0] = nBins;
     histSize[1] = nBins;
     metric->SetHistogramSize(histSize);
