@@ -3,8 +3,8 @@
 Program:   Insight Segmentation & Registration Toolkit
 Module:    $RCSfile: itkOtsuMultipleThresholdsCalculatorTest.cxx,v $
 Language:  C++
-Date:      $Date: 2005-11-25 15:52:39 $
-Version:   $Revision: 1.6 $
+Date:      $Date: 2009-05-12 00:34:55 $
+Version:   $Revision: 1.10 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,16 +26,26 @@ PURPOSE.  See the above copyright notices for more information.
 int itkOtsuMultipleThresholdsCalculatorTest(int, char*[])
 {
   typedef float MeasurementType ;
+#ifdef ITK_USE_REVIEW_STATISTICS
+  typedef itk::Statistics::Histogram< MeasurementType > HistogramType ;
+#else
   typedef itk::Statistics::Histogram< MeasurementType, 1 > HistogramType ;
+#endif
   HistogramType::Pointer histogram = HistogramType::New() ;
 
   // initialize histogram
   HistogramType::SizeType size;
-  size.Fill(64) ;
   HistogramType::MeasurementVectorType lowerBound ;
   HistogramType::MeasurementVectorType upperBound ;
-  lowerBound[0] = 0.0 ;
-  upperBound[0] = 64.0 ;
+#ifdef ITK_USE_REVIEW_STATISTICS
+  lowerBound.SetSize(1);
+  upperBound.SetSize(1);
+  histogram->SetMeasurementVectorSize(1);
+  size.SetSize(1);
+#endif
+  lowerBound[0] = 0.0;
+  upperBound[0] = 64.0;
+  size.Fill(64);
 
   histogram->Initialize(size, lowerBound, upperBound ) ;
   
@@ -58,7 +68,7 @@ int itkOtsuMultipleThresholdsCalculatorTest(int, char*[])
       {
       if (measurement > (*viter-range) && measurement <  (*viter+range))
         {
-        iter.SetFrequency(1.0);
+        iter.SetFrequency(1);
         }
       }
     }
@@ -77,9 +87,9 @@ int itkOtsuMultipleThresholdsCalculatorTest(int, char*[])
     {
     otsuThresholdCalculator->Update();
     }
-  catch(itk::ExceptionObject & exp)
+  catch(itk::ExceptionObject & excp)
     {
-    std::cerr << exp << std::endl;
+    std::cerr << excp << std::endl;
     }
   otsuThresholdCalculator->Print (std::cout);
 
