@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPointSetToImageRegistrationTest_1.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-08-12 06:36:38 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2008-05-09 11:59:46 $
+  Version:   $Revision: 1.10 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,7 +14,7 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifdef _WIN32
+#ifdef _MSC_VER
 #pragma warning ( disable : 4786 )
 #endif
 
