@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRecursiveMultiResolutionPyramidImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-02-03 04:05:34 $
-  Version:   $Revision: 1.16 $
+  Date:      $Date: 2009-04-06 21:21:58 $
+  Version:   $Revision: 1.19 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -38,7 +38,7 @@ namespace
 double F( double x, double y, double z )
 {
   const double s = 50;
-  double value = 200.0 * exp( - ( x*x + y*y + z*z )/(s*s) );
+  double value = 200.0 * vcl_exp( - ( x*x + y*y + z*z )/(s*s) );
   x -= 8; y += 3; z += 0;
   double r = vcl_sqrt( x*x + y*y + z*z );
   if( r > 35 )
@@ -70,7 +70,7 @@ public:
 };
 }
 
-int itkRecursiveMultiResolutionPyramidImageFilterTest(int, char* [] )
+int itkRecursiveMultiResolutionPyramidImageFilterTest(int argc, char* argv[] )
 {
 
 //------------------------------------------------------------
@@ -82,6 +82,21 @@ int itkRecursiveMultiResolutionPyramidImageFilterTest(int, char* [] )
   typedef itk::Image<PixelType,3>           InputImageType;
   typedef itk::Image<float,3>               OutputImageType;
   enum { ImageDimension = InputImageType::ImageDimension };
+  bool useShrinkFilter(false);
+  if(argc > 1)
+    {
+    std::string s(argv[1]);
+    if(s == "Shrink")
+      {
+      useShrinkFilter = true;
+      std::cout << "true";
+      }
+    else
+      {
+      std::cout << "false";
+      }
+    std::cout << std::endl;
+    }
 
   InputImageType::SizeType size = {{100,100,40}};
   InputImageType::IndexType index = {{0,0,0}};
@@ -140,6 +155,7 @@ int itkRecursiveMultiResolutionPyramidImageFilterTest(int, char* [] )
     PyramidType;
   typedef PyramidType::ScheduleType ScheduleType;
   PyramidType::Pointer pyramid = PyramidType::New();
+  pyramid->SetUseShrinkImageFilter(useShrinkFilter);
 
   pyramid->SetInput( imgTarget );
 
@@ -251,24 +267,16 @@ int itkRecursiveMultiResolutionPyramidImageFilterTest(int, char* [] )
   // check the output image information
   InputImageType::SizeType inputSize =
     pyramid->GetInput()->GetLargestPossibleRegion().GetSize();
-  const InputImageType::PointType& inputOrigin =
-    pyramid->GetInput()->GetOrigin();
   const InputImageType::SpacingType& inputSpacing =
     pyramid->GetInput()->GetSpacing();
 
   OutputImageType::SizeType outputSize =
     pyramid->GetOutput( testLevel )->GetLargestPossibleRegion().GetSize();
-  const OutputImageType::PointType& outputOrigin =
-    pyramid->GetOutput( testLevel )->GetOrigin();
   const OutputImageType::SpacingType& outputSpacing =
     pyramid->GetOutput( testLevel )->GetSpacing();
 
   for( j = 0; j < ImageDimension; j++ )
     {
-    if( outputOrigin[j] != inputOrigin[j] )
-      {
-      break;
-      }
     if( outputSpacing[j] !=
       inputSpacing[j] * (double) schedule[testLevel][j] )
       {
@@ -301,6 +309,7 @@ int itkRecursiveMultiResolutionPyramidImageFilterTest(int, char* [] )
 
   PyramidType::Pointer pyramid2 = PyramidType::New();
   pyramid2->SetInput( caster->GetOutput() );
+  pyramid2->SetUseShrinkImageFilter(useShrinkFilter);
   pyramid2->SetNumberOfLevels( pyramid->GetNumberOfLevels() );
   pyramid2->SetSchedule( pyramid->GetSchedule() );
 
