@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRegularSphereMeshSourceTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2004-04-19 11:15:18 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2009-06-14 19:55:37 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -39,10 +39,13 @@ int itkRegularSphereMeshSourceTest(int, char* [] )
   typedef SphereMeshSourceType::VectorType  VectorType;
 
   PointType center; 
-  center.Fill( 0.0 );
+  center.Fill( 7.4 );
+
+  const double radius = 1.5;
+  const double tolerance = 1e-5;
 
   VectorType scale;
-  scale.Fill( 1.0 );
+  scale.Fill( radius );
   
   mySphereMeshSource->SetCenter( center );
   mySphereMeshSource->SetResolution( 1 );
@@ -65,6 +68,9 @@ int itkRegularSphereMeshSourceTest(int, char* [] )
   MeshType::Pointer myMesh = mySphereMeshSource->GetOutput();
 
   PointType  pt;
+  pt.Fill(0);
+
+  bool testPassed = true;
 
   std::cout << "Testing itk::RegularSphereMeshSource "<< std::endl;
 
@@ -72,9 +78,56 @@ int itkRegularSphereMeshSourceTest(int, char* [] )
     {
     myMesh->GetPoint(i, &pt);
     std::cout << "Point[" << i << "]: " << pt << std::endl;
+
+    const double distanceToCenter = pt.EuclideanDistanceTo( center );
+ 
+    if( vnl_math_abs( distanceToCenter - radius ) > tolerance )
+      {
+      std::cerr << "Distance to center " << distanceToCenter;
+      std::cerr << " is too different from radius " << radius << std::endl;
+      testPassed = false;
+      }
     }
 
-  std::cout << "Test End "<< std::endl;
+  typedef MeshType::CellsContainerPointer  CellsContainerPointer;
+  typedef MeshType::CellsContainerIterator CellsContainerIterator;
+  typedef MeshType::CellType               CellType;
+
+  CellsContainerPointer cells = myMesh->GetCells();
+
+  unsigned faceId = 0;
+
+  MeshType::CellsContainerIterator cellsItr = cells->Begin();
+
+
+  while( cellsItr != cells->End() )
+    {
+    CellType * cellPointer = cellsItr.Value();
+
+    if( cellPointer->GetType() != 1 )
+      {
+      const unsigned int numberOfPoints = cellPointer->GetNumberOfPoints();
+
+      std::cout <<"Face " << faceId << " has " << numberOfPoints <<" points" << std::endl;
+
+      if( numberOfPoints != 3 )
+        {
+        std::cerr << "Face with wrong number of points" << std::endl;
+        testPassed = false;
+        }
+      }
+
+    ++cellsItr;
+    ++faceId;
+    }
+
+  if( !testPassed )
+    {
+    std::cout << "Test FAILED! "<< std::endl;
+    return EXIT_FAILURE;
+    }
+
+  std::cout << "Test PASSED! "<< std::endl;
 
   return EXIT_SUCCESS;
 
