@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSymmetricForcesDemonsRegistrationFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2004-06-17 15:25:59 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2009-07-12 10:52:58 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -108,7 +108,7 @@ int itkSymmetricForcesDemonsRegistrationFilterTest(int, char* [] )
   std::cout << "Generate input images and initial deformation field";
   std::cout << std::endl;
 
-  unsigned long sizeArray[ImageDimension] = { 128, 128 };
+  FloatImageType::SizeValueType sizeArray[ImageDimension] = { 128, 128 };
   SizeType size;
   size.SetSize( sizeArray );
 
