@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBasicFiltersPrintTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2006/03/06 21:56:45 $
-  Version:   $Revision: 1.19 $
+  Date:      $Date: 2007-08-10 14:34:01 $
+  Version:   $Revision: 1.20 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -405,5 +405,5 @@ int itkBasicFiltersPrintTest(int , char* [])
   std::cout << "-------------HausdorffDistanceImageFilter" << HausdorffDistanceImageFilterObj;
 
 #endif
-  return 0;
+  return EXIT_SUCCESS;
 }
