@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBinaryThresholdImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-01-15 04:28:36 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2009-07-12 10:52:59 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -49,7 +49,7 @@ int itkBinaryThresholdImageFilterTest(int, char* [] )
   typedef itk::RandomImageSource<InputImageType> SourceType;
   SourceType::Pointer source = SourceType::New();
 
-  unsigned long sizeArray[ImageDimension] = { 3,3,3 };
+  InputImageType::SizeValueType sizeArray[ImageDimension] = { 3,3,3 };
 
   source->SetMin( itk::NumericTraits<InputPixelType>::Zero );
   source->SetMax( itk::NumericTraits<InputPixelType>::max() );
