@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCannyEdgeDetectionImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-10 14:34:01 $
-  Version:   $Revision: 1.14 $
+  Date:      $Date: 2008-12-17 14:45:10 $
+  Version:   $Revision: 1.15 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -77,5 +77,18 @@ int itkCannyEdgeDetectionImageFilterTest(int argc, char * argv[] )
       (&err)->Print(std::cerr);
       return EXIT_FAILURE;
     } 
+
+  // test for correct setting of non-macro methods
+  if (filter->GetVariance()[0] != 1.0f || filter->GetMaximumError()[0] != .01f) 
+    {
+      return EXIT_FAILURE;
+    }
+  filter->SetVariance(0.5f);
+  filter->SetMaximumError(0.5f);
+  if (filter->GetVariance()[0] != 0.5f || filter->GetMaximumError()[0] != 0.5f) 
+    {
+      return EXIT_FAILURE;
+    }
+
   return EXIT_SUCCESS;   
 }
