@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkComplexToPhaseFilterAndAdaptorTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-05-27 16:27:10 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2009-04-06 15:37:23 $
+  Version:   $Revision: 1.4 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -20,11 +20,11 @@
 
 
 
-#include <itkImage.h>
-#include <itkComplexToPhaseImageFilter.h>
-#include <itkComplexToPhaseImageAdaptor.h>
-#include <itkImageRegionIteratorWithIndex.h>
-#include <itkSubtractImageFilter.h>
+#include "itkImage.h"
+#include "itkComplexToPhaseImageFilter.h"
+#include "itkComplexToPhaseImageAdaptor.h"
+#include "itkImageRegionIteratorWithIndex.h"
+#include "itkSubtractImageFilter.h"
 
 
 int itkComplexToPhaseFilterAndAdaptorTest(int, char* [] ) 
@@ -128,7 +128,7 @@ int itkComplexToPhaseFilterAndAdaptorTest(int, char* [] )
     const InputImageType::PixelType  input  = it.Get();
     const OutputImageType::PixelType output = ot.Get();
     
-    double phased = atan2( input.imag(), input.real() );
+    double phased = vcl_atan2( input.imag(), input.real() );
 
     const OutputImageType::PixelType phase  = 
        static_cast<OutputImageType::PixelType>( phased );
@@ -136,7 +136,7 @@ int itkComplexToPhaseFilterAndAdaptorTest(int, char* [] )
     std::cout <<  output << " = ";
     std::cout <<  phase  << std::endl; 
 
-    if( fabs( phase - output ) > epsilon )
+    if( vcl_fabs( phase - output ) > epsilon )
       {
       std::cerr << "Error in itkComplexToPhaseImageFilterTest " << std::endl;
       std::cerr << " phase( " << input << ") = " << phase << std::endl;
@@ -188,7 +188,7 @@ int itkComplexToPhaseFilterAndAdaptorTest(int, char* [] )
     {
     std::cout <<  dt.Get() << std::endl;
     const OutputImageType::PixelType diff = dt.Get();
-    if( fabs( diff ) > epsilon )
+    if( vcl_fabs( diff ) > epsilon )
       {
       std::cerr << "Error in itkComplexToPhaseImageFilterTest " << std::endl;
       std::cerr << "Comparing results with Adaptors" << std::endl;
@@ -201,11 +201,5 @@ int itkComplexToPhaseFilterAndAdaptorTest(int, char* [] )
     }
 
 
-
   return EXIT_SUCCESS;
-
 }
-
-
-
-
