@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkConstantPadImageTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:06 $
-  Version:   $Revision: 1.15 $
+  Date:      $Date: 2009-07-12 10:53:00 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -70,11 +70,19 @@ int itkConstantPadImageTest(int, char* [] )
   FilterWatcher watch(constantPad);
   constantPad->SetInput( if2 );
   
-  unsigned long upperfactors[2] = { 0, 0};
-  unsigned long lowerfactors[2] = { 0, 0};
+  typedef ShortImage::SizeValueType   SizeValueType;
+  typedef ShortImage::IndexValueType  IndexValueType;
+
+  SizeValueType upperfactors[2] = { 0, 0};
+  SizeValueType lowerfactors[2] = { 0, 0};
+
   constantPad->SetConstant(13);
-  constantPad->SetPadLowerBound(lowerfactors);
-  constantPad->SetPadUpperBound(upperfactors);
+  // check the method using the SizeType rather than the simple table type.
+  ShortImage::SizeType stfactors;
+  stfactors.Fill( 0 );
+  constantPad->SetPadLowerBound(stfactors);
+  constantPad->SetPadUpperBound(stfactors);
+  constantPad->SetPadBound(stfactors);
   constantPad->UpdateLargestPossibleRegion();
 
   std::cout << constantPad << std::endl;
@@ -102,8 +110,8 @@ int itkConstantPadImageTest(int, char* [] )
   passed = true; 
   size = requestedRegion.GetSize();
   index = requestedRegion.GetIndex();
-  if ((index[0] != (0 - (long) lowerfactors[0])) 
-      || (index[1] != (0 - (long) lowerfactors[1]))
+  if ((index[0] != (0 - (IndexValueType) lowerfactors[0])) 
+      || (index[1] != (0 - (IndexValueType) lowerfactors[1]))
       || (size[0] != (8 + lowerfactors[0] + upperfactors[0])) 
       || (size[1] != (12 + lowerfactors[1] + upperfactors[1])))
     {
@@ -178,8 +186,8 @@ int itkConstantPadImageTest(int, char* [] )
     passed = true; 
     size = requestedRegion.GetSize();
     index = requestedRegion.GetIndex();
-    if ((index[0] != (0 - (long) lowerfactors[0])) 
-        || (index[1] != (0 - (long) lowerfactors[1]))
+    if ((index[0] != (0 - (IndexValueType) lowerfactors[0])) 
+        || (index[1] != (0 - (IndexValueType) lowerfactors[1]))
         || (size[0] != (8 + lowerfactors[0] + upperfactors[0])) 
         || (size[1] != (12 + lowerfactors[1] + upperfactors[1])))
       {
