@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkEdgePotentialImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-10 14:34:01 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2009-04-06 11:27:13 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -122,10 +122,10 @@ int itkEdgePotentialImageFilterTest(int, char* [] )
   {
     const InputImageType::PixelType  input  = it.Get();
     const OutputImageType::PixelType output = ot.Get();
-    const OutputImageType::PixelType pot  = exp( -1.0 * (it.Get().GetNorm() ) );
+    const OutputImageType::PixelType pot  = vcl_exp( -1.0 * (it.Get().GetNorm() ) );
     std::cout <<  ot.Get() << " = ";
     std::cout <<  pot  << std::endl; 
-    if( fabs( pot - output ) > epsilon )
+    if( vcl_fabs( pot - output ) > epsilon )
     {
       std::cerr << "Error in itkEdgePotentialImageFilterTest " << std::endl;
       std::cerr << " potential( " << input << ") = " << pot << std::endl;
@@ -138,9 +138,4 @@ int itkEdgePotentialImageFilterTest(int, char* [] )
   }
 
   return EXIT_SUCCESS;
-
 }
-
-
-
-
