@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkEigenAnalysis2DImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-10 14:34:01 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-04-05 23:54:28 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -153,11 +153,10 @@ int itkEigenAnalysis2DImageFilterTest(int, char* [] )
   myImageType::Pointer inputImageXY  = myImageType::New();
   myImageType::Pointer inputImageYY  = myImageType::New();
 
-  const double myPI = 4.0 * atan(1.0);
 
-  InitializeImage( inputImageXX, cos( myPI / 6.0 ) );
-  InitializeImage( inputImageXY, sin( myPI / 6.0 ) );
-  InitializeImage( inputImageYY, cos( myPI / 6.0 ) );
+  InitializeImage( inputImageXX, vcl_cos( vnl_math::pi / 6.0 ) );
+  InitializeImage( inputImageXY, vcl_sin( vnl_math::pi / 6.0 ) );
+  InitializeImage( inputImageYY, vcl_cos( vnl_math::pi / 6.0 ) );
 
 
   // Create a  Filter                                
