@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkExpNegativeImageFilterAndAdaptorTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-10 14:34:01 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-04-06 11:27:14 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -83,16 +83,15 @@ int itkExpNegativeImageFilterAndAdaptorTest(int, char* [] )
   InputIteratorType it( inputImage, inputImage->GetBufferedRegion() );
 
   // Initialize the content of Image A
-  const double pi    = atan( 1.0 ) * 4.0;
-  const double value = pi / 6.0;
+  const double value = vnl_math::pi / 6.0;
   std::cout << "Content of the Input " << std::endl;
   it.GoToBegin();
   while( !it.IsAtEnd() ) 
-  {
+    {
     it.Set( value );
     std::cout << it.Get() << std::endl;
     ++it;
-  }
+    }
 
   // Declare the type for the ExpNegative filter
   typedef itk::ExpNegativeImageFilter< InputImageType,
@@ -123,23 +122,23 @@ int itkExpNegativeImageFilterAndAdaptorTest(int, char* [] )
   ot.GoToBegin();
   it.GoToBegin();
   while( !ot.IsAtEnd() ) 
-  {
+    {
     std::cout <<  ot.Get() << " = ";
     const InputImageType::PixelType  input  = it.Get();
     const OutputImageType::PixelType output = ot.Get();
-    const OutputImageType::PixelType exponential  = exp( - input);
+    const OutputImageType::PixelType exponential  = vcl_exp( - input);
     std::cout <<  exponential  << std::endl; 
-    if( fabs( exponential - output ) > epsilon )
-    {
+    if( vcl_fabs( exponential - output ) > epsilon )
+      {
       std::cerr << "Error in itkExpNegativeImageFilterTest " << std::endl;
-      std::cerr << " exp( - " << input << ") = " << exponential << std::endl;
+      std::cerr << " vcl_exp( - " << input << ") = " << exponential << std::endl;
       std::cerr << " differs from " << output;
       std::cerr << " by more than " << epsilon << std::endl;
       return EXIT_FAILURE;
-    }
+      }
     ++ot;
     ++it;
-  }
+    }
 
 
   //---------------------------------------
@@ -177,28 +176,21 @@ int itkExpNegativeImageFilterAndAdaptorTest(int, char* [] )
   
   dt.GoToBegin();
   while( !dt.IsAtEnd() ) 
-  {
+    {
     std::cout <<  dt.Get() << std::endl;
     const OutputImageType::PixelType diff = dt.Get();
-    if( fabs( diff ) > epsilon )
-    {
+    if( vcl_fabs( diff ) > epsilon )
+      {
       std::cerr << "Error in itkExpNegativeImageFilterTest " << std::endl;
       std::cerr << "Comparing results with Adaptors" << std::endl;
       std::cerr << " difference = " << diff << std::endl;
       std::cerr << " differs from 0 ";
       std::cerr << " by more than " << epsilon << std::endl;
       return EXIT_FAILURE;
-    }
+      }
     ++dt;
-  }
-
-
+    }
 
   
   return EXIT_SUCCESS;
-
 }
-
-
-
-
