@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkExpandImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-01-29 14:42:11 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2009-05-19 18:31:17 $
+  Version:   $Revision: 1.10 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -23,7 +23,11 @@
 #include "itkIndex.h"
 #include "itkImage.h"
 #include "itkImageRegionIteratorWithIndex.h"
+#ifndef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
 #include "itkLinearInterpolateImageFunction.h"
+#else
+#include "itkNearestNeighborInterpolateImageFunction.h"
+#endif
 #include "itkExpandImageFilter.h"
 #include "itkCastImageFilter.h"
 #include "itkStreamingImageFilter.h"
@@ -74,7 +78,6 @@ public:
 };
 
 
-
 int itkExpandImageFilterTest(int, char* [] )
 {
   typedef float PixelType;
@@ -107,9 +110,10 @@ int itkExpandImageFilterTest(int, char* [] )
   typedef itk::ImageRegionIteratorWithIndex<ImageType> Iterator;
   Iterator inIter( input, region );
 
-  for( ; !inIter.IsAtEnd(); ++inIter )
+  while( !inIter.IsAtEnd() )
     {
     inIter.Set( pattern.Evaluate( inIter.GetIndex() ) );
+    ++inIter;
     }
 
   //=============================================================
@@ -119,7 +123,11 @@ int itkExpandImageFilterTest(int, char* [] )
   typedef itk::ExpandImageFilter<ImageType,ImageType> ExpanderType;
   ExpanderType::Pointer expander = ExpanderType::New();
 
+#ifndef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
   typedef itk::LinearInterpolateImageFunction<ImageType,double> InterpolatorType;
+#else
+  typedef itk::NearestNeighborInterpolateImageFunction<ImageType,double> InterpolatorType;
+#endif
   InterpolatorType::Pointer interpolator = InterpolatorType::New();
 
   expander->SetInterpolator( interpolator );
@@ -154,19 +162,25 @@ int itkExpandImageFilterTest(int, char* [] )
   ImageType::RegionType validRegion = 
     expander->GetOutput()->GetLargestPossibleRegion();
   ImageType::SizeType validSize = validRegion.GetSize();
+
+#ifndef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
   for( j = 0; j < ImageDimension; j++ )
     {
     validSize[j] -= (factors[j] - 1);
     }
+#endif
+
   validRegion.SetSize( validSize );
 
+#ifndef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
   // adjust the pattern coefficients to match
   for( j = 0; j < ImageDimension; j++ )
     {
     pattern.coeff[j] /= (double) factors[j];
     }
+#endif
 
-  for( ; !outIter.IsAtEnd(); ++outIter )
+  while( !outIter.IsAtEnd() )
     {
     ImageType::IndexType index = outIter.GetIndex();
     double value = outIter.Get();
@@ -174,7 +188,15 @@ int itkExpandImageFilterTest(int, char* [] )
     if( validRegion.IsInside( index ) )
       {
 
+#ifndef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
       double trueValue = pattern.Evaluate( outIter.GetIndex() );
+#else
+      ImageType::PointType point;
+      ImageType::IndexType inputIndex;
+      expander->GetOutput()->TransformIndexToPhysicalPoint( outIter.GetIndex(), point );
+      input->TransformPhysicalPointToIndex(point, inputIndex );
+      double trueValue = pattern.Evaluate( inputIndex );
+#endif
 
       if( vnl_math_abs( trueValue - value ) > 1e-4 )
         {
@@ -186,7 +208,6 @@ int itkExpandImageFilterTest(int, char* [] )
       }
     else
       {
-      
       if( value != padValue )
         {
         testPassed = false;
@@ -195,7 +216,7 @@ int itkExpandImageFilterTest(int, char* [] )
         std::cout << "Actual: " << value << std::endl;
         }
       }
-
+    ++outIter;
     }
 
   //=============================================================
@@ -214,6 +235,7 @@ int itkExpandImageFilterTest(int, char* [] )
   expander2->SetInput( caster->GetOutput() );
   expander2->SetExpandFactors( expander->GetExpandFactors() );
   expander2->SetEdgePaddingValue( expander->GetEdgePaddingValue() );
+  expander2->SetInterpolator( expander->GetInterpolator() );
 
   typedef itk::StreamingImageFilter<ImageType,ImageType> StreamerType;
   StreamerType::Pointer streamer = StreamerType::New();
