@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFloodFillIteratorTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:06 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-07-12 10:53:00 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -35,15 +35,15 @@ int itkFloodFillIteratorTest(int, char* [] )
 {
   const unsigned int dim = 3;
 
-  //-----------------Create a new input image--------------------
-  // Image size and spacing parameters
-  unsigned long sourceImageSize[]  = { 20,20,20 };
-  double sourceImageSpacing[] = { 1.0,1.0,1.0 };
-  double sourceImageOrigin[] = { 0,0,0 };
-
   // Image typedef
   typedef itk::Image< int, dim > TImageType;
 
+  //-----------------Create a new input image--------------------
+  // Image size and spacing parameters
+  TImageType::SizeValueType    sourceImageSize[]  = { 20,20,20 };
+  TImageType::SpacingValueType sourceImageSpacing[] = { 1.0,1.0,1.0 };
+  TImageType::PointValueType   sourceImageOrigin[] = { 0,0,0 };
+
   // Creates the sourceImage (but doesn't set the size or allocate memory)
   TImageType::Pointer sourceImage = TImageType::New();
   sourceImage->SetOrigin(sourceImageOrigin);
