@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGaussianImageSourceTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:06 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2009-07-12 10:53:00 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -35,9 +35,9 @@ int itkGaussianImageSourceTest(int, char* [] )
   GaussianSourceType::Pointer pSource = GaussianSourceType::New();
   FilterWatcher watcher(pSource, "pSource");
 
-  float spacing[]       = { 1.2f, 1.3f, 1.4f };
-  float origin[]        = { 1.0f, 4.0f, 2.0f };
-  unsigned long size[]  = {  130,  150,  120 };
+  ImageType::SpacingValueType   spacing[] = { 1.2f, 1.3f, 1.4f };
+  ImageType::PointValueType     origin[] = { 1.0f, 4.0f, 2.0f };
+  ImageType::SizeValueType      size[] = {  130,  150,  120 };
 
   GaussianSourceType::ArrayType mean;
   mean[0] = size[0]/2.0f + origin[0];
@@ -59,6 +59,7 @@ int itkGaussianImageSourceTest(int, char* [] )
   pSource->GetSize();
   pSource->GetSpacing();
   pSource->GetOrigin();
+  pSource->GetDirection();
   pSource->GetScale();
   pSource->GetNormalized();
   pSource->GetSigma();
