@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkHoughTransform2DCirclesImageTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-02-04 13:46:52 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-04-05 23:09:35 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -60,8 +60,8 @@ int itkHoughTransform2DCirclesImageTest(int, char* [])
   {
     for(double angle = 0; angle <= 2 * nPI; angle += nPI / 1000 )
     {
-      index[0] = (long int)(center[0][0] + i * cos(angle));
-      index[1] = (long int)(center[0][1] + i * sin(angle));
+      index[0] = (long int)(center[0][0] + i * vcl_cos(angle));
+      index[1] = (long int)(center[0][1] + i * vcl_sin(angle));
       m_Image->SetPixel(index,255);
     }
   }
@@ -74,8 +74,8 @@ int itkHoughTransform2DCirclesImageTest(int, char* [])
   {
     for(double angle = 0; angle <= 2 * nPI; angle += nPI / 1000 )
     {
-      index[0] = (long int)(center[1][0] + i * cos(angle));
-      index[1] = (long int)(center[1][1] + i * sin(angle));
+      index[0] = (long int)(center[1][0] + i * vcl_cos(angle));
+      index[1] = (long int)(center[1][1] + i * vcl_sin(angle));
       m_Image->SetPixel(index,255);
     }
   }
@@ -88,8 +88,8 @@ int itkHoughTransform2DCirclesImageTest(int, char* [])
   {
     for(double angle = 0; angle <= 2 * nPI; angle += nPI / 1000)
     {
-      index[0] = (long int)(center[2][0] + i * cos(angle));
-      index[1] = (long int)(center[2][1] + i * sin(angle));
+      index[0] = (long int)(center[2][0] + i * vcl_cos(angle));
+      index[1] = (long int)(center[2][1] + i * vcl_sin(angle));
       m_Image->SetPixel(index,255);
     }
   }
@@ -198,15 +198,15 @@ int itkHoughTransform2DCirclesImageTest(int, char* [])
       /** Draw the circle */
       for(double angle = 0; angle <= 2 * nPI; angle += nPI / 1000)
       {
-        index[0] = (long int)(it_output.GetIndex()[0] + radius2 * cos(angle));
-        index[1] = (long int)(it_output.GetIndex()[1] + radius2 * sin(angle));
+        index[0] = (long int)(it_output.GetIndex()[0] + radius2 * vcl_cos(angle));
+        index[1] = (long int)(it_output.GetIndex()[1] + radius2 * vcl_sin(angle));
         m_HoughSpaceImage->SetPixel(index,255);
         
         /** Remove the maximum from the accumulator */
         for(double length = 0; length < discRatio*radius2;length+=1)
         {
-          index[0] = (long int)(it_output.GetIndex()[0] + length * cos(angle));
-          index[1] = (long int)(it_output.GetIndex()[1] + length* sin(angle));
+          index[0] = (long int)(it_output.GetIndex()[0] + length * vcl_cos(angle));
+          index[1] = (long int)(it_output.GetIndex()[1] + length * vcl_sin(angle));
           m_PostProcessImage->SetPixel(index,0);
         } 
       }
@@ -226,24 +226,24 @@ int itkHoughTransform2DCirclesImageTest(int, char* [])
   std::cout << "Done." << std::endl;
 
   for(unsigned int i=0;i<3;i++)
-  {
-     if((fabs((double)(center_result[i][0])-(double)(center[i][0]))>2.0) ||
-        (fabs((double)(center_result[i][1])-(double)(center[i][1]))>2.0) ||
-        (fabs((double)(radius_result[i]-radius[i]))>2.0)
-       )
-     {
-       std::cout << "Failure for circle #" << i << std::endl;
-       std::cout << "Excpected center: [" << center_result[i][0] <<"," << center_result[i][1]
-                 << "] found [" << center[i][0] <<"," << center[i][1] << "]" << std::endl;
-       std::cout << "Excpected radius: " << radius_result[i] << " found " << radius[i] << std::endl;
-       return EXIT_FAILURE;
-     }
-    else
     {
+    if((vcl_fabs((double)(center_result[i][0])-(double)(center[i][0]))>2.0) ||
+       (vcl_fabs((double)(center_result[i][1])-(double)(center[i][1]))>2.0) ||
+       (vcl_fabs((double)(radius_result[i]-radius[i]))>2.0)
+       )
+      {
+      std::cout << "Failure for circle #" << i << std::endl;
+      std::cout << "Excpected center: [" << center_result[i][0] <<"," << center_result[i][1]
+                << "] found [" << center[i][0] <<"," << center[i][1] << "]" << std::endl;
+      std::cout << "Excpected radius: " << radius_result[i] << " found " << radius[i] << std::endl;
+      return EXIT_FAILURE;
+      }
+    else
+      {
       std::cout << "Circle #" << i << " [" << center_result[i][0] << "," 
                 << center_result[i][1] << "] -> radius = " <<  radius_result[i] << std::endl;
+      }
     }
-  }
 
   std::cout << "Hough Transform Successful" << std::endl;
   return EXIT_SUCCESS;
