@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkHoughTransform2DLinesImageTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-03-07 14:05:39 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-04-06 00:19:18 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -73,12 +73,12 @@ int itkHoughTransform2DLinesImageTest(int, char* [])
   float teta = 0.20; // radians
   float radius = 50;
   
-  double Vx = radius*cos( teta );
-  double Vy = radius*sin( teta );
+  double Vx = radius * vcl_cos( teta );
+  double Vy = radius * vcl_sin( teta );
 
-  double norm = sqrt(Vx*Vx+Vy*Vy);
-  double VxNorm = Vx/norm;
-  double VyNorm = Vy/norm;
+  double norm = vcl_sqrt(Vx*Vx+Vy*Vy);
+  double VxNorm = Vx / norm;
+  double VyNorm = Vy / norm;
        
   unsigned int maxval = size[0]*size[1];
 
@@ -214,9 +214,9 @@ int itkHoughTransform2DLinesImageTest(int, char* [])
         {     
           for(double length = 0; length < m_HoughDiscRadius;length += 1)
           {
-            m_Index[0] = (long int)(it_input.GetIndex()[0] + length * cos(angle));
-            m_Index[1] = (long int)(it_input.GetIndex()[1] + length * sin(angle));
-            if( ((m_Index[0]<=sqrt((double)400*400+400*400)) && (m_Index[0]>=0))
+            m_Index[0] = (long int)(it_input.GetIndex()[0] + length * vcl_cos(angle));
+            m_Index[1] = (long int)(it_input.GetIndex()[1] + length * vcl_sin(angle));
+            if( ((m_Index[0]<=vcl_sqrt((double)400*400+400*400)) && (m_Index[0]>=0))
               && ((m_Index[1]<=500) && (m_Index[1]>=0))
             )
             {
@@ -238,22 +238,22 @@ int itkHoughTransform2DLinesImageTest(int, char* [])
   std::list<houghPoint>::iterator it_list = m_LinesList.begin();
 
   while(it_list != m_LinesList.end())
-  {
+    {
     std::cout << "Angle = " << it_list->angle << " (expected " << teta << ")"<< std::endl;
     std::cout << "Radius = " << it_list->radius << " (expected " << radius << ")"<< std::endl;
     
-    if(fabs(it_list->angle-teta)>0.1)
-    {
+    if( vcl_fabs(it_list->angle-teta)>0.1)
+      {
       std::cout << "Failure" << std::endl;
       return EXIT_FAILURE;
-    }
-    if(fabs(it_list->radius-radius)>1.0)
-    {
+      }
+    if( vcl_fabs(it_list->radius-radius)>1.0)
+      {
       std::cout << "Failure" << std::endl;
       return EXIT_FAILURE;
-    } 
+      } 
     it_list++;  
-  }
+    }
 
   std::cout << "Printing Hough Fiter information:" << std::endl;
   std::cout << houghFilter << std::endl;
