@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkInterpolateImagePointsFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:06 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-07-12 10:53:00 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -242,7 +242,7 @@ int test3DInterpolateImagePointsFilter()
     ++outIter;
     ++inIter;
     }
-  rmse = sqrt( (rmse / size[0] / size[1] / size[2] ) );
+  rmse = vcl_sqrt( (rmse / size[0] / size[1] / size[2] ) );
 
   // Write home and let mom & dad know how we're doing.
   std::cout << "rmse of image is " << rmse << "\n " ;
@@ -324,9 +324,9 @@ ImageTypePtr3D set3DData()
   typedef itk::GaussianImageSource< ImageType3D > GaussianSourceType;
   GaussianSourceType::Pointer pSource = GaussianSourceType::New();
 
-  float spacing[]       = { 1.2f, 1.3f, 1.4f };
-  float origin[]        = { 1.0f, 4.0f, 2.0f };
-  unsigned long size[]  = { 65, 75, 60};
+  ImageType3D::SpacingValueType spacing[] = { 1.2f, 1.3f, 1.4f };
+  ImageType3D::PointValueType origin[] = { 1.0f, 4.0f, 2.0f };
+  ImageType3D::SizeValueType    size[]  = { 65, 75, 60};
 
   GaussianSourceType::ArrayType mean;
   mean[0] = size[0]/2.0f + origin[0];
