@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLogImageFilterAndAdaptorTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-10 14:34:02 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date: 2009-04-06 15:30:18 $
+  Version:   $Revision: 1.15 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -17,11 +17,12 @@
 #if defined(_MSC_VER)
 #pragma warning ( disable : 4786 )
 #endif
-#include <itkImage.h>
-#include <itkLogImageFilter.h>
-#include <itkLogImageAdaptor.h>
-#include <itkImageRegionIteratorWithIndex.h>
-#include <itkSubtractImageFilter.h>
+
+#include "itkImage.h"
+#include "itkLogImageFilter.h"
+#include "itkLogImageAdaptor.h"
+#include "itkImageRegionIteratorWithIndex.h"
+#include "itkSubtractImageFilter.h"
 
 
 int itkLogImageFilterAndAdaptorTest(int, char* [] ) 
@@ -81,16 +82,15 @@ int itkLogImageFilterAndAdaptorTest(int, char* [] )
   InputIteratorType it( inputImage, inputImage->GetBufferedRegion() );
 
   // Initialize the content of Image A
-  const double pi    = atan( 1.0 ) * 4.0;
-  const double value = pi / 6.0;
+  const double value = vnl_math::pi / 6.0;
   std::cout << "Content of the Input " << std::endl;
   it.GoToBegin();
   while( !it.IsAtEnd() ) 
-  {
+    {
     it.Set( value );
     std::cout << it.Get() << std::endl;
     ++it;
-  }
+    }
 
   // Declare the type for the Log filter
   typedef itk::LogImageFilter< InputImageType,
@@ -121,23 +121,23 @@ int itkLogImageFilterAndAdaptorTest(int, char* [] )
   ot.GoToBegin();
   it.GoToBegin();
   while( !ot.IsAtEnd() ) 
-  {
+    {
     std::cout <<  ot.Get() << " = ";
-    std::cout <<  log( it.Get() )  << std::endl; 
+    std::cout <<  vcl_log( it.Get() )  << std::endl; 
     const InputImageType::PixelType  input  = it.Get();
     const OutputImageType::PixelType output = ot.Get();
-    const OutputImageType::PixelType logarithm  = log(input);
-    if( fabs( logarithm - output ) > epsilon )
-    {
+    const OutputImageType::PixelType logarithm  = vcl_log(input);
+    if( vcl_fabs( logarithm - output ) > epsilon )
+      {
       std::cerr << "Error in itkLogImageFilterTest " << std::endl;
-      std::cerr << " log( " << input << ") = " << logarithm << std::endl;
+      std::cerr << " vcl_log( " << input << ") = " << logarithm << std::endl;
       std::cerr << " differs from " << output;
       std::cerr << " by more than " << epsilon << std::endl;
       return EXIT_FAILURE;
-    }
+      }
     ++ot;
     ++it;
-  }
+    }
 
 
   //---------------------------------------
@@ -175,29 +175,20 @@ int itkLogImageFilterAndAdaptorTest(int, char* [] )
   
   dt.GoToBegin();
   while( !dt.IsAtEnd() ) 
-  {
+    {
     std::cout <<  dt.Get() << std::endl;
     const OutputImageType::PixelType diff = dt.Get();
-    if( fabs( diff ) > epsilon )
-    {
+    if( vcl_fabs( diff ) > epsilon )
+      {
       std::cerr << "Error in itkLogImageFilterTest " << std::endl;
       std::cerr << "Comparing results with Adaptors" << std::endl;
       std::cerr << " difference = " << diff << std::endl;
       std::cerr << " differs from 0 ";
       std::cerr << " by more than " << epsilon << std::endl;
       return EXIT_FAILURE;
-    }
+      }
     ++dt;
-  }
+    }
 
-
-
-
-  
   return EXIT_SUCCESS;
-
 }
-
-
-
-
