@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMaskImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-10 14:34:02 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2009-02-15 17:31:39 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -17,10 +17,10 @@
 #if defined(_MSC_VER)
 #pragma warning ( disable : 4786 )
 #endif
-#include <itkImage.h>
+#include "itkImage.h"
 
-#include <itkImageRegionIteratorWithIndex.h>
-#include <itkMaskImageFilter.h>
+#include "itkImageRegionIteratorWithIndex.h"
+#include "itkMaskImageFilter.h"
 
 int itkMaskImageFilterTest(int, char* [] ) 
 {
@@ -144,12 +144,14 @@ int itkMaskImageFilterTest(int, char* [] )
   //  Print the content of the result image
   std::cout << " Result " << std::endl;
   while( !it3.IsAtEnd() ) 
-  {
+    {
     std::cout << it3.Get() << std::endl;
     ++it3;
-  }
+    }
 
 
+  filter->Print( std::cout );
+
   // All objects should be automatically destroyed at this point
   return EXIT_SUCCESS;
 
