@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRecursiveGaussianImageFiltersTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-01-20 15:21:16 $
-  Version:   $Revision: 1.14 $
+  Date:      $Date: 2009-04-05 23:09:35 $
+  Version:   $Revision: 1.15 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -227,7 +227,7 @@ int itkRecursiveGaussianImageFiltersTest(int, char* [] )
 
     const PixelType valueB = filter->GetOutput()->GetPixel( index );
 
-    if( fabs( (valueB - valueA) / valueA ) > 1e-4 )
+    if( vcl_fabs( (valueB - valueA) / valueA ) > 1e-4 )
       {
       std::cout << "FAILED !" << std::endl;
       std::cerr << "Error, Normalization across scales is failing" << std::endl;
