@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkResampleImageTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-03-29 16:42:31 $
-  Version:   $Revision: 1.24 $
+  Date:      $Date: 2009-04-05 23:09:35 $
+  Version:   $Revision: 1.25 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -110,7 +110,7 @@ int itkResampleImageTest(int, char* [] )
     value  = iter2.Get();
     pixval = value;
     PixelType expectedValue = static_cast<PixelType>( (index[0] + index[1]) / 2.0 );
-    if ( fabs( expectedValue - pixval ) > tolerance ) 
+    if ( vcl_fabs( expectedValue - pixval ) > tolerance ) 
       {
       std::cout << "Error in resampled image: Pixel " << index
                 << "value    = " << value << "  "
@@ -121,10 +121,11 @@ int itkResampleImageTest(int, char* [] )
     }
 
   // Report success or failure
-  if (!passed) {
+  if (!passed)
+    {
     std::cout << "Resampling test failed" << std::endl;
     return EXIT_FAILURE;
-  }
+    }
 
   // Exercise other member functions
   resample->Print( std::cout );
