@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkShiftScaleImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-10 14:34:02 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-07-12 10:53:00 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -62,13 +62,13 @@ int itkShiftScaleImageFilterTest(int, char* [] )
 
   typedef itk::RandomImageSource<TestInputImage> SourceType;
   SourceType::Pointer source = SourceType::New();
-  unsigned long randomSize[3] = {17, 8, 20};
+  TestInputImage::SizeValueType randomSize[3] = {17, 8, 20};
 
   // Set up Start, End and Progress callbacks
   FilterWatcher sourceWatch(source);
 
   // Set up source
-  source->SetSize(randomSize);
+  source->SetSize( randomSize );
   double minValue = -128.0;
   double maxValue = 127.0;
 
