@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkShiftScaleInPlaceImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:07 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-07-12 10:53:00 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -69,7 +69,8 @@ int itkShiftScaleInPlaceImageFilterTest(int, char* [] )
 
   typedef itk::RandomImageSource<TestInputImage> SourceType;
   SourceType::Pointer source = SourceType::New();
-  unsigned long randomSize[3] = {17, 8, 20};
+
+  TestInputImage::SizeValueType randomSize[3] = {17, 8, 20};
 
   // Set up Start, End and Progress callbacks
   ShiftScaleInPlaceFilterWatcher sourceWatch(source, "source");
