@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSparseFieldFourthOrderLevelSetImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-10 14:34:02 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date: 2009-04-06 00:19:18 $
+  Version:   $Revision: 1.14 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -50,13 +50,13 @@ const unsigned int WIDTH  = (128);
 float square(unsigned x, unsigned y)
 {
     float X, Y;
-    X = ::fabs(x - (float)WIDTH/2.0);
-    Y = ::fabs(y - (float)HEIGHT/2.0);
+    X = vcl_fabs(x - (float)WIDTH/2.0);
+    Y = vcl_fabs(y - (float)HEIGHT/2.0);
     float dis;
     if (!((X > RADIUS)&&(Y > RADIUS)))
       dis = RADIUS - vnl_math_max(X, Y);
     else
-      dis = -sqrt((X - RADIUS)*(X - RADIUS) +  (Y - RADIUS)*(Y - RADIUS));
+      dis = -vcl_sqrt((X - RADIUS)*(X - RADIUS) +  (Y - RADIUS)*(Y - RADIUS));
     return(dis);
 }
 
