@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSpatialFunctionImageEvaluatorFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:08 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-07-12 10:53:00 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -35,15 +35,15 @@ int itkSpatialFunctionImageEvaluatorFilterTest(int, char* [] )
 {
   const unsigned int dim = 3;
 
-  //-----------------Create a new input image--------------------
-  // Image size and spacing parameters
-  unsigned long sourceImageSize[]  = { 20,20,20 };
-  double sourceImageSpacing[] = { 1.0,1.0,1.0 };
-  double sourceImageOrigin[] = { 0,0,0 };
-
   // Image typedef
   typedef itk::Image< unsigned char, dim > ImageType;
 
+  //-----------------Create a new input image--------------------
+  // Image size and spacing parameters
+  ImageType::SizeValueType sourceImageSize[]  = { 20,20,20 };
+  ImageType::SpacingValueType sourceImageSpacing[] = { 1.0,1.0,1.0 };
+  ImageType::PointValueType sourceImageOrigin[] = { 0,0,0 };
+
   // Create the sourceImage
   ImageType::Pointer sourceImage = ImageType::New();
   sourceImage->SetOrigin(sourceImageOrigin);
