@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkStreamingImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:08 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2009-02-04 16:37:58 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -22,9 +22,12 @@
 #include "itkImageRegionIterator.h"
 #include "itkShrinkImageFilter.h"
 #include "itkStreamingImageFilter.h"
+#include "../IO/itkPipelineMonitorImageFilter.h"
 
 int itkStreamingImageFilterTest(int, char* [] )
 {
+  const unsigned int numberOfStreamDivisions = 4;
+
   // typedefs to simplify the syntax
   typedef itk::Image<short, 2>   ShortImage;
 
@@ -33,7 +36,7 @@ int itkStreamingImageFilterTest(int, char* [] )
 
   // fill in an image
   ShortImage::IndexType  index = {{0, 0}};
-  ShortImage::SizeType   size = {{80, 125}};
+  ShortImage::SizeType   size = {{80, 122}};
   ShortImage::RegionType region;
   region.SetSize( size );
   region.SetIndex( index );
@@ -50,20 +53,25 @@ int itkStreamingImageFilterTest(int, char* [] )
     scalar = i;
     iterator.Set( scalar );
     }
-  
+
   // Create a filter
   itk::ShrinkImageFilter< ShortImage, ShortImage >::Pointer shrink;
   shrink = itk::ShrinkImageFilter< ShortImage, ShortImage >::New();
   shrink->SetInput( if2 );
   
-  unsigned int factors[2] = { 2, 3 };
+  unsigned int factors[2] = { 3, 5 };
   shrink->SetShrinkFactors(factors);
   // shrink->DebugOn();
 
+  // monitor what's going on
+  itk::PipelineMonitorImageFilter<ShortImage>::Pointer monitor;
+  monitor = itk::PipelineMonitorImageFilter<ShortImage>::New();
+  monitor->SetInput( shrink->GetOutput() );
+
   itk::StreamingImageFilter<ShortImage, ShortImage>::Pointer streamer;
   streamer = itk::StreamingImageFilter<ShortImage, ShortImage>::New();
-  streamer->SetInput( shrink->GetOutput() );
-  streamer->SetNumberOfStreamDivisions( 4 );
+  streamer->SetInput( monitor->GetOutput() );
+  streamer->SetNumberOfStreamDivisions( numberOfStreamDivisions );
   streamer->Update();
 
   std::cout << "Input spacing: " << if2->GetSpacing()[0] << ", "
@@ -78,6 +86,16 @@ int itkStreamingImageFilterTest(int, char* [] )
   std::cout << "streamer->GetNumberOfStreamDivisions(): " << value << std::endl;
   streamer->GetRegionSplitter();
   //SplitterType * streamer->GetRegionSplitter();
+  
+  // check if the pipeline executed as expected
+  if (monitor->GetNumberOfUpdates() != value ||
+      monitor->GetOutputRequestedRegions().size() != value) 
+    {    
+    std::cout << monitor;
+    std::cout << "ImageStreaming Filter test failed because pipeline didn't execute as expected." << std::endl;
+    return EXIT_FAILURE;
+    }
+
 
   //
   // The rest of this code determines whether the shrink code produced
@@ -88,18 +106,48 @@ int itkStreamingImageFilterTest(int, char* [] )
   
   itk::ImageRegionIterator<ShortImage>
     iterator2(streamer->GetOutput(), requestedRegion);
+  std::cout << "requestedRegion: " << requestedRegion;
+
+  // If size is not a multiple of the shrink factors, then adjust the
+  // row/col indicies
+  short rowOffset = 0;
+  short colOffset = 0;
+  if (region.GetSize()[1] % shrink->GetShrinkFactors()[1])
+    {
+    rowOffset = static_cast<short>(
+      region.GetSize()[1] / 2.0 -
+      ((region.GetSize()[1] / shrink->GetShrinkFactors()[1]) / 2.0 *
+       shrink->GetShrinkFactors()[1])
+      );
+    }
+  if (region.GetSize()[0] % shrink->GetShrinkFactors()[0])
+    {
+    colOffset = static_cast<short>(
+      region.GetSize()[0] / 2.0 -
+      ((region.GetSize()[0] / shrink->GetShrinkFactors()[0]) / 2.0 *
+       shrink->GetShrinkFactors()[0])
+      );
+    }
 
   bool passed = true;
   for (; !iterator2.IsAtEnd(); ++iterator2)
     {
-    short trueValue = (short) (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0])
-              + (region.GetSize()[0]
-                * shrink->GetShrinkFactors()[1] * iterator2.GetIndex()[1]);
+    short col = (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0] +
+                 (shrink->GetShrinkFactors()[0] - 1) / 2);
+    col += colOffset;
+
+    short row = (shrink->GetShrinkFactors()[1] * iterator2.GetIndex()[1] +
+                 (shrink->GetShrinkFactors()[1] - 1) / 2);
+    row += rowOffset;
+    short trueValue = col + region.GetSize()[0] * row;
 
     if ( iterator2.Get() != trueValue )
       {
       passed = false;
-      std::cout << "Pixel " << iterator2.GetIndex() << " is incorrect" << std::endl;
+      std::cout << "Pixel " << iterator2.GetIndex() 
+                << " expected " << trueValue
+                << " but got " << iterator2.Get()
+                << std::endl;
       }
     }
 
