@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkStreamingImageFilterTest2.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-06-01 21:53:22 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-10-27 16:05:15 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -138,11 +138,11 @@ int itkStreamingImageFilterTest2(int, char* [] )
   for (; !iterator2.IsAtEnd(); ++iterator2)
     {
 #ifdef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
-    short col = itk::Math::RoundHalfIntegerUp( static_cast<float> (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0] +
+    short col = itk::Math::RoundHalfIntegerUp<short>( static_cast<float> (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0] +
                                                                    (shrink->GetShrinkFactors()[0] ) / 2.0 ) );
     col += colOffset;
 
-    short row =  itk::Math::RoundHalfIntegerUp( static_cast<float> (shrink->GetShrinkFactors()[1] * iterator2.GetIndex()[1] +
+    short row =  itk::Math::RoundHalfIntegerUp<short>( static_cast<float> (shrink->GetShrinkFactors()[1] * iterator2.GetIndex()[1] +
                                                                     (shrink->GetShrinkFactors()[1] ) / 2.0 ) );
     row += rowOffset;
 #else    
