@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkThresholdImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-20 13:23:56 $
-  Version:   $Revision: 1.24 $
+  Date:      $Date: 2009-07-12 10:53:00 $
+  Version:   $Revision: 1.25 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -42,9 +42,10 @@ int itkThresholdImageFilterTest(int, char* [] )
   random->SetMax(1000.0);
   random->ReleaseDataFlagOn();
   
-  float spacing[2] = {0.7, 2.1};
+  FloatImage2DType::SpacingValueType spacing[2] = {0.7, 2.1};
   random->SetSpacing( spacing );
-  float origin[2] = {15, 400};
+
+  FloatImage2DType::PointValueType origin[2] = {15, 400};
   random->SetOrigin( origin );
     
   itksys_ios::ostringstream *os;
