@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkThresholdLabelerImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-01-29 14:42:11 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-04-06 11:27:19 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -113,9 +113,9 @@ int itkThresholdLabelerImageFilterTest( int, char *[] )
       labelerFilter->SetFunctor(labelerFilter->GetFunctor());
     }
 
-  catch(itk::ExceptionObject & exp)
+  catch(itk::ExceptionObject & excp)
     {
-      std::cerr << exp << std::endl;
+      std::cerr << excp << std::endl;
     }
 
   // check if labels coincide with expected labels
