@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTriangleMeshToBinaryImageFilterTest2.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-06-13 14:46:46 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2009-05-19 19:50:05 $
+  Version:   $Revision: 1.2 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -30,7 +30,7 @@
 #include "itkTriangleMeshToBinaryImageFilter.h"
 #include "itkImageFileWriter.h"
 
-int itkTriangleMeshToBinaryImageFilterTest2( int , char * [] )
+int itkTriangleMeshToBinaryImageFilterTest2( int argc, char * argv [] )
 { 
   
   // Declare the type of the input and output mesh
@@ -108,15 +108,17 @@ int itkTriangleMeshToBinaryImageFilterTest2( int , char * [] )
 
   //Update the filter
   imageFilter->Update();
-  // uncomment to save the binary image
-  /*
-  typedef itk::ImageFileWriter<ImageType > WriterType;
 
-  WriterType::Pointer ImageWriter = WriterType::New();
-  ImageWriter->SetInput(imageFilter->GetOutput() );
-  ImageWriter->SetFileName("mybinaryimage.mhd");
-  ImageWriter->Update();
-  */
+  if( argc > 1 )
+    {
+    typedef itk::ImageFileWriter<ImageType > WriterType;
+
+    WriterType::Pointer ImageWriter = WriterType::New();
+    ImageWriter->SetInput(imageFilter->GetOutput() );
+    ImageWriter->SetFileName( argv[1] );
+    ImageWriter->Update();
+    }
+
   std::cout << "[TEST DONE]" << std::endl;
   return EXIT_SUCCESS;
 
