@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBSplineDeformableTransformTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-01-18 17:25:49 $
-  Version:   $Revision: 1.17 $
+  Date:      $Date: 2009-04-05 10:56:55 $
+  Version:   $Revision: 1.18 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -465,7 +465,7 @@ int itkBSplineDeformableTransformTest1()
     std::cout << "numberOfParameters =  " << numberOfParameters2 << std::endl;
     for(unsigned int i=0; i<numberOfParameters2; i++)
       {
-      if( fabs( parameters2[i] ) > 1e-10 )
+      if( vcl_fabs( parameters2[i] ) > 1e-10 )
         {
         std::cerr << "SetIdentity failed, parameters are not null after invoking SetIdentity() " << std::endl;
         return EXIT_FAILURE;
