@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBSplineInterpolationWeightFunctionTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-03-21 00:43:04 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-07-12 10:53:03 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -69,7 +69,7 @@ int itkBSplineInterpolationWeightFunctionTest(int, char* [] )
 
     const unsigned int numberOfWeigts = weights1.size();
     
-    const int indexDifference = abs( startIndex2[0] + startIndex1[0] ) & 1;
+    const int indexDifference = vnl_math_abs( startIndex2[0] + startIndex1[0] ) & 1;
 
 
     const double tolerance = 1e-6;
@@ -77,7 +77,7 @@ int itkBSplineInterpolationWeightFunctionTest(int, char* [] )
 
     for( unsigned int nw = 0; nw < numberOfWeigts - indexDifference; nw++ )
       {
-      if( vcl_abs( weights1[nw] - weights2[numberOfWeigts-nw-1-indexDifference] ) > tolerance )
+      if( vnl_math_abs( weights1[nw] - weights2[numberOfWeigts-nw-1-indexDifference] ) > tolerance )
         {
         symmetryForXBroken = true;
         }
@@ -161,7 +161,7 @@ int itkBSplineInterpolationWeightFunctionTest(int, char* [] )
 
     const unsigned int numberOfWeigts = weights1.size();
     
-    const int indexDifference = abs( startIndex2[0] + startIndex1[0] + 1 ) & 1;
+    const int indexDifference = vnl_math_abs( startIndex2[0] + startIndex1[0] + 1 ) & 1;
 
 
     const double tolerance = 1e-6;
@@ -169,7 +169,7 @@ int itkBSplineInterpolationWeightFunctionTest(int, char* [] )
 
     for( unsigned int nw = 0; nw < numberOfWeigts - indexDifference; nw++ )
       {
-      if( vcl_abs( weights1[nw] - weights2[numberOfWeigts-nw-1-indexDifference] ) > tolerance )
+      if( vnl_math_abs( weights1[nw] - weights2[numberOfWeigts-nw-1-indexDifference] ) > tolerance )
         {
         symmetryForXBroken = true;
         }
