@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCenteredAffineTransformTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-09-05 12:11:41 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-04-09 09:23:19 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -231,6 +231,17 @@ int itkCenteredAffineTransformTest(int, char *[])
     std::cout << "Create an inverse transformation:" << std::endl;
     inv3->Print( std::cout );
 
+    Affine3DType::Pointer inv4 =
+       dynamic_cast<Affine3DType*>(aff3->GetInverseTransform().GetPointer());
+    if(!inv4)
+      {
+      std::cout << "Cannot compute inverse transformation" << std::endl;
+      return EXIT_FAILURE;
+      }
+    std::cout << "Create an inverse transformation:" << std::endl;
+    inv4->Print( std::cout );
+
+
     /* Create an image for testing index<->physical transforms */
     std::cout << "Creating image for testing index<->physical transforms"
               << std::endl;
