@@ -10,6 +10,7 @@
 void RegisterTests()
 {
 REGISTER_TEST(itkBSplineDeformableTransformTest2 );
+REGISTER_TEST(itkBSplineDeformableTransformTest3 );
 REGISTER_TEST(itkCellInterfaceTest);
 REGISTER_TEST(itkImageTransformTest);
 REGISTER_TEST(itkLinearInterpolateImageFunctionTest);
@@ -32,6 +33,7 @@ REGISTER_TEST(itkNeighborhoodIteratorTest );
 REGISTER_TEST(itkNeighborhoodOperatorImageFunctionTest);
 REGISTER_TEST(itkNeighborhoodOperatorTest );
 REGISTER_TEST(itkNumericTraitsTest );
+REGISTER_TEST(itkIntTypesTest);
 REGISTER_TEST(itkObjectStoreTest );
 REGISTER_TEST(itkObjectFactoryTest );
 REGISTER_TEST(itkObjectFactoryTest2 );
@@ -69,6 +71,7 @@ REGISTER_TEST(itkSemaphoreTest );
 REGISTER_TEST(itkShapedNeighborhoodIteratorTest );
 REGISTER_TEST(itkSimilarity2DTransformTest );
 REGISTER_TEST(itkSimilarity3DTransformTest );
+REGISTER_TEST(itkSimpleFilterWatcherTest );
 REGISTER_TEST(itkSimplexMeshTest );
 REGISTER_TEST(itkSizeTest );
 REGISTER_TEST(itkSliceIteratorTest );
@@ -99,8 +102,11 @@ REGISTER_TEST(itkVersorRigid3DTransformTest );
 REGISTER_TEST(itkVectorTest );
 REGISTER_TEST(itkVectorInterpolateImageFunctionTest );
 REGISTER_TEST(itkVectorToRGBImageAdaptorTest );
+REGISTER_TEST(itkMathRoundTest );
+REGISTER_TEST(itkMathRoundTest2 );
 REGISTER_TEST(itkVNLRoundProfileTest1 );
 REGISTER_TEST(itkMathRoundProfileTest1 );
+REGISTER_TEST(itkMathCastWithRangeCheckTest );
 REGISTER_TEST(itkWindowedSincInterpolateImageFunctionTest );
 REGISTER_TEST(itkEllipsoidInteriorExteriorSpatialFunctionTest );
 REGISTER_TEST(itkSymmetricEllipsoidInteriorExteriorSpatialFunctionTest );
@@ -113,5 +119,6 @@ REGISTER_TEST(itkVariableLengthVectorTest);
 REGISTER_TEST(itkVariableSizeMatrixTest);
 // REGISTER_TEST(itkQuaternionOrientationAdapterTest);
 REGISTER_TEST(itkImportContainerTest);
+REGISTER_TEST(itkImageFillBufferTest);
 }
 
