@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFixedArrayTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-20 13:00:21 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-07-09 18:07:24 $
+  Version:   $Revision: 1.14 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -111,7 +111,7 @@ int itkFixedArrayTest(int, char* [] )
     std::cout << *bit << std::endl;
     }
 
-  std::cout << "FixedArray<unsigned int, 20>::ConstIterator it = array20.End();" << std::endl;
+  std::cout << "FixedArray<unsigned int, 20>::ConstIterator it = array20.Begin();" << std::endl;
   itk::FixedArray<unsigned int, 20>::ConstIterator cit = array20.Begin();
   while (cit != array20.End())
     {
@@ -119,6 +119,22 @@ int itkFixedArrayTest(int, char* [] )
     ++cit;
     }
 
+  std::cout << "FixedArray<unsigned int, 20>::ReverseIterator rit = array20.rBegin();" << std::endl;
+  itk::FixedArray<unsigned int, 20>::ReverseIterator rit = array20.rBegin();
+  while (rit != array20.rEnd())
+    {
+    std::cout << *rit << std::endl;
+    ++rit;
+    }
+
+  std::cout << "FixedArray<unsigned int, 20>::ConstReverseIterator crit = array20.rBegin();" << std::endl;
+  itk::FixedArray<unsigned int, 20>::ConstReverseIterator crit = array20.rBegin();
+  while (crit != array20.rEnd())
+    {
+    std::cout << *crit << std::endl;
+    ++crit;
+    }
+
   // Try all index types
 #define TRY_INDEX_CONST(T) {T in = 10; if (array20[in] != 10) {std::cerr << "index failed" << std::endl; return EXIT_FAILURE;}}
       TRY_INDEX_CONST(short);
