@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGaussianBlurImageFunctionTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-12-26 19:39:26 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-05-19 15:49:30 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -109,7 +109,7 @@ int itkGaussianBlurImageFunctionTest(int, char* [] )
     
     for(unsigned int i=0;i<Dimension;i++)
     {
-      if( fabs( setError[i] - readError[i] ) > 1e-6 )
+      if( vcl_fabs( setError[i] - readError[i] ) > 1e-6 )
       {
       std::cerr << "[FAILED]" << std::endl;
       return EXIT_FAILURE;
@@ -193,7 +193,7 @@ int itkGaussianBlurImageFunctionTest(int, char* [] )
   
   
   std::cout << "Testing Evaluate(), EvaluateAtIndex() and EvaluateIndex: ";
-  if( (fabs(blurredvalue_index-blurredvalue_point)>0.01)
+  if( (vcl_fabs(blurredvalue_index-blurredvalue_point)>0.01)
      || blurredvalue_point != blurredvalue_continuousIndex)
     {
     std::cerr << "[FAILED] : " 
@@ -207,7 +207,7 @@ int itkGaussianBlurImageFunctionTest(int, char* [] )
 
   std::cout << "Testing Evaluate() : ";
 
-  if( fabs(blurredvalue_point-0.158)> 0.1)
+  if( vcl_fabs(blurredvalue_point-0.158)> 0.1)
     {
     std::cerr << "[FAILED]" << std::endl;
     return EXIT_FAILURE;
@@ -215,6 +215,7 @@ int itkGaussianBlurImageFunctionTest(int, char* [] )
  
   std::cout << "[PASSED] " << std::endl;
 
+  gaussianFunction->Print( std::cout );
   std::cout << "GaussianBlurImageFunctionTest: [DONE] " << std::endl;
   return EXIT_SUCCESS;
 }
