@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGaussianDerivativeImageFunctionTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:09 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-04-05 23:09:35 $
+  Version:   $Revision: 1.4 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -124,7 +124,7 @@ int itkGaussianDerivativeImageFunctionTest(int, char* [] )
   std::cout << "Testing Evaluate() : ";
   
   if( (gradient_point[0] > 0.1)  || 
-      (fabs(gradient_point[1]+1.0)> 10e-4)
+      (vcl_fabs(gradient_point[1]+1.0)> 10e-4)
     )
     {
     std::cerr << "[FAILED]" << std::endl;
@@ -142,7 +142,7 @@ int itkGaussianDerivativeImageFunctionTest(int, char* [] )
   std::cout << "Testing Evaluate() : ";
   
   if( (gradient_point[0] > 0.1)  || 
-      (fabs(gradient_point[1]-1.0)> 10e-4)
+      (vcl_fabs(gradient_point[1]-1.0)> 10e-4)
     )
     {
     std::cerr << "[FAILED]" << std::endl;
