@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMeshSourceGraftOutputTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-20 13:00:21 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-09-17 11:14:57 $
+  Version:   $Revision: 1.4 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -118,7 +118,7 @@ void MeshSourceGraftOutputFilter<TInputMesh,TOutputMesh,TTransform>
   typedef typename TInputMesh::PointsContainerPointer  InputPointsContainerPointer;
   typedef typename TOutputMesh::PointsContainerPointer OutputPointsContainerPointer;
 
-  InputMeshPointer    inputMesh      =  this->GetInput();
+  const InputMeshType * inputMesh    =  this->GetInput();
   OutputMeshPointer   outputMesh     =  this->GetOutput();
   
   if( !inputMesh )
@@ -309,7 +309,3 @@ int itkMeshSourceGraftOutputTest(int, char* [] )
   return EXIT_SUCCESS;
 
 }
-
-
-
-
