@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNearestNeighborExtrapolateImageFunctionTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-06-16 07:58:47 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-10-27 16:05:11 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -70,8 +70,8 @@ int itkNearestNeighborExtrapolateImageFunctionTest( int, char *[])
   point[1] = 3.25;
   value = function->Evaluate( point );
 
-  trueValue = itk::Math::Round( point[0] ) +
-    ( itk::Math::Round( point[1] ) )  * static_cast<double>( imageSize[0] );
+  trueValue = itk::Math::Round<int>( point[0] ) +
+    ( itk::Math::Round<int>( point[1] ) )  * static_cast<double>( imageSize[0] );
 
   std::cout << "Point: " << point << " Value: " << value << std::endl;
   if ( value != trueValue )
@@ -86,7 +86,7 @@ int itkNearestNeighborExtrapolateImageFunctionTest( int, char *[])
   point[1] = 8.0;
   value = function->Evaluate( point );
 
-  trueValue = itk::Math::Round( point[0] ) +
+  trueValue = itk::Math::Round<int>( point[0] ) +
     ( 6.0 )  * static_cast<double>( imageSize[0] );
 
   std::cout << "Point: " << point << " Value: " << value << std::endl;
