@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPCAShapeSignedDistanceFunctionTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:09 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-04-05 10:56:56 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -166,8 +166,8 @@ int itkPCAShapeSignedDistanceFunctionTest( int, char *[])
     p[1] =  point[1] - parameters[startIndexOfTranslationParameters + 1]; 
 
     double angle = parameters[numberOfShapeParameters]; 
-    q[0] =  p[0] * cos(-angle) - p[1] * sin(-angle);
-    q[1] =  p[0] * sin(-angle) + p[1] * cos(-angle);    
+    q[0] =  p[0] * vcl_cos(-angle) - p[1] * vcl_sin(-angle);
+    q[1] =  p[0] * vcl_sin(-angle) + p[1] * vcl_cos(-angle);    
 
     // evaluate shape function
     output = shape->Evaluate(q);
