@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkQuaternionRigidTransformTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2006/08/09 04:35:32 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-04-05 18:14:47 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -48,7 +48,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
 
     for(unsigned int i=0; i<N; i++)
     {
-      if( fabs( offset[i]-0.0 ) > epsilon )
+      if( vcl_fabs( offset[i]-0.0 ) > epsilon )
       {
         Ok = false;
         break;    
@@ -81,7 +81,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
 
     for(unsigned int i=0; i<N; i++)
     {
-      if( fabs( translationVector[i]- itransVector[i] ) > epsilon )
+      if( vcl_fabs( translationVector[i]- itransVector[i] ) > epsilon )
       {
         Ok = false;
         break;    
@@ -103,7 +103,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
       r = translation->TransformPoint( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i]- r[i] ) > epsilon )
+        if( vcl_fabs( q[i]- r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -130,7 +130,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
       q = translation->TransformVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i]- p[i] ) > epsilon )
+        if( vcl_fabs( q[i]- p[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -156,7 +156,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
       q = translation->TransformCovariantVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i]- p[i] ) > epsilon )
+        if( vcl_fabs( q[i]- p[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -185,7 +185,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
       q = translation->TransformVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i] - p[i] ) > epsilon )
+        if( vcl_fabs( q[i] - p[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -215,12 +215,12 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
     TransformType::VnlQuaternionType qrotation;
    
     // 15 degrees in radians
-    const double angle = 15.0 * atan( 1.0f ) / 45.0; 
-    const double sinth2 = sin( angle / 2.0 );
-    const double costh2 = cos( angle / 2.0 );
+    const double angle = 15.0 * vcl_atan( 1.0f ) / 45.0; 
+    const double sinth2 = vcl_sin( angle / 2.0 );
+    const double costh2 = vcl_cos( angle / 2.0 );
 
-    const double sinth  = sin( angle );
-    const double costh  = cos( angle );
+    const double sinth  = vcl_sin( angle );
+    const double costh  = vcl_cos( angle );
 
     // around the positive Z axis 
     qrotation[0] =     0.0;
@@ -245,7 +245,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
 
     for(unsigned int i=0; i<N; i++)
     {
-      if( fabs( offset[i]- ioffset[i] ) > epsilon )
+      if( vcl_fabs( offset[i]- ioffset[i] ) > epsilon )
       {
         Ok = false;
         break;    
@@ -269,7 +269,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
     {
       for(unsigned int j=0; j<N; j++)
       {
-        if( fabs( matrix[i][j]- mrotation[j][i] ) > epsilon )
+        if( vcl_fabs( matrix[i][j]- mrotation[j][i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -297,7 +297,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
       r = rotation->TransformPoint( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i]- r[i] ) > epsilon )
+        if( vcl_fabs( q[i]- r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -330,7 +330,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
       r = rotation->TransformVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -364,7 +364,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
 
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -402,7 +402,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
       r = rotation->TransformVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -434,10 +434,10 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
 
     double angle = 0.62 / 180.0 * vnl_math::pi;
 
-    parameters[0] =  2.0 * sin( 0.5 * angle );
-    parameters[1] =  5.0 * sin( 0.5 * angle );
-    parameters[2] = -4.0 * sin( 0.5 * angle );
-    parameters[3] =        cos( 0.5 * angle );
+    parameters[0] =  2.0 * vcl_sin( 0.5 * angle );
+    parameters[1] =  5.0 * vcl_sin( 0.5 * angle );
+    parameters[2] = -4.0 * vcl_sin( 0.5 * angle );
+    parameters[3] =        vcl_cos( 0.5 * angle );
     parameters[4] = 6.0;
     parameters[5] = 8.0;
     parameters[6] = 10.0;
@@ -524,12 +524,12 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
     TransformType::VnlQuaternionType qrotation;
    
     // 15 degrees in radians
-    const double angle = 15.0 * atan( 1.0f ) / 45.0; 
-    const double sinth2 = sin( angle / 2.0 );
-    const double costh2 = cos( angle / 2.0 );
+    const double angle = 15.0 * vcl_atan( 1.0f ) / 45.0; 
+    const double sinth2 = vcl_sin( angle / 2.0 );
+    const double costh2 = vcl_cos( angle / 2.0 );
 
-    const double sinth  = sin( angle );
-    const double costh  = cos( angle );
+    const double sinth  = vcl_sin( angle );
+    const double costh  = vcl_cos( angle );
 
     // around the positive Z axis 
     qrotation[0] =     0.0;
@@ -578,7 +578,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
 
     for(unsigned int i=0; i<N; i++)
     {
-      if( fabs( offset[i]- ioffset[i] ) > epsilon )
+      if( vcl_fabs( offset[i]- ioffset[i] ) > epsilon )
       {
         Ok = false;
         break;    
@@ -602,7 +602,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
     {
       for(unsigned int j=0; j<N; j++)
       {
-        if( fabs( matrix[i][j]- mrotation[j][i] ) > epsilon )
+        if( vcl_fabs( matrix[i][j]- mrotation[j][i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -634,7 +634,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
       r = rotation->TransformPoint( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i]- r[i] ) > epsilon )
+        if( vcl_fabs( q[i]- r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -667,7 +667,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
       r = rotation->TransformVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -701,7 +701,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
 
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -739,7 +739,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
       r = rotation->TransformVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -812,10 +812,10 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
       matrix.GetVnlMatrix().set_identity();
 
       double a = 1.0 / 180.0 * vnl_math::pi;
-      matrix[0][0] =        cos( a );
-      matrix[0][1] = -1.0 * sin( a );
-      matrix[1][0] =        sin( a ); 
-      matrix[1][1] =        cos( a );
+      matrix[0][0] =        vcl_cos( a );
+      matrix[0][1] = -1.0 * vcl_sin( a );
+      matrix[1][0] =        vcl_sin( a ); 
+      matrix[1][1] =        vcl_cos( a );
 
      Ok = true;
      try
@@ -844,8 +844,8 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
     typedef TransformType::ParametersType ParametersType;
     ParametersType e( t->GetNumberOfParameters() );
     e.Fill( 0.0 );
-    e[2] = sin(0.5 * a);
-    e[3] = cos(0.5 * a );
+    e[2] = vcl_sin(0.5 * a);
+    e[3] = vcl_cos(0.5 * a );
 
     t = TransformType::New();
     t->SetParameters( e );
@@ -857,7 +857,7 @@ int itkQuaternionRigidTransformTest(int ,char * [] )
 
     for( unsigned int k = 0; k < e.GetSize(); k++ )
       {
-      if( fabs( e[k] - p[k] ) > epsilon )
+      if( vcl_fabs( e[k] - p[k] ) > epsilon )
         {
         std::cout << " [ FAILED ] " << std::endl;
         std::cout << "Expected parameters: " << e << std::endl;
