@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRGBPixelTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-01-25 16:41:36 $
-  Version:   $Revision: 1.15 $
+  Date:      $Date: 2009-04-05 10:56:56 $
+  Version:   $Revision: 1.16 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -122,7 +122,7 @@ int itkRGBPixelTest(int, char* [] )
                               rgbl[2] * 0.11;
   const float tolerance = 1e-4;
 
-  if( fabs( luminance - realLuminance ) > tolerance )
+  if( vcl_fabs( luminance - realLuminance ) > tolerance )
     {
     std::cerr << "Error in luminance conversion" << std::endl;
     return EXIT_FAILURE;
