@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRigid3DTransformTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-06-29 13:25:41 $
-  Version:   $Revision: 1.19 $
+  Date:      $Date: 2009-04-09 09:23:19 $
+  Version:   $Revision: 1.23 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -35,7 +35,7 @@ bool CheckEqual(
   const double epsilon = 1e-10;
   for( unsigned int i = 0; i < 2; i++ )
     {
-    if( fabs( p1[i] - p2[i] ) > epsilon )
+    if( vcl_fabs( p1[i] - p2[i] ) > epsilon )
       {
       std::cout << p1 << " != " << p2 << ": FAILED" << std::endl;
       return false;
@@ -46,6 +46,64 @@ bool CheckEqual(
 }
 }
 
+bool TestSettingTranslation(void)
+{
+
+    itk::Matrix<double, 3, 3> R;
+    R.SetIdentity();
+    const double alpha = vnl_math::pi / 180.0;
+    R[0][0] =        vcl_cos( alpha );
+    R[0][1] =        vcl_sin( alpha );
+    R[1][0] = -1.0 * vcl_sin( alpha ); 
+    R[1][1] =        vcl_cos( alpha );
+
+
+    itk::Vector< double, 3> T; T[0]=100;T[1]=200;T[2]=300;
+    itk::Rigid3DTransform<double>::Pointer r1=itk::Rigid3DTransform<double>::New();
+    //r1->SetIdentity();
+    r1->SetRotationMatrix( R );
+    r1->Translate( T );
+    itk::Rigid3DTransform<double>::ParametersType p1;
+    p1.set_size(12);
+    p1=r1->GetParameters();
+
+    itk::Rigid3DTransform<double>::Pointer r2=itk::Rigid3DTransform<double>::New();
+    itk::Rigid3DTransform<double>::ParametersType p2;
+    p2.set_size(12);
+    for(int r=0;r<3;r++)
+      {
+      for(int c=0;c<3;c++)
+        { 
+        p2[r*3+c]=R[r][c];
+        }
+      }
+    p2[ 9]=T[0];
+    p2[10]=T[1];
+    p2[11]=T[2];
+    r2->SetParameters( p2 );
+    itk::Rigid3DTransform<double>::Pointer r3=itk::Rigid3DTransform<double>::New();
+    r3->SetFixedParameters( r1->GetFixedParameters() );
+    r3->SetParameters( r1->GetParameters() );
+
+    itk::Rigid3DTransform<double>::ParametersType p3;
+    p3.set_size(12);
+    p3=r3->GetParameters();
+    if( (p1 == p2)  && (p1 == p3))
+    {
+      return true;
+    }
+    else
+    {
+      std::cout << "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!" << std::endl;
+      std::cout << "r1\n" << r1 << std::endl;
+      std::cout << "r2\n" << r2 << std::endl;
+      std::cout << "r3\n" << r3 << std::endl;
+      std::cout << p1 << "\n" << p2 << "\n" << p3 << std::endl;
+      std::cout << "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!" << std::endl;
+    }
+
+  return false;
+}
 
 int itkRigid3DTransformTest(int ,char * [] )
 {
@@ -70,7 +128,7 @@ int itkRigid3DTransformTest(int ,char * [] )
 
     for(unsigned int i=0; i<N; i++)
     {
-      if( fabs( offset[i]-0.0 ) > epsilon )
+      if( vcl_fabs( offset[i]-0.0 ) > epsilon )
       {
         Ok = false;
         break;    
@@ -102,6 +160,15 @@ int itkRigid3DTransformTest(int ,char * [] )
     std::cout << "translation: " << translation;
     std::cout << "translationInverse: " << translationInverse;
 
+    translationInverse = dynamic_cast<TransformType*>(translation->GetInverseTransform().GetPointer());
+    if(!translationInverse)
+      {
+      std::cout << "Cannot compute inverse" << std::endl;
+      return EXIT_FAILURE;
+      }
+    std::cout << "translation: " << translation;
+    std::cout << "translationInverse: " << translationInverse;
+
 
     TransformType::OffsetType offset = translation->GetOffset();
     std::cout << "pure Translation test:  ";
@@ -109,7 +176,7 @@ int itkRigid3DTransformTest(int ,char * [] )
 
     for(unsigned int i=0; i<N; i++)
     {
-      if( fabs( offset[i]- ioffset[i] ) > epsilon )
+      if( vcl_fabs( offset[i]- ioffset[i] ) > epsilon )
       {
         Ok = false;
         break;    
@@ -131,7 +198,7 @@ int itkRigid3DTransformTest(int ,char * [] )
       r = translation->TransformPoint( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i]- r[i] ) > epsilon )
+        if( vcl_fabs( q[i]- r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -158,7 +225,7 @@ int itkRigid3DTransformTest(int ,char * [] )
       q = translation->TransformVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i]- p[i] ) > epsilon )
+        if( vcl_fabs( q[i]- p[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -184,7 +251,7 @@ int itkRigid3DTransformTest(int ,char * [] )
       q = translation->TransformCovariantVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i]- p[i] ) > epsilon )
+        if( vcl_fabs( q[i]- p[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -213,7 +280,7 @@ int itkRigid3DTransformTest(int ,char * [] )
       q = translation->TransformVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i] - p[i] ) > epsilon )
+        if( vcl_fabs( q[i] - p[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -245,9 +312,9 @@ int itkRigid3DTransformTest(int ,char * [] )
     mrotation.SetIdentity();
 
     // 15 degrees in radians
-    const double angle = 15.0 * atan( 1.0f ) / 45.0; 
-    const double sinth = sin( angle );
-    const double costh = cos( angle );
+    const double angle = 15.0 * vcl_atan( 1.0f ) / 45.0; 
+    const double sinth = vcl_sin( angle );
+    const double costh = vcl_cos( angle );
 
     // around the positive Z axis 
     mrotation[0][0] =  costh;
@@ -271,6 +338,15 @@ int itkRigid3DTransformTest(int ,char * [] )
     std::cout << "rotation: " << rotation;
     std::cout << "rotationInverse: " << rotationInverse;
 
+    rotationInverse = dynamic_cast<TransformType*>(rotation->GetInverseTransform().GetPointer());
+    if(!rotationInverse)
+      {
+      std::cout << "Cannot compute inverse" << std::endl;
+      return EXIT_FAILURE;
+      }
+    std::cout << "rotation: " << rotation;
+    std::cout << "rotationInverse: " << rotationInverse;
+
 
     // Verify the Offset content
     TransformType::OffsetType offset = rotation->GetOffset();
@@ -279,7 +355,7 @@ int itkRigid3DTransformTest(int ,char * [] )
 
     for(unsigned int i=0; i<N; i++)
     {
-      if( fabs( offset[i]- ioffset[i] ) > epsilon )
+      if( vcl_fabs( offset[i]- ioffset[i] ) > epsilon )
       {
         Ok = false;
         break;    
@@ -300,7 +376,7 @@ int itkRigid3DTransformTest(int ,char * [] )
     {
       for(unsigned int j=0; j<N; j++)
       {
-        if( fabs( matrix0[i][j]- mrotation[i][j] ) > epsilon )
+        if( vcl_fabs( matrix0[i][j]- mrotation[i][j] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -328,7 +404,7 @@ int itkRigid3DTransformTest(int ,char * [] )
       r = rotation->TransformPoint( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i]- r[i] ) > epsilon )
+        if( vcl_fabs( q[i]- r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -361,7 +437,7 @@ int itkRigid3DTransformTest(int ,char * [] )
       r = rotation->TransformVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -395,7 +471,7 @@ int itkRigid3DTransformTest(int ,char * [] )
 
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -433,7 +509,7 @@ int itkRigid3DTransformTest(int ,char * [] )
       r = rotation->TransformVector( p );
       for(unsigned int i=0; i<N; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -496,10 +572,10 @@ int itkRigid3DTransformTest(int ,char * [] )
     matrix.GetVnlMatrix().set_identity();
 
     double a = 1.0 / 180.0 * vnl_math::pi;
-    matrix[0][0] =        cos( a );
-    matrix[0][1] =        sin( a );
-    matrix[1][0] = -1.0 * sin( a ); 
-    matrix[1][1] =        cos( a );
+    matrix[0][0] =        vcl_cos( a );
+    matrix[0][1] =        vcl_sin( a );
+    matrix[1][0] = -1.0 * vcl_sin( a ); 
+    matrix[1][1] =        vcl_cos( a );
 
     unsigned int par = 0;
     for( unsigned int row = 0; row < 3; row++ )
@@ -623,10 +699,10 @@ int itkRigid3DTransformTest(int ,char * [] )
       matrix.GetVnlMatrix().set_identity();
 
       double a = 1.0 / 180.0 * vnl_math::pi;
-      matrix[0][0] =        cos( a );
-      matrix[0][1] =        sin( a );
-      matrix[1][0] = -1.0 * sin( a ); 
-      matrix[1][1] =        cos( a );
+      matrix[0][0] =        vcl_cos( a );
+      matrix[0][1] =        vcl_sin( a );
+      matrix[1][0] = -1.0 * vcl_sin( a ); 
+      matrix[1][1] =        vcl_cos( a );
 
      Ok = true;
      try
@@ -649,13 +725,19 @@ int itkRigid3DTransformTest(int ,char * [] )
       std::cerr << "Error: caught unexpected exception" << std::endl;
       return EXIT_FAILURE;
       }
+     bool TranslationSettingOK=TestSettingTranslation();
+     if( !TranslationSettingOK )
+     {
+       std::cerr << "Error:  SetTranslation() did not result in consisent internal state for Rigid3DTransform." << std::endl;
+       return EXIT_FAILURE;
+     }
 
     std::cout << "done." << std::endl;
     }
 
   }
-
- 
   return EXIT_SUCCESS;
 
 }
+
+
