@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkScaleSkewVersor3DTransformTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-04-30 14:50:10 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-04-05 18:31:51 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -87,7 +87,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
 
     VectorType axis(1.5);
 
-    ValueType angle = 120.0*atan(1.0)/45.0;
+    ValueType angle = 120.0*vcl_atan(1.0)/45.0;
 
     VersorType versor;
     versor.Set( axis, angle );
@@ -135,7 +135,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
 
     itk::Vector<double,3> axis(1);
 
-    const double angle = (atan(1.0)/45.0)*120.0; // turn 120 degrees
+    const double angle = (vcl_atan(1.0)/45.0)*120.0; // turn 120 degrees
 
     // this rotation will permute the axis x->y, y->z, z->x
     rotation->SetRotation( axis, angle );
@@ -146,7 +146,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
 
     for(unsigned int i=0; i<3; i++)
     {
-      if( fabs( offset[i] - 0.0 ) > epsilon )
+      if( vcl_fabs( offset[i] - 0.0 ) > epsilon )
       {
         Ok = false;
         break;    
@@ -173,7 +173,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
       r = rotation->TransformPoint( p );
       for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( q[i]- r[i] ) > epsilon )
+        if( vcl_fabs( q[i]- r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -203,7 +203,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
       r = rotation->TransformVector( p );
       for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -234,7 +234,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
       r = rotation->TransformCovariantVector( p );
       for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -268,7 +268,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
       r = rotation->TransformVector( p );
       for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -301,7 +301,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
 
     itk::Vector<double,3> axis(1);
 
-    const double angle = (atan(1.0)/45.0)*30.0; // turn 30 degrees
+    const double angle = (vcl_atan(1.0)/45.0)*30.0; // turn 30 degrees
 
     transform->SetRotation( axis, angle );
 
@@ -317,7 +317,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
 
     for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( center[i] - transformedPoint[i] ) > epsilon )
+        if( vcl_fabs( center[i] - transformedPoint[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -361,7 +361,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
 
     for(unsigned int p=0; p<np; p++)
       {
-      if( fabs( parameters[p] - parameters2[p] ) > tolerance )
+      if( vcl_fabs( parameters[p] - parameters2[p] ) > tolerance )
         {
         std::cerr << "Output parameter does not match input " << std::endl;
         return EXIT_FAILURE;
@@ -443,7 +443,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
 
   itk::Vector<double,3> axis(1);
 
-  const double angle = (atan(1.0)/45.0)*30.0; // turn 30 degrees
+  const double angle = (vcl_atan(1.0)/45.0)*30.0; // turn 30 degrees
 
   transform->SetRotation( axis, angle );
 
@@ -484,7 +484,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
 
   for(unsigned int p=0; p<np; p++)
     {
-    if( fabs( parameters[p] - parameters2[p] ) > tolerance )
+    if( vcl_fabs( parameters[p] - parameters2[p] ) > tolerance )
       {
       std::cerr << "Output parameter does not match input " << std::endl;
       return EXIT_FAILURE;
@@ -499,7 +499,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
 
   itk::Vector<double,3> axis(1);
 
-  const double angle = (atan(1.0)/45.0)*30.0; // turn 30 degrees
+  const double angle = (vcl_atan(1.0)/45.0)*30.0; // turn 30 degrees
 
   transform->SetRotation( axis, angle );
 
@@ -528,7 +528,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
 
   for( unsigned int j = 0; j < 3; j++ )
     {
-    if( fabs( rscale[j] - scale[j] ) > tolerance )
+    if( vcl_fabs( rscale[j] - scale[j] ) > tolerance )
       {
       std::cerr << "Error in Set/Get Scale() " << std::endl;
       std::cerr << "Input scale: " << scale << std::endl;
@@ -560,7 +560,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
 
   for(unsigned int p=0; p<np; p++)
     {
-    if( fabs( parameters[p] - parameters2[p] ) > tolerance )
+    if( vcl_fabs( parameters[p] - parameters2[p] ) > tolerance )
       {
       std::cerr << "Output parameter does not match input " << std::endl;
       return EXIT_FAILURE;
@@ -622,10 +622,10 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
 
       double a = 1.0 / 180.0 * vnl_math::pi;
       double s = 1.0;
-      matrix[0][0] =        cos( a ) * s;
-      matrix[0][1] = -1.0 * sin( a ) * s;
-      matrix[1][0] =        sin( a ) * s; 
-      matrix[1][1] =        cos( a ) * s;
+      matrix[0][0] =        vcl_cos( a ) * s;
+      matrix[0][1] = -1.0 * vcl_sin( a ) * s;
+      matrix[1][0] =        vcl_sin( a ) * s; 
+      matrix[1][1] =        vcl_cos( a ) * s;
       matrix[2][2] =                   s;
 
      Ok = true;
@@ -659,7 +659,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
     typedef TransformType::ParametersType ParametersType;
     ParametersType e( t->GetNumberOfParameters() );
     e.Fill( 0.0 );
-    e[2] = sin(0.5 * a);
+    e[2] = vcl_sin(0.5 * a);
     e[6] = s;
     e[7] = s;
     e[8] = s;
@@ -678,7 +678,7 @@ int itkScaleSkewVersor3DTransformTest(int, char* [] )
 
     for( unsigned int k = 0; k < e.GetSize(); k++ )
       {
-      if( fabs( e[k] - p[k] ) > epsilon )
+      if( vcl_fabs( e[k] - p[k] ) > epsilon )
         {
         std::cout << " [ FAILED ] " << std::endl;
         std::cout << "Expected parameters: " << e << std::endl;
