@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkThreadDefsTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003/09/10 14:30:10 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2007-08-20 13:00:21 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -27,8 +27,8 @@ int itkThreadDefsTest (int, char* [] )
   std::cout << "ERROR: _NOTHREADS is defined and ITK_USE_PTHREADS is defined." << std::endl;
   std::cout << "STL containers WILL NOT BE thread safe on SGI's and GNU c++ systems." << std::endl;
     std::cout << "The C++ compiler needs a -D_PTHREADS option." << std::endl;
-  return 1;
+  return EXIT_FAILURE;
 #endif
   
-  return 0;
+  return EXIT_SUCCESS;
 }
