@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVersorRigid3DTransformTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-08-09 04:35:32 $
-  Version:   $Revision: 1.22 $
+  Date:      $Date: 2009-04-05 10:56:56 $
+  Version:   $Revision: 1.23 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -89,7 +89,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
 
     VectorType axis(1.5);
 
-    ValueType angle = 120.0*atan(1.0)/45.0;
+    ValueType angle = 120.0*vcl_atan(1.0)/45.0;
 
     VersorType versor;
     versor.Set( axis, angle );
@@ -134,7 +134,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
 
     itk::Vector<double,3> axis(1);
 
-    const double angle = (atan(1.0)/45.0)*120.0; // turn 120 degrees
+    const double angle = (vcl_atan(1.0)/45.0)*120.0; // turn 120 degrees
 
     // this rotation will permute the axis x->y, y->z, z->x
     rotation->SetRotation( axis, angle );
@@ -145,7 +145,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
 
     for(unsigned int i=0; i<3; i++)
     {
-      if( fabs( offset[i] - 0.0 ) > epsilon )
+      if( vcl_fabs( offset[i] - 0.0 ) > epsilon )
       {
         Ok = false;
         break;    
@@ -172,7 +172,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
       r = rotation->TransformPoint( p );
       for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( q[i]- r[i] ) > epsilon )
+        if( vcl_fabs( q[i]- r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -202,7 +202,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
       r = rotation->TransformVector( p );
       for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -233,7 +233,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
       r = rotation->TransformCovariantVector( p );
       for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -267,7 +267,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
       r = rotation->TransformVector( p );
       for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -300,7 +300,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
 
     itk::Vector<double,3> axis(1);
 
-    const double angle = (atan(1.0)/45.0)*30.0; // turn 30 degrees
+    const double angle = (vcl_atan(1.0)/45.0)*30.0; // turn 30 degrees
 
     transform->SetRotation( axis, angle );
 
@@ -316,7 +316,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
 
     for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( center[i] - transformedPoint[i] ) > epsilon )
+        if( vcl_fabs( center[i] - transformedPoint[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -339,7 +339,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
 
     VersorType versor;
 
-    parameters[0] = versor.GetX();   // Rotation axis * sin(t/2)
+    parameters[0] = versor.GetX();   // Rotation axis * vcl_sin(t/2)
     parameters[1] = versor.GetY();
     parameters[2] = versor.GetZ();
     parameters[3] = 8.0;             // Translation
@@ -354,7 +354,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
 
     for(unsigned int p=0; p<np; p++)
       {
-      if( fabs( parameters[p] - parameters2[p] ) > tolerance )
+      if( vcl_fabs( parameters[p] - parameters2[p] ) > tolerance )
         {
         std::cerr << "Output parameter does not match input " << std::endl;
         return EXIT_FAILURE;
@@ -423,7 +423,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
 
   itk::Vector<double,3> axis(1);
 
-  const double angle = (atan(1.0)/45.0)*30.0; // turn 30 degrees
+  const double angle = (vcl_atan(1.0)/45.0)*30.0; // turn 30 degrees
 
   transform->SetRotation( axis, angle );
 
@@ -442,7 +442,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
 
   VersorType versor;
 
-  parameters[0] = versor.GetX();   // Rotation axis * sin(t/2)
+  parameters[0] = versor.GetX();   // Rotation axis * vcl_sin(t/2)
   parameters[1] = versor.GetY();
   parameters[2] = versor.GetZ();
   parameters[3] = 0.0;             // Translation
@@ -456,7 +456,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
 
   for(unsigned int p=0; p<np; p++)
     {
-    if( fabs( parameters[p] - parameters2[p] ) > tolerance )
+    if( vcl_fabs( parameters[p] - parameters2[p] ) > tolerance )
       {
       std::cerr << "Output parameter does not match input " << std::endl;
       return EXIT_FAILURE;
@@ -514,10 +514,10 @@ int itkVersorRigid3DTransformTest(int, char* [] )
       matrix.GetVnlMatrix().set_identity();
 
       double a = 1.0 / 180.0 * vnl_math::pi;
-      matrix[0][0] =        cos( a );
-      matrix[0][1] = -1.0 * sin( a );
-      matrix[1][0] =        sin( a ); 
-      matrix[1][1] =        cos( a );
+      matrix[0][0] =        vcl_cos( a );
+      matrix[0][1] = -1.0 * vcl_sin( a );
+      matrix[1][0] =        vcl_sin( a ); 
+      matrix[1][1] =        vcl_cos( a );
 
      Ok = true;
      try
@@ -546,7 +546,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
     typedef TransformType::ParametersType ParametersType;
     ParametersType e( t->GetNumberOfParameters() );
     e.Fill( 0.0 );
-    e[2] = sin(0.5 * a);
+    e[2] = vcl_sin(0.5 * a);
 
     t = TransformType::New();
     t->SetParameters( e );
@@ -558,7 +558,7 @@ int itkVersorRigid3DTransformTest(int, char* [] )
 
     for( unsigned int k = 0; k < e.GetSize(); k++ )
       {
-      if( fabs( e[k] - p[k] ) > epsilon )
+      if( vcl_fabs( e[k] - p[k] ) > epsilon )
         {
         std::cout << " [ FAILED ] " << std::endl;
         std::cout << "Expected parameters: " << e << std::endl;
