@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVersorTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-12-20 19:19:18 $
-  Version:   $Revision: 1.19 $
+  Date:      $Date: 2009-04-05 10:56:56 $
+  Version:   $Revision: 1.22 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,10 +26,132 @@
  *
  */
 
-
 #include "itkVersor.h"
 #include <iostream>
 
+itk::Matrix<double,3,3> TestCreateRotationMatrixFromAngles(const double alpha, const double beta, const double gamma)
+{
+  //alpha is rotate the X axis -- Attitude
+  //beta is rotate the Y axis  -- Bank
+  //gamma is rotate the Z axis -- Heading
+  const double ca=vcl_cos(alpha);
+  const double sa=vcl_sin(alpha);
+  const double cb=vcl_cos(beta);
+  const double sb=vcl_sin(beta);
+  const double cg=vcl_cos(gamma);
+  const double sg=vcl_sin(gamma);
+
+  itk::Matrix<double,3,3> R;
+
+  R(0,0)=cb*cg;  R(0,1)=-ca*sg+sa*sb*cg; R(0,2)=sa*sg+ca*sb*cg;
+  R(1,0)=cb*sg;  R(1,1)=ca*cg+sa*sb*sg;  R(1,2)=-sa*cg+ca*sb*sg;
+  R(2,0)=-sb;    R(2,1)=sa*cb;           R(2,2)=ca*cb;
+  itk::Matrix<double,3,3>::InternalMatrixType test =
+    R.GetVnlMatrix() * R.GetTranspose();
+   if( !test.is_identity( 1.0e-10 ) )
+    {
+    std::cout << "Computed matrix is not orthogonal!!!" << std::endl;
+    std::cout << R << std::endl;
+    }
+  return R;
+}
+
+
+itk::Versor<double> TestCreateRotationVersorFromAngles(const double alpha, const double beta, const double gamma)
+{
+  //http://en.wikipedia.org/wiki/Conversion_between_quaternions_and_Euler_angles
+  //psi = alpha is rotate the X axis -- Attitude
+  //theta= beta is rotate the Y axis  -- Bank
+  //phi=  gamma is rotate the Z axis -- Heading
+  const double cha=vcl_cos(alpha*0.5);
+  const double chb=vcl_cos(beta*0.5);
+  const double chg=vcl_cos(gamma*0.5);
+  const double sha=vcl_sin(alpha*0.5);
+  const double shb=vcl_sin(beta*0.5);
+  const double shg=vcl_sin(gamma*0.5);
+
+  vnl_vector_fixed<double,4> q;
+  q[0]=cha*chb*chg+sha*shb*shg;
+  q[1]=sha*chb*chg-cha*shb*shg;
+  q[2]=cha*shb*chg+sha*chb*shg;
+  q[3]=cha*chb*shg-sha*shb*chg;
+
+  itk::Versor<double> v;
+  v.Set(q[1],q[2],q[3],q[0]);
+  std::cout << "versor: " << v << std::endl;
+  return v;
+}
+
+/**
+ * This test that the conversion to and from Rotaion Matrix and 
+ * Versor produces consistent results. 
+ */
+int RotationMatrixToVersorTest(void)
+{
+  int errorCount=0;
+  //const double onedegree=1e-10*vnl_math::pi/180.0;
+  const double onedegree=vnl_math::pi/180.0;
+  //const double td=180.0/vnl_math::pi;
+  double centers[6];
+  centers[0]=0;
+  centers[1]=vnl_math::pi*0.25;
+  centers[2]=vnl_math::pi*0.5;
+  centers[3]=vnl_math::pi;
+  centers[4]=vnl_math::pi*1.5;
+  centers[5]=vnl_math::pi*2.0;
+
+  const double steps=0;
+  const double small_degree_steps=onedegree/1000.0; //1/1000 of a degree
+  for(int j = 0; j < 6; j++)
+    {
+    for(double alpha=centers[j]-steps*small_degree_steps; alpha <= centers[j]+steps*small_degree_steps; alpha += small_degree_steps)
+      {
+      for(double beta=centers[j]-steps*small_degree_steps; beta <= centers[j]+steps*small_degree_steps; beta += small_degree_steps)
+        {
+        for(double gamma=centers[j]-steps*small_degree_steps; gamma <= centers[j]+steps*small_degree_steps; gamma += small_degree_steps)
+          {
+          itk::Matrix<double,3,3> MR=TestCreateRotationMatrixFromAngles(alpha, beta, gamma);
+          itk::Versor<double> VR=TestCreateRotationVersorFromAngles(alpha, beta, gamma);
+
+          itk::Point<double,3> testPoint;
+          testPoint[0]=-1020.27;
+          testPoint[1]=3.21;
+          testPoint[2]=1000.786432;
+
+          itk::Versor<double> VFROMMR;
+          VFROMMR.Set(MR);
+          itk::Matrix<double,3,3> VRMatrix = VR.GetMatrix();
+          const itk::Point<double,3> newMRtestPoint=(MR)*testPoint;
+          const itk::Point<double,3> newVRtestPoint=(VRMatrix)*testPoint;
+
+          const itk::Point<double,3> newVRFROMMRPoint=(VFROMMR.GetMatrix())*testPoint;
+          const itk::Point<double,3> newVRFROMMRTransformPoint=VFROMMR.Transform(testPoint);
+
+          const double error_newMRtestPoint_newVRtestPoint=(newMRtestPoint-newVRtestPoint).GetNorm();
+          const double error_newMRtestPoint_newVRFROMMRPoint=(newMRtestPoint-newVRFROMMRPoint).GetNorm();
+          const double error_newVRFROMMRPoint_newVRFROMMRTransformPoint=(newVRFROMMRPoint-newVRFROMMRTransformPoint).GetNorm();
+
+          const double maxAllowedPointError=1e-5;
+          if( ( error_newMRtestPoint_newVRtestPoint + error_newMRtestPoint_newVRFROMMRPoint 
+                + error_newVRFROMMRPoint_newVRFROMMRTransformPoint) > maxAllowedPointError)
+            {
+            std::cout << "(alpha,beta,gamma)= (" << alpha << ","<< beta << "," << gamma << ")" << std::endl;
+
+            std::cout << newMRtestPoint << " " << newVRtestPoint << " " << newVRFROMMRPoint << " " << newVRFROMMRTransformPoint << std::endl;
+            std::cout << "ERRORS: " << error_newMRtestPoint_newVRtestPoint << " " 
+                      << error_newMRtestPoint_newVRFROMMRPoint << " " 
+                      << error_newVRFROMMRPoint_newVRFROMMRTransformPoint << std::endl;
+            std::cout << "MR=\n"<< MR << "\nVR=\n" << VR.GetMatrix() << "\nVFROMMR=\n" << VFROMMR.GetMatrix() << std::endl;
+            errorCount++;
+            }
+          
+          }
+        }
+      }
+    }
+  return errorCount;
+}
+
 
 
 //-------------------------
@@ -44,56 +166,46 @@ int itkVersorTest(int, char* [] )
 
   const ValueType epsilon = 1e-12;
 
-
   //  Versor type
   typedef    itk::Versor< ValueType >    VersorType;
 
-
   //  Vector type
   typedef    VersorType::VectorType      VectorType;
 
-
   //  Point type
   typedef    VersorType::PointType      PointType;
 
-
   //  Covariant Vector type
   typedef    VersorType::CovariantVectorType      CovariantVectorType;
 
-
   //  VnlVector type
   typedef    VersorType::VnlVectorType       VnlVectorType;
 
-
   //  VnlQuaternion type
   typedef    VersorType::VnlQuaternionType   VnlQuaternionType;
 
-
   //  Matrix type
   typedef    VersorType::MatrixType          MatrixType;
 
-
-
-
   {
     std::cout << "Test default constructor... ";
     VersorType qa;
-    if( fabs(qa.GetX()) > epsilon ) 
+    if( vcl_abs(qa.GetX()) > epsilon ) 
       {
       std::cout << "Error ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(qa.GetY()) > epsilon ) 
+    if( vcl_abs(qa.GetY()) > epsilon ) 
       {
       std::cout << "Error ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(qa.GetZ()) > epsilon ) 
+    if( vcl_abs(qa.GetZ()) > epsilon ) 
       {
       std::cout << "Error ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(qa.GetW()-1.0) > epsilon ) 
+    if( vcl_abs(qa.GetW()-1.0) > epsilon ) 
       {
       std::cout << "Error ! " << std::endl;
       return EXIT_FAILURE;
@@ -112,7 +224,6 @@ int itkVersorTest(int, char* [] )
   }
 
 
-
   {
     std::cout << "Test for setting Axis and Angle...";
     VersorType qa;
@@ -120,40 +231,39 @@ int itkVersorTest(int, char* [] )
     xa[0] = 2.5;
     xa[1] = 1.5;
     xa[2] = 0.5;
-    ValueType angle = atan(1.0)/3.0; // 15 degrees in radians
-    
+    ValueType angle = vcl_atan(1.0)/3.0; // 15 degrees in radians
     qa.Set( xa, angle );
         
     xa.Normalize();
 
-    ValueType cosangle = cos( angle / 2.0 );
-    ValueType sinangle = sin( angle / 2.0 );
+    ValueType cosangle = vcl_cos( angle / 2.0 );
+    ValueType sinangle = vcl_sin( angle / 2.0 );
 
     VectorType xb;
 
     xb =  xa * sinangle;
 
-    if( fabs(qa.GetX()-xb[0]) > epsilon ) 
+    if( vcl_abs(qa.GetX()-xb[0]) > epsilon ) 
       {
       std::cout << "Error in X ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(qa.GetY()-xb[1]) > epsilon ) 
+    if( vcl_abs(qa.GetY()-xb[1]) > epsilon ) 
       {
       std::cout << "Error in Y ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(qa.GetZ()-xb[2]) > epsilon ) 
+    if( vcl_abs(qa.GetZ()-xb[2]) > epsilon ) 
       {
       std::cout << "Error in Z ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(qa.GetW()-cosangle) > epsilon ) 
+    if( vcl_abs(qa.GetW()-cosangle) > epsilon ) 
       {
       std::cout << "Error in W ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(qa.GetAngle()-angle) > epsilon ) 
+    if( vcl_abs(qa.GetAngle()-angle) > epsilon ) 
       {
       std::cout << "Error in Angle ! " << std::endl;
       return EXIT_FAILURE;
@@ -164,63 +274,57 @@ int itkVersorTest(int, char* [] )
 
   {
     std::cout << "Test for setting Right part...";
-    VersorType qa;
+    ValueType angle = vcl_atan(1.0)*30.0/45.0;
+    ValueType sin2a = vcl_sin( angle/2.0 );
+    
     VectorType xa;
-    
-    ValueType angle = atan(1.0)*30.0/45.0;
-    ValueType sin2a = sin( angle/2.0 );
-    
     xa[0] = 0.7;
     xa[1] = 0.3;
     xa[2] = 0.1;
     
     xa.Normalize();
-
     xa *= sin2a;
 
+    VersorType qa;
     qa.Set( xa, angle );
-        
-    ValueType cos2a = cos( angle/2.0 );
+    ValueType cos2a = vcl_cos( angle/2.0 );
 
-    if( fabs(qa.GetW()-cos2a) > epsilon ) 
+    if( vcl_abs(qa.GetW()-cos2a) > epsilon ) 
       {
       std::cout << "Error in W ! " << std::endl;
       std::cout << "W= " << qa.GetW();
       std::cout << " it should be " << cos2a << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(qa.GetAngle()-angle) > epsilon ) 
+    if( vcl_abs(qa.GetAngle()-angle) > epsilon ) 
       {
       std::cout << "Error in Angle ! " << std::endl;
       return EXIT_FAILURE;
       } 
-
     std::cout << " PASSED !" << std::endl;
   }
 
  {
     std::cout << "Test for Square Root...";
-    VersorType qa;
+    
+    ValueType angle = vcl_atan(1.0)*30.0/45.0;
+    ValueType sin2a = vcl_sin( angle/2.0 );
+    
     VectorType xa;
-    
-    ValueType angle = atan(1.0)*30.0/45.0;
-    ValueType sin2a = sin( angle/2.0 );
-    
     xa[0] = 0.7;
     xa[1] = 0.3;
     xa[2] = 0.1;
     
     xa.Normalize();
-
     xa *= sin2a;
 
+    VersorType qa;
     qa.Set( xa, angle );
         
     VersorType qb;
- 
     qb = qa.SquareRoot();
 
-    if( fabs( qa.GetAngle() - 2.0 * qb.GetAngle() ) > epsilon ) 
+    if( vcl_abs( qa.GetAngle() - 2.0 * qb.GetAngle() ) > epsilon ) 
       {
       std::cout << "Error in Square Root ! " << std::endl;
       std::cout << "Angle = " << qb.GetAngle();
@@ -232,35 +336,32 @@ int itkVersorTest(int, char* [] )
 
   {
     std::cout << "Test for Transforming a vector...";
-    VersorType qa;
     VectorType xa;
     xa[0] = 2.5;
     xa[1] = 2.5;
     xa[2] = 2.5;
-    ValueType angle = 8.0*atan(1.0)/3.0; // 120 degrees in radians
+    ValueType angle = 8.0*vcl_atan(1.0)/3.0; // 120 degrees in radians
     
+    VersorType qa;
     qa.Set( xa, angle );
         
     VectorType::ValueType xbInit[3] = {3.0, 7.0, 9.0};
     VectorType xb = xbInit;
 
-    VectorType xc;
-
-    xc = qa.Transform( xb );
+    VectorType xc= qa.Transform( xb );
 
     // This rotation will just permute the axis
-
-    if( fabs(xc[1]-xb[0]) > epsilon ) 
+    if( vcl_abs(xc[1]-xb[0]) > epsilon ) 
       {
       std::cout << "Error in X ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(xc[2]-xb[1]) > epsilon ) 
+    if( vcl_abs(xc[2]-xb[1]) > epsilon ) 
       {
       std::cout << "Error in Y ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(xc[0]-xb[2]) > epsilon ) 
+    if( vcl_abs(xc[0]-xb[2]) > epsilon ) 
       {
       std::cout << "Error in Z ! " << std::endl;
       return EXIT_FAILURE;
@@ -270,35 +371,32 @@ int itkVersorTest(int, char* [] )
 
   {
     std::cout << "Test for Transforming a point...";
-    VersorType qa;
     VectorType xa;
     xa[0] = 2.5;
     xa[1] = 2.5;
     xa[2] = 2.5;
-    ValueType angle = 8.0*atan(1.0)/3.0; // 120 degrees in radians
+    ValueType angle = 8.0*vcl_atan(1.0)/3.0; // 120 degrees in radians
     
+    VersorType qa;
     qa.Set( xa, angle );
         
     PointType::ValueType xbInit[3] = {3.0, 7.0, 9.0};
     PointType xb = xbInit;
 
-    PointType xc;
-
-    xc = qa.Transform( xb );
+    PointType xc = qa.Transform( xb );
 
     // This rotation will just permute the axis
-
-    if( fabs(xc[1]-xb[0]) > epsilon ) 
+    if( vcl_abs(xc[1]-xb[0]) > epsilon ) 
       {
       std::cout << "Error in X ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(xc[2]-xb[1]) > epsilon ) 
+    if( vcl_abs(xc[2]-xb[1]) > epsilon ) 
       {
       std::cout << "Error in Y ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(xc[0]-xb[2]) > epsilon ) 
+    if( vcl_abs(xc[0]-xb[2]) > epsilon ) 
       {
       std::cout << "Error in Z ! " << std::endl;
       return EXIT_FAILURE;
@@ -309,35 +407,32 @@ int itkVersorTest(int, char* [] )
 
   {
     std::cout << "Test for Transforming a covariantvector...";
-    VersorType qa;
     VectorType xa;
     xa[0] = 2.5;
     xa[1] = 2.5;
     xa[2] = 2.5;
-    ValueType angle = 8.0*atan(1.0)/3.0; // 120 degrees in radians
+    ValueType angle = 8.0*vcl_atan(1.0)/3.0; // 120 degrees in radians
     
+    VersorType qa;
     qa.Set( xa, angle );
         
     CovariantVectorType::ValueType xbInit[3] = {3.0, 7.0, 9.0};
     CovariantVectorType xb = xbInit;
 
-    CovariantVectorType xc;
-
-    xc = qa.Transform( xb );
+    CovariantVectorType xc = qa.Transform( xb );
 
     // This rotation will just permute the axis
-
-    if( fabs(xc[1]-xb[0]) > epsilon ) 
+    if( vcl_abs(xc[1]-xb[0]) > epsilon ) 
       {
       std::cout << "Error in X ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(xc[2]-xb[1]) > epsilon ) 
+    if( vcl_abs(xc[2]-xb[1]) > epsilon ) 
       {
       std::cout << "Error in Y ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(xc[0]-xb[2]) > epsilon ) 
+    if( vcl_abs(xc[0]-xb[2]) > epsilon ) 
       {
       std::cout << "Error in Z ! " << std::endl;
       return EXIT_FAILURE;
@@ -347,13 +442,13 @@ int itkVersorTest(int, char* [] )
 
   {
     std::cout << "Test for Transforming a vnl_vector...";
-    VersorType qa;
     VectorType xa;
     xa[0] = 2.5;
     xa[1] = 2.5;
     xa[2] = 2.5;
-    ValueType angle = 8.0*atan(1.0)/3.0; // 120 degrees in radians
+    ValueType angle = 8.0*vcl_atan(1.0)/3.0; // 120 degrees in radians
     
+    VersorType qa;
     qa.Set( xa, angle );
         
     VnlVectorType xb;
@@ -361,23 +456,20 @@ int itkVersorTest(int, char* [] )
     xb[1] = 7.0;
     xb[2] = 9.0;
 
-    VnlVectorType xc;
-
-    xc = qa.Transform( xb );
+    VnlVectorType xc = qa.Transform( xb );
 
     // This rotation will just permute the axis
-
-    if( fabs(xc[1]-xb[0]) > epsilon ) 
+    if( vcl_abs(xc[1]-xb[0]) > epsilon ) 
       {
       std::cout << "Error in X ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(xc[2]-xb[1]) > epsilon ) 
+    if( vcl_abs(xc[2]-xb[1]) > epsilon ) 
       {
       std::cout << "Error in Y ! " << std::endl;
       return EXIT_FAILURE;
       } 
-    if( fabs(xc[0]-xb[2]) > epsilon ) 
+    if( vcl_abs(xc[0]-xb[2]) > epsilon ) 
       {
       std::cout << "Error in Z ! " << std::endl;
       return EXIT_FAILURE;
@@ -385,20 +477,16 @@ int itkVersorTest(int, char* [] )
     std::cout << " PASSED !" << std::endl;
   }
   
-
-
   {
-
     std::cout << "Test for Set components operations ...";
 
     // First, create a known versor
-    VersorType v1;
-
     VectorType::ValueType x1Init[3] = {2.5f, 1.5f, 3.5f};
     VectorType x1 = x1Init;
 
-    ValueType angle1 = atan(1.0)/3.0; // 15 degrees in radians
+    ValueType angle1 = vcl_atan(1.0)/3.0; // 15 degrees in radians
     
+    VersorType v1;
     v1.Set( x1, angle1 );
  
     // Get the components and scale them
@@ -412,10 +500,10 @@ int itkVersorTest(int, char* [] )
     v2.Set( x, y, z, w );
 
     // Compare both versors
-    if( fabs(v1.GetX() - v2.GetX() ) > epsilon ||
-        fabs(v1.GetY() - v2.GetY() ) > epsilon ||
-        fabs(v1.GetZ() - v2.GetZ() ) > epsilon ||
-        fabs(v1.GetW() - v2.GetW() ) > epsilon )
+    if( vcl_abs(v1.GetX() - v2.GetX() ) > epsilon ||
+        vcl_abs(v1.GetY() - v2.GetY() ) > epsilon ||
+        vcl_abs(v1.GetZ() - v2.GetZ() ) > epsilon ||
+        vcl_abs(v1.GetW() - v2.GetW() ) > epsilon )
       {
       std::cout << "Error in Versor Set(x,y,z,w) ! " << std::endl;
       std::cout << "v1  = " << v1 << std::endl;
@@ -424,20 +512,18 @@ int itkVersorTest(int, char* [] )
       } 
     std::cout << " PASSED !" << std::endl;
 
-
     std::cout << "Test for Set quaternion ...";
     // Get a vnl_quaternion
     VnlQuaternionType vnlq = v1.GetVnlQuaternion();
-   
     vnlq *= scale;
 
     v2.Set( vnlq );
 
     // Compare both versors
-    if( fabs(v1.GetX() - v2.GetX() ) > epsilon ||
-        fabs(v1.GetY() - v2.GetY() ) > epsilon ||
-        fabs(v1.GetZ() - v2.GetZ() ) > epsilon ||
-        fabs(v1.GetW() - v2.GetW() ) > epsilon )
+    if( vcl_abs(v1.GetX() - v2.GetX() ) > epsilon ||
+        vcl_abs(v1.GetY() - v2.GetY() ) > epsilon ||
+        vcl_abs(v1.GetZ() - v2.GetZ() ) > epsilon ||
+        vcl_abs(v1.GetW() - v2.GetW() ) > epsilon )
       {
       std::cout << "Error in Versor Set( vnl_quaternion ) ! " << std::endl;
       std::cout << "v1  = " << v1 << std::endl;
@@ -446,7 +532,6 @@ int itkVersorTest(int, char* [] )
       } 
     std::cout << " PASSED !" << std::endl;
 
-
     std::cout << "Test for Set(x,y,z,w) with negative W.";
     // Check that a negative W results in negating 
     // all the versor components.
@@ -459,10 +544,10 @@ int itkVersorTest(int, char* [] )
     v3.Set( x, y, z, w );
 
      // Compare both versors 
-    if( fabs( v1.GetX() - v3.GetX() ) > epsilon ||
-        fabs( v1.GetY() - v3.GetY() ) > epsilon ||
-        fabs( v1.GetZ() - v3.GetZ() ) > epsilon ||
-        fabs( v1.GetW() - v3.GetW() ) > epsilon )
+    if( vcl_abs( v1.GetX() - v3.GetX() ) > epsilon ||
+        vcl_abs( v1.GetY() - v3.GetY() ) > epsilon ||
+        vcl_abs( v1.GetZ() - v3.GetZ() ) > epsilon ||
+        vcl_abs( v1.GetW() - v3.GetW() ) > epsilon )
       {
       std::cout << "Error in Versor Set() with negative W ! " << std::endl;
       std::cout << "v1  = " << v1 << std::endl;
@@ -470,42 +555,33 @@ int itkVersorTest(int, char* [] )
       return EXIT_FAILURE;
       } 
     std::cout << " PASSED !" << std::endl;
-
   }
 
-
-
   {
-
     std::cout << "Test for Reciprocal and Conjugate Operations...";
 
-    VersorType  v1;
-    VersorType  v2;
-
     VectorType::ValueType x1Init[3] = {2.5f, 1.5f, 0.5f};
     VectorType x1 = x1Init;
 
-    ValueType angle1 = atan(1.0)/3.0; // 15 degrees in radians
+    ValueType angle1 = vcl_atan(1.0)/3.0; // 15 degrees in radians
     
     VectorType::ValueType x2Init[3] = {1.5f, 0.5f, 0.5f};
     VectorType x2 = x2Init;
 
-    ValueType angle2 = atan(1.0)/1.0; // 45 degrees in radians
+    ValueType angle2 = vcl_atan(1.0)/1.0; // 45 degrees in radians
     
+    VersorType  v1;
     v1.Set( x1, angle1 );
+    VersorType  v2;
     v2.Set( x2, angle2 );
         
+    VersorType v2r = v2.GetReciprocal();
+    VersorType unit = v2 * v2r;
 
-    VersorType unit;
-    VersorType v2r;
-
-    v2r  = v2.GetReciprocal();
-    unit = v2 * v2r;
-
-    if( fabs( unit.GetX() ) > epsilon ||
-        fabs( unit.GetY() ) > epsilon ||
-        fabs( unit.GetZ() ) > epsilon ||
-        fabs( unit.GetW() - 1.0 ) > epsilon )
+    if( vcl_abs( unit.GetX() ) > epsilon ||
+        vcl_abs( unit.GetY() ) > epsilon ||
+        vcl_abs( unit.GetZ() ) > epsilon ||
+        vcl_abs( unit.GetW() - 1.0 ) > epsilon )
       {
       std::cout << "Error in Reciprocal ! " << std::endl;
       std::cout << "Versor     = " << v2    << std::endl;
@@ -515,13 +591,12 @@ int itkVersorTest(int, char* [] )
       return EXIT_FAILURE;
       }  
 
-
     unit = v2 / v2;
 
-    if( fabs( unit.GetX() ) > epsilon ||
-        fabs( unit.GetY() ) > epsilon ||
-        fabs( unit.GetZ() ) > epsilon ||
-        fabs( unit.GetW() - 1.0 ) > epsilon )
+    if( vcl_abs( unit.GetX() ) > epsilon ||
+        vcl_abs( unit.GetY() ) > epsilon ||
+        vcl_abs( unit.GetZ() ) > epsilon ||
+        vcl_abs( unit.GetW() - 1.0 ) > epsilon )
       {
       std::cout << "Error in Division ! " << std::endl;
       std::cout << "Versor          = " << v2    << std::endl;
@@ -532,11 +607,10 @@ int itkVersorTest(int, char* [] )
 
     unit =  v2;
     unit /= v2;
-
-    if( fabs( unit.GetX() ) > epsilon ||
-        fabs( unit.GetY() ) > epsilon ||
-        fabs( unit.GetZ() ) > epsilon ||
-        fabs( unit.GetW() - 1.0 ) > epsilon )
+    if( vcl_abs( unit.GetX() ) > epsilon ||
+        vcl_abs( unit.GetY() ) > epsilon ||
+        vcl_abs( unit.GetZ() ) > epsilon ||
+        vcl_abs( unit.GetW() - 1.0 ) > epsilon )
       {
       std::cout << "Error in Division operator/= ! " << std::endl;
       std::cout << "Versor          = " << v2    << std::endl;
@@ -545,27 +619,17 @@ int itkVersorTest(int, char* [] )
       return EXIT_FAILURE;
       }  
 
-
-
-
-
     x1.Normalize();
     x2.Normalize();
 
    
-    VersorType  v3;
+    VersorType v3= v1 * v2;
+    VersorType v4= v3 * v2r;
 
-    v3 = v1 * v2;
-
-    VersorType v4;
-
-    v4 = v3 * v2r;
-
-
-    if( fabs(v1.GetX() - v4.GetX() ) > epsilon ||
-        fabs(v1.GetY() - v4.GetY() ) > epsilon ||
-        fabs(v1.GetZ() - v4.GetZ() ) > epsilon ||
-        fabs(v1.GetW() - v4.GetW() ) > epsilon )
+    if( vcl_abs(v1.GetX() - v4.GetX() ) > epsilon ||
+        vcl_abs(v1.GetY() - v4.GetY() ) > epsilon ||
+        vcl_abs(v1.GetZ() - v4.GetZ() ) > epsilon ||
+        vcl_abs(v1.GetW() - v4.GetW() ) > epsilon )
       {
       std::cout << "Error in Versor division ! " << std::endl;
       std::cout << "v1  = " << v1 << std::endl;
@@ -573,18 +637,12 @@ int itkVersorTest(int, char* [] )
       return EXIT_FAILURE;
       } 
     std::cout << " PASSED !" << std::endl;
-
-
   }
 
 
   { // Test for the Set() matrix method
-    
     std::cout << "Test for Set( MatrixType ) method ...";
-
-    VersorType vv;
     MatrixType mm;
-
     // Setting the matrix of a 90 degrees rotation around Z
     mm[0][0] =  0.0;
     mm[0][1] =  1.0;
@@ -598,26 +656,36 @@ int itkVersorTest(int, char* [] )
     mm[2][1] =  0.0;
     mm[2][2] =  1.0;
 
+    VersorType vv;
     vv.Set( mm );
 
     const double halfSqrtOfTwo = vcl_sqrt( 2.0 ) / 2.0;
 
-    if( fabs(vv.GetX() -             0.0  ) > epsilon ||
-        fabs(vv.GetY() -             0.0  ) > epsilon ||
-        fabs(vv.GetZ() - (-halfSqrtOfTwo) ) > epsilon ||
-        fabs(vv.GetW() -   halfSqrtOfTwo  ) > epsilon )
+    if( vcl_abs(vv.GetX() -             0.0  ) > epsilon ||
+        vcl_abs(vv.GetY() -             0.0  ) > epsilon ||
+        vcl_abs(vv.GetZ() - (-halfSqrtOfTwo) ) > epsilon ||
+        vcl_abs(vv.GetW() -   halfSqrtOfTwo  ) > epsilon )
       {
       std::cout << "Error in Versor Set(Matrix) method ! " << std::endl;
       std::cout << "vv  = " << vv << std::endl;
       return EXIT_FAILURE;
       } 
     std::cout << " PASSED !" << std::endl;
+  }
+  {
+  std::cout << "Test for Set( MatrixType ) method with rotations that are susceptible to errors in conversion to/from the rotation matrix...";
 
-
+  const int RotationMatrixStabilityTestErrors=RotationMatrixToVersorTest();
+  if( RotationMatrixStabilityTestErrors > 0 )
+    {
+    std::cout << "Error in stability of converting to/from RotationMatrix with Set(Matrix) method ! " << std::endl;
+    std::cout << "Errors Found  = " << RotationMatrixStabilityTestErrors << std::endl;
+    return EXIT_FAILURE;
+    }
+  std::cout << " PASSED !" << std::endl;
 
   }
 
-
   return EXIT_SUCCESS;
 
 }
