@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVersorTransformTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-08-09 04:35:32 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-04-05 10:56:56 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -89,7 +89,7 @@ int itkVersorTransformTest(int, char* [] )
 
     VectorType axis(1.5);
 
-    ValueType angle = 120.0*atan(1.0)/45.0;
+    ValueType angle = 120.0*vcl_atan(1.0)/45.0;
 
     VersorType versor;
     versor.Set( axis, angle );
@@ -131,7 +131,7 @@ int itkVersorTransformTest(int, char* [] )
 
     itk::Vector<double,3> axis(1);
 
-    const double angle = (atan(1.0)/45.0)*120.0; // turn 120 degrees
+    const double angle = (vcl_atan(1.0)/45.0)*120.0; // turn 120 degrees
 
     // this rotation will permute the axis x->y, y->z, z->x
     rotation->SetRotation( axis, angle );
@@ -142,7 +142,7 @@ int itkVersorTransformTest(int, char* [] )
 
     for(unsigned int i=0; i<3; i++)
     {
-      if( fabs( offset[i] - 0.0 ) > epsilon )
+      if( vcl_fabs( offset[i] - 0.0 ) > epsilon )
       {
         Ok = false;
         break;    
@@ -169,7 +169,7 @@ int itkVersorTransformTest(int, char* [] )
       r = rotation->TransformPoint( p );
       for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( q[i]- r[i] ) > epsilon )
+        if( vcl_fabs( q[i]- r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -199,7 +199,7 @@ int itkVersorTransformTest(int, char* [] )
       r = rotation->TransformVector( p );
       for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -230,7 +230,7 @@ int itkVersorTransformTest(int, char* [] )
       r = rotation->TransformCovariantVector( p );
       for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -264,7 +264,7 @@ int itkVersorTransformTest(int, char* [] )
       r = rotation->TransformVector( p );
       for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( q[i] - r[i] ) > epsilon )
+        if( vcl_fabs( q[i] - r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -296,7 +296,7 @@ int itkVersorTransformTest(int, char* [] )
 
     itk::Vector<double,3> axis(1);
 
-    const double angle = (atan(1.0)/45.0)*30.0; // turn 30 degrees
+    const double angle = (vcl_atan(1.0)/45.0)*30.0; // turn 30 degrees
 
     transform->SetRotation( axis, angle );
 
@@ -312,7 +312,7 @@ int itkVersorTransformTest(int, char* [] )
 
     for(unsigned int i=0; i<3; i++)
       {
-        if( fabs( center[i] - transformedPoint[i] ) > epsilon )
+        if( vcl_fabs( center[i] - transformedPoint[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -335,7 +335,7 @@ int itkVersorTransformTest(int, char* [] )
 
     VersorType versor;
 
-    parameters[0] = versor.GetX();   // Rotation axis * sin(t/2)
+    parameters[0] = versor.GetX();   // Rotation axis * vcl_sin(t/2)
     parameters[1] = versor.GetY();
     parameters[2] = versor.GetZ();
 
@@ -347,7 +347,7 @@ int itkVersorTransformTest(int, char* [] )
 
     for(unsigned int p=0; p<np; p++)
       {
-      if( fabs( parameters[p] - parameters2[p] ) > tolerance )
+      if( vcl_fabs( parameters[p] - parameters2[p] ) > tolerance )
         {
         std::cerr << "Output parameter does not match input " << std::endl;
         return EXIT_FAILURE;
@@ -447,10 +447,10 @@ int itkVersorTransformTest(int, char* [] )
       matrix.GetVnlMatrix().set_identity();
 
       double a = 1.0 / 180.0 * vnl_math::pi;
-      matrix[0][0] =        cos( a );
-      matrix[0][1] = -1.0 * sin( a );
-      matrix[1][0] =        sin( a ); 
-      matrix[1][1] =        cos( a );
+      matrix[0][0] =        vcl_cos( a );
+      matrix[0][1] = -1.0 * vcl_sin( a );
+      matrix[1][0] =        vcl_sin( a ); 
+      matrix[1][1] =        vcl_cos( a );
 
      Ok = true;
      try
@@ -500,7 +500,7 @@ int itkVersorTransformTest(int, char* [] )
 
     for( unsigned int k = 0; k < e.GetSize(); k++ )
       {
-      if( fabs( e[k] - p[k] ) > epsilon )
+      if( vcl_fabs( e[k] - p[k] ) > epsilon )
         {
         std::cout << " [ FAILED ] " << std::endl;
         std::cout << "Expected parameters: " << e << std::endl;
