@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ImageCopy.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-10-06 14:45:24 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2008-11-09 18:18:52 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -68,6 +68,11 @@ int main(int argc, char *argv[])
     writer->SetFileName( baseName.str().c_str() );
     writer->Update();
     }
+  catch(const std::exception& e)
+    {
+    std::cerr << "Error during write of " << baseName.str() << std::endl;
+    std::cerr << e.what() << "\n";
+    }
   catch (...)
     {
     std::cerr << "Error during write of " << baseName.str() << std::endl;
