@@ -3,8 +3,8 @@
 Program:   Insight Segmentation & Registration Toolkit
 Module:    $RCSfile: itkAnalyzeImageIOTest.cxx,v $
 Language:  C++
-Date:      $Date: 2009-04-30 21:34:46 $
-Version:   $Revision: 1.43 $
+Date:      $Date: 2009-10-30 14:58:27 $
+Version:   $Revision: 1.44 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -387,27 +387,31 @@ int itkAnalyzeImageIOTest(int ac, char* av[])
       AugmentName="Nifti";
       }
 
+    // copy ac and av in another var so we can reuse it in the second step of the loop
+    int ac2 = ac;
+    char** av2 = av;
+
     //
     // first argument is passing in the writable directory to do all testing
-    if(ac > 1)
+    if(ac2 > 1)
       {
-      char *testdir = *++av;
-      --ac;
+      char *testdir = *++av2;
+      --ac2;
       itksys::SystemTools::ChangeDirectory(testdir);
       }
 
-    if(ac > 1) //This is a mechanism for reading unsigned char images for testing.
+    if(ac2 > 1) //This is a mechanism for reading unsigned char images for testing.
       {
       typedef itk::Image<unsigned char, 3> ImageType;
       ImageType::Pointer input;
       itk::ImageFileReader<ImageType>::Pointer imageReader =
         itk::ImageFileReader<ImageType>::New();
-      for(int imagenameindex=1; imagenameindex < ac; imagenameindex++)
+      for(int imagenameindex=1; imagenameindex < ac2; imagenameindex++)
         {
-        //std::cout << "Attempting to read " << av[imagenameindex] << std::endl;
+        //std::cout << "Attempting to read " << av2[imagenameindex] << std::endl;
         try
           {
-          imageReader->SetFileName(av[imagenameindex]);
+          imageReader->SetFileName(av2[imagenameindex]);
           imageReader->Update();
           input=imageReader->GetOutput();
           }
