@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBioRadImageIOTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-11-21 15:28:03 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2008-09-16 17:29:23 $
+  Version:   $Revision: 1.4 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -49,8 +49,7 @@ int itkBioRadImageIOTest(int argc, char* argv[])
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file reader " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
 
@@ -67,8 +66,7 @@ int itkBioRadImageIOTest(int argc, char* argv[])
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file writer " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
 
