@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGDCMImageIOTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-18 13:18:45 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2008-09-16 17:29:23 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -61,8 +61,7 @@ int main(int ac, char* av[])
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file reader " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
 
@@ -86,8 +85,7 @@ int main(int ac, char* av[])
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file writer " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
 
@@ -121,8 +119,7 @@ int main(int ac, char* av[])
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file writer " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
  
@@ -145,8 +142,7 @@ int main(int ac, char* av[])
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file writer " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
 
