@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGDCMImageIOTest2.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-20 12:21:34 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2008-09-16 17:29:23 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -47,8 +47,7 @@ int main(int argc, char *argv[] )
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file writer " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
 
@@ -128,8 +127,7 @@ int main(int argc, char *argv[] )
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file writer " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
 
@@ -143,8 +141,7 @@ int main(int argc, char *argv[] )
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file writer " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
 
@@ -158,8 +155,7 @@ int main(int argc, char *argv[] )
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file writer " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
 
