@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGiplImageIOTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:10 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2008-09-16 17:29:23 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -50,8 +50,7 @@ int itkGiplImageIOTest( int ac, char* av[] )
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file reader " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
   
