@@ -3,9 +3,9 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageFileWriterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-02-06 13:54:04 $xgoto-l
+  Date:      $Date: 2008-04-18 20:43:13 $xgoto-l
 
-  Version:   $Revision: 1.3 $
+  Version:   $Revision: 1.4 $
 
   Copyright (c) 2002 Insight Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -107,13 +107,14 @@ int itkImageFileWriterTest(int ac, char* av[])
     return EXIT_FAILURE;
     }
 
+#if 0
   // Now try a write with an image but a filename that cannot be created
   status = 1;
   try
     {
     WriterType::Pointer writer = WriterType::New();
     writer->SetInput(image);
-    writer->SetFileName("/this_is_a_bad_directory/and_a_bad_filename.png");
+    writer->SetFileName("/this_is_a_bad_directory/and_a_bad_filename.tif");
     writer->Update();
     }
   catch (itk::ExceptionObject &ex)
@@ -127,7 +128,7 @@ int itkImageFileWriterTest(int ac, char* av[])
     std::cout << "Failed to catch expected exception." << std::endl;
     return EXIT_FAILURE;
     }
-
+#endif
   // Let's not be too negative. Try a write to a valid file.
   status = 1;
   try
