@@ -3,9 +3,9 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLargeImageWriteReadTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-07-10 22:04:02 $xgoto-l
+  Date:      $Date: 2010-01-28 15:48:48 $xgoto-l
 
-  Version:   $Revision: 1.6 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) 2002 Insight Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -25,57 +25,59 @@
 #include "itkImageRegionIterator.h"
 #include "itkTimeProbesCollectorBase.h"
 
-int itkLargeImageWriteReadTest(int ac, char* av[])
+
+namespace {
+
+template <typename TImageType>
+int ActualTest( std::string filename, typename TImageType::SizeType size ) 
 {
+  typedef TImageType ImageType;
+  typedef typename ImageType::PixelType PixelType;
 
-  if (ac < 3)
-    {
-    std::cout << "usage: itkIOTests itkLargeImageWriteReadTest outputFileName numberOfPixelsInOneDimension" << std::endl;
-    return EXIT_FAILURE;
-    }
-
-  typedef unsigned short  PixelType;
-  typedef itk::Image<PixelType,2> ImageType;
 
   typedef itk::ImageFileWriter< ImageType >   WriterType;
   typedef itk::ImageFileReader< ImageType >   ReaderType;
 
-  ImageType::Pointer image = ImageType::New();
-  ImageType::RegionType region;
-  ImageType::IndexType index;
-  ImageType::SizeType size;
+  typedef itk::ImageRegionIterator< ImageType >  IteratorType;
+  typedef itk::ImageRegionConstIterator< ImageType >  ConstIteratorType;
+
+  typename ImageType::RegionType region;
+  typename ImageType::IndexType index;
+
+  PixelType pixelValue;
 
   itk::TimeProbesCollectorBase chronometer;
 
-  const unsigned long numberOfPixelsInOneDimension = atol( av[2] );
- 
-  size.Fill( numberOfPixelsInOneDimension );
+  { // begin write block
+  typename ImageType::Pointer image = ImageType::New();
   index.Fill(0);
   region.SetSize(size);
   region.SetIndex(index);
   
   image->SetRegions(region);
+  
+  size_t numberOfPixels = 1;
+  for (unsigned int i = 0; i < ImageType::ImageDimension; ++i )
+    {
+    numberOfPixels *= region.GetSize( i );
+    }
+         
+  const unsigned long sizeInMegaBytes = static_cast< unsigned long >(
+    ( sizeof(PixelType) * numberOfPixels ) / ( 1024.0 * 1024.0 ) );
 
-  const unsigned long sizeInMegaBytes =
-    static_cast< unsigned long >(
-      ( sizeof(PixelType) * numberOfPixelsInOneDimension * numberOfPixelsInOneDimension ) /
-      ( 1024.0 * 1024.0 ) );
-
-
+  
   std::cout << "Trying to allocate an image of size " << sizeInMegaBytes << " Mb " << std::endl; 
-
+  
   chronometer.Start("Allocate");
   image->Allocate();
   chronometer.Stop("Allocate");
-
+  
   std::cout << "Initializing pixel values " << std::endl;
-  typedef itk::ImageRegionIterator< ImageType >  IteratorType;
-  typedef itk::ImageRegionConstIterator< ImageType >  ConstIteratorType;
-
+  
   IteratorType itr( image, region );
   itr.GoToBegin();
-
-  PixelType pixelValue = itk::NumericTraits< PixelType >::Zero;
+  
+  pixelValue = itk::NumericTraits< PixelType >::Zero;
 
   chronometer.Start("Initializing");
   while( !itr.IsAtEnd() )
@@ -89,9 +91,9 @@ int itkLargeImageWriteReadTest(int ac, char* av[])
   std::cout << "Trying to write the image to disk" << std::endl;
   try
     {
-    WriterType::Pointer writer = WriterType::New();
+    typename WriterType::Pointer writer = WriterType::New();
     writer->SetInput(image);
-    writer->SetFileName(av[1]);
+    writer->SetFileName( filename );
     chronometer.Start("Write");
     writer->Update();
     chronometer.Stop("Write");
@@ -101,10 +103,11 @@ int itkLargeImageWriteReadTest(int ac, char* av[])
     std::cout << ex << std::endl;
     return EXIT_FAILURE;
     }
+  } // end write block to free the memory
 
   std::cout << "Trying to read the image back from disk" << std::endl;
-  ReaderType::Pointer reader = ReaderType::New();
-  reader->SetFileName(av[1]);
+  typename ReaderType::Pointer reader = ReaderType::New();
+  reader->SetFileName( filename );
 
   try
     {
@@ -118,13 +121,13 @@ int itkLargeImageWriteReadTest(int ac, char* av[])
     return EXIT_FAILURE;
     }
 
-  ImageType::ConstPointer readImage = reader->GetOutput();
+  typename ImageType::ConstPointer readImage = reader->GetOutput();
 
   ConstIteratorType ritr( readImage, region );
-  IteratorType oitr( image, region );
+  // IteratorType oitr( image, region );
 
   ritr.GoToBegin();
-  oitr.GoToBegin();
+  // oitr.GoToBegin();
 
   std::cout << "Comparing the pixel values.. :" << std::endl;
 
@@ -133,17 +136,18 @@ int itkLargeImageWriteReadTest(int ac, char* av[])
   chronometer.Start("Compare");
   while( !ritr.IsAtEnd() )
     {
-    if( ( oitr.Get() != ritr.Get() ) || ( oitr.Get() != pixelValue ) )
+    // if( ( oitr.Get() != ritr.Get() ) || ( oitr.Get() != pixelValue ) )
+    if( ritr.Get() != pixelValue )
       {
-      std::cerr << "Pixel comparison failed at index = " << oitr.GetIndex() << std::endl;
+      std::cerr << "Pixel comparison failed at index = " << ritr.GetIndex() << std::endl;
       std::cerr << "Expected pixel value " << pixelValue << std::endl;
-      std::cerr << "Original Image pixel value " << oitr.Get() << std::endl;
+      // std::cerr << "Original Image pixel value " << oitr.Get() << std::endl;
       std::cerr << "Read Image pixel value " << ritr.Get() << std::endl;
       return EXIT_FAILURE;
       }
 
     ++pixelValue;
-    ++oitr;
+    // ++oitr;
     ++ritr;
     }
   chronometer.Stop("Compare");
@@ -154,5 +158,48 @@ int itkLargeImageWriteReadTest(int ac, char* av[])
   std::cout << "Test PASSED !" << std::endl;
 
   return EXIT_SUCCESS;
+}
+
+}
+
+int itkLargeImageWriteReadTest(int ac, char* argv[])
+{
+
+  if (ac < 3)
+    {
+    std::cout << "usage: itkIOTests itkLargeImageWriteReadTest outputFileName numberOfPixelsInOneDimension [numberOfZslices]" << std::endl;
+    return EXIT_FAILURE;
+    }
+  
+  const std::string filename = argv[1];
+        
+  if ( ac == 3 )
+    {
+    const unsigned int Dimension = 2;
+    
+    typedef unsigned short PixelType;
+    typedef itk::Image< PixelType, Dimension> ImageType;
+
+    ImageType::SizeType size;
+    
+    size.Fill( atol( argv[2] ) );
+    
+    return ActualTest< ImageType >( filename, size );
+    
+    }
+  else
+    {    
+    const unsigned int Dimension = 3;
+
+    typedef unsigned short PixelType;
+    typedef itk::Image< PixelType, Dimension> ImageType;
+
+    ImageType::SizeType size;
+    
+    size.Fill( atol( argv[2] ) );
+    size[2] = atol( argv[3] );
+    
+    return ActualTest< ImageType >( filename, size );
+    }
 
 }
