@@ -3,8 +3,8 @@
 Program:   Insight Segmentation & Registration Toolkit
 Module:    $RCSfile: itkNiftiImageIOTest.cxx,v $
 Language:  C++
-Date:      $Date: 2009-05-15 12:14:13 $
-Version:   $Revision: 1.37 $
+Date:      $Date: 2010-03-20 20:27:18 $
+Version:   $Revision: 1.40 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,17 +21,17 @@ PURPOSE.  See the above copyright notices for more information.
 #include "itkNiftiImageIOTest.h"
 
 
-static void RemoveByteSwapTestFiles(void)
+static void RemoveByteSwapTestFiles(std::string prefix)
 {
-  Remove("NiftiLittleEndian.hdr");
-  Remove("NiftiLittleEndian.img");
-  Remove("NiftiBigEndian.hdr");
-  Remove("NiftiBigEndian.img");
+  Remove((prefix+"NiftiLittleEndian.hdr").c_str());
+  Remove((prefix+"NiftiLittleEndian.img").c_str());
+  Remove((prefix+"NiftiBigEndian.hdr").c_str());
+  Remove((prefix+"NiftiBigEndian.img").c_str());
 }
 
 //The WriteTestFiles function writes binary data to disk to ensure that both big and little endian files are available.
 //This allows all the data necessary to create the images to be stored in source files rather than have separate reference images.
-static int WriteTestFiles(void)
+static int WriteTestFiles(std::string prefix)
 {
 #include "LittleEndian_hdr.h"
     struct nifti_1_header NiftiLittleEndian;
@@ -48,23 +48,23 @@ static int WriteTestFiles(void)
     strncpy(NiftiBigEndian.magic,"ni1\0",4);
 #include "BigEndian_img.h"
     //Force to be Nifti-compliant
-  std::ofstream little_hdr("NiftiLittleEndian.hdr", std::ios::binary | std::ios::out);
+  std::ofstream little_hdr((prefix+"NiftiLittleEndian.hdr").c_str(), std::ios::binary | std::ios::out);
   if(!little_hdr.is_open())
     return EXIT_FAILURE;
   std::cout << "NiftiLittleEndian written" << std::endl;
   little_hdr.write(reinterpret_cast<const char *>(LittleEndian_hdr),sizeof(LittleEndian_hdr));
   little_hdr.close();
-  std::ofstream little_img("NiftiLittleEndian.img", std::ios::binary | std::ios::out);
+  std::ofstream little_img((prefix+"NiftiLittleEndian.img").c_str(), std::ios::binary | std::ios::out);
   if(!little_img.is_open())
     return EXIT_FAILURE;
   little_img.write(reinterpret_cast<const char *>(LittleEndian_img),sizeof(LittleEndian_img));
   little_img.close();
-  std::ofstream big_hdr("NiftiBigEndian.hdr", std::ios::binary | std::ios::out);
+  std::ofstream big_hdr((prefix+"NiftiBigEndian.hdr").c_str(), std::ios::binary | std::ios::out);
   if(!big_hdr.is_open())
     return EXIT_FAILURE;
   big_hdr.write(reinterpret_cast<const char *>(BigEndian_hdr),sizeof(BigEndian_hdr));
   big_hdr.close();
-  std::ofstream big_img("NiftiBigEndian.img", std::ios::binary | std::ios::out);
+  std::ofstream big_img((prefix+"NiftiBigEndian.img").c_str(), std::ios::binary | std::ios::out);
   if(!big_img.is_open())
     return EXIT_FAILURE;
   big_img.write(reinterpret_cast<const char *>(BigEndian_img),sizeof(BigEndian_img));
@@ -72,11 +72,11 @@ static int WriteTestFiles(void)
   return EXIT_SUCCESS;
 }
 
-static int TestByteSwap(void)
+static int TestByteSwap(std::string prefix)
 {
   int rval;
   typedef itk::Image<double, 3> ImageType ;
-  if(WriteTestFiles() == -1)
+  if(WriteTestFiles(prefix) == -1)
     {
       return EXIT_FAILURE;
     }
@@ -86,8 +86,8 @@ static int TestByteSwap(void)
 
   try
     {
-    little = ReadImage<ImageType>(std::string("NiftiLittleEndian.hdr"), false);
-    const std::string fname("NiftiBigEndian.hdr");
+    little = ReadImage<ImageType>(prefix+"NiftiLittleEndian.hdr", false);
+    const std::string fname(prefix+"NiftiBigEndian.hdr");
     big = ReadImage<ImageType>(fname, false);
     std::cout << "Printing Dictionary" << std::endl;
     big->GetMetaDataDictionary().Print(std::cout);
@@ -95,7 +95,7 @@ static int TestByteSwap(void)
   catch (itk::ExceptionObject &e)
     {
     e.Print(std::cerr) ;
-    RemoveByteSwapTestFiles();
+    RemoveByteSwapTestFiles(prefix);
     return EXIT_FAILURE;
     }
   rval = 0;
@@ -121,7 +121,7 @@ static int TestByteSwap(void)
       rval= -1;
     }
 
-  RemoveByteSwapTestFiles();
+  RemoveByteSwapTestFiles(prefix);
   return rval;
 }
 
@@ -138,6 +138,11 @@ int itkNiftiImageIOTest(int ac, char* av[])
     --ac;
     itksys::SystemTools::ChangeDirectory(testdir);
   }
+  std::string prefix = "";
+  if(ac > 1) {
+    prefix = *++av;
+    --ac;
+  }
   static bool firstTime = true;
   if(firstTime) 
     {
@@ -189,6 +194,7 @@ int itkNiftiImageIOTest(int ac, char* av[])
           std::cerr << "Error writing Nifti file type unsigned short" << std::endl;
           rval += cur_return;
         }
+#ifndef __BORLANDC__
       cur_return = MakeNiftiImage<int>();
       if(cur_return != 0)
         {
@@ -201,7 +207,6 @@ int itkNiftiImageIOTest(int ac, char* av[])
           std::cerr << "Error writing Nifti file type float" << std::endl;
           rval += cur_return;
         }
-#ifndef __BORLANDC__
       // awaiting a double precision byte swapper
       cur_return = MakeNiftiImage<double>();
       if(cur_return != 0)
@@ -209,7 +214,7 @@ int itkNiftiImageIOTest(int ac, char* av[])
           std::cerr << "Error writing Nifti file type double" << std::endl;
           rval += cur_return;
         }
-      rval += TestByteSwap();
+      rval += TestByteSwap(prefix);
 #endif
     }
   //Tests added to increase code coverage.
@@ -229,15 +234,16 @@ int itkNiftiImageIOTest2(int ac, char* av[])
     --ac;
     itksys::SystemTools::ChangeDirectory(testdir);
   }
-  if(ac != 3)
+  if(ac != 4)
     return EXIT_FAILURE;
   char *arg1 = av[1];
   char *arg2 = av[2];
+  char *prefix = av[3];
   int test_success = 0;
   typedef itk::Image<signed short, 3> ImageType ;
   typedef ImageType::Pointer ImagePointer ;
 
-  if((strcmp(arg1, "true") == 0) && WriteTestFiles() == -1)
+  if((strcmp(arg1, "true") == 0) && WriteTestFiles(prefix) == -1)
     {
       return EXIT_FAILURE;
     }
@@ -272,6 +278,8 @@ int itkNiftiImageIOTest2(int ac, char* av[])
 
 }
 
+#ifndef __BORLANDC__
+#if defined(_MSC_VER) && _MSC_VER > 1300
 template <class ScalarType, unsigned VecLength, unsigned Dimension>
 int
 TestImageOfVectors(const std::string &fname)
@@ -510,6 +518,8 @@ TestImageOfVectors(const std::string &fname)
     }
   return same ? 0 : EXIT_FAILURE;
 }
+#endif
+#endif
 /** Test writing and reading a Vector Image
  */
 int itkNiftiImageIOTest3(int ac, char* av[])
@@ -526,13 +536,15 @@ int itkNiftiImageIOTest3(int ac, char* av[])
     return EXIT_FAILURE;
     }
   int success(0);
-  success |= TestImageOfVectors<float,3,1>(std::string("testVectorImage_float_3_1.nii.gz"));
 #ifndef __BORLANDC__
+#if defined(_MSC_VER) && _MSC_VER > 1300
+  success |= TestImageOfVectors<float,3,1>(std::string("testVectorImage_float_3_1.nii.gz"));
   success |= TestImageOfVectors<float,3,2>(std::string("testVectorImage_float_3_2.nii.gz"));
   success |= TestImageOfVectors<float,3,3>(std::string("testVectorImage_float_3_3.nii.gz"));
   success |= TestImageOfVectors<float,4,3>(std::string("testVectorImage_float_4_3.nii.gz"));
   success |= TestImageOfVectors<float,4,4>(std::string("testVectorImage_float_4_4.nii.gz"));
   success |= TestImageOfVectors<double,3,3>(std::string("testVectorImage_double_3_3.nii.gz"));
+#endif
 #endif
   return success;
 }
