@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNrrdComplexImageReadTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-08-20 16:16:13 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2009-04-05 23:09:36 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -44,8 +44,7 @@ int itkNrrdComplexImageReadTest( int ac, char* av[] )
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file reader " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
 
@@ -63,44 +62,44 @@ int itkNrrdComplexImageReadTest( int ac, char* av[] )
   coord[0] = 0;
   coord[1] = 0;
   sample = image->GetPixel(coord);
-  err += fabs(sample.real() - 27.985973);
-  err += fabs(sample.imag() - 0.0);
+  err += vcl_fabs(sample.real() - 27.985973);
+  err += vcl_fabs(sample.imag() - 0.0);
 
   coord[0] = 53;
   coord[1] = 43;
   sample = image->GetPixel(coord);
-  err += fabs(sample.real() - -0.94961888);
-  err += fabs(sample.imag() - 0.409872);
+  err += vcl_fabs(sample.real() - -0.94961888);
+  err += vcl_fabs(sample.imag() - 0.409872);
 
   coord[0] = 10;
   coord[1] = 43;
   sample = image->GetPixel(coord);
-  err += fabs(sample.real() - -0.096564025);
-  err += fabs(sample.imag() - 0.0094992276);
+  err += vcl_fabs(sample.real() - -0.096564025);
+  err += vcl_fabs(sample.imag() - 0.0094992276);
 
   coord[0] = 10;
   coord[1] = 0;
   sample = image->GetPixel(coord);
-  err += fabs(sample.real() - 0.036231704);
-  err += fabs(sample.imag() - -0.016659589);
+  err += vcl_fabs(sample.real() - 0.036231704);
+  err += vcl_fabs(sample.imag() - -0.016659589);
 
   coord[0] = 42;
   coord[1] = 42;
   sample = image->GetPixel(coord);
-  err += fabs(sample.real() - -0.027012844);
-  err += fabs(sample.imag() - -0.012217643);
+  err += vcl_fabs(sample.real() - -0.027012844);
+  err += vcl_fabs(sample.imag() - -0.012217643);
 
   coord[0] = 50;
   coord[1] = 40;
   sample = image->GetPixel(coord);
-  err += fabs(sample.real() - 0.44949868);
-  err += fabs(sample.imag() - -0.033380687);
+  err += vcl_fabs(sample.real() - 0.44949868);
+  err += vcl_fabs(sample.imag() - -0.033380687);
 
   coord[0] = 8;
   coord[1] = 9;
   sample = image->GetPixel(coord);
-  err += fabs(sample.real() - -0.036674671);
-  err += fabs(sample.imag() - -0.0061681992);
+  err += vcl_fabs(sample.real() - -0.036674671);
+  err += vcl_fabs(sample.imag() - -0.0061681992);
 
   double thresh = 0.00000038;
   if (err > thresh)
