@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNrrdCovariantVectorImageReadTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-08-20 22:47:07 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2009-04-05 23:09:36 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -44,8 +44,7 @@ int itkNrrdCovariantVectorImageReadTest( int ac, char* av[] )
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file reader " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
 
@@ -67,10 +66,10 @@ int itkNrrdCovariantVectorImageReadTest( int ac, char* av[] )
         {
         coord[0] = xi;
         sample = image->GetPixel(coord);
-        err += fabs(sample[0] - coord[0]);
-        err += fabs(sample[1] - coord[1]);
-        err += fabs(sample[2] - coord[2]);
-        err += fabs(sample[3] - idx);
+        err += vcl_fabs(sample[0] - coord[0]);
+        err += vcl_fabs(sample[1] - coord[1]);
+        err += vcl_fabs(sample[2] - coord[2]);
+        err += vcl_fabs(sample[3] - idx);
         idx++;
         }
       }
