@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNrrdCovariantVectorImageReadWriteTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-08-20 22:47:07 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2008-09-16 17:29:23 $
+  Version:   $Revision: 1.2 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -45,8 +45,7 @@ int itkNrrdCovariantVectorImageReadWriteTest( int ac, char* av[] )
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file reader " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
   
@@ -65,8 +64,7 @@ int itkNrrdCovariantVectorImageReadWriteTest( int ac, char* av[] )
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file writer " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
 
