@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNrrdDiffusionTensor3DImageReadTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-08-20 16:16:13 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2009-04-05 23:09:36 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -44,8 +44,7 @@ int itkNrrdDiffusionTensor3DImageReadTest( int ac, char* av[] )
   catch (itk::ExceptionObject & e)
     {
     std::cerr << "exception in file reader " << std::endl;
-    std::cerr << e.GetDescription() << std::endl;
-    std::cerr << e.GetLocation() << std::endl;
+    std::cerr << e << std::endl;
     return EXIT_FAILURE;
     }
 
@@ -64,56 +63,56 @@ int itkNrrdDiffusionTensor3DImageReadTest( int ac, char* av[] )
   coord[1] = 0;
   coord[2] = 0;
   sample = image->GetPixel(coord);
-  err += fabs(sample(0,0) - 4.0248222);
-  err += fabs(sample(0,1) - -0.2367909);
-  err += fabs(sample(0,2) - 0.23370844);
-  err += fabs(sample(1,1) - 1.2593846);
-  err += fabs(sample(1,2) - -0.042955428);
-  err += fabs(sample(2,2) - -0.15239859);
+  err += vcl_fabs(sample(0,0) - 4.0248222);
+  err += vcl_fabs(sample(0,1) - -0.2367909);
+  err += vcl_fabs(sample(0,2) - 0.23370844);
+  err += vcl_fabs(sample(1,1) - 1.2593846);
+  err += vcl_fabs(sample(1,2) - -0.042955428);
+  err += vcl_fabs(sample(2,2) - -0.15239859);
 
   coord[0] = 4;
   coord[1] = 5;
   coord[2] = 6;
   sample = image->GetPixel(coord);
-  err += fabs(sample(0,0) - 6.3746634);
-  err += fabs(sample(0,1) - -0.10792637);
-  err += fabs(sample(0,2) - 0.078167915);
-  err += fabs(sample(1,1) - 6.2988205);
-  err += fabs(sample(1,2) - 0.40197921);
-  err += fabs(sample(2,2) - 4.8993769);
+  err += vcl_fabs(sample(0,0) - 6.3746634);
+  err += vcl_fabs(sample(0,1) - -0.10792637);
+  err += vcl_fabs(sample(0,2) - 0.078167915);
+  err += vcl_fabs(sample(1,1) - 6.2988205);
+  err += vcl_fabs(sample(1,2) - 0.40197921);
+  err += vcl_fabs(sample(2,2) - 4.8993769);
 
   coord[0] = 3;
   coord[1] = 3;
   coord[2] = 3;
   sample = image->GetPixel(coord);
-  err += fabs(sample(0,0) - 4.9852095);
-  err += fabs(sample(0,1) - 0.51356757);
-  err += fabs(sample(0,2) - -1.1457335);
-  err += fabs(sample(1,1) - 0.6538533);
-  err += fabs(sample(1,2) - -0.19546235);
-  err += fabs(sample(2,2) - 1.3520061);
+  err += vcl_fabs(sample(0,0) - 4.9852095);
+  err += vcl_fabs(sample(0,1) - 0.51356757);
+  err += vcl_fabs(sample(0,2) - -1.1457335);
+  err += vcl_fabs(sample(1,1) - 0.6538533);
+  err += vcl_fabs(sample(1,2) - -0.19546235);
+  err += vcl_fabs(sample(2,2) - 1.3520061);
 
   coord[0] = 3;
   coord[1] = 0;
   coord[2] = 5;
   sample = image->GetPixel(coord);
-  err += fabs(sample(0,0) - 6.1530757);
-  err += fabs(sample(0,1) - 0.40738893);
-  err += fabs(sample(0,2) - 0.11354899);
-  err += fabs(sample(1,1) - 5.968379);
-  err += fabs(sample(1,2) - -0.22650599);
-  err += fabs(sample(2,2) - 5.0935121);
+  err += vcl_fabs(sample(0,0) - 6.1530757);
+  err += vcl_fabs(sample(0,1) - 0.40738893);
+  err += vcl_fabs(sample(0,2) - 0.11354899);
+  err += vcl_fabs(sample(1,1) - 5.968379);
+  err += vcl_fabs(sample(1,2) - -0.22650599);
+  err += vcl_fabs(sample(2,2) - 5.0935121);
 
   coord[0] = 0;
   coord[1] = 3;
   coord[2] = 6;
   sample = image->GetPixel(coord);
-  err += fabs(sample(0,0) - 7.3227096);
-  err += fabs(sample(0,1) - -0.34219909);
-  err += fabs(sample(0,2) - -0.2011447);
-  err += fabs(sample(1,1) - 5.6443777);
-  err += fabs(sample(1,2) - 0.43205333);
-  err += fabs(sample(2,2) - 5.3755102);
+  err += vcl_fabs(sample(0,0) - 7.3227096);
+  err += vcl_fabs(sample(0,1) - -0.34219909);
+  err += vcl_fabs(sample(0,2) - -0.2011447);
+  err += vcl_fabs(sample(1,1) - 5.6443777);
+  err += vcl_fabs(sample(1,2) - 0.43205333);
+  err += vcl_fabs(sample(2,2) - 5.3755102);
 
   double thresh = 0.00000041;
   if (err > thresh)
