@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNrrdImageIOTest.h,v $
   Language:  C++
-  Date:      $Date: 2004-09-07 20:41:58 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2009-07-12 10:53:04 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -34,9 +34,10 @@ itkNrrdImageIOTestGenerateRandomImage(unsigned int size)
   typename itk::RandomImageSource<ImageType>::Pointer source
     = itk::RandomImageSource<ImageType>::New();
 
-  unsigned long sz[VImageDimension];
-  float spacing[VImageDimension];
-  float origin[VImageDimension];
+  typename ImageType::SizeType sz;
+  typename ImageType::SpacingType spacing;
+  typename ImageType::PointType origin;
+
   for (unsigned int i = 0; i < VImageDimension; i++)
     {
     sz[i]      = size;
