@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRawImageIOTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-03-06 04:52:59 $
-  Version:   $Revision: 1.13 $
+  Date:      $Date: 2009-07-12 10:53:04 $
+  Version:   $Revision: 1.14 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -40,7 +40,8 @@ int itkRawImageIOTest(int argc, char* argv[])
   // Create a source object (in this case a random image generator).
   // The source object is templated on the output type.
   //
-  unsigned long size[2];
+  ImageType::SizeValueType size[2];
+
   size[0]=128; size[1]=64;
   
   itk::RandomImageSource<ImageType>::Pointer random;
