@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRawImageIOTest2.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-09-22 23:46:20 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2008-05-27 12:57:52 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -46,6 +46,8 @@ int itkRawImageIOTest2(int argc, char * argv [])
   itk::RawImageIO<RGBPixelType>::Pointer io;
   io = itk::RawImageIO<RGBPixelType>::New();
   io->SetFileName(argv[1]);
+  io->SetFileDimensionality(3);
+  io->SetNumberOfDimensions(3);
   unsigned int dim[3] = {50,50,10};
   double spacing[3] = {1.0, 1.0, 1.0};
   double origin[3] = {0.0,0.0,0.0};
@@ -64,9 +66,9 @@ int itkRawImageIOTest2(int argc, char * argv [])
 
   std::cout << "IO: " << io << std::endl;
 
-  typedef itk::Image<RGBPixelType,2> RGBImage2DType;
-  itk::ImageFileReader<RGBImage2DType>::Pointer reader;
-  reader = itk::ImageFileReader<RGBImage2DType>::New();
+  typedef itk::Image<RGBPixelType,3> RGBImage3DType;
+  itk::ImageFileReader<RGBImage3DType>::Pointer reader;
+  reader = itk::ImageFileReader<RGBImage3DType>::New();
   reader->SetFileName(argv[1]);
   reader->SetImageIO(io);
   reader->Update();
