@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkReadWriteSpatialObjectTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-01-27 19:48:47 $
-  Version:   $Revision: 1.24 $
+  Date:      $Date: 2010-04-03 12:17:24 $
+  Version:   $Revision: 1.27 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -17,6 +17,7 @@
 #if defined(_MSC_VER)
 #pragma warning ( disable : 4786 )
 #endif
+#include "itkImageHelper.h"
 #include "itkSpatialObject.h"
 #include "itkTubeSpatialObject.h"
 #include "itkDTITubeSpatialObject.h"
@@ -265,7 +266,7 @@ int itkReadWriteSpatialObjectTest(int argc, char* argv[])
   for(unsigned int i=0;i<dim;i++)
     {
     size[i] = 10;
-    spacing[i] = i;
+    spacing[i] = i + 1;
     }
 
   RegionType region;
@@ -370,7 +371,7 @@ int itkReadWriteSpatialObjectTest(int argc, char* argv[])
 
   WriterType::Pointer writer = WriterType::New();
   writer->SetInput(tubeN1);
-  writer->SetFileName("Objects.meta");
+  writer->SetFileName(argv[1]);
   writer->SetBinaryPoints(false);
   if(writer->GetBinaryPoints())
     {
@@ -378,7 +379,7 @@ int itkReadWriteSpatialObjectTest(int argc, char* argv[])
     return EXIT_FAILURE;
     }
 
-  if((argc>1) && (!strcmp(argv[1],"binary")))
+  if((argc>2) && (!strcmp(argv[2],"binary")))
     {
     writer->SetBinaryPoints(true);
     }
@@ -389,13 +390,13 @@ int itkReadWriteSpatialObjectTest(int argc, char* argv[])
   std::cout<<"Testing Reading SceneSpatialObject: ";
 
   ReaderType::Pointer reader = ReaderType::New();
-  if((argc>1) && (strcmp(argv[1],"binary")))
+  if((argc>2) && (strcmp(argv[2],"binary")))
     {
-    reader->SetFileName(argv[1]);
+    reader->SetFileName(argv[2]);
     }
   else
     {
-    reader->SetFileName("Objects.meta");
+    reader->SetFileName(argv[1]);
     }
   reader->Update();
 
