@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTransformIOTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-01-28 15:06:32 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date: 2009-11-13 17:51:20 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -24,6 +24,7 @@
 #include "itkTransformFactory.h"
 #include "itkSimilarity2DTransform.h"
 #include "itkBSplineDeformableTransform.h"
+#include <itksys/SystemTools.hxx>
 
 static int oneTest(const char *goodname,const char *badname)
 {
@@ -164,8 +165,12 @@ static int oneTest(const char *goodname,const char *badname)
   return EXIT_SUCCESS;
 }
 
-int itkTransformIOTest(int itkNotUsed(ac), char* itkNotUsed(av)[])
+int itkTransformIOTest(int argc, char* argv[])
 {
+  if (argc > 1)
+    {
+    itksys::SystemTools::ChangeDirectory(argv[1]);
+    }
   int result1 =  oneTest("Transforms.txt", "TransformsBad.txt" );
   int result2 =  oneTest("Transforms.mat", "TransformsBad.mat" );
   return !(result1 == EXIT_SUCCESS && result2 == EXIT_SUCCESS);
