@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: testMetaArray.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-11-01 14:57:38 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-11-13 17:51:20 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -24,9 +24,15 @@
 #include <itkVariableLengthVector.h>
 #include <itkMetaArrayWriter.h>
 #include <itkMetaArrayReader.h>
+#include <itksys/SystemTools.hxx>
 
-int testMetaArray(int , char * [])
+int testMetaArray(int argc, char * argv[])
   {
+  if (argc > 1)
+    {
+    itksys::SystemTools::ChangeDirectory(argv[1]);
+    }
+
   std::cout << "Array" << std::endl;
   itk::Array<short> arr;
   arr.SetSize(5);
