@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: testMetaLandmark.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-24 17:03:22 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-11-13 17:51:20 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -20,10 +20,16 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#include <cstdlib>
 #include <metaLandmark.h>
+#include <itksys/SystemTools.hxx>
 
-int testMetaLandmark(int , char * [])
+int testMetaLandmark(int argc, char * argv[])
 {
+  if (argc > 1)
+    {
+    itksys::SystemTools::ChangeDirectory(argv[1]);
+    }
 
   std::cout << "Creating test file ..." << std::endl;
   MetaLandmark Landmark0;
