@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: testMetaMesh.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-24 17:03:22 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-11-13 17:51:20 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,9 +21,12 @@
 #include <stdio.h>
 #include <iostream>
 #include <ctype.h>
+#include <cstdlib>
 #include <metaMesh.h>
 #include <metaScene.h>
 #include <math.h>
+#include <vcl_cmath.h>
+#include <itksys/SystemTools.hxx>
 
 
 bool TestingMetaMesh(MetaMesh* _mesh)
@@ -149,7 +152,7 @@ bool TestingMetaMesh(MetaMesh* _mesh)
   float f = (float)(0.1);
   for(j=0;j< static_cast<int>(_mesh->GetCellData().size());j++)
     {
-    if(((*it_cd)->m_Id != j) || (fabs((float)(static_cast<MeshData<float>*>(*it_cd)->m_Data)-f)>0.001))
+    if(((*it_cd)->m_Id != j) || (vcl_fabs((float)(static_cast<MeshData<float>*>(*it_cd)->m_Data)-f)>0.001))
       {
       std::cout << "CellData ID = " << (*it_cd)->m_Id << " : " << (float)(static_cast<MeshData<float>*>(*it_cd)->m_Data) << " : " << f << std::endl;    
       std::cout << "[FAILED]" << std::endl;
@@ -164,8 +167,12 @@ bool TestingMetaMesh(MetaMesh* _mesh)
 
 
 /** Main */
-int testMetaMesh(int , char * [])
+int testMetaMesh(int argc, char * argv[])
 {
+  if (argc > 1)
+    {
+    itksys::SystemTools::ChangeDirectory(argv[1]);
+    }
 
   MetaScene myScene = MetaScene(3);
   
