@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: testMetaObject.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-24 17:03:22 $
-  Version:   $Revision: 1.13 $
+  Date:      $Date: 2009-11-13 17:51:20 $
+  Version:   $Revision: 1.14 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -25,9 +25,15 @@
 #include <metaObject.h>
 #include <metaUtils.h>
 #include "itkNumericTraits.h"
+#include <itksys/SystemTools.hxx>
 
-int testMetaObject(int , char *[])
+int testMetaObject(int argc, char *argv[])
   {
+  if (argc > 1)
+    {
+    itksys::SystemTools::ChangeDirectory(argv[1]);
+    }
+
   MetaObject tObj;
 
   tObj.InitializeEssential(3);
