@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: testMetaSurface.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-24 17:03:22 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-11-13 17:51:22 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -20,10 +20,16 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#include <cstdlib>
 #include <metaSurface.h>
+#include <itksys/SystemTools.hxx>
 
-int testMetaSurface(int , char * [])
+int testMetaSurface(int argc, char * argv[])
 {
+  if (argc > 1)
+    {
+    itksys::SystemTools::ChangeDirectory(argv[1]);
+    }
 
   std::cout << "Creating test file ...";
   MetaSurface* surface = new MetaSurface(3);
