@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: testMetaTube.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-24 17:03:22 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-11-13 17:51:22 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,12 +21,18 @@
 #include <stdio.h>
 #include <iostream>
 #include <ctype.h>
+#include <cstdlib>
 #include <metaTube.h>
 #include <metaScene.h>
 #include <metaEllipse.h>
+#include <itksys/SystemTools.hxx>
 
-int testMetaTube(int , char * [])
+int testMetaTube(int argc, char * argv[])
 {
+  if (argc > 1)
+    {
+    itksys::SystemTools::ChangeDirectory(argv[1]);
+    }
 
   std::cout << "Initializing scene ..." << std::endl;
   MetaScene myScene = MetaScene(3);
