@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: testMetaUtils.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-24 17:03:22 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-11-13 17:51:22 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,12 +21,18 @@
 #include <stdio.h>
 #include <fstream>
 #include <ctype.h>
+#include <cstdlib>
 
 
 #include <metaUtils.h>
+#include <itksys/SystemTools.hxx>
 
-int testMetaUtils(int , char * [])
-  {
+int testMetaUtils(int argc, char * argv[])
+{
+  if (argc > 1)
+    {
+    itksys::SystemTools::ChangeDirectory(argv[1]);
+    }
 
   if(MET_SystemByteOrderMSB())
     {
@@ -265,4 +271,4 @@ int testMetaUtils(int , char * [])
 
   std::cout << "[DONE]" << std::endl;
   return EXIT_SUCCESS;
-  }
+}
