@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFEMLinearSystemWrapperItpackTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-11-07 23:23:16 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date: 2009-04-06 19:59:56 $
+  Version:   $Revision: 1.16 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -23,10 +23,12 @@
 
 #include "itkFEMLinearSystemWrapperItpack.h"
 #include <iostream>
+#include <string.h>
+#include <stdlib.h>
 
 
 /* Testing for linear system wrappers */
-int itkFEMLinearSystemWrapperItpackTest( int , char * [] )
+int itkFEMLinearSystemWrapperItpackTest( int argc, char * argv [] )
 {
 
   /* loop vars for printing */
@@ -207,7 +209,6 @@ int itkFEMLinearSystemWrapperItpackTest( int , char * [] )
     }
   std::cout << std::endl;
 
-
   /* solve system */
   std::cout << "Solve for x in: Matrix 0 * x = Vector 0" << std::endl;
   it.Solve();
@@ -291,8 +292,35 @@ int itkFEMLinearSystemWrapperItpackTest( int , char * [] )
   it.DestroyVector(1);
   it.DestroySolution(0);
 
-  
-  
+  if( argc > 1 )
+    {
+    int method = atoi( argv[1] );
+    switch( method )
+      {
+      case 0:
+        it.JacobianConjugateGradient();
+        break;
+      case 1:
+        it.JacobianSemiIterative();
+        break;
+      case 2:
+        it.SuccessiveOverrelaxation();
+        break;
+      case 3:
+        it.SymmetricSuccessiveOverrelaxationConjugateGradient();
+        break;
+      case 4:
+        it.SymmetricSuccessiveOverrelaxationSuccessiveOverrelaxation();
+        break;
+      case 5:
+        it.ReducedSystemConjugateGradient();
+        break;
+      case 6:
+        it.ReducedSystemSemiIteration();
+        break;
+      }
+    }
+
   int        integerPass = 1;
   double     doublePass  = 1.0;
  
