@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: NNetClassifierTest1.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-18 15:16:57 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-04-05 23:09:36 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -57,9 +57,9 @@ static int TestNetwork(SampleType::Pointer TestSample, TargetType::Pointer TestT
     TargetVectorType tv = iter2.GetMeasurementVector();
     TargetVectorType ov = OneHiddenLayerNetwork->GenerateOutput(mv);
     flag = 0;
-    if (fabs(tv[0]-ov[0])>0.2)
+    if (vcl_fabs(tv[0]-ov[0])>0.2)
       {
-      outfile<<fabs(tv[0]-ov[0])<<std::endl;
+      outfile<<vcl_fabs(tv[0]-ov[0])<<std::endl;
       flag = 1;
       }
     if (flag == 1 && ROUND(tv[0]) == 1)
