@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: NNetClassifierTest2.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-17 13:10:57 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-04-05 23:09:36 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -125,7 +125,7 @@ NNetClassifierTest2(int argc, char* argv[])
     tv = iter2.GetMeasurementVector();
     ov.Set_vnl_vector(net1->GenerateOutput(mv));
     flag=0;
-    if (fabs(tv[0]-ov[0])>0.3)
+    if (vcl_fabs(tv[0]-ov[0])>0.3)
       {
       flag = 1;
       }
