@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkChiSquareDistributionTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-05-23 12:37:58 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-04-05 23:09:36 $
+  Version:   $Revision: 1.4 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -64,7 +64,7 @@ int itkChiSquareDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateCDF( x );
 
-    diff = fabs(value - expected1[i]);
+    diff = vcl_fabs(value - expected1[i]);
 
     std::cout << "Chi-Square cdf at ";
     std::cout.width(2);
@@ -103,7 +103,7 @@ int itkChiSquareDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateInverseCDF( expected1[i] );
 
-    diff = fabs(value - double(i));
+    diff = vcl_fabs(value - double(i));
 
     std::cout << "Chi-Square cdf at ";
     std::cout.width(20);
@@ -163,7 +163,7 @@ int itkChiSquareDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateCDF( x );
 
-    diff = fabs(value - expected11[i]);
+    diff = vcl_fabs(value - expected11[i]);
 
     std::cout << "Chi-Square cdf at ";
     std::cout.width(2);
@@ -202,7 +202,7 @@ int itkChiSquareDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateInverseCDF( expected11[i] );
 
-    diff = fabs(value - double(2*i));
+    diff = vcl_fabs(value - double(2*i));
 
     std::cout << "Chi-Square cdf at ";
     std::cout.width(20);
@@ -256,7 +256,7 @@ int itkChiSquareDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateCDF( x );
 
-    diff = fabs(value - expected100[i]);
+    diff = vcl_fabs(value - expected100[i]);
 
     std::cout << "Chi-Square cdf at ";
     std::cout.width(2);
@@ -295,7 +295,7 @@ int itkChiSquareDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateInverseCDF( expected100[i] );
 
-    diff = fabs(value - double(50+20*i));
+    diff = vcl_fabs(value - double(50+20*i));
 
     std::cout << "Chi-Square cdf at ";
     std::cout.width(20);
@@ -344,7 +344,7 @@ int itkChiSquareDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateCDF( x, params );
 
-    diff = fabs(value - expected100[i]);
+    diff = vcl_fabs(value - expected100[i]);
 
     std::cout << "Chi-Square cdf at ";
     std::cout.width(2);
@@ -383,7 +383,7 @@ int itkChiSquareDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateInverseCDF( expected100[i], params );
 
-    diff = fabs(value - double(50+20*i));
+    diff = vcl_fabs(value - double(50+20*i));
 
     std::cout << "Chi-Square cdf at ";
     std::cout.width(20);
@@ -427,7 +427,7 @@ int itkChiSquareDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateCDF( x, (long)params[0] );
 
-    diff = fabs(value - expected100[i]);
+    diff = vcl_fabs(value - expected100[i]);
 
     std::cout << "Chi-Square cdf at ";
     std::cout.width(2);
@@ -467,7 +467,7 @@ int itkChiSquareDistributionTest(int, char* [] )
     value = distributionFunction->EvaluateInverseCDF(
       expected100[i], (long)params[0] );
 
-    diff = fabs(value - double(50+20*i));
+    diff = vcl_fabs(value - double(50+20*i));
 
     std::cout << "Chi-Square cdf at ";
     std::cout.width(20);
