@@ -3,8 +3,8 @@
 Program:   Insight Segmentation & Registration Toolkit
 Module:    $RCSfile: itkExpectationMaximizationMixtureModelEstimatorTest.cxx,v $
 Language:  C++
-Date:      $Date: 2005-02-08 03:18:41 $
-Version:   $Revision: 1.8 $
+Date:      $Date: 2009-09-19 19:40:26 $
+Version:   $Revision: 1.10 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -173,6 +173,8 @@ int itkExpectationMaximizationMixtureModelEstimatorTest(int argc, char* argv[] )
       std::cout << "         " << (components[i])->GetFullParameters() << std::endl ;
       std::cout << "    Proportion: " ;
       std::cout << "         " << (*estimator->GetProportions())[i] << std::endl ;
+      std::cout << "    InitialProportions: " ;
+      std::cout << "         " << (*estimator->GetInitialProportions())[i] << std::endl ;
       displacement = 0.0 ;
       for ( j = 0 ; j < DataSampleType::MeasurementVectorSize ;
            j++)
@@ -180,7 +182,7 @@ int itkExpectationMaximizationMixtureModelEstimatorTest(int argc, char* argv[] )
           temp = (components[i])->GetFullParameters()[j] - trueParameters[i][j] ;
           displacement += (temp * temp) ;
         }
-      displacement = sqrt(displacement) ;
+      displacement = vcl_sqrt(displacement) ;
       std::cout << "    Mean displacement: " << std::endl ;
       std::cout << "        " << displacement 
                 << std::endl << std::endl ;
