@@ -3,8 +3,8 @@
 Program:   Insight Segmentation & Registration Toolkit
 Module:    $RCSfile: itkGoodnessOfFitMixtureModelCostFunctionTest.cxx,v $
 Language:  C++
-Date:      $Date: 2005-02-08 03:18:41 $
-Version:   $Revision: 1.13 $
+Date:      $Date: 2009-04-06 19:25:07 $
+Version:   $Revision: 1.15 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -170,7 +170,7 @@ int itkGoodnessOfFitMixtureModelCostFunctionTest(int argc, char* argv[] )
 
   double initStepSize = 1.05 ;
   double grow = 1.1 ;
-  double shrink = pow(grow, -0.25) ;
+  double shrink = vcl_pow(grow, -0.25) ;
   OptimizerType::ScalesType scales(paramSize) ;
   scales.Fill(1.0) ;
   for ( i = 0 ; i < paramSize ; i++)
@@ -214,7 +214,7 @@ int itkGoodnessOfFitMixtureModelCostFunctionTest(int argc, char* argv[] )
           paramIndex++ ;
         }
       paramIndex++ ;
-      displacement = sqrt(displacement) ;
+      displacement = vcl_sqrt(displacement) ;
       std::cout << "    Mean displacement: " << std::endl ;
       std::cout << "        " << displacement 
                 << std::endl << std::endl ;
