@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageToListAdaptorTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-08 03:18:41 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-07-12 10:53:04 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -34,8 +34,8 @@ int itkImageToListAdaptorTest(int, char* [] )
   // Now generate a random image
   typedef itk::RandomImageSource<FloatImage> SourceType;
   SourceType::Pointer source = SourceType::New();
-  unsigned long size[3] = {17, 8, 20} ;
-  unsigned long totalSize = size[0] * size[1] * size[2] ;
+  FloatImage::SizeValueType size[3] = {17, 8, 20} ;
+  FloatImage::SizeValueType totalSize = size[0] * size[1] * size[2] ;
 
   source->SetSize(size);
   float minValue = -100.0;
