@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkKdTreeGeneratorTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-07-26 15:55:12 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-01-06 20:16:11 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -76,10 +76,10 @@ int itkKdTreeGeneratorTest(int, char* [])
   std::cout << "Split point on the partition dimension = "
             << partitionValue << std::endl ;
 
-  std::cout << "Address of the left chile of the root node = "
+  std::cout << "Address of the left child of the root node = "
             << root->Left() << std::endl ;
   
-  std::cout << "Address of the right chile of the root node = "
+  std::cout << "Address of the right child of the root node = "
             << root->Right() << std::endl ;
 
   MeasurementVectorType queryPoint( measurementVectorSize ) ;
@@ -174,10 +174,10 @@ int itkKdTreeGeneratorTest(int, char* [])
   std::cout << "Split point on the partition dimension = "
             << partitionValue << std::endl ;
 
-  std::cout << "Address of the left chile of the root node = "
+  std::cout << "Address of the left child of the root node = "
             << root->Left() << std::endl ;
   
-  std::cout << "Address of the right chile of the root node = "
+  std::cout << "Address of the right child of the root node = "
             << root->Right() << std::endl ;
 
   MeasurementVectorType queryPoint ;
