@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkStatisticsTests.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-02-24 17:53:01 $
-  Version:   $Revision: 1.31 $
+  Date:      $Date: 2008-04-29 22:56:43 $
+  Version:   $Revision: 1.36 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -45,6 +45,8 @@ void RegisterTests()
   REGISTER_TEST(itkImageToListGeneratorTest);
   REGISTER_TEST(itkKdTreeBasedKmeansEstimatorTest);
   REGISTER_TEST(itkKdTreeGeneratorTest);
+  REGISTER_TEST(itkKdTreeTest1);
+  REGISTER_TEST(itkKdTreeTest2);
   REGISTER_TEST(itkListSampleTest);
   REGISTER_TEST(itkListSampleToHistogramFilterTest);
   REGISTER_TEST(itkListSampleToHistogramGeneratorTest);
@@ -55,6 +57,8 @@ void RegisterTests()
   REGISTER_TEST(itkMeanCalculatorTest);
   REGISTER_TEST(itkNeighborhoodSamplerTest) ;
   REGISTER_TEST(itkNormalVariateGeneratorTest);
+  REGISTER_TEST(itkNthElementTest1);
+  REGISTER_TEST(itkQuickSelectTest1);
   REGISTER_TEST(itkSampleClassifierTest) ;
   REGISTER_TEST(itkSampleClassifierWithMaskTest) ;
   REGISTER_TEST(itkSampleMeanShiftClusteringFilterTest) ;
@@ -66,7 +70,8 @@ void RegisterTests()
   REGISTER_TEST(itkStatisticsAlgorithmTest);
   REGISTER_TEST(itkSubsampleTest);
   REGISTER_TEST(itkVariableDimensionHistogramTest);
-  REGISTER_TEST(itkWeightedMeanCalculatorTest);
+  REGISTER_TEST(itkWeightedCentroidKdTreeGeneratorTest1);
   REGISTER_TEST(itkWeightedCovarianceCalculatorTest);
+  REGISTER_TEST(itkWeightedMeanCalculatorTest);
 }
 
