@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTDistributionTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-02-24 17:53:01 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2009-04-05 23:09:36 $
+  Version:   $Revision: 1.2 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -69,7 +69,7 @@ int itkTDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateCDF( x );
 
-    diff = fabs(value - expected1[i+5]);
+    diff = vcl_fabs(value - expected1[i+5]);
 
     std::cout << "Student-t cdf at ";
     std::cout.width(2);
@@ -108,7 +108,7 @@ int itkTDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateInverseCDF( expected1[i+5] );
 
-    diff = fabs(value - double(i));
+    diff = vcl_fabs(value - double(i));
 
     std::cout << "Student-t cdf at ";
     std::cout.width(20);
@@ -168,7 +168,7 @@ int itkTDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateCDF( x );
 
-    diff = fabs(value - expected11[i+5]);
+    diff = vcl_fabs(value - expected11[i+5]);
 
     std::cout << "Student-t cdf at ";
     std::cout.width(2);
@@ -207,7 +207,7 @@ int itkTDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateInverseCDF( expected11[i+5] );
 
-    diff = fabs(value - double(i));
+    diff = vcl_fabs(value - double(i));
 
     std::cout << "Student-t cdf at ";
     std::cout.width(20);
@@ -258,7 +258,7 @@ int itkTDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateCDF( x, params );
 
-    diff = fabs(value - expected11[i+5]);
+    diff = vcl_fabs(value - expected11[i+5]);
 
     std::cout << "Student-t cdf at ";
     std::cout.width(2);
@@ -297,7 +297,7 @@ int itkTDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateInverseCDF( expected11[i+5],params );
 
-    diff = fabs(value - double(i));
+    diff = vcl_fabs(value - double(i));
 
     std::cout << "Student-t cdf at ";
     std::cout.width(20);
@@ -344,7 +344,7 @@ int itkTDistributionTest(int, char* [] )
 
     value = distributionFunction->EvaluateCDF( x, (long)params[0] );
 
-    diff = fabs(value - expected11[i+5]);
+    diff = vcl_fabs(value - expected11[i+5]);
 
     std::cout << "Student-t cdf at ";
     std::cout.width(2);
@@ -384,7 +384,7 @@ int itkTDistributionTest(int, char* [] )
     value = distributionFunction->EvaluateInverseCDF( expected11[i+5],
                                                       (long) params[0] );
 
-    diff = fabs(value - double(i));
+    diff = vcl_fabs(value - double(i));
 
     std::cout << "Student-t cdf at ";
     std::cout.width(20);
