@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkConjugateGradientOptimizerTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-09-10 15:22:47 $
-  Version:   $Revision: 1.23 $
+  Date:      $Date: 2009-06-24 12:03:51 $
+  Version:   $Revision: 1.26 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -20,6 +20,7 @@
 
 #include <itkConjugateGradientOptimizer.h>
 #include <vnl/vnl_math.h>
+#include <cstdlib>
 
 
 /** 
@@ -233,7 +234,7 @@ int itkConjugateGradientOptimizerTest(int, char* [] )
   std::cout << "Number of evals = " << vnlOptimizer->get_num_evaluations() << std::endl;    
 
   std::cout << "Report from vnl optimizer: " << std::endl;
-  vnlOptimizer->diagnose_outcome( std::cout );
+  std::cout << "Stop description   = " << itkOptimizer->GetStopConditionDescription() << std::endl;
 
   std::cout << std::endl;
 
@@ -265,7 +266,7 @@ int itkConjugateGradientOptimizerTest(int, char* [] )
   // Get the final value of the optimizer
   std::cout << "Testing GetValue() : ";
   OptimizerType::MeasureType finalValue = itkOptimizer->GetValue();
-  if(fabs(finalValue+10.0)>0.01)
+  if(vcl_fabs(finalValue+10.0)>0.01)
     {
     std::cout << "[FAILURE]" << std::endl;
     return EXIT_FAILURE;
