@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFRPROptimizerTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-05-25 13:42:34 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2009-08-17 14:32:46 $
+  Version:   $Revision: 1.4 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -17,6 +17,7 @@
 
 #include <vnl/vnl_math.h>
 #include "itkFRPROptimizer.h"
+#include <cstdlib>
 
 
 /** 
@@ -192,13 +193,11 @@ int itkFRPROptimizerTest(int, char* [] )
 
   if( !pass )
     {
-    std::cout << "Test failed." << std::endl;
+    std::cout << "Fletch Reeves test failed." << std::endl;
     return EXIT_FAILURE;
     }
 
-  std::cout << "Test passed." << std::endl;
-  return EXIT_SUCCESS;
-
+  std::cout << "Fletch Reeves test passed." << std::endl;
   }
 
   {
@@ -247,14 +246,14 @@ int itkFRPROptimizerTest(int, char* [] )
 
   if( !pass )
     {
-    std::cout << "Test failed." << std::endl;
+    std::cout << "Polak Ribiere test failed." << std::endl;
     return EXIT_FAILURE;
     }
 
-  std::cout << "Test passed." << std::endl;
-  return EXIT_SUCCESS;
-
+  std::cout << "Polak Ribiere test passed." << std::endl;
   }
+  
+  return EXIT_SUCCESS;
 }
 
 
