@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLBFGSBOptimizerTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-08 03:18:41 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-06-24 12:03:51 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) 2002 Insight Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -39,16 +39,16 @@
  *   the solution is the vector | 4/3 -1 |
  *
  */ 
-class LBFCostFunction : public itk::SingleValuedCostFunction 
+class LBFGSBCostFunction : public itk::SingleValuedCostFunction 
 {
 public:
 
-  typedef LBFCostFunction                    Self;
+  typedef LBFGSBCostFunction                    Self;
   typedef itk::SingleValuedCostFunction     Superclass;
   typedef itk::SmartPointer<Self>           Pointer;
   typedef itk::SmartPointer<const Self>     ConstPointer;
   itkNewMacro( Self );
-  itkTypeMacro( LBFCostFunction, SingleValuedCostFunction );
+  itkTypeMacro( LBFGSBCostFunction, SingleValuedCostFunction );
 
   enum { SpaceDimension=2 };
 
@@ -60,7 +60,7 @@ public:
 
   typedef double MeasureType ;
 
-  LBFCostFunction()
+  LBFGSBCostFunction()
   {
   }
 
@@ -130,7 +130,7 @@ int itkLBFGSBOptimizerTest(int, char *[])
 
 
   // Declaration of the CostFunction adaptor
-  LBFCostFunction::Pointer costFunction = LBFCostFunction::New();
+  LBFGSBCostFunction::Pointer costFunction = LBFGSBCostFunction::New();
 
 
   itkOptimizer->SetCostFunction( costFunction.GetPointer() );
@@ -198,6 +198,8 @@ int itkLBFGSBOptimizerTest(int, char *[])
   std::cout << "Infinity Norm of Projected Gradient = ";
   std::cout << itkOptimizer->GetInfinityNormOfProjectedGradient() << std::endl;
   
+  std::cout << "End condition   = " << itkOptimizer->GetStopConditionDescription() << std::endl;
+
   //
   // check results to see if it is within range
   //
