@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLevenbergMarquardtOptimizerTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-12-28 15:34:56 $
-  Version:   $Revision: 1.34 $
+  Date:      $Date: 2009-06-24 12:03:51 $
+  Version:   $Revision: 1.37 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -24,6 +24,7 @@
 #include <vnl/vnl_math.h>
 #include <itkArray.h>
 #include <itkArray2D.h>
+#include <stdlib.h>
 
 
 
@@ -332,6 +333,7 @@ int itkRunLevenbergMarquardOptimization( bool useGradient,
                       std::cout << " Failed user request "; break;
   }
   std::cout << std::endl;
+  std::cout << "Stop description   = " << optimizer->GetStopConditionDescription() << std::endl;
   std::cout << "Number of iters = " << vnlOptimizer->get_num_iterations() << std::endl;
   std::cout << "Number of evals = " << vnlOptimizer->get_num_evaluations() << std::endl;    
   std::cout << std::endl;
@@ -368,7 +370,7 @@ int itkRunLevenbergMarquardOptimization( bool useGradient,
   OptimizerType::MeasureType finalValue = optimizer->GetValue();
 
   // We compare only the first value for this test
-  if(fabs(finalValue[0]-0.0)>0.01)
+  if(vcl_fabs(finalValue[0]-0.0)>0.01)
     {
     std::cout << "[FAILURE]" << std::endl;
     return EXIT_FAILURE;
