@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVersorRigid3DTransformOptimizerTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-08 03:18:41 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2009-04-05 10:56:56 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -91,7 +91,7 @@ public:
     m_Q1[2] =  0.0;
 
     VersorType versor;
-    const double angle = 10.0 * atan( 1.0 ) / 45.0;
+    const double angle = 10.0 * vcl_atan( 1.0 ) / 45.0;
     versor.SetRotationAroundX( angle );
 
     m_Transform->SetRotation( versor );
@@ -348,7 +348,7 @@ int itkVersorRigid3DTransformOptimizerTest(int, char* [] )
   trueAxis[0]  = 1.0f;
   trueAxis[1]  = 0.0f;
   trueAxis[2]  = 0.0f;
-  trueAngle = 10.0 * atan( 1.0f ) / 45.0;
+  trueAngle = 10.0 * vcl_atan( 1.0f ) / 45.0;
   VersorType trueRotation;
   trueRotation.Set( trueAxis, trueAngle );
     
