@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAddConstantToImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-04-05 23:54:28 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-08-04 16:23:06 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -97,7 +97,6 @@ int itkAddConstantToImageFilterTest(int, char* [] )
   // Create an ADD Filter
   FilterType::Pointer filter = FilterType::New();
 
-
   // Connect the input images
   filter->SetInput( inputImage );
 
@@ -110,6 +109,7 @@ int itkAddConstantToImageFilterTest(int, char* [] )
 
   // Execute the filter
   filter->Update();
+  filter->Print(std::cout);
 
   // Create an iterator for going through the image output
   OutputIteratorType ot(outputImage, outputImage->GetRequestedRegion());
@@ -139,5 +139,13 @@ int itkAddConstantToImageFilterTest(int, char* [] )
     ++it;
     }
 
+  FilterType::Pointer filter2 = FilterType::New();
+  filter2 = filter;
+  filter2->Print(std::cout);
+  if (filter2 != filter)
+    {
+    std::cout << "Error: operator = failed. filter2 != filter." << std::endl;
+    return EXIT_FAILURE;
+    }
   return EXIT_SUCCESS;
 }
