@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkDiffeomorphicDemonsRegistrationFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-03-18 14:27:16 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-07-12 10:53:04 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -135,7 +135,7 @@ int itkDiffeomorphicDemonsRegistrationFilterTest(int argc, char * argv [] )
   std::cout << "Generate input images and initial deformation field";
   std::cout << std::endl;
 
-  unsigned long sizeArray[ImageDimension] = { 128, 128 };
+  ImageType::SizeValueType sizeArray[ImageDimension] = { 128, 128 };
   SizeType size;
   size.SetSize( sizeArray );
 
