@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkReviewTests.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-04-29 23:54:31 $
-  Version:   $Revision: 1.103 $
+  Date:      $Date: 2010-03-05 20:01:05 $
+  Version:   $Revision: 1.106 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -54,6 +54,12 @@ void RegisterTests()
   REGISTER_TEST(itkBinaryMorphologicalOpeningImageFilterTest);
 
   REGISTER_TEST(itkOptImageToImageMetricsTest);
+
+#ifdef ITK_USE_OPTIMIZED_REGISTRATION_METHODS
+  REGISTER_TEST(itkOptImageToImageMetricsTest2);
+#endif
+  
+  REGISTER_TEST(itkOptMattesMutualInformationImageToImageMetricThreadsTest1);
   REGISTER_TEST(itkTimeAndMemoryProbeTest);
 
   REGISTER_TEST(itkBruker2DSEQImageIOTest);
