@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkReviewTests2.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-05-20 12:29:23 $
-  Version:   $Revision: 1.31 $
+  Date:      $Date: 2010-02-07 04:57:46 $
+  Version:   $Revision: 1.33 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -91,12 +91,6 @@ void RegisterTests()
   REGISTER_TEST(itkAtanRegularizedHeavisideStepFunctionTest1);
   REGISTER_TEST(itkRegionBasedLevelSetFunctionTest);
   REGISTER_TEST(itkScalarRegionBasedLevelSetFunctionTest);
-  REGISTER_TEST(itkScalarChanAndVeseLevelSetFunctionTest1);
-  REGISTER_TEST(itkScalarChanAndVeseLevelSetFunctionTest2);
-  REGISTER_TEST(itkScalarChanAndVeseDenseLevelSetImageFilterTest1);
-  REGISTER_TEST(itkScalarChanAndVeseDenseLevelSetImageFilterTest2);
-  REGISTER_TEST(itkScalarChanAndVeseSparseLevelSetImageFilterTest1);
-  REGISTER_TEST(itkScalarChanAndVeseSparseLevelSetImageFilterTest2);
   REGISTER_TEST(itkScalarToRGBColormapImageFilterTest);
   REGISTER_TEST(itkStochasticFractalDimensionImageFilterTest);
   REGISTER_TEST(itkSinRegularizedHeavisideStepFunctionTest1);
