@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkEllipseSpatialObjectTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-08 03:18:42 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2009-04-07 14:34:48 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -29,6 +29,9 @@ int itkEllipseSpatialObjectTest(int, char* [])
   typedef itk::EllipseSpatialObject<4>   EllipseType;
   
   EllipseType::Pointer myEllipse = EllipseType::New();
+  std::cout << "Testing Print after construction" << std::endl;
+  myEllipse->Print(std::cout);
+
   EllipseType::ArrayType radius;
 
   for(unsigned int i = 0; i<4 ;i++)
@@ -131,6 +134,9 @@ int itkEllipseSpatialObjectTest(int, char* [])
     }
 
   }
+  std::cout << "Testing Print after use" << std::endl;
+  myEllipse->Print(std::cout);
+
   std::cout<<"[PASSED]"<<std::endl;
   return EXIT_SUCCESS;
 
