@@ -3,8 +3,8 @@
   Program:   DICOMParser
   Module:    $RCSfile: DICOMParser.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-02-14 17:51:20 $
-  Version:   $Revision: 1.38 $
+  Date:      $Date: 2009-04-05 10:56:58 $
+  Version:   $Revision: 1.40 $
 
   Copyright (c) 2003 Matt Turek
   All rights reserved.
@@ -36,7 +36,7 @@
 #include <sys/types.h>
 #endif
 
-#include <string>
+#include <string.h>
 #include <map>
 
 #include "DICOMConfig.h"
@@ -726,7 +726,7 @@ void DICOMParser::AddDICOMTagCallbackToAllTags(DICOMCallback* cb)
   DICOMParserMap::iterator miter;
   for (miter = Implementation->Map.begin();
        miter != Implementation->Map.end();
-       miter++);
+       miter++)
   {
   dicom_stl::vector<DICOMCallback*>* callbacks = (*miter).second.second;
   callbacks->push_back(cb);
