@@ -3,8 +3,8 @@
   Program:   MetaIO
   Module:    $RCSfile: metaContour.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-09 01:44:28 $
-  Version:   $Revision: 1.15 $
+  Date:      $Date: 2009-11-21 18:59:39 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -44,10 +44,10 @@ ContourControlPnt(int dim)
     m_V[i] = 0;
     } 
   //Color is red by default
-  m_Color[0]=1.0;
-  m_Color[1]=0.0;
-  m_Color[2]=0.0;
-  m_Color[3]=1.0;
+  m_Color[0]=1.0f;
+  m_Color[1]=0.0f;
+  m_Color[2]=0.0f;
+  m_Color[3]=1.0f;
   }
 
 ContourControlPnt::
@@ -337,7 +337,7 @@ M_SetupWriteFields(void)
     m_Fields.push_back(mF);
     }
 
-  m_NControlPoints = m_ControlPointsList.size();
+  m_NControlPoints = static_cast<int>(m_ControlPointsList.size());
   mF = new MET_FieldRecordType;
   MET_InitWriteField(mF, "NControlPoints", MET_INT,m_NControlPoints);
   m_Fields.push_back(mF);
@@ -833,7 +833,7 @@ M_Write(void)
     m_Fields.push_back(mF);
     }
 
-  m_NInterpolatedPoints = m_InterpolatedPointsList.size();
+  m_NInterpolatedPoints = static_cast<int>(m_InterpolatedPointsList.size());
   if(m_NInterpolatedPoints>0)
     {
     mF = new MET_FieldRecordType;
@@ -841,7 +841,7 @@ M_Write(void)
                            strlen(m_InterpolatedPointDim),m_InterpolatedPointDim);
     m_Fields.push_back(mF);
 
-    m_NInterpolatedPoints = m_InterpolatedPointsList.size();
+    m_NInterpolatedPoints = static_cast<int>(m_InterpolatedPointsList.size());
     mF = new MET_FieldRecordType;
     MET_InitWriteField(mF, "NInterpolatedPoints", MET_INT,m_NInterpolatedPoints);
     m_Fields.push_back(mF);
