@@ -3,8 +3,8 @@
   Program:   MetaIO
   Module:    $RCSfile: metaDTITube.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-09 01:44:29 $
-  Version:   $Revision: 1.18 $
+  Date:      $Date: 2008-04-24 19:13:40 $
+  Version:   $Revision: 1.19 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -692,7 +692,7 @@ M_Write(void)
     unsigned int pntDim = m_NDims+6; 
     const DTITubePnt::FieldListType & extraList =
                                     (*(m_PointList.begin()))->GetExtraFields();
-    pntDim += extraList.size();
+    pntDim += static_cast<unsigned int>(extraList.size());
 
     char* data = new char[pntDim*m_NPoints*elementSize];
     int i=0;
