@@ -3,8 +3,8 @@
   Program:   MetaIO
   Module:    $RCSfile: metaImageUtils.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-09 01:44:28 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date: 2009-06-21 21:54:05 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -16,6 +16,12 @@
 =========================================================================*/
 #include <stdio.h>
 
+#ifdef _MSC_VER
+#pragma warning(disable:4702)
+#pragma warning(disable:4996)
+#endif
+
+
 #include "metaImageTypes.h"
 #include <string.h>
 
