@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: metaOutput.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-03-19 20:42:12 $
-  Version:   $Revision: 1.20 $
+  Date:      $Date: 2009-06-21 21:54:04 $
+  Version:   $Revision: 1.22 $
 
   Copyright (c) 2002 Insight Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -16,6 +16,7 @@
 =========================================================================*/
 #ifdef _MSC_VER
 #pragma warning(disable:4702)
+#pragma warning(disable:4996)
 #endif
 
 #include "metaOutput.h"
@@ -33,6 +34,7 @@
 #endif
 
 #include <string.h>
+#include <time.h>
 
 #include <typeinfo>
 
@@ -40,6 +42,18 @@
 namespace METAIO_NAMESPACE {
 #endif
 
+
+/** Stolen from kwsys */
+METAIO_STL::string GetCurrentDateTime(const char* format)
+{
+  char buf[1024];
+  time_t t;
+  time(&t);
+  strftime(buf, sizeof(buf), format, localtime(&t));
+  return METAIO_STL::string(buf);
+}
+
+
 /****/
 MetaOutputStream::
 MetaOutputStream()
@@ -394,9 +408,9 @@ METAIO_STL::string MetaOutput::GenerateXML(const char* filename)
   buffer += " version=\""+m_CurrentVersion+"\">\n";
 
   buffer += "<Creation date=\"" 
-             + METAIO_KWSYS::SystemTools::GetCurrentDateTime("%Y%m%d") + "\"";
+             + GetCurrentDateTime("%Y%m%d") + "\"";
   buffer += " time=\"" 
-             + METAIO_KWSYS::SystemTools::GetCurrentDateTime("%H%M%S") + "\"";
+             + GetCurrentDateTime("%H%M%S") + "\"";
   buffer += " hostname=\""+this->GetHostname() +"\"";
   buffer += " hostIP=\""+this->GetHostip() +"\"";
   buffer += " user=\"" + this->GetUsername() + "\"/>\n";
@@ -498,7 +512,8 @@ METAIO_STL::string MetaOutput::GenerateXML(const char* filename)
   buffer += "</Outputs>\n";
   
   // CRC32
-  unsigned long crc = crc32(0L,(const Bytef*)buffer.c_str(),buffer.size());
+  unsigned long crc = crc32(0L,(const Bytef*)buffer.c_str(),
+    static_cast<int>(buffer.size()));
   char * crcstring = new char[10];
   sprintf(crcstring,"%lu",crc);
   // Compute the crc
