@@ -3,8 +3,8 @@
 Program:   MetaIO
 Module:    $RCSfile: metaScene.cxx,v $
 Language:  C++
-Date:      $Date: 2008-04-09 01:44:28 $
-Version:   $Revision: 1.41 $
+Date:      $Date: 2008-04-24 19:13:40 $
+Version:   $Revision: 1.42 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -387,7 +387,7 @@ Write(const char *_headName)
 
   // Set the number of objects based on the net list
   //ObjectListType::const_iterator itNet = m_ObjectList.begin();
-  m_NObjects = m_ObjectList.size();
+  m_NObjects = static_cast<int>(m_ObjectList.size());
 
   M_SetupWriteFields();
 
