@@ -3,8 +3,8 @@
   Program:   MetaIO
   Module:    $RCSfile: metaUtils.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-07-08 15:54:08 $
-  Version:   $Revision: 1.58 $
+  Date:      $Date: 2010-03-10 21:54:04 $
+  Version:   $Revision: 1.62 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -123,7 +123,7 @@ bool MET_SystemByteOrderMSB(void)
 //
 METAIO_STL::string MET_ReadForm(METAIO_STREAM::istream &_fp)
   {
-  unsigned int pos = _fp.tellg();
+  METAIO_STL::streampos pos = _fp.tellg();
   METAIO_STL::vector<MET_FieldRecordType *> fields;
   MET_FieldRecordType* mF = new MET_FieldRecordType;
   MET_InitReadField(mF, "Form", MET_STRING, false);
@@ -153,7 +153,7 @@ METAIO_STL::string MET_ReadForm(METAIO_STREAM::istream &_fp)
 //
 METAIO_STL::string MET_ReadType(METAIO_STREAM::istream &_fp)
   {
-  unsigned int pos = _fp.tellg();
+  METAIO_STL::streampos pos = _fp.tellg();
   METAIO_STL::vector<MET_FieldRecordType *> fields;
   MET_FieldRecordType* mF = new MET_FieldRecordType;
   MET_InitReadField(mF, "ObjectType", MET_STRING, false);
@@ -183,7 +183,7 @@ METAIO_STL::string MET_ReadType(METAIO_STREAM::istream &_fp)
 //
 char* MET_ReadSubType(METAIO_STREAM::istream &_fp)
   {
-  unsigned int pos = _fp.tellg();
+  METAIO_STL::streampos pos = _fp.tellg();
   METAIO_STL::vector<MET_FieldRecordType *> fields;
   MET_FieldRecordType* mF;
   mF = new MET_FieldRecordType;
@@ -251,7 +251,7 @@ bool MET_TypeToString(MET_ValueEnumType _vType, char *_s)
 // Value to Double
 //
 bool MET_ValueToDouble(MET_ValueEnumType _type, const void *_data, 
-                       METAIO_STL::streamsize _index,
+                       METAIO_STL::streamoff _index,
                        double *_value)
   {
   switch(_type)
@@ -324,7 +324,7 @@ bool MET_ValueToDouble(MET_ValueEnumType _type, const void *_data,
 bool MET_DoubleToValue(double _value,
                        MET_ValueEnumType _type,
                        void *_data,
-                       METAIO_STL::streamsize _index)
+                       METAIO_STL::streamoff _index)
   {
   switch(_type)
     {
@@ -387,7 +387,7 @@ bool MET_DoubleToValue(double _value,
   }
 
 bool MET_ValueToValue(MET_ValueEnumType _fromType, const void *_fromData,
-                      METAIO_STL::streamsize _index,
+                      METAIO_STL::streamoff _index,
                       MET_ValueEnumType _toType, void *_toData,
                       double _fromMin, double _fromMax,
                       double _toMin, double _toMax)
@@ -468,29 +468,29 @@ bool MET_ValueToValue(MET_ValueEnumType _fromType, const void *_fromData,
 
 // Uncompress a stream given an uncompressedSeekPosition
 METAIO_EXPORT
-long MET_UncompressStream(METAIO_STREAM::ifstream * stream,
-                          METAIO_STL::streamsize uncompressedSeekPosition,
+METAIO_STL::streamoff MET_UncompressStream(METAIO_STREAM::ifstream * stream,
+                          METAIO_STL::streamoff uncompressedSeekPosition,
                           unsigned char * uncompressedData,
-                          METAIO_STL::streamsize uncompressedDataSize,
-                          METAIO_STL::streamsize compressedDataSize,
+                          METAIO_STL::streamoff uncompressedDataSize,
+                          METAIO_STL::streamoff compressedDataSize,
                           MET_CompressionTableType * compressionTable
                           )
 {
   // Keep the currentpos of the string
-  METAIO_STL::streamsize currentPos = stream->tellg();
-  if(currentPos == -1)
+  METAIO_STL::streampos currentPos = stream->tellg();
+  if(currentPos == METAIO_STL::streampos(-1))
     {
     METAIO_STREAM::cout << "MET_UncompressStream: ERROR Stream is not valid!" << METAIO_STREAM::endl;
     return -1;
     }
 
-  long read = 0;
+  METAIO_STL::streamoff read = 0;
 
   //METAIO_STREAM::cout << "Wanted Seek = " << uncompressedSeekPosition << METAIO_STREAM::endl;
   //METAIO_STREAM::cout << "Wanted size = " << uncompressedDataSize << METAIO_STREAM::endl;
 
   // Size of the output buffer
-  unsigned long buffersize = 1000;
+  METAIO_STL::streamoff buffersize = 1000;
 
   // We try to guess the compression rate
   // Note that sometime the size of the input buffer
@@ -498,8 +498,8 @@ long MET_UncompressStream(METAIO_STREAM::ifstream * stream,
   // We assume that they are equal
   double compressionRate = 1;
 
-  long zseekpos = 0;
-  long seekpos = 0;
+  METAIO_STL::streamoff zseekpos = 0;
+  METAIO_STL::streamoff seekpos = 0;
   bool firstchunk = true;
 
   // Allocate the stream if necessary
@@ -535,14 +535,14 @@ long MET_UncompressStream(METAIO_STREAM::ifstream * stream,
         }
 
       char* buffer = compressionTable->buffer;
-      unsigned long start = uncompressedSeekPosition-((*it).uncompressedOffset-compressionTable->bufferSize);
+      METAIO_STL::streamoff start = uncompressedSeekPosition-((*it).uncompressedOffset-compressionTable->bufferSize);
       buffer += start;
 
-      unsigned long readSize = uncompressedDataSize;
-      unsigned long sizeInBuffer = compressionTable->bufferSize-start;
+      METAIO_STL::streamoff readSize = uncompressedDataSize;
+      METAIO_STL::streamoff sizeInBuffer = compressionTable->bufferSize-start;
       if(readSize>sizeInBuffer)
         {
-        memcpy(uncompressedData,buffer,sizeInBuffer);
+        memcpy(uncompressedData,buffer,(size_t)sizeInBuffer);
         uncompressedData += sizeInBuffer;
         zseekpos = (*it).compressedOffset;
         seekpos = (*it).uncompressedOffset;
@@ -551,7 +551,7 @@ long MET_UncompressStream(METAIO_STREAM::ifstream * stream,
         }
       else // read from buffer and return
         {
-        memcpy(uncompressedData,buffer,readSize);
+        memcpy(uncompressedData,buffer,(size_t)readSize);
         return uncompressedDataSize;
         }
       }
@@ -564,10 +564,10 @@ long MET_UncompressStream(METAIO_STREAM::ifstream * stream,
 
   //METAIO_STREAM::cout << "Using = " << seekpos << " : " << zseekpos << METAIO_STREAM::endl;
 
-  while(seekpos < (long)uncompressedSeekPosition+uncompressedDataSize)
+  while(seekpos < uncompressedSeekPosition+uncompressedDataSize)
     {
     // If we are reading the current buffer we read everything
-    if(seekpos >= (long)uncompressedSeekPosition)
+    if(seekpos >= uncompressedSeekPosition)
       {
       buffersize = uncompressedSeekPosition+uncompressedDataSize-seekpos;
       firstchunk = false;
@@ -575,22 +575,23 @@ long MET_UncompressStream(METAIO_STREAM::ifstream * stream,
 
     unsigned char* outdata = new unsigned char[buffersize];
 
-    d_stream->avail_out = buffersize;
+    d_stream->avail_out = (uInt)( buffersize );
 
     // How many byte from compressed streamed should we read
-    unsigned long inputBufferSize = (unsigned long)(buffersize/compressionRate);
+    METAIO_STL::streamoff inputBufferSize = (METAIO_STL::streamoff)(buffersize/compressionRate);
+
     if(inputBufferSize == 0)
       {
       inputBufferSize = 1;
       }
-    if((long)(currentPos+zseekpos+inputBufferSize) > compressedDataSize)
+    if((currentPos+zseekpos+inputBufferSize) > compressedDataSize)
       {
       inputBufferSize = compressedDataSize-zseekpos;
       }
 
     unsigned char* inputBuffer = new unsigned char[inputBufferSize];
     stream->seekg(currentPos+zseekpos,METAIO_STREAM::ios::beg);
-    stream->read((char *)inputBuffer, inputBufferSize);
+    stream->read((char *)inputBuffer, (size_t)inputBufferSize);
 
     d_stream->next_in  = inputBuffer;
     d_stream->avail_in = stream->gcount();
@@ -598,39 +599,39 @@ long MET_UncompressStream(METAIO_STREAM::ifstream * stream,
 
     inflate(d_stream, Z_NO_FLUSH);
 
-    unsigned long previousSeekpos = seekpos;
+    METAIO_STL::streampos previousSeekpos = seekpos;
 
     seekpos += buffersize-d_stream->avail_out;
     zseekpos += stream->gcount()-d_stream->avail_in;
 
     // Store the last buffer into memory in case we need it
     // in the near future.
-    long previousBufferSize = seekpos-previousSeekpos;
+    METAIO_STL::streamoff previousBufferSize = seekpos-previousSeekpos;
     if(previousBufferSize>1000)
       {
       // WARNING: We probably need to offset outdata at some point...
       previousBufferSize = 1000;
       }
 
-    memcpy(compressionTable->buffer,outdata,previousBufferSize);
+    memcpy(compressionTable->buffer,outdata,(size_t)previousBufferSize);
     compressionTable->bufferSize = previousBufferSize;
 
     //METAIO_STREAM::cout << "Current pos = " << seekpos << " : " << zseekpos << METAIO_STREAM::endl;
 
     // If go further than the uncompressedSeekPosition we start writing the stream
-    if(seekpos >= (long)uncompressedSeekPosition)
+    if(seekpos >= uncompressedSeekPosition)
       {
       if(firstchunk)
         {
         outdata += uncompressedSeekPosition-previousSeekpos;
-        METAIO_STL::streamsize writeSize = seekpos-uncompressedSeekPosition;
+        METAIO_STL::streamoff writeSize = seekpos-uncompressedSeekPosition;
 
         if(writeSize > uncompressedDataSize)
           {
           writeSize = uncompressedDataSize;
           }
 
-        memcpy(uncompressedData,outdata,writeSize);
+        memcpy(uncompressedData,outdata,(size_t)writeSize);
 
         // Restore the position of the buffer
         outdata -= uncompressedSeekPosition-previousSeekpos;
@@ -642,8 +643,8 @@ long MET_UncompressStream(METAIO_STREAM::ifstream * stream,
         }
       else // read everything
         {
-        METAIO_STL::streamsize writeSize = seekpos-previousSeekpos;
-        memcpy(uncompressedData,outdata,writeSize);
+        METAIO_STL::streamoff writeSize = seekpos-previousSeekpos;
+        memcpy(uncompressedData,outdata,(size_t)writeSize);
         if(writeSize > uncompressedDataSize)
           {
           writeSize = uncompressedDataSize;
@@ -672,8 +673,8 @@ long MET_UncompressStream(METAIO_STREAM::ifstream * stream,
 //
 //
 unsigned char * MET_PerformCompression(const unsigned char * source,
-                                       METAIO_STL::streamsize sourceSize,
-                                       unsigned int * compressedDataSize)
+                                       METAIO_STL::streamoff sourceSize,
+                                       METAIO_STL::streamoff * compressedDataSize)
   {
   unsigned char * compressedData;
 
@@ -686,7 +687,7 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
   // Choices are Z_BEST_SPEED,Z_BEST_COMPRESSION,Z_DEFAULT_COMPRESSION
   int compression_rate = Z_DEFAULT_COMPRESSION;
 
-  METAIO_STL::streamsize             buffer_size     = sourceSize;
+  METAIO_STL::streamoff             buffer_size     = sourceSize;
   unsigned char * input_buffer    = const_cast<unsigned char *>(source);
   unsigned char * output_buffer   = new unsigned char[buffer_size];
 
@@ -694,13 +695,13 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
 
   deflateInit(&z, compression_rate);
 
-  z.avail_in   = buffer_size;
+  z.avail_in   = (uInt)buffer_size;
   z.next_in    = input_buffer;
   z.next_out   = output_buffer;
-  z.avail_out  = buffer_size;
+  z.avail_out  = (uInt)buffer_size;
 
-  METAIO_STL::streamsize count;
-  METAIO_STL::streamsize j=0;
+  METAIO_STL::streamoff count;
+  METAIO_STL::streamoff j=0;
   // Perform the compression
   for ( ; ; )
     {
@@ -715,12 +716,12 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
         if(j+count>=buffer_size) 
           {
           unsigned char* compressedDataTemp = new unsigned char[j+count+1];
-          memcpy(compressedDataTemp,compressedData,buffer_size);
+          memcpy(compressedDataTemp,compressedData,(size_t)buffer_size);
           delete [] compressedData;
           compressedData = compressedDataTemp;
           }
         
-        memcpy((char*)compressedData+j, (char *)output_buffer, count);
+        memcpy((char*)compressedData+j, (char *)output_buffer, (size_t)count);
         }
       break;
       }
@@ -732,16 +733,16 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
       if(j+count>=buffer_size) 
         {
         unsigned char* compressedDataTemp = new unsigned char[j+count+1];
-        memcpy(compressedDataTemp,compressedData,buffer_size);
+        memcpy(compressedDataTemp,compressedData,(size_t)buffer_size);
         delete [] compressedData;
         compressedData = compressedDataTemp;
         }
-      memcpy((char*)compressedData+j, (char*)output_buffer, count);
+      memcpy((char*)compressedData+j, (char*)output_buffer, (size_t)count);
       }
 
     j += count;
     z.next_out = output_buffer;
-    z.avail_out = buffer_size;
+    z.avail_out = (uInt)buffer_size;
     }
 
   delete [] output_buffer;
@@ -758,9 +759,9 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
 //
 //
 bool MET_PerformUncompression(const unsigned char * sourceCompressed,
-                              METAIO_STL::streamsize sourceCompressedSize,
+                              METAIO_STL::streamoff sourceCompressedSize,
                               unsigned char * uncompressedData,
-                              METAIO_STL::streamsize uncompressedDataSize)
+                              METAIO_STL::streamoff uncompressedDataSize)
   {
   z_stream d_stream;
 
@@ -770,12 +771,12 @@ bool MET_PerformUncompression(const unsigned char * sourceCompressed,
 
   inflateInit(&d_stream);
   d_stream.next_in  = const_cast<unsigned char *>(sourceCompressed);
-  d_stream.avail_in = sourceCompressedSize;
+  d_stream.avail_in = (uInt)sourceCompressedSize;
   
   for (;;)
     {
     d_stream.next_out = (unsigned char *)uncompressedData;
-    d_stream.avail_out = uncompressedDataSize;
+    d_stream.avail_out = (uInt)uncompressedDataSize;
     int err = inflate(&d_stream, Z_NO_FLUSH);
         
     if((err == Z_STREAM_END)
@@ -801,16 +802,16 @@ bool MET_PerformUncompression(const unsigned char * sourceCompressed,
 //
 bool MET_StringToWordArray(const char *s, int *n, char ***val)
 {
-  long l = static_cast<long>( strlen(s) );
+  ptrdiff_t l = strlen(s);
 
-  int p = 0;
+  ptrdiff_t p = 0;
   while(p<l && s[p] == ' ')
     {
     p++;
     }
 
   *n = 0;
-  int pp = p;
+  ptrdiff_t pp = p;
   bool space = false;
   while(pp<l)
     {
@@ -841,7 +842,7 @@ bool MET_StringToWordArray(const char *s, int *n, char ***val)
 
   *val = new char *[*n];
 
-  long i, j;
+  ptrdiff_t i, j;
   for(i=0; i<*n; i++)
     {
     if(p == l)
@@ -872,9 +873,9 @@ bool MET_GetFilePath(const char *_fName, char *_fPath)
   {
   long i;
 
-  long l = static_cast<long>( strlen(_fName) );
+  size_t l = strlen(_fName);
 
-  for(i=l-1; i>=0; i--)
+  for(i=(long)l-1; i>=0; i--)
     if(_fName[i] == '\\' || _fName[i] == '/')
       break;
 
@@ -1037,7 +1038,8 @@ bool MET_Read(METAIO_STREAM::istream &fp,
   {
 
   char s[1024];
-  int i, j;
+  int i;
+  size_t j;
 
   METAIO_STL::vector<MET_FieldRecordType *>::iterator fieldIter;
 
@@ -1136,7 +1138,7 @@ bool MET_Read(METAIO_STREAM::istream &fp,
               }
             MET_CHAR_TYPE * str = (MET_CHAR_TYPE *)((*fieldIter)->value);
             fp.getline( str, 500 );
-            j = static_cast<long>( strlen(str) ) - 1;
+            j = strlen(str) - 1;
             while(!isprint(str[j]) || isspace(str[j]))
               {
               str[j--] = '\0';
@@ -1166,7 +1168,7 @@ bool MET_Read(METAIO_STREAM::istream &fp,
               {
               (*fieldIter)->length =
                     (int)((*fields)[(*fieldIter)->dependsOn]->value[0]);
-              for(j=0; j<(*fieldIter)->length; j++)
+              for(j=0; j<(size_t)(*fieldIter)->length; j++)
                 {
                 fp >> (*fieldIter)->value[j];
                 }
@@ -1180,7 +1182,7 @@ bool MET_Read(METAIO_STREAM::istream &fp,
                   << METAIO_STREAM::endl;
                 return false;
                 }
-              for(j=0; j<(*fieldIter)->length; j++)
+              for(j=0; j<(size_t)(*fieldIter)->length; j++)
                 {
                 fp >> (*fieldIter)->value[j];
                 }
@@ -1199,7 +1201,7 @@ bool MET_Read(METAIO_STREAM::istream &fp,
               {
               (*fieldIter)->length =
                     (int)((*fields)[(*fieldIter)->dependsOn]->value[0]);
-              for(j=0; j<(*fieldIter)->length*(*fieldIter)->length;
+              for(j=0; j<(size_t)(*fieldIter)->length*(*fieldIter)->length;
                   j++)
                 {
                 fp >> (*fieldIter)->value[j];
@@ -1214,7 +1216,7 @@ bool MET_Read(METAIO_STREAM::istream &fp,
                   << METAIO_STREAM::endl;
                 return false;
                 }
-              for(j=0; j<(*fieldIter)->length*(*fieldIter)->length; j++)
+              for(j=0; j<(size_t)(*fieldIter)->length*(*fieldIter)->length; j++)
                 {
                 fp >> (*fieldIter)->value[j];
                 }
