@@ -3,8 +3,8 @@
   Program:   MetaIO
   Module:    $RCSfile: metaVesselTube.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-04-09 01:44:27 $
-  Version:   $Revision: 1.17 $
+  Date:      $Date: 2009-11-21 18:59:39 $
+  Version:   $Revision: 1.18 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -55,10 +55,10 @@ VesselTubePnt(int dim)
   m_Mark=false;
   
   //Color is red by default
-  m_Color[0]=1.0;
-  m_Color[1]=0.0;
-  m_Color[2]=0.0;
-  m_Color[3]=1.0;
+  m_Color[0]=1.0f;
+  m_Color[1]=0.0f;
+  m_Color[2]=0.0f;
+  m_Color[3]=1.0f;
   m_ID = -1;
 }
 
