@@ -3,8 +3,8 @@
   Program:   gdcm
   Module:    $RCSfile: gdcmDicomDir.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-02-20 15:56:57 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date: 2009-11-21 20:00:35 $
+  Version:   $Revision: 1.14 $
   
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
@@ -144,8 +144,7 @@ DicomDir::DicomDir()
  * @deprecated use : new DicomDir() + [ SetLoadMode(lm) + ] SetDirectoryName(name)
  *              or : new DicomDir() + SetFileName(name)
  */
-DicomDir::DicomDir(std::string const &fileName, bool parseDir ):
-   Document( )
+DicomDir::DicomDir(std::string const &fileName, bool parseDir )
 {
    // At this step, Document constructor is already executed,
    // whatever user passed (either a root directory or a DICOMDIR)
@@ -740,7 +739,7 @@ void DicomDir::Initialize()
    ProgressArg             = NULL;
    EndArg                  = NULL;
 
-   Progress = 0.0;
+   Progress = 0.0f;
    Abort = false;
 
    MetaElems = NULL;   
