@@ -3,8 +3,8 @@
   Program:   gdcm
   Module:    $RCSfile: gdcmUtil.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-05-19 07:14:39 $
-  Version:   $Revision: 1.44 $
+  Date:      $Date: 2009-05-23 11:28:54 $
+  Version:   $Revision: 1.46 $
                                                                                 
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
@@ -23,6 +23,7 @@
 #include <stdarg.h> // for va_list
 
 // For GetCurrentDate, GetCurrentTime
+#include <math.h> // pow
 #include <time.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -92,7 +93,11 @@
    #include <thread.h>
 #endif
 
-#if _WIN32
+#if defined(__CYGWIN__)
+#undef GDCM_SYSTEM_UUID_FOUND
+#endif
+
+#if defined(_WIN32)
 #define HAVE_UUIDCREATE
 #else
 #ifdef GDCM_SYSTEM_UUID_FOUND
@@ -981,11 +986,19 @@ std::string Util::CreateUniqueUID(const std::string &root)
      }
    append += Util::GetCurrentDateTime();
 
-   //Also add a mini random number just in case:
-   char tmp[10];
-   int r = (int) (100.0*rand()/RAND_MAX);
+   // Also add a mini random number since machine are now so fast that within the same
+   // millisecond you could generate the same UID...
+   // Using all remaining bytes should avoid issues most of the time.
+   int diff = 64 - (prefix + append).size() - 1;
+   if( diff <= 0 )
+      {
+      gdcmErrorMacro( "Size of UID is too long." );
+      }
+   const double mult = pow(10., diff);
+   char tmp[64];
+   int r = (int) (mult*rand()/(RAND_MAX+1.0)); // output will be in [0, mult - 1]
    // Don't use Util::Format to accelerate the execution
-   sprintf(tmp,"%02d", r);
+   sprintf(tmp,".%d", r);
    append += tmp;
 
    // If append is too long we need to rehash it
