@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: wrap_ITKRigidTransforms.cxx,v $
   Language:  C++
-  Date:      $Date: 2005/03/25 13:17:57 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2007-11-02 15:59:47 $
+  Version:   $Revision: 1.2 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -20,7 +20,6 @@
 #include "itkRigid2DTransform.h"
 #include "itkRigid3DPerspectiveTransform.h"
 #include "itkRigid3DTransform.h"
-#include "itkVersorRigid3DTransform.h"
 
 #ifdef CABLE_CONFIGURATION
 #include "itkCSwigMacros.h"
@@ -39,7 +38,6 @@ namespace _cable_
     ITK_WRAP_TRANSFORM_1(Rigid2DTransform);
     ITK_WRAP_TRANSFORM_1(Rigid3DPerspectiveTransform);
     ITK_WRAP_TRANSFORM_1(Rigid3DTransform);
-    ITK_WRAP_TRANSFORM_1(VersorRigid3DTransform);
   }
 }
 #endif
